(function (context) {
    'use strict';

    // starting global context
    context.pling = {};

}(window));

(function () {
    'use strict';

    // Injeção de Dependência
    angular.module('plingUi', [
        'luegg.directives',
        'plingUi.templates',
        'ngMaterial',
        'ngAnimate',
        'ngAria',
        'datetime',
        'angular.filter',
        'md.data.table',
        'angular-web-notification'
    ]);

    angular.module('plingUi').config(PlingUiConfig);
    PlingUiConfig.$inject = [ '$provide', '$httpProvider', '$mdThemingProvider' ];

    angular.module('plingUi').run(PlingUiRun);
    PlingUiRun.$inject = [ 'boot.options', '$injector', 'plingThemingService' ];

    // init pling-ui
    (function() {

        /*
            Unfortunately when you use window.history.replaceState with angular-route you have big problems
            (angular-issue:6172)
            The reason for this is that Angular can't change anything before the hash without the browser reloading the page
        */
        var // eslint-disable-line
            clean_uri = location.protocol + "//" + location.host + location.pathname, // eslint-disable-line
            hash_pos  = location.href.indexOf("#"), // eslint-disable-line
            hash,
            queryString = '',
            token = new RegExp(/[\?|\&]{1}token=[a-zA-Z0-9._-]*/);

        if (hash_pos > 0) {
            hash = location.href.substring(hash_pos, location.href.length); // eslint-disable-line
            clean_uri += hash;
        }

        if (window && window.location && window.location.search) {
            localStorage.setItem('PLING-QUERY-STRING', window.location.search); // eslint-disable-line
            queryString = window.location.search;

            // Checking if it comes from other applications with querystring token
            if (token.test(queryString)) {
                // Will set token to localStorage
                localStorage.setItem('PLING-TOKEN', token.exec(queryString)[0].replace('?token=', '').replace('&token=', '')); // eslint-disable-line
            }

            queryString = queryString.replace(token, '');
            if (queryString.indexOf('&') === 0)
                queryString = queryString.replace('&', '?');

            if (queryString && queryString.indexOf('?') !== 0)
                queryString = '?' + queryString;

            clean_uri += queryString;
        }

        // WebCam Init
        // GetUserMedia is not yet supported by all browsers
        // Until then, we need to handle the vendor prefixes
        window.navigator.getMedia =
            window.navigator.getUserMedia ||
            window.navigator.webkitGetUserMedia ||
            window.navigator.mozGetUserMedia ||
            window.navigator.msGetUserMedia;

        // Checks if getUserMedia is available on the client browser
        window.hasUserMedia = function hasUserMedia() {
            return window.navigator.getMedia ? true : false;
        };

        // Clear URL
        window.history.replaceState({}, document.title, clean_uri);
    }());

    // Config method
    function PlingUiConfig($provide, $httpProvider, $mdThemingProvider) {

        $mdThemingProvider.theme('default')
            .primaryPalette('green', {
                'default': '600',
                'hue-1': '100',
                'hue-2': '400',
                'hue-3': 'A200'
            })
            .accentPalette('green', {
                'default': '600',
                'hue-1': '100',
                'hue-2': '400',
                'hue-3': 'A200'
            });

        $provide.decorator('$$rAF', [ '$delegate', function rAFDecorator($delegate) {
            $delegate.throttle = function(cb) {
                var queueArgs, alreadyQueued, queueCb, context;

                return function debounced() {
                    queueArgs = arguments;
                    context = this;
                    queueCb = cb;
                    if (!alreadyQueued) {
                        alreadyQueued = true;
                        $delegate(function() {
                            queueCb.apply(context, queueArgs);
                            alreadyQueued = false;
                        });
                    }
                };
            };
            return $delegate;
        }]);

        $provide.decorator('$log', function ($delegate, shadowLogger) {
            return shadowLogger($delegate);
        });

        // Interceptor that add token in each Header Request
        $httpProvider.interceptors.push('plingRequestInterceptor');
    }

    // Run method
    function PlingUiRun(options, $injector, plingThemingService) {
        var cache = null;

        plingThemingService.onCreate('theming-default', {
            'primary'      : '#43A047',
            'hue-1'        : '#C8E6C9',
            'hue-2'        : '#66BB6A',
            'hue-3'        : '#69F0AE',
            'primaryColor' : '#FFFFFF'
        });

        if (options.onRun && options.onRun.cacheViews) {
            cache = $injector.get('cacheService');
            cache.cacheViews();
        }
    }
}());

(function() {
    'use strict';

    angular
        .module('plingUi')
        .filter('filterDynamic', filerDynamicController);

    filerDynamicController.$inject = [ '$filter' ];

    function filerDynamicController ($filter) {

        var output = [], querys = {}, date;

        function filter(items, value, pkey) {
            if (value && value.fromDate) {
                return items.filter(function (i) {
                    date = moment(i[pkey], 'DD/MM/YYYY').isValid() ? moment(i[pkey], 'DD/MM/YYYY').format('YYYY-MM-DD') : moment(i[pkey]).format('YYYY-MM-DD');
                    return i[pkey] && (value.fromDate <= date &&  value.toDate >= date);
                });
            } else {
                return $filter('filter')(items, typeof value === 'object' ? '' : value);
            }
        }

        return function(items, option) {
            querys = {};
            output.length = 0;

            if (!items || !option || items.length <= 0) {
                return items;
            }

            if (typeof option === 'object') {
                Object.keys(option).forEach(function (pkey) {
                    querys[pkey] = angular.copy(option[pkey]);
                });
            } else {
                querys['default'] = option;
            }

            Object.keys(querys).forEach(function (pkey) {
                output = filter(output.length > 0 ? output : items, querys[pkey], pkey);
            });

            return output || items;
        };
    }

})();

(function () {
    'use strict';
    angular
        .module('plingUi')
        .filter('plgToTrustedHtml', plgToTrustedHtml);

    plgToTrustedHtml.$inject = ['$sce'];

    function plgToTrustedHtml($sce) {
        return function(text) {
            return $sce.trustAsHtml(text);
        };
    }

}());
(function () {
    'use strict';
    angular
        .module('plingUi')
        .filter('plgUrlify', plgUrlify);

    function plgUrlify() {
        return function(text, openInSamePage) {
            var
                urlRegex =/((https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/ig,
                target = '_blank';

            if (openInSamePage === true)
                target = '_self';

            return text.replace(urlRegex, function(url) {
                return '<a target="' + target + '" href="' + url + '">' + url + '</a>';
            });
        };
    }
}());
(function () {
    'use strict';

    angular
        .module('plingUi')
        .factory('plgCalendarFactory', plgCalendarFactory);

    function plgCalendarFactory() {
        var i, j, output = [];

        return {
            'getDaysInMonths': function (daysInMonths, monthsLimit, currentMoment, events) {
                var month, days, firstDay, arr = [], position, objDay;

                daysInMonths = daysInMonths || [];

                if (monthsLimit > 0)
                    daysInMonths.length = 0;

                for (i = 0; i <= monthsLimit - 1; i++) {
                    month      = moment(currentMoment).add(i, 'months');
                    days       = month.daysInMonth();
                    firstDay   = moment(month).date(1).day();
                    arr.length = 0;

                    for (position = 1; position <= firstDay + days; position += 1) {

                        objDay = position > firstDay ? position - firstDay : false;

                        /*
                        if (wantFullDay && day !== false) {
                            day = moment(currentMoment).add(i, 'month').date(day).format('YYYY-MM-DD');
                        }*/

                        objDay = { 'day': objDay };

                        if (events && events.length > 0 && objDay.day) {
                            objDay.events = this.filterEventsInDay(events, month.date(objDay.day));
                        }

                        arr.push(objDay);
                    }
                    daysInMonths.push(angular.copy(arr));
                }
                return daysInMonths;
            },
            'filterEventsInDay': function (events, day) {
                output.length = 0;
                for (j = events.length - 1; j >= 0; j--) {
                    if (moment(typeof events[j] === 'object' ? events[j].date : events[j]).utc().format('YYYY-MM-DD') === moment(day).utc().format('YYYY-MM-DD')) {
                        output.push(events[j]);
                    }
                }
                return angular.copy(output);
            }
        };
    }
}());

(function() {
    'use strict';

    angular
        .module('plingUi')
        .factory('chatFactory', ChatFactory);

    ChatFactory.$inject = [ 'credentialsService' ];

    function ChatFactory(credentialsService) {
        return {

            'buildTooltipUsersList' : function(room, currentUser) {
                var usersList = [];

                if (room && room.people && room.people.length > 1) {
                    usersList = room.people.map(function(item) {
                        if (item._id !== currentUser.id)
                            return item.name;
                    });
                    if (currentUser.id !== room.owner._id)
                        usersList.push(currentUser.nickname);
                    return usersList.sort().join(', ');
                }
            },
            // Constroi uma sala de conversa / room
            'buildRoom': function(credentialsObj, roomName, cb) {
                var
                    currentUser = credentialsService.getLocal(),
                    roomObj     = {};

                // Garante que o argumento seja um array
                if (!Array.isArray(credentialsObj))
                    credentialsObj = [ credentialsObj ];

                // Owner do Chat
                roomObj.owner = {
                    '_id'  : currentUser.id,
                    'name' : currentUser.nickname || currentUser.fullname
                };

                // Setando imagem se disponível
                if (currentUser.imageDriveId)
                    roomObj.owner.imageDriveId = currentUser.imageDriveId;

                // Definindo nome do Chat
                if (roomName) roomObj.name = roomName;

                // Inicializando objeto de participantes do Chat
                roomObj.people = [];

                // Definindo participantes do Chat
                credentialsObj.forEach(function(credential, index) {
                    var peopleObj;

                    // Criando objeto
                    if (credential._id && (credential.nickname || credential.fullname))
                        peopleObj = {
                            '_id': credential._id,
                            'name': credential.nickname || credential.fullname
                        };

                    // Imagem de usuario
                    if (credential.imageDriveId)
                        peopleObj.imageDriveId = credential.imageDriveId;

                    // Validando se é objeto e se nào é null
                    if (peopleObj !== null && typeof peopleObj === 'object')
                        roomObj.people.push(peopleObj);

                    // Verificação de Índice
                    if (credentialsObj.length === index + 1)
                        return cb(roomObj);
                });
            }
        };
    }

}());
(function() {
    'use strict';

    angular
        .module('plingUi')
        .factory('plgLoginFactory', plgLoginFactory);

    plgLoginFactory.$inject = ['credentialsService', 'tokenService'];

    function plgLoginFactory(credentialsService, tokenService) {
        var countLogin = 3, cb;

        return {
            'showModal'  : showModal,
            'removeToken': removeToken
        };

        function validateFields(user, password, $scope) {
            if (!user) return $scope.$emit('TOAST-ACTION', { 'message' : 'Por favor digite seu email.' });
            if (!password || password.length < 3) return $scope.$emit('TOAST-ACTION', { 'message' : 'Senha não informada ou menor que 3 caracteres.' });

            return false;
        }

        function error($scope, user) {
            $scope.isLoading = false;

            countLogin--;
            if (countLogin <= 0)
                credentialsService.logoutWithEmail(user);

            $scope.onLogin(false);
            return $scope.$emit('TOAST-ACTION', { 'message' : 'Usuário ou senha errados (Tentativas restantes: '+ countLogin +')' });
        }

        function login(user, password, close, $scope) {
            if (validateFields(user, password, $scope)) return false;

            $scope.onLogin = $scope.onLogin || angular.noop;

            $scope.isLoading = true;

            credentialsService.login({ 'usr': user, 'pwd': password }, function (err, token) {
                if (err) return error($scope, user);

                if (token) {
                    localStorage.setItem('PLING-TOKEN', token);//eslint-disable-line
                    tokenService.validate(function (err, data) {
                        if (err) return error($scope, user);

                        if (data) {
                            close();
                            $scope.onLogin(true);
                            if (cb) cb($scope);
                            $scope.isOpen = false;
                        } else {
                            if (!$scope.isByEvent)
                                credentialsService.logout();
                            $scope.onLogin(false);
                        }

                        $scope.isLoading = false;
                    });
                } else {
                    if (!$scope.isByEvent)
                        credentialsService.logout();
                    $scope.onLogin(false);
                }
            });
        }

        function removeToken() {
            credentialsService.logout(true);
        }

        function showModal(scope, isByEvent, callback) {
            cb = callback || angular.noop;

            scope.isOpen       = true;
            scope.isByEvent    = isByEvent;
            scope.fakePassword = '';
            scope.pwd          = '';
            scope.$broadcast('LOGIN_PANEL_OPEN', {
                'dom_id'        : 'LOGIN_PANEL_ID',
                'user'          : JSON.parse(localStorage.getItem('PLING-USER') || {}).username, // eslint-disable-line
                'submit'        : login,
                'scope'         : scope
            });

            scope.$watch('fakePassword', function (newValue, oldValue) {
                newValue = newValue || '';
                oldValue = oldValue || '';
                if (oldValue.length > newValue.length) {
                    scope.pwd     = '';
                    scope.fakePassword = '';
                }
                if (newValue && newValue.substr(-1) !== '*') {
                    scope.pwd     = scope.pwd || '';
                    scope.pwd    += newValue.substr(-1);
                    scope.fakePassword = replaceCharToAsterisk(scope.pwd);
                }
            });
        }

        function replaceCharToAsterisk(string) {
            return string.length > 0 ? string.split('').map(function () {
                return '*';
            }).join('') : '';
        }
    }

}());
(function() {
    'use strict';

    angular
        .module('plingUi')
        .factory('plgPanelFactory', plgPanelFactory);

    function plgPanelFactory() {

        return {
            'checkIdError': checkIdError,
            'buildConfig': buildConfig,
            'buildTemplate': buildTemplate,
            'setAligment': setAligment,
            'limitInScreen': limitInScreen
        };

        function checkIdError(dom_id) {
            if (!document.getElementById(dom_id))
                console.warn('Plg-Panel - elemento onde plg-panel deve ser relativo não encontrado.. não existe um elemento com esse id === ' + dom_id); //eslint-disable-line
        }

        function buildConfig(config, configB) {
            if (config)
                Object.keys(configB).map(function (key) {
                    config[key] = typeof config[key] === 'undefined' ? configB[key] : config[key];
                });
        }

        function buildTemplate(content, attrs) {
            attrs.class = 'plg-panel ' + attrs.class;
            return '<md-content class="'+ attrs.class + '" layout="column" ng-click="close()" id="' + (attrs.id || '""') + '" ng-keyup="'+ attrs.onKeyPress +'">' + content +'</md-content>';
        }

        /**
        * @function setAligment
        * @param  {Object} mdPanelNewPanelPosition {$mdPanel.newPanelPosition()}
        * @param  {String} type                    {center, above}
        * @param  {Object} $mdPanel                {}
        * @return {Object} {$mdPanel.newPanelPosition() aligned}
        */
        function setAligment(mdPanelNewPanelPosition, type, $mdPanel) {
            switch (type) {
                case 'none':
                    return mdPanelNewPanelPosition;
                case 'center':
                    return mdPanelNewPanelPosition.centerVertically();
                case 'middle':
                    return mdPanelNewPanelPosition.absolute().center();
                default:
                    return mdPanelNewPanelPosition.addPanelPosition($mdPanel.xPosition.ALIGN_START, $mdPanel.yPosition.ABOVE);
            }
        }

        /**
        * @function limitInScreen
        * @param  {Object} result {$mdPanel.open promise result}
        * @return {void} {}
        */
        function limitInScreen(result) {
            var rect;

            if (result && result.panelEl && result.panelEl[0] && result.panelEl[0].getBoundingClientRect && result.panelEl[0].style) {
                rect = result.panelEl[0].getBoundingClientRect();

                if (rect) {
                    if (rect.left + rect.width > window.innerWidth)
                        result.panelEl[0].style.left = Math.abs(rect.left + rect.width - window.innerWidth - rect.left) + 'px';
                    if (rect.top < 0)
                        result.panelEl[0].style.top = '0px';
                }
            }
        }
    }

}());
(function () {
    'use strict';

    angular
        .module('plingUi')
        .factory('zxcvbnFactory', zxcvbnFactory);

    function zxcvbnFactory() {
        return {
            'score': function() {
                var compute = zxcvbn.apply(null, arguments); //eslint-disable-line

                return compute && compute.score;
            }
        };
    }
}());
angular.module('plingUi').factory('plgScreenImageCropFactory',  function () {
    return {
        'base64ToFile': function(base64, fileName) {

            var contentType,
                byteCharacters,
                sliceSize,
                bytesLength,
                slicesCount,
                byteArrays,
                sliceIndex,
                offset,
                file,
                begin,
                bytes,
                blob,
                end,
                i;

            if (!base64 || !fileName) {
                return null;
            }
            contentType     = base64.split(';')[0].split(':')[1];
            byteCharacters  = window.atob(base64.split(',')[1]);
            sliceSize       = 1024;
            bytesLength     = byteCharacters.length;
            slicesCount     = Math.ceil(bytesLength / sliceSize);
            byteArrays      = new Array(slicesCount);
            sliceIndex      = 0;


            contentType = contentType || null;

            for (sliceIndex; sliceIndex < slicesCount; sliceIndex += 1) {
                begin = sliceIndex * sliceSize;
                end = Math.min(begin + sliceSize, bytesLength);
                bytes = new Array(end - begin);

                for (offset = begin, i = 0; offset < end; i += 1, offset += 1) {
                    bytes[i] = byteCharacters[offset].charCodeAt(0);
                }
                byteArrays[sliceIndex] = new Uint8Array(bytes);
            }

            blob = new File(byteArrays, fileName, { 'type': contentType });

            file = new File([ blob ], fileName + '.' + contentType.split('/')[1], { 'type': contentType });

            return file;

        },

        'isImageFile': function (file, cb) {

            const AvailableImageFormats = [ 'JPG', 'JPEG', 'PNG' ], maxSize = 2000000;
            var isImage = false,
                fileFormat;

            if (!file || file.size > maxSize)
                return cb('A imagem deve ser menor que 2MB');

            fileFormat = file.name.split('.').pop().toUpperCase();

            AvailableImageFormats.forEach(function (value) {
                if (value === fileFormat) {
                    isImage = true;
                }
            });

            if (isImage)
                return cb(null, true);

            return cb('Extensão inválida');

        },

        'isImageData': function (base64) {

            const AvailableImageFormats = [ 'JPG', 'JPEG', 'PNG' ];
            var isImageData = false,
                fileFormat;

            if (!base64)
                return false;

            fileFormat = base64.split('/')[1].split(';')[0].toUpperCase();

            AvailableImageFormats.forEach(function (value) {
                if (value === fileFormat) {
                    isImageData = true;
                }
            });

            return isImageData;
        }

    };

});

(function() {
    'use strict';

    angular
        .module('plingUi')
        .factory('plgSearchFactory', plgSearchFactory);

    function plgSearchFactory() {

        return {
            'fieldSelected': fieldSelected,
            'showMenu': showMenu,
            'bodyClick': bodyClick
        };

        function fieldSelected(ctrl) {
            return function (f) {
                f.isSelected = !f.isSelected;

                if (ctrl.dateField && (ctrl.dateField !== f || !ctrl.dateField.isSelected)) {
                    ctrl.dateField.isSelected = false;
                    ctrl.dateField = null;
                }
                if (f.isSelected && f.isDate) {
                    ctrl.dateField = f;
                    ctrl.getFields().forEach(function(elem) {
                        if (elem !== f) {
                            elem.isSelected = false;
                        }
                    });
                }
            };
        }

        function showMenu(ctrl, $element) {
            ctrl.firstTime = true;
            return function (open) {

                if (typeof open !== 'boolean' || open) {
                    var inp = $element && $element[0] ? $element[0].getBoundingClientRect() : false;//eslint-disable-line

                    if (inp) {
                        ctrl.listStyle = {
                            'position': 'absolute',
                            'top'     : inp.height + 'px',
                            'left'    : '0px',
                            'width'   : inp.width + 'px'
                        };

                        if (ctrl.firstTime) {
                            ctrl.firstTime = false;
                            ctrl.querySearch(ctrl.searchText);
                        }
                    }
                    ctrl.isOpen = true;
                    return openMenu(true);
                }
                ctrl.isMenu       = false;
                ctrl.firstTime    = true;
                ctrl.items.length = 0;
                ctrl.isOpen       = false;
                ctrl.isEmpty      = false;
                openMenu(false);
            };
        }

        function bodyClick(ctrl, $element, $rootScope) {
            return function (event) {
                if (event.target && event.target.nodeName !== 'PLG-SEARCH-BAR' && !isDescendant($element[0], event.target)) {
                    ctrl.showMenu(false);
                    $rootScope.$broadcast('PLG-SEARCH-BAR-BODY-CLICK', true);
                }
            };
        }

        function isDescendant(parent, child) {
            var node = child.parentNode;

            while (node) {
                if (node === parent) {
                    return true;
                }
                node = node.parentNode;
            }
            return false;
        }

        function openMenu(open) {
            if (document.getElementById('plgSBarContent')) {
                document.getElementById('plgSBarContent').style.display = open ? 'block' : 'none';
            }
        }
    }

}());
(function() {

    'use strict';

    angular
        .module('plingUi')
        .factory('preloaderFactory', PreloaderFactory);

    PreloaderFactory.$inject = [ '$q', '$rootScope' ];

    function PreloaderFactory( $q, $rootScope ) {

        // I manage the preloading of image objects. Accepts an array of image URLs.
        function Preloader(imageLocations) {

            // I am the image SRC values to preload.
            this.imageLocations = imageLocations;
            // As the images load, we'll need to keep track of the load/error
            // counts when announing the progress on the loading.
            this.imageCount = this.imageLocations.length;
            this.loadCount = 0;
            this.errorCount = 0;
            // I am the possible states that the preloader can be in.
            this.states = {
                'PENDING' : 1,
                'LOADING' : 2,
                'RESOLVED': 3,
                'REJECTED': 4
            };
            // I keep track of the current state of the preloader.
            this.state = this.states.PENDING;
            // When loading the images, a promise will be returned to indicate
            // when the loading has completed (and / or progressed).
            this.deferred = $q.defer();
            this.promise = this.deferred.promise;

        }

        // ---
        // STATIC METHODS.
        // ---
        // I reload the given images [Array] and return a promise. The promise
        // will be resolved with the array of image locations.
        Preloader.preloadImages = function( imageLocations ) {
            var preloader = new Preloader( imageLocations );

            return preloader.load();
        };

        // ---
        // INSTANCE METHODS.
        // ---
        Preloader.prototype = {
            // Best practice for "instnceof" operator.
            'constructor': Preloader,
            // ---
            // PUBLIC METHODS.
            // ---
            // I determine if the preloader has started loading images yet.
            'isInitiated': function isInitiated() {
                return this.state !== this.states.PENDING;
            },
            // I determine if the preloader has failed to load all of the images.
            'isRejected' : function isRejected() {
                return this.state === this.states.REJECTED;
            },
            // I determine if the preloader has successfully loaded all of the images.
            'isResolved' : function isResolved() {
                return this.state === this.states.RESOLVED;
            },
            // I initiate the preload of the images. Returns a promise.
            'load'       : function load() {
                var i;

                // If the images are already loading, return the existing promise.
                if ( this.isInitiated() ) {
                    return this.promise;
                }
                this.state = this.states.LOADING;
                for (i = 0; i < this.imageCount; i++ ) {
                    this.loadImageLocation( this.imageLocations[ i ] );
                }
                // Return the deferred promise for the load event.
                return this.promise;
            },
            // ---
            // PRIVATE METHODS.
            // ---
            // I handle the load-failure of the given image location.
            'handleImageError': function handleImageError( imageLocation ) {
                this.errorCount++;
                // If the preload action has already failed, ignore further action.
                if ( this.isRejected() ) {
                    return;
                }
                this.state = this.states.REJECTED;
                this.deferred.reject( imageLocation );
            },
            // I handle the load-success of the given image location.
            'handleImageLoad': function handleImageLoad( imageLocation ) {
                this.loadCount++;
                // If the preload action has already failed, ignore further action.
                if ( this.isRejected() ) {
                    return;
                }
                // Notify the progress of the overall deferred. This is different
                // than Resolving the deferred - you can call notify many times
                // before the ultimate resolution (or rejection) of the deferred.
                this.deferred.notify({
                    'percent': Math.ceil( this.loadCount / this.imageCount * 100 ),
                    'imageLocation': imageLocation
                });
                // If all of the images have loaded, we can resolve the deferred
                // value that we returned to the calling context.
                if ( this.loadCount === this.imageCount ) {
                    this.state = this.states.RESOLVED;
                    this.deferred.resolve( this.imageLocations );
                }
            },
            // I load the given image location and then wire the load / error
            // events back into the preloader instance.
            // --
            // NOTE: The load/error events trigger a $digest.
            'loadImageLocation': function loadImageLocation(imageLocation) {
                var
                    preloader = this,
                    image = $(new window.Image()).on('load', function( event ) { //eslint-disable-line
                        // Since the load event is asynchronous, we have to
                        // tell AngularJS that something changed.
                        $rootScope.$apply(
                            function() {
                                preloader.handleImageLoad( event.target.src );
                                // Clean up object reference to help with the
                                // garbage collection in the closure.
                                preloader = null;
                                image     = null;
                                event     = null;
                            }
                        );
                    }).bind('error', function( event ) {
                        // Since the load event is asynchronous, we have to
                        // tell AngularJS that something changed.
                        $rootScope.$apply(
                            function() {
                                preloader.handleImageError( event.target.src );
                                // Clean up object reference to help with the
                                // garbage collection in the closure.
                                preloader = image = event = null;
                            }
                        );
                    }).attr( 'src', imageLocation );
            }
        };

        // Return the factory instance.
        return Preloader;

    }

}());

(function() {

    'use strict';

    angular
        .module('plingUi')
        .service('browserNotificationService', BrowserNotificationService);

    BrowserNotificationService.$inject = [ 'webNotification' ];

    function BrowserNotificationService(webNotification) {

        this.showNotification = function (obj) {

            if (obj) {

                webNotification.showNotification(obj.title, {
                    'body'      : obj.description,
                    'icon'      : '../../node_modules/pling-ui/assets/img/pp.jpg',
                    'onClick'   : obj.fnClickNotification,
                    'autoClose' : obj.autoClose || 4000
                }, function onShow(error, hide) {
                    if (error) {
                        window.alert('Não é possível mostrar a notificação');
                    } else {
                        if (obj.fnNotificationShow)
                            obj.fnNotificationShow();

                        setTimeout(function hideNotification() {
                            if (obj.fnNotificationHide)
                                obj.fnNotificationHide();
                            hide();
                        }, obj.setTimeoutHide || 5000);
                    }
                });

            } else if (!obj) {

                webNotification.lib.requestPermission();

            }

        };

    }

}());

(function () {
    'use strict';

    angular.module('plingUi').service('plgSearchService', plgSearchService);

    plgSearchService.$inject = ['routesConfigMap', 'elasticSearchApiService'];

    function plgSearchService(routesConfigMap, elasticSearchApiService) {
        var API = {}, cb = angular.noop, cbClose = angular.noop, self = this, prettyMode;

        this.getRouteAPI          = getRouteAPI;
        this.setRouteAPI          = setRouteAPI;
        this.onSearch             = onSearch;
        this.onClose              = onClose;
        this.close                = close;
        this.addMustQueries       = addMustQueries;
        this.getRefName           = getRefName;
        this.getFields            = getFields;
        this.onSelectedItemChange = onSelectedItemChange;
        this.querySearch          = querySearch;
        this.items                = [];

        /**
         * Get current API
         * @returns {Object} {API}
         */
        function getRouteAPI() {
            return API;
        }

        /**
         * @public Config route API
         * @param {String} routeName Route name
         */
        function setRouteAPI(routeName) {
            routesConfigMap = routesConfigMap || {};
            API = routesConfigMap[routeName] || routesConfigMap['*'];
        }

        /**
         * @public Push must elasticsearch queries
         * @param {Object[]} must Array of queries
         */
        function addMustQueries(must) {
            if (API) {
                API.must = API.must || [];
                API.must = API.must.concat(must);
            }
        }

        /**
         * @public Config search callback
         * @param {Function} callback callback
         * @param {Function} pretty return pretty json onQuery
         */
        function onSearch(callback, pretty) {
            cb = callback || angular.noop;
            prettyMode = pretty;
        }

        /**
         * @public Config onClose callback
         * @param {Function} callback callback
         */
        function onClose(callback) {
            cbClose = callback || angular.noop;
        }

        /**
         * @public Call close callback
         */
        function close() {
            cbClose();
        }

        /**
         * @public Get the prop name of object from elasticsearch that need to show to the client
         * @returns {String} Attribute name
         */
        function getRefName() {
            return API ? API.refName : 'name';
        }

        /**
         * @public Get fields for search
         * @returns {Object[]} Fields for search
         */
        function getFields() {
            return API ? API.fields : [];
        }

        /**
         * @public handle on user selected a item
         * @param {Object} items ElasticSearch document
         */
        function onSelectedItemChange(items) {
            items = items && !items.length ? [items] : items;
            if (prettyMode && items && items.length > 0) {
                items = items.map(function (item) {
                    item = item || {};
                    item._source = item._source || {};
                    item._source._id = item._id;
                    return item._source;
                });
            }
            cb(null, angular.copy(items && !items.length ? [items] : items));
        }

        function querySearch(term, cb) {
            var must, should;

            try {
                cb = cb || angular.noop;

                if (!API || !API.index || !API.entity) {
                    console.warn('plgSearchBar::injetando conf *');// eslint-disable-line
                    setRouteAPI('*');
                }

                must   = angular.copy(API.must) || [];
                should = angular.copy(API.should) || [];

                term = buildTriggersQueries(API.triggers, term, should);
                term = buildShouldQueries(API.fields, term, should);

                elasticSearchApiService.suggest(API.index, API.entity, term, must, should, API.source, API.size, function (err, data) {
                    if (!err) {
                        cloneArray(self.items, data);
                        cb(null, data);
                    } else {
                        self.items.length = 0;
                        cb(err);
                    }
                });
            } catch (error) {
                cb(error);
            }
        }

        /**
         * Add should queries for selected fields
         * @param {Object[]} fields Fields options
         * @param {String} value Term
         * @param {Object[]} must Array of queries
         * @returns {String} value
         */
        function buildShouldQueries(fields, value, must) {
            var multiMatch = [], valueWithoutTrigger;

            fields = fields || [];
            fields.map(function (f) {
                if (f.isSelected) {

                    // if is date field
                    if (f.isDate && value.fromDate) {
                        must.push({ 'range': { 'date': { 'gte': value.fromDate, 'lte': value.toDate } } });
                        return;
                    }

                    // if field has trigger
                    if (f.triggers && f.triggers.length > 0) {
                        valueWithoutTrigger = buildTriggersQueries(f.triggers, value, must, f.field);
                        if (valueWithoutTrigger !== value) {
                            value = valueWithoutTrigger;
                            return;
                        }
                    }

                    // normal query
                    multiMatch.push(f.field);
                }
            });

            if (multiMatch.length > 0) {
                must.push({
                    'multi_match': {
                        'query': value,
                        'fields': multiMatch
                    }
                });
            }

            return value;
        }

        /**
         * Add must queries for triggers values
         * @param {Object[]} triggers Fields options
         * @param {String} value Term
         * @param {Object[]} must Array of queries
         * @param {String?} field Optional field
         * @returns {String} value without triggers
         */
        function buildTriggersQueries(triggers, value, must, field) {
            var i, pos, q;

            if (triggers && typeof value === 'string') {
                for (i = triggers.length - 1; i >= 0; i--) {
                    if (!triggers[i].when) break;

                    // Save trigger position
                    pos = value.replace(triggers[i].when, '');

                    if (pos !== value) {
                        // add query
                        q = {};
                        q[triggers[i].field || field] = triggers[i].value ? triggers[i].value : value.match(triggers[i].when);
                        must.push({ 'match': q });
                        // remove trigger term
                        value = pos.trim();
                    }
                }
            }

            return value;
        }

        /**
         * Clone array B to array A
         * @param {Object[]} a Array A
         * @param {Object[]} b Array B
         */
        function cloneArray(a, b) {
            var i;

            a.length = 0;
            for (i = 0; i < b.length; i++) {
                a.push(b[i]);
            }
        }
    }
}());
(function() {

    'use strict';

    angular
        .module('plingUi')
        .service('plingThemingService', PlingThemingService);

    function PlingThemingService() {
        var event  = {};

        this.onCreate = function (name, obj) {

            if (name)
                event[name] = obj;

            if (!obj.id)
                event[name].id = name;

        };

        this.showCreate = function (name) {

            if (name)
                if (event[name])
                    return event[name];

        };
    }

}());

(function() {

    'use strict';

    angular
        .module('plingUi')
        .service('sidenavAllBar', SidenavAllBar);

    SidenavAllBar.$inject = [ ];

    function SidenavAllBar() {
        var event  = {},
            attr  = {};

        this.onCreate = function (name, obj) {

            if (name)
                event[name] = obj;

            if (!obj.id)
                event[name].id = name;

        };

        this.showCreate = function (name) {

            if (name)
                if (event[name])
                    return event[name];

        };

        this.on = function (name, cb) {

            attr[name] = attr[name] || [];
            if (cb) attr[name].push(cb);

        };

        this.emit = function (name, args) {

            if (attr[name])
                attr[name].map(function (cb) {
                    cb(args);
                });

        };

    }

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .service('httpHelperService', HttpHelperService);

    HttpHelperService.$inject = [ '$http', '$q' ];

    function HttpHelperService($http, $q) {
        var groups = {};

        this.registerUrl = function (url, groupName) {
            var defer;

            if (!groupName)
                groupName = 'default';

            if (!groups[groupName]) {
                defer = $q.defer();
                groups[groupName] = defer;
            } else
                defer = groups[groupName];

            return defer.promise;
        };

        this.cancelRequest = function (groupName) {
            if (!groupName)
                groupName = 'default';

            groups[groupName].resolve('cancelled');
            delete groups[groupName];
        };
    }

}());

(function () {
    'use strict';

    function CachingService($templateCache, $route, $http) {


        this.cacheViews = function (cacheObj, routeObj) {
            // setting defaults
            var partial, r,
                viewCache = cacheObj || $templateCache,
                router = routeObj || $route;

            // looping routes
            for (r in router.routes) {
                // jslint -object protection
                if (router.routes.hasOwnProperty(r)) {
                    // evaluate partial
                    partial = router.routes[r].templateUrl;
                    if (partial) {
                        // caching route
                        $http.get(partial, {'cache': viewCache});
                    }
                }
            }
        };
    }

    CachingService.$inject = ['$templateCache', '$route', '$http'];

    // registering service
    angular.module('plingUi').service('cacheService', CachingService);

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .service('$localstorage', LocalStorage);

    LocalStorage.$inject = [ '$window' ];

    function LocalStorage($window) {
        return {

            'clearAll': function () {
                $window.localStorage.clear();
            },

            'set': function (key, value) {
                $window.localStorage[key] = value;
            },

            'get': function (key) {
                return $window.localStorage[key];
            },

            'setObject': function (key, value) {
                $window.localStorage[key] = JSON.stringify(value);
            },

            'getObject': function (key) {
                return JSON.parse($window.localStorage[key] || '{}');
            },

            'deleteKey' : function (key) {
                delete $window.localStorage[key];
            }
        };
    }

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .service('sessionstorage', SessionStorage);

    SessionStorage.$inject = [ '$window' ];

    function SessionStorage($window) {
        return {

            'clearAll': function () {
                $window.sessionStorage.clear();
            },

            'set': function (key, value) {
                $window.sessionStorage[key] = value;
            },

            'get': function (key) {
                return $window.sessionStorage[key];
            },

            'setObject': function (key, value) {
                $window.sessionStorage[key] = JSON.stringify(value);
            },

            'getObject': function (key) {
                return JSON.parse($window.sessionStorage[key] || null);
            }
        };
    }

}());

(function () {
    'use strict';

    function ToastrService() {

        // this.emit = function(message, type) {
        //     $mdToast.show(
        //         $mdToast.simple()
        //             .textContent(message)
        //             .position($scope.getToastPosition())
        //             .hideDelay(delay || 2000)
        //     );
        // };

    }

    ToastrService.$inject = [ '$mdToast' ];

    angular.module('plingUi').service('toastrService', ToastrService);

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .service('plingRequestInterceptor', PlingRequestInterceptor);

    PlingRequestInterceptor.$inject = [
        '$q', '$window', '$rootScope'
    ];

    function PlingRequestInterceptor($q, $window, $rootScope) {

        return {

            // On request
            'request': function (config) {
                var isAuth = $window.localStorage.getItem('PLING-TOKEN');

                // Add Token info to every request
                if (isAuth !== false)
                    config.headers.Authorization = $window.localStorage.getItem('PLING-TOKEN');

                if (isAuth === false) {
                    if (config.url.startsWith('http', 'https')) {
                        config.headers['Access-Control-Allow-Origin']  = '*';
                    }
                }

                return config;
            },

            // On request error
            'requestError': function (reason) {

                // Return the promise error reason.
                return $q.reject(reason);
            },

            // On response success
            'response': function (response) {

                // Return the response or promise.
                return response || $q.when(response);
            },

            // On response error
            'responseError': function (reason) {

                if (reason.status === 401 && (!reason.config || reason.config && reason.config.url && reason.config.url.substr(-5) !== 'login')) {
                    $rootScope.$broadcast('PLG-LOGIN-RETOKEN');
                }

                // Return the promise error reason.
                return $q.reject(reason);
            }

        };
    }

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .factory('$exceptionHandler', PlingUiExceptionHandler);

    PlingUiExceptionHandler.$inject = ['$injector'];

    function PlingUiExceptionHandler($injector) {

        return function (exception, cause) {

            // preparing message to be dispatched
            var dispatcher = null,
                logger = null,
                data   = {
                    'error': exception,
                    'details': cause
                };

            // logging
            logger = $injector.get('$log');
            logger.error(exception);

            if (cause && logger.debug) {
                logger.debug(cause);
            }

            // dispatching message
            dispatcher = $injector.get('$rootScope');
            dispatcher.$broadcast('PLINGUI_INTERNAL_ERROR', data);
        };
    }

}());

(function () {
    'use strict';

    // registering on angular
    angular
        .module('plingUi')
        .factory('shadowLogger', PlingUiLogger);

    // logger definition
    function PlingUiLogger() {
        return function ($delegate) {
            return {

                'dispatch': function (method, params) {

                    // defining method
                    var
                        proc  = $delegate[method] || $delegate.log,

                        stamp = new Date().toString(),
                        prefix = '[' + stamp + '][' + method + ']::',
                        msg = [],
                        arg;

                    if (method) {

                        // preparing msg
                        msg.push(prefix);

                        // joining params
                        for (arg in params) {
                            if (params.hasOwnProperty(arg)) {
                                msg.push(params[arg]);
                            }
                        }

                        // applying log info
                        proc.apply(null, msg);
                    }
                },

                'log': function () {
                    this.dispatch('log', arguments);
                },

                'info': function () {
                    this.dispatch('info', arguments);
                },

                'error': function () {
                    this.dispatch('error', arguments);
                },

                'warn': function () {
                    this.dispatch('warn', arguments);
                },

                'debug': function () {
                    this.dispatch('debug', arguments);
                }
            };
        };
    }
}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .service('activitiesService', ActivitiesService);

    ActivitiesService.$inject = [ 'httpService' ];

    function ActivitiesService(httpService) {

        this.get = function (cb) {
            var
                module_id,
                pathname = window.location.pathname,
                viewPreferences = JSON.parse(window.localStorage['PLING-MODULES']),
                query;

            viewPreferences.map(function(obj) {
                if (obj.route === pathname)
                    module_id = obj._id;
            });

            viewPreferences = JSON.parse(window.localStorage['PLING-CURRENT-VIEW-PREFERENCES'])[0];

            query = {
                'product_id'  : viewPreferences.product_id,
                'module_id'   : module_id
            };

            return httpService.get('accounts', 'activities/' + query.product_id + '/' + query.module_id)
            .success(function (result) {
                cb(null, result);
            })
            .error(function(result) {
                cb(result);
            });
        };

        this.post = function (description, cb) {
            var payload = {
                'description' :  description
            };

            var pathname = window.location.pathname;

            var viewPreferences = JSON.parse(window.localStorage['PLING-MODULES']);

            viewPreferences.map(function(obj) {
                if (obj.route === pathname)
                    payload.module_id = obj._id;
            });

            viewPreferences = JSON.parse(window.localStorage['PLING-CURRENT-VIEW-PREFERENCES'])[0];

            payload.product_id = viewPreferences.product_id;

            return httpService.post('accounts', 'activities', payload)
                .success(function (result) {
                    if (cb) return cb(null, result);
                })
                .error(function(result) {
                    if (cb) return cb(result);
                });
        };
    }

}());

(function () {

    'use strict';

    angular
        .module('plingUi')
        .service('ApplicationsService', ApplicationsService);

    ApplicationsService.$inject = [
        '$window', '$localstorage',
        'httpService', 'tokenService'
    ];

    function ApplicationsService($window, $localstorage, httpService, tokenService) {

        this.getLocal = function() {
            var localAppData = $localstorage.get('PLING-APPS');

            localAppData = localAppData && localAppData !== 'undefined' ? JSON.parse(localAppData) : {};
            return localAppData;
        };

        this.getCurrentAppModule = function() {
            var currentAppModule = $localstorage.get('PLING-CURRENT-APP');

            return currentAppModule;
        };

        this.getCurrentApp = function() {
            var currentApp = {
                'appModule': $localstorage.get('PLING-CURRENT-APP'),
                'env'      : $localstorage.get('PLING-CURRENT-ENV')
            };

            return currentApp;
        };

        this.getCurrentAppId = function(cb) {
            $localstorage.getObject('PLING-APPS')
                .filter(function (app) {
                    if (app.appModule === $localstorage.get('PLING-CURRENT-APP')) {
                        return cb(app._id);
                    }
                });
        };

        this.getCallbackUrl = function(appId, cb) {
            httpService.post('accounts', '_oauth', { 'appid': appId })
                .success(function (data) {
                    if (data.callbackUrl) {
                        cb(null, data.callbackUrl + '?token=' + tokenService.get());
                    } else {
                        cb('Callback url not found');
                    }
                })
                .error(function (reason) {
                    cb(reason || 'Server Unavailable', null);
                });
        };

        this.redirect = function(url) {
            $window.location.href = url;
        };

        this.redirectOpen = function(url) {
            $window.open(url, '_blank');
        };

    }

}());

(function () {
    'use strict';

    CardValidatorService.$inject = [ ];

    angular.module('plingUi').service('cardValidatorService', CardValidatorService);

    function CardValidatorService() {
        var types = [];

        types.push({
            'niceType': 'Visa',
            'type': 1,
            'prefixPattern': /^4$/,
            'exactPattern': /^4\d*$/,
            'gaps': [4, 8, 12],
            'lengths': [13, 16],
            'code': {
                'name': 'CVV',
                'size': 3
            }
        });

        types.push({
            'niceType': 'MasterCard',
            'type': 2,
            'prefixPattern': /^(5|5[1-5]|2|22|222|222[1-9]|2[3-6]|27[0-1]|2720)$/,
            'exactPattern': /^(5[1-5]|222[1-9]|2[3-6]|27[0-1]|2720)\d*$/,
            'gaps': [4, 8, 12],
            'lengths': [16],
            'code': {
                'name': 'CVV',
                'size': 3
            }
        });

        types.push({
            'niceType' : 'Diners Club',
            'type' : 3,
            'prefixPattern' : /^(36|38|30[0-5])$/,
            'exactPattern' : /^(36|38|30[0-5])\d*$/,
            'gaps' : [4, 8, 12],
            'lengths' : [14, 16],
            'code' : {
                'name' : 'CVV',
                'size' : 3
            }
        });

        types.push({
            'niceType' : 'Elo',
            'type' : 4,
            'prefixPattern' : /^(636368|636369|438935|504175|451416|636297|5067|4576|4011|506699)$/,
            'exactPattern' : /^(636368|636369|438935|504175|451416|636297|5067|4576|4011|506699)\d*$/,
            'gaps' : [4, 8, 12],
            'lengths' : [16],
            'code' : {
                'name' : 'CVV',
                'size' : 3
            }
        });

        function luhn10(identifier) {
            var sum = 0;
            var alt = false;
            var i = identifier.length - 1;
            var num;

            while (i >= 0) {
                num = parseInt(identifier.charAt(i), 10);

                if (alt) {
                    num *= 2;
                    if (num > 9) {
                        num = (num % 10) + 1; // eslint-disable-line no-extra-parens
                    }
                }

                alt = !alt;

                sum += num;

                i--;
            }

            return sum % 10 === 0;
        }

        function validateDate (date) {
            var now = new Date();
            var month = parseInt(date.substr(0, 2), 10) - 1;
            var year = parseInt(date.substr(2, 2), 10) + 2000;

            if (month < 0 || month > 11 || year - now.getFullYear() > 15)
                return false;

            return new Date(year, month, 1).getTime() > now.getTime();
        }

        this.validate = function (cardNumber, dateExpiration, cvv) {
            var number, numberResult, dateResult, i, validType;

            if (!cardNumber)
                return {
                    'isValid' : false,
                    'type'    : null
                };

            number = cardNumber.toString();

            for (i=0; i<types.length; i++) {
                if (types[i].exactPattern.test(number)) {
                    validType = types[i];
                    break;
                }
            }

            if (!validType)
                return {
                    'isValid' : false,
                    'type'    : null
                };

            numberResult = luhn10(number);
            dateResult = validateDate(dateExpiration);

            return {
                'isValid' : numberResult && dateResult && cvv.length >= 3,
                'type'    : validType
            };
        };

        this.validateDate = function (dateExpiration) {
            var dateResult;

            dateResult = validateDate(dateExpiration);

            return {
                'isValid' : dateResult
            };
        };

        this.validateCardNumber = function (cardNumber) {
            var number, numberResult, i, validType;

            if (!cardNumber)
                return {
                    'isValid'  : false,
                    'type'     : null
                };

            number = cardNumber.toString();

            for (i = 0; i < types.length; i++) {
                if (types[i].exactPattern.test(number)) {
                    validType = types[i];
                    break;
                }
            }

            if (!validType)
                return {
                    'isValid' : false,
                    'type'    : null
                };

            numberResult = luhn10(number);

            return {
                'isValid' : numberResult,
                'type'    : validType
            };
        };
    }

})();
(function () {
    'use strict';

    function CepService(httpService) {

        this.getCep = function (cep) {
            return httpService.get('smart', 'cep', cep);
        };
    }

    CepService.$inject = [ 'httpService' ];

    angular.module('plingUi').service('cepService', CepService);

}());


(function () {
    'use strict';

    angular
        .module('plingUi')
        .service('chatService', ChatService);

    ChatService.$inject = [
        'sessionstorage', 'httpService', 'websocketService', 'credentialsService'
    ];

    function ChatService(sessionstorage, httpService, websocketService, credentialsService) {
        var
            focusedRoomId = '',
            soundNotificationStatus = true;

        this.openedRooms = '';

        this.getSoundNotificationStatus = function() {
            return soundNotificationStatus;
        };

        this.setSoundNotificationStatus = function(status) {
            soundNotificationStatus = status;
        };

        this.getFocusedRoomId = function() {
            return focusedRoomId;
        };

        this.setFocusedRoomId = function(roomId) {
            focusedRoomId = roomId;
        };

        this.getLocalUser = function() {
            return credentialsService.getLocal();
        };

        this.setRealTimeListener = function(channel, cbMessage) {
            websocketService.setRealTimeListener(channel, cbMessage);
        };

        this.sendSignedIn = function() {
            var
                channelStr = 'chat:customer:' + credentialsService.getLocal().customer_id,
                signedinMessage = {
                    'action'  : 'signedin',
                    'channel' : channelStr,
                    'sender'  : credentialsService.getLocal()
                };

            websocketService.send(channelStr, signedinMessage);
        };

        this.sendInteractionViaWs = function() {
            var
                channelStr = 'chat:customer:' + credentialsService.getLocal().customer_id,
                message = {
                    'action' : 'interaction',
                    'sender' : credentialsService.getLocal()
                };

            websocketService.send(channelStr, message);
        };

        this.sendReadingConfirmation = function(obj, isMessage) {
            var
                channelStr = 'chat:customer:' + credentialsService.getLocal().customer_id,
                message = {
                    'action' : 'readed',
                    'sender' : credentialsService.getLocal()
                };

            if (isMessage) {
                message.message = obj;
            } else {
                message.room = obj;
            }

            if (message.room || message.message)
                websocketService.send(channelStr, message);
        };


        this.sendDeliveryConfirmation = function(obj, isMessage) {
            var
                channelStr = 'chat:customer:' + credentialsService.getLocal().customer_id,
                message = {
                    'action' : 'received',
                    'sender' : credentialsService.getLocal()
                };

            if (isMessage) {
                message.message = obj;
            } else {
                message.rooms = obj;
            }

            if (message.rooms || message.message)
                websocketService.send(channelStr, message);
        };

        this.sendTypingViaWs = function(roomObj, event) {
            var
                channelStr = 'chat:customer:' + credentialsService.getLocal().customer_id,
                message = {
                    'room' : roomObj,
                    'action' : 'typing',
                    'event'  : event,
                    'sender' : credentialsService.getLocal()
                };

            websocketService.send(channelStr, message);
        };

        this.sendMessageViaWs = function(messageObj, roomObj) {
            var roomMessage = {
                'action' : 'newMessage',
                'sender' : credentialsService.getLocal(),
                'room'   : roomObj,
                'data' : {
                    'username'       : messageObj.username,
                    'credential_id'  : credentialsService.getLocal().id,
                    'imageDriveId'   : messageObj.imageDriveId,
                    'message'        : messageObj.message,
                    'name'           : messageObj.name,
                    'createDate'     : messageObj.createDate,
                    'isFirstMessage' : messageObj.isFirstMessage,
                    'room_id'        : roomObj._id
                }
            };

            delete roomMessage.sender.modules;
            delete roomMessage.sender.viewPreferences;

            websocketService.send('chat:customer:' + roomMessage.sender.customer_id, roomMessage);
        };

        this.signin = function() {
            return httpService.get('chat', 'signin');
        };

        /**
         * Cria ou busca uma sala de conversa baseado em usuário(s).
         * @param {object} roomObj - Objeto Room/Chat.
         * @returns {promise} Retorno da API.
         */
        this.openRoom = function(roomObj) {
            return httpService.post('chat', 'room', roomObj);
        };

        this.removeRoom = function(roomId) {
            return httpService.delete('chat', 'room', roomId);
        };

        this.sendMessageViaApi = function(messageObj) {
            return httpService.post('chat', 'messages', messageObj);
        };

        this.getMessages = function(roomId, skip) {
            skip = skip ? skip : 0;
            return httpService.get('chat', 'messages/' + roomId + '?skip=' + skip);
        };

        this.getUserPicture = function(imageDriveId) {
            return httpService.get('drive', 'base64', imageDriveId);
        };

        this.getSingleRoom = function(userId) {
            return httpService.get('chat', 'singleroom/' + userId);
        };
    }

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .service('coreApiService', CoreApiService);

    CoreApiService.$inject = [
        '$window', '$rootScope', '$http',
        'boot.options', '$localstorage'
    ];

    function CoreApiService($window, $rootScope, $http, options, $localstorage) {

        var self = this;

        /*
        *  url do core obtido do conf.json da aplicacao corrente concatenado com parametros
        * @param {string} nome da aplicacao. ex: 'accounts', 'drive', 'integra'
        * @param {string} nome do modulo. ex: 'contactPreferences', 'users/list'.
        * @returns {string} concatenacao da url do core com parametros.
        */
        this.getAppCoreUrl = function (app, module, version) {
            var url;
            var def_api_version = version ? version : options.def_api_version;

            url = options.core_url + def_api_version;

            url += app ? '/' + app : '';
            url += module ? '/' + module : '';

            return url;
        };

        // Returns Application name capitalizing the first letter with UpperCase
        this.getApplicationName = function () {
            return options.def_api_app.charAt(0).toUpperCase() + options.def_api_app.slice(1);
        };

        this.redirectToLoginWithCallback = function(callbackUrl) {
            var callbackQueryString;

            $rootScope.$emit('PLING-SERVICE-BAR-ISLOADING', true);

            // Seta callback url
            callbackQueryString = callbackUrl ? '?callbackurl=' + callbackUrl : '';

            // Busca a URL do login por ambiente (conf.json)
            $http.get(self.getAppCoreUrl('accounts', 'products/Login/' + options.environment))
                .success(function(data) {
                    if (data)
                        $window.location.href = data.callbackUrl + callbackQueryString;
                })
                .error(function() {
                    $rootScope.toast('Erro ao obter URL para aplicação de Login');
                    $rootScope.$emit('PLING-SERVICE-BAR-ISLOADING', false);
                    return false;
                });
        };

        this.redirectToControlPanel = function() {
            var token = $localstorage.get('PLING-TOKEN') || '';

            $rootScope.$emit('PLING-SERVICE-BAR-ISLOADING', true);

            $http.get(self.getAppCoreUrl('accounts', 'products/Backoffice/' + options.environment))
                .success(function(data) {
                    if (data)
                        $window.location.href = data.callbackUrl + 'minha-conta' + (token ? '?token=' + token : '');
                })
                .error(function() {
                    $rootScope.toast('Erro ao obter URL para Minha Conta');
                    $rootScope.$emit('PLING-SERVICE-BAR-ISLOADING', false);
                    return false;
                });
        };

        this.getS3Config = function() {
            return options.s3Aws;
        };
    }

}());

(function () {

    'use strict';

    CredentialsService.$inject = [
        'httpService', '$localstorage', 'driveService', 'coreApiService', '$location' ];

    angular.module('plingUi').service('credentialsService', CredentialsService);

    function CredentialsService(httpService, $localstorage, driveService, core, $location) {
        this.beforeLogout = null;

        this.isUserActive = function(credential_id) {
            return httpService.get('accounts', 'credentials/is-user-active', credential_id);
        };

        this.login = function (credentials, cb) {
            cb = cb || angular.noop;
            return httpService.post('accounts', 'login', credentials)
            .success(function (data) {
                cb(null, data.token);
            })
            .error(function (error, httpcode) {
                if (httpcode === 401 && error) {
                    cb('Usuário ou Senha inválidos', null);
                } else {
                    cb('Servidor indisponível', null);
                }
            });
        };

        this.logoutWithEmail = function(username) {
            if (this.beforeLogout)
                this.beforeLogout();
            httpService.post('accounts', 'wrong-pwd-email', { 'username': username }).success(function () {
                $localstorage.clearAll();
                core.redirectToLoginWithCallback();
            }).error(function () {
                core.redirectToLoginWithCallback();
            });
        };

        this.logout = function(noRedirect) {
            if (this.beforeLogout)
                this.beforeLogout();
            // Consumir o Core para o token entrar em Blacklist
            httpService.post('accounts', 'logout')
                .success(function() {
                    if (noRedirect) return;
                    $localstorage.clearAll();
                    core.redirectToLoginWithCallback();
                })
                .error(function(reason) {
                    // Chamar Toastr
                    console.log(reason); // eslint-disable-line no-console
                });
        };

        this.get = function(id, cb) {
            httpService.get('accounts', 'credentials', id ? id : '')
            .success(function (data) {
                cb(null, data);
            })
            .error(function (reason) {
                cb(reason);
            });
        };

        this.getLocalCustomerId = function() {
            var userData = $localstorage.get('PLING-USER');

            if (!userData) return null;

            userData = JSON.parse(userData);
            return userData.customer_id;
        };

        this.create = function(user) {
            return httpService
                .post('accounts', 'credentials', user);
        };

        this.update = function(user, cb) {
            var usr;

            httpService.put('accounts', 'credentials', user)
                .success(function (data) {
                    usr = JSON.parse($localstorage.get('PLING-USER') || {});
                    if (usr) {
                        usr.imageDriveId = user.imageDriveId;
                        $localstorage.set('PLING-USER', JSON.stringify(usr));
                    }

                    cb(null, data);
                })
                .error(function (reason) {
                    cb(reason);
                });
        };

        this.delete = function(userId, cb) {
            httpService.delete('accounts', 'credentials/delete', userId)
                .success(function (data) {
                    cb(null, data);
                })
                .error(function (reason) {
                    cb(reason);
                });
        };

        this.getLocal = function() {
            var userData = $localstorage.get('PLING-USER');

            if (!userData) return null;

            userData = JSON.parse(userData);
            return userData;
        };

        this.setViewPreference = function(view, cb) {
            var currentApp, viewData, sortsRoute = [], route = $location.path().split('/');

            cb = cb || function () {};

            if (!view)
                return cb('View não pode ser nula');

            currentApp = JSON.parse($localstorage.get('PLING-APPS')).find(function(appItem) {
                return appItem.appModule === $localstorage.get('PLING-CURRENT-APP');
            });

            if (!currentApp)
                return cb('Modulo não encontrado');

            viewData = {
                'product_id' : currentApp._id
            };

            // Salva apenas tipo de visualizacao
            if (typeof view === 'string')
                viewData.viewType = view;
            else if (view) {
                // Tipo de visualizacao
                if (view.viewType)
                    viewData.viewType = view.viewType;


                // Limite por pagina
                if (view.limit) {
                    viewData.limit = view.limit;
                    viewData.route = route[1];
                }

                // Preferencia de filtros
                if (view.name) {
                    viewData.name = view.name;
                    viewData.filters = view.filters || [];
                }

                // Preferencia de ordenação
                if (view.sorts)
                    viewData.sorts = view.sorts;
            }

            httpService.post('accounts', 'credentials/view-preference', viewData)
                .success(function(viewPreferences) {

                    if (viewPreferences) {

                        viewPreferences.map(function(objView) {

                            if (objView.sorts) {
                                objView.sorts.map(function(obj) {
                                    if (obj.route === route[route.length - 1])
                                        sortsRoute.push(obj);
                                });

                                viewPreferences.sorts = sortsRoute;
                            }

                            if (objView.limits) {
                                objView.limits.map(function(obj) {
                                    if (obj.route === route[route.length - 1])
                                        viewPreferences.limit = obj.limit;
                                });

                            }

                        });


                    }

                    $localstorage.set('PLING-CURRENT-VIEW-PREFERENCES', JSON.stringify(viewPreferences));

                    cb(null, viewPreferences);
                })
                .error(function (reason) {
                    cb(reason);
                });
        };

        this.getViewPreference = function() {
            var sortsRoute = [], currentApp, viewPreferences, route = $location.path().split('/');

            viewPreferences = $localstorage.get('PLING-CURRENT-VIEW-PREFERENCES');
            if (!viewPreferences)
                return null;

            currentApp = JSON.parse($localstorage.get('PLING-APPS')).find(function(appItem) {
                return appItem.appModule === $localstorage.get('PLING-CURRENT-APP');
            });

            if (!currentApp)
                return null;

            viewPreferences = JSON.parse(viewPreferences).find(function(vp) {
                return currentApp._id === vp.product_id;
            });

            if (viewPreferences) {
                if (viewPreferences.sorts) {

                    viewPreferences.sorts.map(function(obj) {
                        if (obj.route === route[route.length - 1])
                            sortsRoute.push(obj);
                    });

                    viewPreferences.sorts = sortsRoute;

                    if (!viewPreferences.sorts)
                        viewPreferences.sorts = [];

                }

                return viewPreferences;
            }

            return null;
        };

        this.deleteViewPreference = function(name) {
            var query, currentApp;

            currentApp = JSON.parse($localstorage.get('PLING-APPS')).find(function(appItem) {
                return appItem.appModule === $localstorage.get('PLING-CURRENT-APP');
            });

            if (!currentApp)
                return false;

            query = '?name=' + name + '&product_id=' + currentApp._id;

            return httpService.delete('accounts', 'credentials/view-preference', query);
        };

        this.getAll = function() {
            return httpService.get('accounts', 'credentials');
        };

        this.getAllCredentialsAllCustomers = function() {
            return httpService.get('accounts', 'credentials/all');
        };

        this.getProfileImage =  function(imageDriveId, customerId, size) {
            var s3 = core.getS3Config();
            var customerBucket = s3.buckets;
            var imageDimension = s3.imageDimensions.find(function(item) { return item.key === size; });

            if (!imageDimension)
                imageDimension = s3.imageDimensions.find(function(item) { return item.key === 'default'; });

            if (!imageDriveId ||!customerId)
                return null;

            return s3.url + customerBucket.name + '/' + customerId + '/profile-images/' + imageDriveId + '_' + imageDimension.size;
        };

        this.uploadProfileImage = function(file, fileData) {

            var fd = new FormData(); //eslint-disable-line

            fd.append('file', file);
            fd.append('data', angular.toJson(fileData));

            return httpService.upload('accounts', 'credentials/upload', fd);
        };

    }

}());

(function () {
    'use strict';

    CustomersService.$inject = [ 'httpService', 'coreApiService' ];

    angular.module('plingUi').service('customersService', CustomersService);

    function CustomersService(httpService, core) {

        this.get = function (query) {
            return httpService.get('accounts', 'customers', query);
        };

        this.getList = function (query) {
            return httpService.get('accounts', 'customers/list', query);
        };

        this.update = function (customer) {
            return httpService.put('accounts', 'customers', customer);
        };

        this.getProtocols = function (query) {
            return httpService.get('accounts', 'customers/protocols/' + query);
        };

        this.getStatuses = function () {
            return httpService.get('accounts', 'customers/status/');
        };

        this.create = function (env, customer) {
            return httpService.post('accounts', 'customers/admin/' + env, customer);
        };

        this.historyComment = function (payload) {
            return httpService.post('accounts', 'customers/history', payload);
        };

        this.getHistoryByCustomer = function (customerId) {
            return httpService.get('accounts', 'customers/history/' + customerId);
        };

        this.getById = function (customerId) {
            return httpService.get('accounts', 'customers/' + customerId);
        };

        this.getProfileImage =  function (imageDriveId, customerId, size) {
            var s3 = core.getS3Config();
            var customerBucket = s3.buckets.find(function(item) { return item.key === 'customer'; });
            var imageDimension = s3.imageDimensions.find(function(item) { return item.key === size; });

            if (!imageDriveId || !customerId)
                return null;

            if (!imageDimension)
                imageDimension = s3.imageDimensions.find(function(item) { return item.key === 'default'; });

            return s3.url + customerBucket.name + '/' + customerId + '/profile-images/' + imageDriveId + '_' + imageDimension.size;
        };

        this.uploadProfileImage = function (file, fileData) {

            var fd = new FormData(); //eslint-disable-line

            fd.append('file', file);
            fd.append('data', angular.toJson(fileData));

            return httpService.upload('accounts', 'customers/upload', fd);
        };
    }

}());

(function () {
    'use strict';

    function DriveService(httpService) {

        this.getFile = function(imageDriveId, type, customerId) {
            customerId =  customerId || '';
            return httpService.get('drive', '', imageDriveId + '/' + type + '/' + customerId);
        };

        this.getTree = function (credential_id) {
            return httpService.get('drive', credential_id);
        };

        this.delete = function(imageDriveId, customerId) {
            customerId = customerId || '';
            return httpService.delete('drive', '', imageDriveId + '/' + customerId);
        };

    }

    DriveService.$inject = [ 'httpService' ];

    angular.module('plingUi').service('driveService', DriveService);

}());

(function() {
    'use strict';

    angular
        .module('plingUi')
        .service('elasticSearchApiService', ElasticSearchApi);

    ElasticSearchApi.$inject = ['httpService'];

    function ElasticSearchApi(httpService) {

        this.getDocument       = getDocument;
        this.suggest           = suggest;

        /**
         * Get a document by id
         * @param {String} index Index name
         * @param {String} entity Type name
         * @param {String} id primarykey
         * @param {Function} cb callback
         * @public
         */
        function getDocument(index, entity, id, cb) {
            if (index && entity) {
                httpService.get('smart', buildUrl(index, entity), id ? id : '').success(function (data) {
                    cb(null, data);
                }).error(function (reason) {
                    cb(reason);
                });
            } else {
                cb(new Error('ElasticSearch paramenters missed'));
            }
        }

        /**
         * Get documents by a suggest query
         * @param {String} index Index name
         * @param {String} entity Type name
         * @param {String} term Search term
         * @param {Object[]} must Must query
         * @param {Object[]} should Should query
         * @param {String[]} source Fields to return
         * @param {Integer} size Limit documents
         * @param {Function} cb callback
         * @public
         */
        function suggest(index, entity, term, must, should, source, size, cb) {

            if (term && index && entity) {
                httpService.post('smart', buildUrl(index, entity + '/suggest/'), {
                    'term'   : term,
                    '_source' : source,
                    'must'   : must,
                    'should' : should,
                    'size'   : size
                }).success(function (data) {
                    data = data && data.hits && data.hits.hits ? data.hits.hits : [];
                    cb(null, data);
                }).error(function (reason) {
                    cb(reason);
                });
            } else {
                cb(new Error('ElasticSearch paramenters missed'));
            }
        }

        /**
         * Build ElasticSearch api url
         * @param {String} index Index name
         * @param {String} entity Type name
         * @returns {String} complete url
         */
        function buildUrl(index, entity) {
            return 'elastic/' + index + '/' + entity;
        }
    }

}());
(function () {
    'use strict';

    angular
        .module('plingUi')
        .service('httpService', HttpService);

    HttpService.$inject = [
        '$http', '$q',
        'coreApiService'
    ];

    function HttpService($http, $q, core) {

        var cancelPromises = {};

        function createCancelRequest(options, name) {
            cancelPromises[name] = $q.defer();
            options = options || {};
            options['timeout'] = cancelPromises[name].promise;
            return options;
        }

        this.save = function (app, module, data, version) {
            return $http.post(core.getAppCoreUrl(app, module, version), data);
        };

        this.update = function (app, module, data, version) {
            return $http.put(core.getAppCoreUrl(app, module, version), data);
        };

        this.upload = function (app, module, file, version) {
            return $http
               .post(core.getAppCoreUrl(app, module, version), file, {
                   'transformRequest' : angular.identity,
                   'headers'          : { 'Content-Type': undefined }  // eslint-disable-line
               });
        };

        this.getImage = function (url, cb) {
            this.get('credentials/public?imagepath=' + url)
                .success(function (imageDownloadData) {
                    var blob   = new Blob([ imageDownloadData ], { 'type': 'image/jpeg' }),
                        reader = new FileReader();

                    reader.readAsDataURL(blob);
                    reader.onloadend = function () {
                        cb(null, reader.result);
                    };
                    // cb(null, objectUrl);
                })
                .error(function (err) {
                    cb(err);
                });
        };

        // To Get values
        this.get = function (app, module, id, isCancelRequest, version) {
            var url = core.getAppCoreUrl(app, module, version), type;

            if (id) url += '/' + id;
            else if (module && module.indexOf('public') > 0) type = { 'responseType': 'arraybuffer' };

            if (isCancelRequest) type = createCancelRequest(type, url);

            return $http.get(url, type);
        };

        // To insert values
        this.post = function (app, module, data, version) {
            var req = {
                'method'  : 'POST',
                'url'     : core.getAppCoreUrl(app, module, version),
                'data'    : data,
                'headers' : {
                    'Content-Type': 'application/json'
                }
            };

            return $http(req);
        };

        // To Update/Modify
        this.patch = function (app, module, data, version) {
            var req = {
                'method'  : 'PATCH',
                'url'     : core.getAppCoreUrl(app, module, version),
                'data'    : data,
                'headers' : {
                    'Content-Type': 'application/json'
                }
            };

            return $http(req);
        };

        // To Update/Replace
        this.put = function (app, module, data, version) {
            var req = {
                'method'  : 'PUT',
                'url'     : core.getAppCoreUrl(app, module, version),
                'data'    : data,
                'headers' : {
                    'Content-Type': 'application/json'
                }
            };

            return $http(req);
        };

        // To Delete
        this.delete = function (app, module, id, version) {
            var req = {
                'method'  : 'DELETE',
                'url'     : core.getAppCoreUrl(app, module, version) + '/' + id,
                'headers' : {
                    'Content-Type': 'application/json'
                }
            };

            return $http(req);
        };

        this.cancelRequests = function (urls) {
            var i;

            for (i = urls.length - 1; i >= 0; i--) {
                urls[i] = core.getAppCoreUrl(urls[i].app, urls[i].module);
                urls[i] = urls[i].id ? urls[i] + '/' + urls[i].id : urls[i];
                if (cancelPromises[urls[i]])
                    cancelPromises[urls[i]].resolve();
            }

            urls.length = 0;
        };

    }

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .service('notificationService', NotificationService);

    NotificationService.$inject = [
        'websocketService'
    ];

    function NotificationService(websocketService) {

        this.setRealTimeListener = function(channel, cbMessage) {
            websocketService.setRealTimeListener(channel, cbMessage);
        };
    }

}());

(function () {

    'use strict';

    function ProfilesService(httpService) {

        this.getProfileDefault = function (cb) {
            httpService.get('accounts', 'profiles/profile-default')
            .success(function (data) {
                cb(null, data);
            })
            .error(function (reason) {
                cb(reason);
            });
        };

    }

    ProfilesService.$inject = [
        'httpService' ];

    angular.module('plingUi').service('profilesService', ProfilesService);

}());

(function () {
    'use strict';

    function TokenService($http, $localstorage, coreApiService) {

        this.get = function() {
            return $localstorage.get('PLING-TOKEN');
        };

        this.set = function(token) {
            if (token) {
                $localstorage.set('PLING-TOKEN', token);
                return true;
            }

            return false;
        };

        this.validate = function (cb) {
            $http.get(coreApiService.getAppCoreUrl('accounts', 'me'))
                .success(function(credentialData) {
                    cb(null, credentialData);
                })
                .error(function(reason) {
                    cb(reason);
                });
        };

    }

    TokenService.$inject = [ '$http', '$localstorage', 'coreApiService' ];

    angular.module('plingUi').service('tokenService', TokenService);

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .service('websocketService', WebsocketService);

    WebsocketService.$inject = [
        '$rootScope', '$window', '$timeout',
        'coreApiService', 'credentialsService'
    ];

    function WebsocketService($rootScope, $window, $timeout, core, credentialsService) {

        var
            socket,
            currentToken = $window.localStorage.getItem('PLING-TOKEN'),
            coreUrl      = core.getAppCoreUrl().replace('/v2', '');

        this.getInstance = function() {
            return socket;
        };

        credentialsService.beforeLogout = function() {
            try {
                this.getInstance.disconnect();
            } catch (e) { console.error(e); } //eslint-disable-line
        };

        this.connect = function(cb) {

            try {

                if ($rootScope.websocket) return cb();
                if (!io) return false; // eslint-disable-line

                $rootScope.isWebsocketConnected = false;
                $rootScope.isWebsocketLoading   = true;

                socket = io(coreUrl, { // eslint-disable-line
                    'query'      : 'token=' + currentToken,
                    'transports' : [ 'websocket' ]
                });

                socket.on('connect_timeout', function() {
                    $timeout(function() {
                        $rootScope.isWebsocketLoading   = false;
                        $rootScope.isWebsocketConnected = false;
                        $rootScope.websocket            = null;
                    });
                });

                socket.on('error', function() {
                    console.error('Erro'); // eslint-disable-line
                });

                socket.on('connect_error', function() {
                    $timeout(function() {
                        var errorObj = {
                            'error': 'CONNECTION_ERROR'
                        };

                        $rootScope.isWebsocketLoading   = false;
                        $rootScope.isWebsocketConnected = false;
                        $rootScope.websocket            = null;

                        $rootScope.$broadcast('PLING-WEBSOCKET-ERROR', errorObj);
                    });
                });

                socket.on('connect', function() {
                    var self = this;

                    $rootScope.websocket            = self;
                    $rootScope.isWebsocketConnected = true;
                    $rootScope.isWebsocketLoading   = false;

                    return cb();
                });

                socket.on('reconnecting', function() {
                    $timeout(function() {
                        $rootScope.isWebsocketConnected = false;
                        $rootScope.isWebsocketLoading   = true;
                        $rootScope.websocket            = null;
                    });
                });

                socket.on('reconnect_error', function() {
                    $timeout(function() {
                        $rootScope.isWebsocketLoading   = false;
                        $rootScope.isWebsocketConnected = false;
                        $rootScope.websocket            = null;
                    });
                });

                socket.on('error', function() {
                    $timeout(function() {
                        $rootScope.isWebsocketLoading   = false;
                        $rootScope.isWebsocketConnected = false;
                        $rootScope.websocket            = null;
                    });
                });

            } catch (err) {
                $timeout(function() {
                    $rootScope.isWebsocketLoading   = false;
                    $rootScope.isWebsocketConnected = false;
                    $rootScope.websocket            = null;
                });
            }
        };

        this.send = function(channel, message) {
            if (!$rootScope.websocket) throw new Error('Websocket is null');

            socket.emit(channel, message);
        };

        this.setRedisListener = function(channel) {
            var redisMessage = {
                'action'         : 'setListener',
                'sender'         : credentialsService.getLocal(),
                'customerChannel': 'chat:customer:' + credentialsService.getLocal().customer_id,
                'channel'        : channel
            };

            this.send(redisMessage.customerChannel, redisMessage);
        };

        this.setRealTimeListener = function(channel, cbListener) {
            this.setRedisListener(channel);
            $rootScope.websocket.removeListener(channel);
            $rootScope.websocket.on(channel, cbListener);
        };
    }

}());

(function (context, logger) {
    'use strict';

    // creating namespace
    function Bootstrapper() {
        this.isBootstrapped = false;
    }

    // boot a module
    Bootstrapper.prototype.Angular = function (root, appname, source, cb) {
        var self = this;

        window.localStorage.setItem('PLING-CURRENT-APP', appname);

        // loading file
        context.loader.load(source, function (err, options) {

            options.core_url = options.environment === 'local' ? options.local_core_url || options.core_url
                                                               : options.core_url;

            var // eslint-disable-line
                token         = window.localStorage['PLING-TOKEN'],
                coreUrl       = options.core_url,
                environment   = options.environment,
                defApiVersion = options.def_api_version,
                initInjector  = angular.injector(['ng']),
                $http         = initInjector.get('$http'),
                currentUrl    = window.location.href,
                localCallbackUrl;

            window.localStorage.setItem('PLING-CURRENT-ENV', environment);

            // checking errors...
            if (err) {
                logger.warn('Arquivo de configuracao nao encontrado!');
                logger.debug(err);

                return false;
            }

            // No authentication
            if ('auth' in options && options.auth === false) {
                window.localStorage.setItem('PLING-TOKEN', false);

                // saving boot settings
				angular.module(appname).value('boot.options', options); // eslint-disable-line

				// starting app
                angular.bootstrap(root, [appname]);
                self.isBootstrapped = true;

				// calling callback
                if (cb) cb();
                return false;
            }

            // if there's no token it must redirect to login
            if (!token && coreUrl) {
                window.localStorage.clear();
                localCallbackUrl = currentUrl ? '?callbackurl=' + currentUrl : '';

                $http
                    .get(coreUrl + defApiVersion + '/products/Login')
                    .success(function(urlData) {
                        window.location.href = urlData.data.callbackUrl + localCallbackUrl;
                        return false;
                    })
                    .error(function(reason) {
                        logger.error(reason);
                        return false;
                    });
            }

            // else it must validate it and then start the application
            else {

                // get s3 config
                $http
                    .get(coreUrl + defApiVersion + '/backoffice/aws/s3-config')
                    .success(function(s3Config) {
                        options.s3Aws = s3Config;

                        $http
                            .get(coreUrl + defApiVersion + '/backoffice/accounts/me' + '?appmodule=' + appname + '&environment=' + environment, {
                                'headers': { 'Authorization': token }
                            })
                            .success(function(credentialData) {

                                if (credentialData.viewPreferences)
                                    window.localStorage.setItem('PLING-CURRENT-VIEW-PREFERENCES', JSON.stringify(credentialData.viewPreferences));

                                delete credentialData.profilesProducts;
                                delete credentialData.iat;
                                delete credentialData.exp;

                                window.localStorage.setItem('PLING-USER', JSON.stringify(credentialData));

                                if (credentialData.email.indexOf('pling') === -1) {
                                    $http
                                    .get(coreUrl + defApiVersion + '/accounts/products/Login/' + environment)
                                    .success(function(urlData) {
                                        window.location.href = urlData.callbackUrl + localCallbackUrl;
                                        return false;
                                    })
                                    .error(function(reason) {
                                        logger.error(reason);
                                        return false;
                                    });
                                }

                                // saving boot settings
                                angular.module(appname).value('boot.options', options); // eslint-disable-line

                                // starting app
                                angular.bootstrap(root, [appname]);
                                self.isBootstrapped = true;

                                // calling callback
                                if (cb) return cb();
                            })
                            .error(function(reason) {
                                logger.error(reason);
                                window.localStorage.clear();
                                localCallbackUrl = currentUrl ? '?callbackurl=' + currentUrl : '';
                                $http
                                    .get(coreUrl + defApiVersion + '/accounts/products/Login/' + environment)
                                    .success(function(urlData) {
                                        window.location.href = urlData.callbackUrl + localCallbackUrl;
                                        return false;
                                    })
                                    .error(function(reason) {
                                        logger.error(reason);
                                        return false;
                                    });
                            });
                    })
                    .error(function(reason) {
                        logger.error(reason);
                        window.localStorage.clear();
                        localCallbackUrl = currentUrl ? '?callbackurl=' + currentUrl : '';
                        $http
                            .get(coreUrl + defApiVersion + '/accounts/products/Login/' + environment)
                            .success(function(urlData) {
                                window.location.href = urlData.callbackUrl + localCallbackUrl;
                                return false;
                            })
                            .error(function(reason) {
                                logger.error(reason);
                                return false;
                            });
                    });
            }
        });
    };

    // creating instance
    context.boot = new Bootstrapper();

}(window.pling, window.console));

(function (dom, logger, context) {
    'use strict';

    // Content Loaded listener
    function onDOMLoaded() {

        // detect angular application 'directive'
        var root,
            directive = 'plg-app',
            source    = 'src',
            filter    = '[' + directive + ']';

        // retrieving root element
        root = dom.querySelector(filter);

        // working on root
        if (root) {

            // retrieving app name
            context.name   = root.getAttribute(directive);
            context.source = root.getAttribute(source) || 'pling.conf.json';

            // loading config file
            context.boot.Angular(root, context.name, context.source, function (err) {
                if (err)
                    logger.error('Could not boot app ', context.name);
            });

        }
    }

    dom.addEventListener('DOMContentLoaded', onDOMLoaded);

}(document, window.console, window.pling));

(function (context) {
    'use strict';

    // creating namespace
    function ConfLoader() {
        this.settings = null;
    }

    // loading file
    ConfLoader.prototype.load = function (filepath, cb) {
        var self = this,
            parsed,
            xhr = new XMLHttpRequest(); // eslint-disable-line

        // sending result
        xhr.onreadystatechange = function () {
            if (xhr.readyState === 4) {
                if (xhr.status === 200) {

                    parsed = JSON.parse(xhr.responseText);
                    self.settings = parsed;

                    cb(null, parsed);
                } else {
                    cb('Error loading file - status ' + xhr.status, {});
                }
            }
        };

        // handling error
        xhr.onerror = function (err) {
            cb(err);
        };

        // fetching file
        xhr.open('GET', filepath, true);
        xhr.setRequestHeader('Content-Type', 'application/json;charset=UTF-8');
        xhr.send();
    };

    // creating instance
    context.loader = new ConfLoader();
}(window.pling));

(function () {
    'use strict';

    angular
        .module('plingUi')
        .factory('plgAttachmentFactory', plgAttachmentFactory);

    function plgAttachmentFactory() {

        return {
            'validateConfig': function (scope) {
                var config = scope.config || {};

                config.limit_size      = config.limit_size      || 1048576;
                config.extension_regex = config.extension_regex || /\.(jpe?g|png|gif|bmp|pdf|word|txt)$/i;

                scope.config = config;
            },
            'validateAttach': function (file, event, scope) {
                if (file) {
                    if (file.size > scope.config.limit_size) {
                        scope.onUpload('O tamanho do anexo excede o limite permitido', null, angular.noop);
                        return false;
                    }

                    if ( scope.config.extension_regex.test(file.name) === false ) {
                        scope.onUpload('Extensão do arquivo inválida.', null, angular.noop);
                        return false;
                    }

                    scope.onUpload(null, { 'status': 'validated' }, angular.noop);
                    return true;
                }
                return false;
            },
            'buildFormData': buildFormData,
            'removeFile': function (fds, scope) {
                return function (files, file) {
                    removeFds(fds, file);
                    scope.formData = buildFormData(fds);

                    if (!scope.onUpload) return remove(files, file);

                    scope.onUpload(null, {
                        'status': 'remove', 'data': file
                    }, function (isDone) {
                        remove(files, file, isDone);
                    });
                };
            }
        };

        function remove(files, file, isDone) {
            var index = files.indexOf(file);

            file.isLoader = false;

            if (typeof isDone === 'boolean' && isDone || typeof isDone !== 'boolean') {
                files.splice(index, 1);
            }

        }

        function removeFds(fds, file) {
            fds.forEach(function (fd, i) {
                if (fd.get('file') === file)
                    fds.splice(i, 1);
            });
        }

        function buildFormData(fds) {
            var formData = new FormData();//eslint-disable-line

            fds.map(function (fd) {
                formData.append('file', fd.get('file'));
            });

            return formData;
        }
    }
}());

(function () {
    angular.module('plingUi').directive('plgAttachment', PlgAttachment);

    PlgAttachment.$inject = ['plgAttachmentFactory'];

    function PlgAttachment(plgAttachmentFactory) {

        return {
            'restrict'    : 'E',
            'scope'       : {
                // { 'limit_size': 1000, 'extension_regex': /\.(jpe?g|png|gif|bmp|pdf|word|txt)$/i }
                'config': '=?',
                // (err, status) => status === { 'status': 'validated' } || { 'status': 'file', 'data': file }
                'onUpload': '=?',
                'formData': '=?'
            },
            'templateUrl' : 'plg-attachment.html',
            'link'     : function compile(scope) {
                var fds = [];  //eslint-disable-line
                scope.files = [];

                scope.selectFile = function () {
                    var clickEvent = new MouseEvent('click', {//eslint-disable-line
                        'view': window,
                        'bubbles': true,
                        'cancelable': false
                    });
                    setTimeout(function() {
                        document.getElementById('file').dispatchEvent(clickEvent);
                    });
                };
                scope.newAttachSave = function (event) {

                    scope.onUpload = scope.onUpload || angular.noop;
                    plgAttachmentFactory.validateConfig(scope);

                    if (plgAttachmentFactory.validateAttach(event.target.files[0], event, scope)) {
                        fds.push(new FormData());  //eslint-disable-line

                        fds[fds.length - 1].append('file', event.target.files[0]);

                        scope.$apply(function () {
                            scope.formData = plgAttachmentFactory.buildFormData(fds);
                            scope.files.push(event.target.files[0]);
                        });

                        scope.onUpload(null, { 'status': 'file', 'data': event.target.files[0] }, angular.noop);
                    }
                };

                scope.removeFile = plgAttachmentFactory.removeFile(fds, scope);

                setTimeout(function() {
                    document.getElementById('file').addEventListener('change', scope.newAttachSave);
                });
            }
        };
    }
}());
(function () {

    plgAutoFocusDirective.$inject = [ '$timeout' ];

    angular
        .module('plingUi')
        .directive('plgAutoFocus', plgAutoFocusDirective);

    function plgAutoFocusDirective ($timeout) {
        return {
            'link': function (scope, element, attrs) {
                attrs.$observe('plgAutoFocus', function(newValue) {
                    if (newValue === 'true')
                        $timeout(function() { element[0].focus(); });
                });
            }
        };
    }

}());
(function () {
    'use strict';

    angular
        .module('plingUi')
        .directive('plgAutosave', PlgAutosave);

    PlgAutosave.$inject = [ '$rootScope', '$animate', '$mdUtil', '$timeout', '$compile', 'credentialsService' ];

    function PlgAutosave($rootScope, $animate, $mdUtil, $timeout, $compile, credentialsService) {
        return {
            'restrict' : 'A',
            'require' : ['ngModel', '^mdInputContainer'],
            'link' : linkElem
        };

        function linkElem (scope, element, attrs, ctrls) {
            var maxlength, minlength;
            var ngModelCtrl = ctrls[0];
            var containerCtrl = ctrls[1];
            var charCountEl, errorsSpacer, renderCharCount;
            var timeoutSave, firstFieldValue;
            var valueLoaded = false;

            element.on('input keydown keyup', function() {
                var modelValue = ngModelCtrl.$modelValue;

                valueLoaded = true;

                if (attrs.plgType && modelValue) {
                    if (attrs.plgType === 'number')
                        modelValue = modelValue.replace(/[^0-9]+/g, '');

                    if (attrs.plgType === 'text')
                        modelValue = modelValue.replace(/[^a-zA-Z]+/g, '');

                    ngModelCtrl.$setViewValue(modelValue);
                    ngModelCtrl.$render();
                }

                if (timeoutSave)
                    $timeout.cancel(timeoutSave);

                // atualiza indicadores de limite de caracteres
                if (attrs.plgMaxlength || attrs.plgMinlength)
                    renderCharCount();

                // quando inativo por 5s salva
                if (ngModelCtrl.$valid && attrs.plgAutosave) {
                    timeoutSave = $timeout(function() {
                        saveField(true);
                    }, 5000);
                }
            });

            element.on('blur', function() {
                if (attrs.type === 'nickname') {
                    if (credentialsService.getLocal().id === scope.user._id)
                        $rootScope.$broadcast('PLING-ALL-BAR-UPDATE-CREDENTIAL', {'nickname': ngModelCtrl.$modelValue, 'image': scope.imageUrl });

                    attrs.plgSucessMessage = 'Apelido alterado com sucesso.';
                }
                // cancela timeout de salvamento automatico quando campo inativo por X tempo
                if (timeoutSave)
                    $timeout.cancel(timeoutSave);

                if (firstFieldValue === ngModelCtrl.$modelValue)
                    return;

                // salva imediatamente quando último input do form
                if ('plgLastInput' in attrs && ngModelCtrl.$valid) {
                    saveField(true);
                    return;
                }

                if (ngModelCtrl.$valid)
                    timeoutSaveField();

                if ((attrs.plgMaxlength || attrs.plgMinlength || attrs.required) && ngModelCtrl.$invalid) {
                    ngModelCtrl.$setViewValue(firstFieldValue || '');
                    ngModelCtrl.$render();

                    if (attrs.plgMaxlength || attrs.plgMinlength)
                        renderCharCount();
                }
            });

            // toast com opcao de desfazer, aguarda callback e exibe mensagem de sucesso
            function timeoutSaveField() {
                var toastObj = {
                    'message' : attrs.plgSucessMessage || 'Salvo com sucesso.',
                    'button'  : true,
                    'cb'      : function(status) {
                        if (status === 'cancel') {
                            if (attrs.type === 'nickname' && credentialsService.getLocal().id === scope.user._id)
                                $rootScope.$broadcast('PLING-ALL-BAR-UPDATE-CREDENTIAL', { 'nickname': firstFieldValue, 'image': scope.imageUrl });
                            ngModelCtrl.$setViewValue(firstFieldValue || '');
                            ngModelCtrl.$render();
                        } else {
                            saveField(false);
                        }
                    }
                };

                if (attrs.plgAutosave)
                    $rootScope.$broadcast('TOAST-ACTION', toastObj);
            }

            // chama funcao para salvar campo
            function saveField(showMessage) {
                if (timeoutSave)
                    $timeout.cancel(timeoutSave);

                if (firstFieldValue === ngModelCtrl.$modelValue)
                    return;

                if (attrs.plgAutosave) {
                    scope.$apply(function() {
                        scope.$eval(attrs.plgAutosave)(ngModelCtrl.$name, ngModelCtrl.$modelValue, function saveCallback(err) {
                            var toastObj = { 'cb' : function() {} };

                            if (err) {
                                toastObj.message = attrs.plgErrorMessage || 'Ocorreu um erro ao salvar o campo.';
                                $rootScope.$broadcast('TOAST-ACTION', toastObj);
                            } else {
                                if (showMessage) {
                                    toastObj.message = attrs.plgSucessMessage || 'Salvo com sucesso.';
                                    $rootScope.$broadcast('TOAST-ACTION', toastObj);
                                }
                                firstFieldValue = angular.copy(ngModelCtrl.$modelValue);
                            }
                        });
                    });
                }
            }

            function getContainerMessages (messages) {
                var i;
                var formName = ngModelCtrl.$$parentForm ? ngModelCtrl.$$parentForm.$name : '';
                var errorMessageHtml = '<div ng-messages="' + formName + '.' + ngModelCtrl.$name + '.$error">';

                for (i=0; i<messages.length; i++)
                    errorMessageHtml += '<div class="animate-hide" ng-message="' + messages[i].key + '">' + messages[i].text + '</div>';

                errorMessageHtml += '</div>';
                return angular.element(errorMessageHtml);
            }

            function elemBinded() {
                var messages = [], divMessages;
                var parentContainer = element.parent();

                if (attrs.uiMask)
                    messages.push({'key': 'mask', 'text': attrs.plgMessage || 'Campo obrigatório.'});
                else {
                    if (attrs.required && !attrs.plgMinlength)
                        messages.push({'key':'required', 'text': 'Campo obrigatório.'});

                    if (attrs.plgMinlength)
                        messages.push({'key':'plg-minlength', 'text': 'Mínimo ' + attrs.plgMinlength + ' caracteres.'});

                    if (attrs.plgMaxlength)
                        messages.push({'key':'plg-maxlength', 'text': 'Máximo ' + attrs.plgMaxlength + ' caracteres.'});
                }

                if (messages.length > 0 && ngModelCtrl.$$parentForm) {
                    divMessages = getContainerMessages(messages);
                    $(parentContainer).append(divMessages);
                    $compile(divMessages)(scope);
                }

                // Wait until the next tick to ensure that the input has setup the errors spacer where we will
                // append our counter
                $mdUtil.nextTick(function() {
                    // Indicadores de tamanho corrente, minimo e maximo do campo
                    if (attrs.plgMaxlength || attrs.plgMinlength) {
                        firstFieldValue = angular.copy(ngModelCtrl.$modelValue);
                        errorsSpacer = angular.element(containerCtrl.element[0].querySelector('.md-errors-spacer'));
                        charCountEl = angular.element('<div class="md-char-counter">');

                        // Append our character counter inside the errors spacer
                        errorsSpacer.append(charCountEl);

                        // Stop model from trimming. This makes it so whitespace
                        // over the maxlength still counts as invalid.
                        attrs.$set('ngTrim', 'false');

                        ngModelCtrl.$formatters.push(renderCharCount);
                        ngModelCtrl.$viewChangeListeners.push(renderCharCount);

                        if (attrs.plgMaxlength) {
                            scope.$watch(attrs.plgMaxlength, changeMaxLength);

                            ngModelCtrl.$validators['plg-maxlength'] = function(modelValue, viewValue) {
                                if (!angular.isNumber(maxlength) || maxlength < 0)
                                    return true;
                                return ( modelValue || element.val() || viewValue || '' ).length <= maxlength;
                            };
                        }

                        if (attrs.plgMinlength) {
                            scope.$watch(attrs.plgMinlength, changeMinLength);

                            ngModelCtrl.$validators['plg-minlength'] = function(modelValue, viewValue) {
                                if (!angular.isNumber(minlength) || minlength < 0)
                                    return true;
                                return ( modelValue || element.val() || viewValue || '' ).length >= minlength;
                            };
                        }
                    }
                    if (attrs.required)
                        firstFieldValue = angular.copy(ngModelCtrl.$modelValue);
                });

                scope.$watch(attrs.ngModel, function() {
                    if (!valueLoaded && !firstFieldValue && ngModelCtrl.$modelValue) {
                        firstFieldValue = angular.copy(ngModelCtrl.$modelValue);
                        valueLoaded = true;
                    }
                });

                function changeMaxLength(value) {
                    maxlength = value;
                    if (angular.isNumber(value) && value > 0) {
                        if (!charCountEl.parent().length) {
                            $animate.enter(charCountEl, errorsSpacer);
                        }
                        renderCharCount();
                    } else {
                        $animate.leave(charCountEl);
                    }
                }

                function changeMinLength(value) {
                    minlength = value;
                    if (angular.isNumber(value) && value >= 0) {
                        if (!charCountEl.parent().length) {
                            $animate.enter(charCountEl, errorsSpacer);
                        }
                        renderCharCount();
                    } else {
                        $animate.leave(charCountEl);
                    }
                }

                renderCharCount = function(value) {
                    // If we have not been appended to the body yet; do not render
                    if (!charCountEl.parent)
                        return value;

                    // Force the value into a string since it may be a number,
                    // which does not have a length property.
                    if (attrs.plgMaxlength && attrs.plgMinlength)
                        charCountEl.text(String(element.val() || value || '').length + ' / ' + minlength + ' / ' + maxlength);

                    if (attrs.plgMaxlength && !attrs.plgMinlength)
                        charCountEl.text(String(element.val() || value || '').length + ' / ' + maxlength);

                    if (!attrs.plgMaxlength && attrs.plgMinlength)
                        charCountEl.text(String(element.val() || value || '').length + ' / ' + minlength + ' / ' + (maxlength || 255));

                    return value;
                };
            }

            (function init() {
                elemBinded();
            })();

        }
    }

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .directive('plgBackImg', PlgBackgroundImageDirective);

    PlgBackgroundImageDirective.$inject = [];

    function PlgBackgroundImageDirective() {
        return {
            'link': function (scope, element, attrs) {
                attrs.$observe('plgBackImg', function(url) {
                    element.css({
                        'background-image': 'url(' + url + ')',
                        'background-size' : 'cover'
                    });
                });
            }
        };
    }

}());

(function () {
    angular.module('plingUi').directive('plgBackdrop', PlgBackdrop);

    function PlgBackdrop() {

        function updateStyle(scope) {
            scope.style = {
                'opacity': (scope.opacity || 48) * 0.01,
                'z-index': scope.zIndex || 5
            };
        }

        return {
            'restrict': 'EA',
            'scope'   : {
                'id'      : '@?',
                'on'      : '=?',
                'opacity' : '=?',
                'zIndex'  : '=?',
                'click'   : '&'
            },
            'template': '<div class="back-drop" ng-show="on" ng-style="style" ng-click="click()"></div>',
            'compile' : function compile() {
                return {
                    'pre': function(scope) {
                        updateStyle(scope);
                    },
                    'post': function(scope) {
                        scope.id = scope.id || 'BACK_DROP';
                        scope.$on(scope.id + '_ON', function () {
                            scope.on = true;
                        });
                        scope.$on(scope.id + '_OFF', function () {
                            scope.on = false;
                        });
                        scope.$watch('opacity', function (newValue, oldValue) {
                            if (newValue !== oldValue)
                                updateStyle(scope);
                        });
                    }
                };
            }
        };
    }
}());
(function () {

    'use strict';

    angular
        .module('plingUi')
        .component('plgCalendar', {
            'transclude'  : true,
            'controller'  : PlgCalendarCtrl,
            'templateUrl' : 'plg-calendar.html',
            'bindings': {
                'monthsLimit'        : '=',
                'selected'           : '=',
                'shared'             : '=',
                'disableRange'       : '=',
                'disableOptions'     : '=?',
                'disableDateInit'    : '=?',
                'disableEvents'      : '=?',
                'idEvent'            : '=?',
                'forceInit'          : '=?',
                'dayClass'           : '@?',
                'containerClass'     : '@?',
                'onBags'             : '&?',
                'events'             : '='
            }
        });

    PlgCalendarCtrl.$inject = [
        '$scope', '$rootScope', '$attrs', 'plgCalendarFactory', '$mdMenu'
    ];

    function PlgCalendarCtrl($scope, $rootScope, $attrs, plgCalendarFactory, $mdMenu) {
        var ctrl = this,
            i,
            currentMoment = moment(Date.now()),
            todayDate     = moment(currentMoment),
            secondClick   = false,
            fromDateCopy,
            currentDate,
            onClose,
            months = ['Janeiro', 'Fevereiro', 'Março', 'Abril', 'Maio', 'Junho', 'Julho', 'Agosto', 'Setembro', 'Outubro', 'Novembro', 'Dezembro'],
            broadcastEventUpdate = ctrl.idEvent ? 'PLGCALENDAR_UPDATE' + ctrl.idEvent : 'PLGCALENDAR_UPDATE',
            broadcastMenuClose   = ctrl.idEvent ? 'PLGCALENDAR_CLOSE' + ctrl.idEvent : 'PLGCALENDAR_CLOSE',
            user = JSON.parse(window.localStorage['PLING-USER'] || {});

        ctrl.selected  = ctrl.selected && ctrl.selected.fromDate && ctrl.selected.toDate ? ctrl.selected : { 'fromDate': currentMoment.format('YYYY-MM-DD'), 'toDate': currentMoment.format('YYYY-MM-DD') };
        ctrl.selected  = ctrl.disableDateInit ? {} : ctrl.selected;
        ctrl.weekDays  = ['Domingo', 'Segunda', 'Terça', 'Quarta', 'Quinta', 'Sexta', 'Sábado'];
        ctrl.weekDaysMin  = ['D', 'S', 'T', 'Q', 'Q', 'S', 'S'];
        ctrl.todayYear = currentMoment.format('YYYY');
        ctrl.onBags = function (objDate) {
            var output = [], j;

            if (objDate.events) {
                for (j = objDate.events.length - 1; j >= 0; j--) {
                    if (!isDone(objDate.events[j])) {
                        output.push(objDate.events[j]);
                    }
                }
            }

            return output.length;
        };

        if (!ctrl.disableEvents)
            $rootScope.$broadcast(broadcastEventUpdate, ctrl.selected, currentMoment);

        if (ctrl.forceInit) {
            ctrl.daysInMonth = plgCalendarFactory.getDaysInMonths(ctrl.daysInMonth, ctrl.monthsLimit, currentMoment, ctrl.events);
        }

        if (!ctrl.disableDateInit)
            buildDisplay();

        function buildDisplay() {
            ctrl.selected.display = moment(ctrl.selected.fromDate).format('DD/MM/YYYY') + (ctrl.selected.toDate ? ' - ' + moment(ctrl.selected.toDate).format('DD/MM/YYYY') : '');
        }

        /* Responsable to update bindings values in the view */
        function updateValues(isDayChanged, isMonthOrYearChange) {
            ctrl.todayYear   = currentMoment.format('YYYY');
            ctrl.daysInMonth = plgCalendarFactory.getDaysInMonths(ctrl.daysInMonth, ctrl.monthsLimit, currentMoment, ctrl.events);
            if (!ctrl.disableEvents)
                $rootScope.$broadcast(broadcastEventUpdate, ctrl.selected, currentMoment, isDayChanged, isMonthOrYearChange);
        }

        /* Responsable to get the full date in format YYYY-MM-DD */
        function getCurrentDate(day, i) {
            return moment(currentMoment).add(i, 'month').date(day).format('YYYY-MM-DD');
        }

        /* Responsable to convert integer number to array */
        function convertIntegerToArray(n) {
            var range = [];

            for (i = 0; i < n && i < 12; i++) {
                range.push(i);
            }
            return range;
        }

        function changeDay(typeDate) {
            currentDate = angular.copy(currentMoment);
            if (typeDate === 'day') {
                ctrl.selected.fromDate = currentMoment.format('YYYY-MM-DD');
                ctrl.selected.toDate   = currentMoment.format('YYYY-MM-DD');
                updateValues(true, false);
            } else if (typeDate === 'week') {
                ctrl.selected.fromDate = currentDate.startOf('isoWeek').subtract(1, 'day').format('YYYY-MM-DD');
                ctrl.selected.toDate   = ctrl.selected.fromDate;
                updateValues(true, false);
            } else {
                ctrl.selected.fromDate = currentDate.startOf('month').format('YYYY-MM-DD');
                ctrl.selected.toDate   = currentDate.startOf('month').format('YYYY-MM-DD');
                updateValues(false, true);
            }
        }

        function isDone(agendaEvent) {
            return agendaEvent.logs && agendaEvent.logs.length > 0 && !agendaEvent.logs.every(function (l) {
                return l.credential_id !== user.id || l.status !== 'done';
            });
        }

        /* Select the date that user clicked */
        ctrl.selectDate = function (day, i) {
            currentDate = currentMoment.add(i, 'months').date(day);

            if (!ctrl.disableRange) {
                if (!secondClick) {
                    ctrl.selected.fromDate = currentDate.format('YYYY-MM-DD');
                    ctrl.selected.toDate   = currentDate.format('YYYY-MM-DD');
                } else {
                    ctrl.selected.toDate = currentDate.format('YYYY-MM-DD');
                }

                if (ctrl.selected.fromDate > ctrl.selected.toDate) {
                    fromDateCopy  = ctrl.selected.fromDate;
                    ctrl.selected.fromDate = ctrl.selected.toDate;
                    ctrl.selected.toDate   = fromDateCopy;
                }
            } else {
                ctrl.selected.fromDate = currentDate.format('YYYY-MM-DD');
                ctrl.selected.toDate   = currentDate.format('YYYY-MM-DD');
            }

            buildDisplay();

            secondClick = !secondClick;

            updateValues(true);

            if (ctrl.disableRange)
                $mdMenu.hide();
        };

        /* Get days in month by int params i (exp.: currentMonth + 1) */
        ctrl.getDaysInMonth = function (i, wantFullDay) {
            var month    = moment(currentMoment).add(i, 'months'),
                days     = month.daysInMonth(),
                firstDay = moment(month).date(1).day(),
                arr      = [],
                position,
                day;

            for (position = 1; position <= firstDay + days; position += 1) {

                day = position > firstDay ? position - firstDay : false;

                if (wantFullDay && day !== false) {
                    day = getCurrentDate(day, i);
                }

                arr.push(day);
            }

            return arr;
        };

        /* Set the current month */
        ctrl.setToday = function (subtractType, days) {
            secondClick = false;

            currentMoment = moment(todayDate);

            if (subtractType) {
                if (days < 0)
                    currentMoment.subtract(Math.abs(days), subtractType);
                else
                    currentMoment.add(days, subtractType);
                if (!ctrl.disableRange) {
                    ctrl.selectDate(currentMoment.date(), 0);
                    return ctrl.selectDate(moment(todayDate).date(), 0);
                }
            }

            ctrl.selectDate(currentMoment.date(), 0);
            ctrl.selectDate(currentMoment.date(), 0);
        };

        /* Set the current month */
        ctrl.setThisMonth = function () {
            secondClick = false;

            ctrl.selectDate(1, 0);
            ctrl.selectDate(moment(currentMoment).daysInMonth(), 0);
        };

        /* Set the current year */
        ctrl.setThisYear = function () {
            secondClick = false;

            ctrl.selectDate(1, currentMoment.format('M') * -1 + 1);
            ctrl.selectDate(moment(currentMoment).add(12 - currentMoment.format('M')).daysInMonth(), 12 - currentMoment.format('M'));
        };

        /* Get the month format by number */
        ctrl.getMonth = function (i, format) {
            var month = moment(currentMoment).add(i, 'months');

            if (months && months.length > 0 && months[+month.format('M') - 1])
                month = months[+month.format('M') - 1];
            else
                month = month.format(format || 'MM');

            return month;
        };

        /* Check if the day is selected by day and month */
        ctrl.isSelected = function (day, i) {
            return getCurrentDate(day, i) === ctrl.selected.fromDate || getCurrentDate(day, i) === ctrl.selected.toDate;
        };

        /* Check if the day is in range by day and month number */
        ctrl.isInRange = function (day, i) {
            return getCurrentDate(day, i) > ctrl.selected.fromDate && getCurrentDate(day, i) < ctrl.selected.toDate;
        };

        /* Check if is today */
        ctrl.isToday = function (day, i) {
            return getCurrentDate(day, i) === moment().format('YYYY-MM-DD');
        };

        /* Go to the next month or year */
        ctrl.nextDate = function (typeDate) {
            currentMoment.add(1, typeDate);
            changeDay(typeDate);
        };

        /* Go to the previous month or year */
        ctrl.prevDate = function (typeDate) {
            currentMoment.subtract(1, typeDate);
            changeDay(typeDate);
        };

        ctrl.getCurrentWeek = function () {
            var week = [];

            for (i = 0; i <= 6; i += 1)
                week.push(moment(currentMoment, 'YYYY-MM-DD').day(i));
            return week;
        };

        /* Define Shared methods */
        if ($attrs.shared) {
            delete ctrl.shared;
            delete ctrl.events;
            ctrl.shared = angular.copy(ctrl);
        }

        $scope.$watch(function () {
            return ctrl.events;
        }, function (newVal) {
            if (newVal) {
                ctrl.daysInMonth = plgCalendarFactory.getDaysInMonths(ctrl.daysInMonth, ctrl.monthsLimit, currentMoment, newVal);
            }
        });

        $rootScope.$on('$mdMenuClose', function() {
            window.clearTimeout(onClose);
            onClose = setTimeout(function() {
                $rootScope.$broadcast(broadcastMenuClose, ctrl.selected);
            }, 50);
        });

        $rootScope.$on('PLGCALENDAR_SET_TODAY', function() {
            ctrl.setToday();
        });

        $rootScope.$on('PLGCALENDAR_EVENTS_UPDATED', function() {
            if (ctrl.events) {
                ctrl.daysInMonth = plgCalendarFactory.getDaysInMonths(ctrl.daysInMonth, ctrl.monthsLimit, currentMoment, ctrl.events);
            }
        });

        ctrl.monthsNumbers = convertIntegerToArray(ctrl.monthsLimit);
    }
}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .directive('plgChangeIconView', PlgChangeIconView);

    PlgChangeIconView.$inject = [
        '$log', '$compile', '$rootScope'
    ];

    function PlgChangeIconView($log, $compile, $rootScope) {
        return {
            'restrict': 'E',
            'scope'   : {
                'obj': '=',
                'serviceModule': '='
            },
            'replace': true,
            'link'   : function (scope, element) {

                var builder, compiledElm;

                // validating bind value
                if (scope.obj) {
                    builder = {
                        'buildTemplate': function (scope, cb) {
                            var template;

                            scope.viewListSelected  = this.viewListSelected;
                            scope.changeIcon        = this.changeIcon;

                            // Update value to default, if click previous ou next page in pagination DATATABLE
                            scope.$watch('obj', function() {
                                scope.iconView          = 'expand_more';
                                scope.iconViewLabel     = 'Expandir linha';
                            });

                            template =  '<md-button class="md-icon-button" aria-label="expand" ng-click="viewListSelected(obj, serviceModule.isExpandLineList); changeIcon(iconView)">' +
                                        '    <md-tooltip>{{iconViewLabel}}</md-tooltip>' +
                                        '    <md-icon class="icons" aria-hidden="true">{{iconView}}</md-icon>' +
                                        '</md-button>';

                            cb(null, template);
                        },

                        'changeIcon': function (iconLabel) {
                            if (iconLabel === 'expand_more') {
                                scope.iconView = 'expand_less';
                                scope.iconViewLabel = 'Retrair linha';
                            } else {
                                scope.iconView = 'expand_more';
                                scope.iconViewLabel = 'Expandir linha';
                            }
                        },

                        // View effect collapse "open/closed"
                        'viewListSelected': function (obj, visualize) {
                            if (visualize) {
                                $rootScope.$emit('viewListSelected', obj);
                            }
                        }

                    };

                    // defining template
                    builder.buildTemplate(scope, function (err, template) {

                        // handling error
                        if (err) {
                            $log.warn(err);
                            return;
                        }

                        // compiling template
                        compiledElm = $compile(template)(scope);

                        // handling post compile hooks
                        if (builder.postCompile) {
                            builder.postCompile(compiledElm);
                        }

                        // replacing into DOM
                        element.replaceWith(compiledElm);

                    });
                }
            }
        };
    }
}());

(function () {

    // Busca usuarios e grupos
    // Campos: [name, nickname || fullname]
    angular
        .module('plingUi')
        .filter('plgNameFilter', plgNameFilterController);

    function plgNameFilterController () {
        return function(input, value) {
            var i = 0, len = input.length, foundList = [];

            for (; i < len; i++) {
                if (input[i].name && input[i].name.toLowerCase().indexOf(value) !== -1) {
                    foundList.push(input[i]);
                } else if (input[i].nickname && input[i].nickname.toLowerCase().indexOf(value) !== -1) {
                    foundList.push(input[i]);
                }
            }
            return foundList;
        };
    }

    angular
        .module('plingUi')
        .component('plgChat', {
            'bindings'    : {},
            'transclude'  : true,
            'controller'  : PlgChatCrl,
            'templateUrl' : 'plg-chat.html'
        });

    PlgChatCrl.$inject = [
        '$rootScope', '$scope', '$mdSidenav', '$timeout', '$localstorage', '$filter', '$location',
        'websocketService', 'chatService', 'chatFactory', 'credentialsService', 'sessionstorage', 'coreApiService', '$window'
    ];

    function PlgChatCrl($rootScope, scope, $mdSidenav, $timeout, $localstorage, $filter, $location,
        websocketService, chatService,  chatFactory, credentialsService, sessionstorage, coreApiService, $window) {

        var CHAT_ROOM_LOCAL_STORAGE = 'PLING-CHAT-ROOM-SHORTCUT';

        /**
         * Evento $broadcast para abrir ou fechar o sidepanel.
         */
        $rootScope.$on('PLING-TOGGLE-CHAT', function(ev, event) {

            $timeout(function() {
                scope.arrowUp = {
                    'left' : event[0].offsetLeft + 10 + 'px'
                };
            });

            toggleChat();
            if (scope.isChatConnected)
                chatStart(scope.isChatConnected);
        });

        /**
         * Inicializador
         */
        (function() {

            scope.visible = false;
            scope.maximized = false;

            scope.soundEnabled = true;

            // Se o Chat está carregando
            scope.isChatLoading = true;

            // Se o Chat está conectado
            scope.isChatConnected = sessionstorage.getObject('PLING-CHAT-CONNECTED');

            // Se existe algum erro
            scope.isError = false;

            // Define se o Chat já está conectado
            scope.isChatConnected = false;

            // Visibilidade do checkbox nos grupos
            scope.isShowGroupCheckBox = false;

            // Lista de salas de conversa
            scope.roomList = [];

            // Lista de usuários
            scope.peopleList = [];

            // Janelas de Chat Ativas (Bottom)
            scope.chatRoomList = [];

            // Lista de pessoas e conversas
            scope.peopleChatList = [];

            // Agrupador de conversas
            scope.activeChatGroup = [];

            // Contador de usuários selecionados p/ criação de Grupos
            scope.userGroups = { 'name': null, 'count' : 0, 'people': [] };

            // Usuário atual
            scope.currentUser = credentialsService.getLocal();

            scope.activeSection = 'users';

            // Visibilidade campo busca
            scope.showSearchInput = false;

            // Visibilidade campo nome fgrupo
            scope.showGroupInput  = false;

            // Focus nos inputs da topbar do chat
            scope.chatTopBarInputFocused = false;

            // Model input search
            scope.searchObj = { 'text': null };

            scope.screenWidth = document.documentElement.clientWidth;
            scope.chatWindowWidth = 302;
            scope.activeButtonWidth = 60;
            scope.chatRoomListLimit = Math.floor((scope.screenWidth - scope.activeButtonWidth) / scope.chatWindowWidth);

            scope.s3SoundUrlOgg = coreApiService.getS3Config().url + 'pling-public/assets/sounds/chat.ogg';
            scope.s3SoundUrlMp3 = coreApiService.getS3Config().url + 'pling-public/assets/sounds/chat.mp3';

            $timeout(function() {
                chatStart();
            });
        }());

        angular.element($window).bind('resize', function() {
            scope.handleChatListChanges();
        });

        scope.getTooltipUsersList = function(room) {
            return chatFactory.buildTooltipUsersList(room, scope.currentUser);
        };


        scope.$watch('chatRoomList', function (newVal, oldVal) {
            var ids = angular.copy(newVal.map(function(item) {
                return {
                    '_id' : item._id,
                    'isCollapsed' : item.isCollapsed
                };
            }));

            if (newVal !== oldVal) {
                chatService.openedRooms = JSON.stringify(ids);
                $localstorage.set(CHAT_ROOM_LOCAL_STORAGE, JSON.stringify(ids));
            }
        }, true);

        scope.changeChatSection = function(type) {
            scope.activeSection = type;
        };

        scope.toggleChatMode = function() {
            scope.maximized = !scope.maximized;
            scope.closeChat();
            if (scope.maximized)
                document.body.classList.add('plg-chat-maximized');
            else
                document.body.classList.remove('plg-chat-maximized');
        };

        scope.handleChatListChanges = function() {
            var removed = null;

            scope.chatRoomListLimit = Math.floor(($window.innerWidth - scope.activeButtonWidth) / scope.chatWindowWidth);

            while (scope.chatRoomList.length > scope.chatRoomListLimit) {
                removed = scope.chatRoomList.pop();
                scope.activeChatGroup.push(removed);
            }

            while (scope.chatRoomList.length < scope.chatRoomListLimit && scope.activeChatGroup.length > 0) {
                removed = scope.activeChatGroup.pop();
                scope.chatRoomList.push(removed);
            }

            handleBodyClassChange();

            scope.$apply();
        };

        scope.showTopBarInput = function(type) {
            switch (type) {
                case 'search':
                    scope.showGroupInput  = scope.chatTopBarInputGroupFocused  = false;
                    scope.showSearchInput = scope.chatTopBarInputSearchFocused = true;
                    break;
                case 'group':
                    scope.showSearchInput = scope.chatTopBarInputSearchFocused = false;
                    scope.showGroupInput  = scope.chatTopBarInputGroupFocused  = true;
                    scope.activeSection   = 'users';
                    break;
            }

        };

        scope.openMenu = function($mdOpenMenu, ev) {
            $mdOpenMenu(ev);
        };

        scope.toggleNotifications = function() {
            scope.notificationsEnabled = !scope.notificationsEnabled;
        };

        scope.toggleSound = function() {
            scope.soundEnabled = !scope.soundEnabled;
            chatService.setSoundNotificationStatus(scope.soundEnabled);
            $rootScope.toast(scope.soundEnabled ? 'Alertas sonoros ativados com sucesso.' : 'Alertas sonoros desativados com sucesso.');
        };

        scope.clearChatTopBarSelection = function() {
            $timeout(function() {

                // Limpa busca da caixa de texto para devolver a listagem completa
                scope.showSearchInput  = false;
                scope.chatTopBarInputSearchFocused = null;
                scope.searchObj.text = null;
                scope.searchTextChange('');

                // Limpa seleção de grupos'
                scope.showGroupInput = false;
                scope.chatTopBarInputGroupFocused = null;
                scope.cleanGroupSelection();

                initEmoji();
            });
        };


        /**
         * Funcção para colocar class no body quando há um chat ativo
         */
        function handleBodyClassChange() {
            if (scope.chatRoomList.length > 0) {
                document.body.classList.add('chat-active-item');
            } else {
                document.body.classList.remove('chat-active-item');
            }
        }


        /**
         * Inicialização do Chat - Redis, Websocket, Signin obtenção da lista de usuários/messages/groups.
         * @param {boolean} isConnected Define if the Chat is connected
         */
        function chatStart(isConnected) {
            websocketService.connect(function() {
                // Inicializando WebSocket Listener da empresa (customerId)
                chatService.setRealTimeListener(
                    'chat:customer:' + scope.currentUser.customer_id,
                    handleWebSocketMessage
                );

                // Listener do websocket do usuário da empresa (credentials)
                chatService.setRealTimeListener(
                    'chat:user:' + scope.currentUser.id,
                    handleWebSocketMessage
                );

                // Realizando Signin se não estiver conectado
                if (!isConnected) signin();
            });
        }

        function getUserColors(roomObj, skipSearchList) {
            var
                chat = {},
                colors = {},
                used = [];

            if (roomObj.colors)
                return roomObj.colors;

            if (skipSearchList !== true) {
                chat = $filter('filter')(scope.peopleChatList, { '_id' : roomObj._id})[0];
                if (chat && chat.colors)
                    return chat.colors;
            }

            if (roomObj.people && roomObj.people.length > 1) {
                colors[roomObj.owner._id] = generateRandomColor(used);
                used.push(colors[roomObj.owner._id]);
                roomObj.people.map(function(user) {
                    colors[user._id] = generateRandomColor(used);
                    used.push(colors[user._id]);
                });
            }
            return colors;
        }

        function generateRandomColor(usedColors) {
            var color = '#'+ ('000000' + Math.random().toString(16).slice(2, 8).toUpperCase()).slice(-6);

            if (usedColors && usedColors.length > 0 && usedColors.indexOf(color) >= 0)
                color = generateRandomColor(usedColors);
            return color;
        }

        /**
         * Realiza Signin no Core - Busca amigos e conversas
         */
        function signin() {
            chatService.signin()

                .error(function(reason) {
                    scope.isChatLoading = false;
                    $rootScope.toast(reason || 'Erro ao efetuar login, verifique sua conexão!', 5000);
                })

                .success(function(signinData) {
                    $timeout(function() {
                        var openedChats = [];

                        initEmoji();

                        // Setando lista de salas de conversa
                        scope.roomList = signinData.roomList;

                        // Setando lista de grupos e usuarios
                        scope.peopleChatList = $filter('orderBy')(signinData.peopleChatList, ['!lastMessageDate', '-lastMessageDate']);

                        scope.peopleChatList.map(function(item) {
                            // Lógica para usar Emoji na listagem
                            if (item.room && item.room.lastMessage && item.room.lastMessage.message && item.room.lastMessage.message.message)
                                item.room.lastMessage.message.message = $window.EmojiPicker.prototype.unicodeToImage(item.room.lastMessage.message.message);
                            else if (item.lastMessage && item.lastMessage.message)
                                item.lastMessage.message.message = $window.EmojiPicker.prototype.unicodeToImage(item.lastMessage.message.message);
                            item.colors = getUserColors(item, true);
                        });

                        // Definindo atributos extras (Imagem e Nome)
                        scope.roomList.map(setRoomAttributes);

                        // Setando lista de usuários
                        scope.peopleList = signinData.peopleList ? signinData.peopleList : [];

                        // Setando como conectado
                        scope.isChatConnected = true;
                        sessionstorage.setObject('PLING-CHAT-CONNECTED', true);

                        // Setando Websocket listener para cada ROOM
                        // Redis e WS
                        if ($rootScope.websocket && scope.isChatConnected)
                            setRoomArraySocketListener(scope.roomList);

                        scope.isChatLoading = false;

                        chatService.sendSignedIn();
                        chatService.sendDeliveryConfirmation(scope.roomList);
                        if ($location.search().rooms) {
                            chatService.openedRooms = $localstorage.get(CHAT_ROOM_LOCAL_STORAGE);
                            $localstorage.set(CHAT_ROOM_LOCAL_STORAGE, $location.search().rooms);
                        }

                        if ($localstorage.get(CHAT_ROOM_LOCAL_STORAGE)) {
                            openedChats = JSON.parse($localstorage.get(CHAT_ROOM_LOCAL_STORAGE));
                            openedChats.map(function(openedChat) {
                                var peopleOrRoom = scope.peopleChatList.filter(function(people) {
                                    return people._id === openedChat._id || people.room && people.room._id === openedChat._id;
                                })[0];

                                if (peopleOrRoom) {
                                    peopleOrRoom.isCollapsed = openedChat.isCollapsed;
                                    scope.openRoom(peopleOrRoom);
                                }
                            });
                        }
                    });
                });
        }

        /**
        * Verifica se a sala está minimizada ou no agrupador
        * @param {int} roomId roomId da sala
        * @return {boolean} se está (true) ou não(false) minimizada
        */
        function checkRoomIsCollapsed(roomId) {
            var room = $filter('filter')(scope.chatRoomList, {'_id' : roomId});

            if (!room[0])
                return true;

            return room[0].isCollapsed;

        }

        /**
        * Define listeners para Salas de conversas.
        * @param {array} rooms - Sala(s) de conversa.
        */
        function setRoomArraySocketListener(rooms) {

            if (!Array.isArray(rooms)) rooms = [rooms];

            rooms.forEach(function(room) {
                var roomChannel = 'chat:room-item:' + (room.room_id || room._id);

                // Registrando Listener para Sala de Conversa
                chatService.setRealTimeListener(roomChannel, function(messageObj) {
                    var oldList = scope.roomList;

                    // Buscando o chat na listagem
                    oldList.forEach(function(roomObj) {
                        if (roomObj._id === messageObj.data.message.room_id) {

                            roomObj.colors = getUserColors(roomObj);

                            delete messageObj.data.message.room_id;

                            // Definindo última msg
                            roomObj.lastMessage = {
                                'credential_id': messageObj.sender.id,
                                'message': messageObj.data.message
                            };

                            if (chatService.getSoundNotificationStatus() && scope.soundEnabled && messageObj.sender.id !== scope.currentUser.id && checkRoomIsCollapsed(roomObj._id))
                                document.getElementById('chat-notification').play();

                            scope.peopleChatList.map(function(chat) {

                                if (!chat.room && roomObj.people.length === 1 && chat._id === messageObj.sender.id ||
                                    !chat.room && chat._id === roomObj.people[0]._id && roomObj.people.length === 1) {
                                    chat.rroomOrCredentialObjoom = roomObj;
                                }

                                // 1:1 chat
                                if (chat.room && chat.room._id === roomObj._id) {
                                    chat.room.lastMessage = roomObj.lastMessage;
                                    chat.room.lastMessage.message.message = $window.EmojiPicker.prototype.unicodeToImage(chat.room.lastMessage.message.message);
                                    chat.lastMessageDate = messageObj.data.message.createDate;
                                }
                                // 1:N chat
                                if (chat._id === roomObj._id && roomObj.people.length > 1) {
                                    chat.lastMessage = roomObj.lastMessage;
                                    chat.lastMessage.message.message = $window.EmojiPicker.prototype.unicodeToImage(chat.lastMessage.message.message);
                                    chat.lastMessageDate = messageObj.data.message.createDate;
                                }
                            });

                            scope.peopleChatList = $filter('orderBy')(scope.peopleChatList, ['!lastMessageDate', '-lastMessageDate']);
                            // Ativando Chat
                            activateChat(roomObj);
                        }
                    });

                    $timeout(function() {
                        scope.roomList = oldList;
                    });
                });


                $timeout(function() {
                    initEmoji();
                });
            });
        }

        /**
        * Gerencia mensagens provenientes do Websocket
        * @constructor
        * @param {object} websocketObj - Retorno do Websocket.
        */
        function handleWebSocketMessage(websocketObj) {

            scope.isChatLoading = false;

            switch (websocketObj.action) {

                // Erro
                case 'error':

                    // $rootScope.toast('Conexão perdida', 20000);

                    scope.isChatLoading   = false;
                    scope.isChatConnected = false;
                    scope.isError         = true;

                    // Mostrando view de Login novamente
                    scope.isShowListPeople = false;
                    scope.isShowListRooms  = false;
                    scope.isShowMessageContainer = false;
                    scope.isShowGeneralContainer = true;

                    break;

                // Quando uma nova mensagem chega
                // NOVO CHAT
                case 'newMessage':

                    if (websocketObj.data.room._id && websocketObj.data.room.messages.length > 0) {
                        if (!Array.isArray(scope.roomList))
                            scope.roomList = [];

                        if (!websocketObj.data.room)
                            websocketObj.data.room = websocketObj.data;

                        // Ativando listener para esta sala de conversa
                        setRoomArraySocketListener(websocketObj.data.room);

                        // Definindo numero de mensagens nao lida
                        if (!websocketObj.data.room.unreadMessagesLength)
                            websocketObj.data.room['unreadMessagesLength'] = 1;
                        else
                            websocketObj.data.room.unreadMessagesLength += 1;

                        // Define imagem e nome do chat
                        setRoomAttributes(websocketObj.data.room);

                        // Adicionando na lista de Salas de Conversa
                        scope.roomList.push(websocketObj.data.room);

                        chatService.sendDeliveryConfirmation([websocketObj.data.room]);

                        // Adiciona chat novo na listagagem de conversas
                        if (websocketObj.data.room.people.length > 1 && !$filter('filter')(scope.peopleChatList, {'_id' : websocketObj.data.room._id})[0])
                            scope.peopleChatList.unshift(websocketObj.data.room);

                        // Quando for uma sala nova setar como true
                        // Para diferenciar de uma sala ativada a partir de listagem
                        websocketObj.data.room.isNew = true;

                        if (chatService.getSoundNotificationStatus() && checkRoomIsCollapsed(websocketObj.data.room._id))
                            document.getElementById('chat-notification').play();
                        // Ativando Chat
                        activateChat(websocketObj.data.room);
                    }
                    break;

                // Aviso de login de outro usuário
                case 'signin':
                    if (scope.isChatConnected &&  websocketObj.sender.id !== (scope.currentUser.id || scope.currentUser._id)) {
                        // $rootScope.toast('Usuário ' + websocketObj.sender.fullname + ' acaba de ser conectar ao chat!');
                        scope.peopleChatList.map(function(chat) {
                            if (chat._id === websocketObj.sender.id)
                                chat.isConnected = true;
                        });
                    }
                    else
                        chatService.sendSignedIn();

                    break;
                case 'statusUpdate' :
                    if (websocketObj.sender.id !== (scope.currentUser.id || scope.currentUser._id)) {
                        scope.peopleChatList.map(function(people) {
                            if (people._id === websocketObj.sender.id) {
                                people.chatLastInteraction = websocketObj.sender.chatLastInteraction;
                            }
                        });
                        scope.chatRoomList.map(function(chat) {
                            if (chat.people.length === 1 && (chat.owner._id === websocketObj.sender.id || chat.people[0]._id === websocketObj.sender.id))
                                chat.chatLastInteraction = websocketObj.sender.chatLastInteraction;
                        });
                        scope.$apply();
                    }
                    break;
            }
        }

        function removeLocalRoomById(roomId) {
            var oldList = scope.roomList;

            oldList.forEach(function(room, index) {
                if (room._id === roomId)
                    scope.roomList.splice(index, 1);

            });
        }

        /**
        * Verifica se já não existe uma conversa ativa com um determinado usuário.
        * @param {object} credentialsObj - RoomId para ser inativado.
        * @param {function} cb - Callback.
        * @return {cb} - callback
        */
        function hasActiveChat(credentialsObj, cb) {
            var i;

            // Clique proveniente da lista de chats
            if (credentialsObj.lastMessage) return cb(credentialsObj);

            // Clique da lista de usuarios
            if (Array.isArray(credentialsObj)) return cb();

            // Verificar em cada sala se o usuario é owner ||
            // Pertence a alguma colecao de people
            for (i = 0; i < scope.roomList.length; i += 1) {

                // Para salas de 1 pessoa
                if (scope.roomList[i].people.length !== 1) {
                    if (i + 1 === scope.roomList.length) {
                        return cb(null);
                    } else continue;
                }

                // Verifica se existe uma sala onde o usuario selecionado é o friend
                if (scope.roomList[i].people[0]._id === credentialsObj._id) {
                    return cb(scope.roomList[i]);
                }

                // Verifica se existe uma        sala onde o usuario selecioando é owner
                else if (scope.roomList[i].owner._id === credentialsObj._id) {
                    return cb(scope.roomList[i]);
                }
            }

            chatService.getSingleRoom(credentialsObj._id)
                .error(function(reason) {
                    console.error(reason); // eslint-disable-line
                })
                .success(function(room) {
                    if (room) {
                        return cb(room);
                    }
                    return cb();
                });
        }

        /**
        * Insere um Chat no banco e abre.
        * @param {object} credentialsObj - RoomId para ser inativado.
        * @param {string} chatRoomName - RoomId para ser inativado.
        */
        function createChat(credentialsObj, chatRoomName) {

            // Constrói objeto Room (sala de conversa) para salvar.
            chatFactory.buildRoom(credentialsObj, chatRoomName, function(roomObj) {
                // Busca ou gera um novo Room (sala de conversa)
                chatService.openRoom(roomObj)
                    .error(function(reason) {
                        scope.isChatLoading = false;
                        console.error(reason); // eslint-disable-line
                    })
                    .success(function(openRoomResponse) {
                        openRoomResponse.colors = getUserColors(openRoomResponse);

                        scope.isChatLoading = false;

                        openRoomResponse.chatLastInteraction = credentialsObj.chatLastInteraction;
                        // Adiciona chat de grupo novo na listagagem de conversas
                        if (openRoomResponse.people.length > 1) {
                            openRoomResponse.type = 'users';
                            scope.peopleChatList.unshift(openRoomResponse);
                            $rootScope.toast('Grupo criado com sucesso.');
                        }

                        // Setando event listener pro chat
                        setRoomArraySocketListener(openRoomResponse);

                        // Adiciona na lista geral
                        scope.roomList.push(openRoomResponse);

                        // Ativa o Chat
                        if (openRoomResponse.people.length === 1)
                            activateChat(openRoomResponse, openRoomResponse.people.length > 1 ? true : false, true);

                        // Limpa lista de seleção de grupos
                        scope.cleanGroupSelection();
                    });
            });
        }

        /**
        * Define Nome e a Imagem da sala de conversa
        * @param {object} roomObj - Objeto do Room
        */
        function setRoomAttributes(roomObj) {
            var currentUserId = scope.currentUser.id;

            // Validação para sala com 1 people
            if (roomObj.people.length === 1) {

                // Usuário corrente é o owner
                if (currentUserId === roomObj.owner._id) {
                    roomObj.name         = roomObj.people[0].name;
                    roomObj.imageDriveId = roomObj.people[0].imageDriveId;
                }

                // Usuário corrente é amigo
                else if (currentUserId === roomObj.people[0]._id) {
                    roomObj.name         = roomObj.owner.name;
                    roomObj.imageDriveId = roomObj.owner.imageDriveId;
                }
            }
        }

        /**
         * Abre uma sala de conversa.
         * Já assume que o chat exista e não consta na atual lista de chats abertos
         * @param {object} roomObj - Usuário(s) para gerar ou filtrar a sala.
         * @param {object} disableToggleChat - Desabilita toggle.
         * @param {boolean} isOpenRoom Se for uma sala aberta pelo usuário ao clicar na lista
         */
        function activateChat(roomObj, disableToggleChat, isOpenRoom) {

            // Chatroomlist é um array de salas ativas
            var oldList = scope.chatRoomList,
                newRoom = angular.copy(roomObj);

            newRoom.isOpen = true;
            newRoom.isRemoved = false;
            newRoom.isCollapsed = roomObj.isCollapsed;
            newRoom.isOpenRoom = isOpenRoom;
            // N necessita validacao se nao existir nenhuma sala ativa
            if (oldList.length === 0)
                scope.chatRoomList.push(newRoom);

            // Validando se o chat ja nao esta ativo
            else
                oldList.forEach(function(chatRoom, index) {

                    if (chatRoom._id === roomObj._id && chatRoom.isRemoved) {
                        scope.chatRoomList.splice(index, 1);
                        scope.chatRoomList.push(newRoom);
                        return;
                    }

                    if (chatRoom._id === newRoom._id)  {
                        chatRoom.isCollapsed = false;
                        return;
                    }

                    if (index + 1 === scope.chatRoomList.length) {
                        if (scope.chatRoomList.length < scope.chatRoomListLimit)
                            scope.chatRoomList.push(newRoom);
                        else if (!$filter('filter')(scope.activeChatGroup, {'_id' : newRoom._id})[0] && !$filter('filter')(scope.chatRoomList, {'_id' : newRoom._id})[0]) {
                            setRoomAttributes(newRoom);
                            scope.activeChatGroup.push(newRoom);
                        }

                    }
                });

            handleBodyClassChange();
        }

        scope.$on('CHAT-NEW-ACTIVE-LIST', function(ev, newActiveChatList) {
            $timeout(function() {
                scope.chatRoomList = newActiveChatList;
                scope.handleChatListChanges();
            });
        });

        scope.keyUpInputGroup = function($event)  {
            if ($event.keyCode === 13 && scope.userGroups.name.length > 1 && scope.userGroups.count > 1) {
                scope.openRoom(scope.getSelectedUsers(), scope.userGroups.name);
            }
        };

        scope.chatListRightPop = function(roomObj, index) {

            var itemToBeMovedToGroup;

            itemToBeMovedToGroup = scope.chatRoomList.pop();

            itemToBeMovedToGroup.isOpen = false;

            scope.activeChatGroup.splice(index, 1);
            scope.activeChatGroup.push(itemToBeMovedToGroup);

            $timeout(function() {
                roomObj.isOpen = true;
                scope.chatRoomList.push(roomObj);

                // Precisa esperar carregar o input onde digita para aplicar o componente de emoji
                $timeout(function() {
                    initEmoji();
                });
            });
        };

        /**
        * Obtém usuários selecionados para criação de grupo.'
        * @returns {array} Lista de usuários selecionados.
        */
        scope.getSelectedUsers = function() {
            var selectedItems = [];

            if (scope.peopleChatList.length > 0) {
                scope.peopleChatList.forEach(function(user) {
                    if (user.isSelected)
                        selectedItems.push(user);
                });
            }

            return selectedItems;
        };

        scope.incrementeUserGroups = function(isSelected) {
            if (!scope.userGroups) scope.userGroups = { 'count' : 0, 'name': null };
            if (!scope.userGroups.count) scope.userGroups.count = 0;

            scope.userGroups.count = isSelected ? scope.userGroups.count -= 1
                                                : scope.userGroups.count += 1;
        };

        /**
         * Limpa uma seleção de grupos.
         */
        scope.cleanGroupSelection = function() {
            scope.peopleChatList.forEach(function(user) {
                if (user.isSelected) delete user.isSelected;
            });

            scope.showGroupInput = scope.showSearchInput = false;
            scope.chatTopBarInputGroupFocused            = false;
            scope.userGroups = { 'count' : 0, 'name': null };
        };

        /**
         * Deleta um Room.
         * @param {int} roomId - RoomId para ser inativado.
         */
        scope.removeRoom = function(roomId) {

            scope.isChatLoading = true;

            chatService.removeRoom(roomId)
                .error(function() {
                    scope.isChatLoading = false;
                })
                .success(function(removeRoomResp) {
                    scope.isChatLoading = false;

                    if (!removeRoomResp) return false;

                    removeLocalRoomById(roomId);
                });
        };

        /**
         * Abre ou fecha o Sidepanel principal do Chat.
         */
        function toggleChat() {
            $timeout(function() {

                scope.visible = !scope.visible;

                if (scope.visible) {
                    document.body.classList.add('plg-chat-open');
                    chatService.sendInteractionViaWs();
                } else
                    document.body.classList.remove('plg-chat-open');
            });
        }

        scope.closeChat = function() {
            if (!scope.maximized) {
                scope.visible = false;
                document.body.classList.remove('plg-chat-open');
            }
        };

        scope.searchTextChange = function(text) {
            var foundArray = $filter('plgNameFilter')(scope.oldList || scope.peopleChatList, text.length > 0 ? text.toLowerCase() : text);

            if (!scope.oldList) scope.oldList = scope.peopleChatList;

            if (text.length === 0) scope.peopleChatList = scope.oldList;
            else scope.peopleChatList = foundArray;
        };

        scope.getUserImage = function(imageDriveId, customer_id) {
            if (!imageDriveId) return;

            return credentialsService
                .getProfileImage(imageDriveId, customer_id || scope.currentUser.customer_id);
        };


        /**
         * Cria/Abre ou Abre um chat.
         * @param {object} roomOrCredentialObj - Usuário(s) para gerar ou filtrar a sala.
         * @param {object} chatRoomName - Nome da sala.
         */
        scope.openRoom = function(roomOrCredentialObj, chatRoomName) {
            // Verificando se é um Room que já não está aberto ou Credential
            // pois o click pode vir tanto da lista de pessoas como da lista de chats
            // se tiver people é chat

            var
                isClosedRoom = !!(roomOrCredentialObj.people && roomOrCredentialObj._id && !roomOrCredentialObj.isOpen),
                isUser = !!(roomOrCredentialObj._id && roomOrCredentialObj.usr),
                isGroup = Array.isArray(roomOrCredentialObj) && roomOrCredentialObj.length > 1 && chatRoomName;

            scope.isChatLoading = true;

            // Desliga notifiaçaão de uma mensagem nova proveniente de outro usuário
            if (roomOrCredentialObj.isNewMessageArrived)
                roomOrCredentialObj.isNewMessageArrived = false;

            // Se for uma sala existente tornar ativa

            //   > `isOpen = true` (isso acontece no init() de plg-chat-conversation-controller.js)
            if (isClosedRoom) {
                activateChat(roomOrCredentialObj, false, true);
                scope.isChatLoading = false;

                if (scope.visible && !scope.maximized)
                    toggleChat();
            }

            else if (isUser) {
                // Verifica se já não existe uma conversa 1:1
                // Existindo mostra-se a janela de conversa
                hasActiveChat(roomOrCredentialObj, function(foundChatRoom) {
                    // Ativa o Chat
                    if (foundChatRoom) {
                        foundChatRoom.isCollapsed = roomOrCredentialObj.isCollapsed;
                        foundChatRoom.chatLastInteraction = roomOrCredentialObj.chatLastInteraction;
                        activateChat(foundChatRoom, false, true);
                    }

                    // Cria uma novo chat
                    else createChat(roomOrCredentialObj, chatRoomName);

                    // Desliga o Loader
                    scope.isChatLoading = false;

                    // Limpa seleção dos controles da topbar do chat
                    scope.clearChatTopBarSelection();

                    if (scope.visible && !scope.maximized)
                        toggleChat();
                });

            } else if (isGroup) {
                createChat(roomOrCredentialObj, chatRoomName);

            } else {
                // Ativa Loader
                scope.isChatLoading = false;
            }

        };

        scope.closeGroupRoomById = function(room) {
            room.isOpen = false;

            $timeout(function() {
                scope.activeChatGroup = $filter('filter')(scope.activeChatGroup, function(value) {
                    return value._id.toString() !== room._id.toString();
                });
            });
        };

        scope.toggleGroupCheckBox = function(chatPerson) {
            $timeout(function() {
                chatPerson.isShowGroupCheckBox = !chatPerson.isShowGroupCheckBox;
            });
        };

        /**
         * Incrementa/Decrementa contador seleção de usuários para criação de grupo.
         * @constructor
         * @param {object} chatPerson - Usuário do Grupo a ser modificado
         */
        scope.changeGroupSelection = function(chatPerson) {
            $timeout(function() {
                chatPerson.isSelected = !chatPerson.isSelected;

                scope.userGroups.count = chatPerson.isSelected ? scope.userGroups.count += 1
                                                               : scope.userGroups.count -= 1;
            });
        };

        scope.noAvailable = function() {
            $rootScope.toast('Grupos ainda em desenvolvimento!', 7000);
        };

        function initEmoji() {
            // Inicializa componente de Emoji
            window.emojiPicker = new EmojiPicker({ // eslint-disable-line
                'emojiable_selector': '[data-emojiable=true]',
                'assetsPath': './node_modules/pling-ui/assets/img/emoji',
                'norealtime' : true,
                'popupButtonClasses': 'fa fa-smile-o'
            });

            window.emojiPicker.discover();
        }
    }
}());


(function() {

    'use strict';

    angular
        .module('plingUi')
        .directive('plgChips', plgChips);

    plgChips.$inject = [];

    function plgChips() {

        return {
            'restrict'  : 'E',
            'replace'   : true,
            'scope'     : {
                'chips' : '=',
                'remove': '='
            },
            'template'  : function() {
                return '<div class="md-chips">' +
                            '<div ng-repeat="chip in chips" class="md-chip md-chip-hover">' +
                                '<img ng-if="chip.img" class="md-chip-icon" src="{{ chip.img }}">' +
                                '<div class="md-chip-div-text">{{ chip.name }}</div>' +
                                '<md-progress-circular style="float: right; margin: 5px 0 0 11px;" md-diameter="20px"md-mode="indeterminate" ng-if="chip.isLoader" ></md-progress-circular >' +
                                '<button ng-if="!chip.isLoader" type="button" class="md-chip-remove" ng-click="remove(chips, chip)">' +
                            '</div>' +
                        '</div>';
            }
        };

    }

}());

(function() {

    'use strict';

    angular
        .module('plingUi')
        .directive('ngClick', ngClickDirective);

    ngClickDirective.$inject = [ '$timeout' ];

    function ngClickDirective ($timeout) {
        var delay = 500;

        return {
            'restrict': 'A',
            'priority': -1,
            'link': function (scope, elem) {
                var disabled = false;

                function onClick(evt) {
                    if (disabled) {
                        evt.preventDefault();
                        evt.stopImmediatePropagation();
                    } else {
                        disabled = true;
                        $timeout(function () { disabled = false; }, delay, false);
                    }
                }

                scope.$on('$destroy', function () { elem.off('click', onClick); });
                elem.on('click', onClick);
            }
        };

    }

}());
(function() {

    'use strict';

    angular
        .module('plingUi')
        .directive('clickOutside', clickOutside);

    clickOutside.$inject = [
        '$document', '$parse', '$timeout'
    ];

    function clickOutside($document, $parse, $timeout) {
        return {
            'restrict' : 'A',
            'link'     : function($scope, elem, attr) {

                // postpone linking to next digest to allow for unique id generation
                $timeout(function() {
                    var classList = (attr.outsideIfNot !== undefined) ? attr.outsideIfNot.split(/[ ,]+/) : [], //eslint-disable-line
                        fn;

                    function eventHandler(e) {
                        var i,
                            element,
                            r,
                            id,
                            classNames,
                            l;

                        // check if our element already hidden and abort if so
                        if (angular.element(elem).hasClass('ng-hide')) {
                            return;
                        }

                        // if there is no click target, no point going on
                        if (!e || !e.target) {
                            return;
                        }

                        // loop through the available elements, looking for classes in the class list that might match and so will eat
                        for (element = e.target; element; element = element.parentNode) {
                            // check if the element is the same element the directive is attached to and exit if so (props @CosticaPuntaru)
                            if (element === elem[0]) {
                                return;
                            }

                            // now we have done the initial checks, start gathering id's and classes
                            id = element.id;
                            classNames = element.className;
                            l = classList.length;

                            // Unwrap SVGAnimatedString classes
                            if (classNames && classNames.baseVal !== undefined) { //eslint-disable-line
                                classNames = classNames.baseVal;
                            }

                            // if there are no class names on the element clicked, skip the check
                            if (classNames || id) {

                                // loop through the elements id's and classnames looking for exceptions
                                for (i = 0; i < l; i++) {

                                    // prepare regex for class word matching
                                    r = new RegExp('\\b' + classList[i] + '\\b');

                                    // check for exact matches on id's or classes, but only if they exist in the first place
                                    if ((id !== undefined && id === classList[i]) || (classNames && r.test(classNames))) { //eslint-disable-line
                                        // now let's exit out as it is an element that has been defined as being ignored for clicking outside
                                        return;
                                    }
                                }
                            }
                        }

                        // if we have got this far, then we are good to go with processing the command passed in via the click-outside attribute
                        $timeout(function() {
                            fn = $parse(attr['clickOutside']);
                            fn($scope, { 'event': e });
                        });
                    }

                    // if the devices has a touchscreen, listen for this event
                    if (_hasTouch()) {
                        $document.on('touchstart', eventHandler);
                    }

                    // still listen for the click event even if there is touch to cater for touchscreen laptops
                    $document.on('click', eventHandler);

                    // when the scope is destroyed, clean up the documents event handlers as we don't want it hanging around
                    $scope.$on('$destroy', function() {
                        if (_hasTouch()) {
                            $document.off('touchstart', eventHandler);
                        }

                        $document.off('click', eventHandler);
                    });

                    function _hasTouch() {
                        // works on most browsers, IE10/11 and Surface
                        return 'ontouchstart' in window || navigator.maxTouchPoints; //eslint-disable-line
                    }
                });
            }
        };
    }
})();

// http://stackoverflow.com/questions/14474555/how-to-format-a-date-using-ng-model thanks SunnyShah
(function () {
    angular.module('plingUi').directive('plgDateFormat', PlgDateFormat);

    function PlgDateFormat() {
        return {
            'require' :'^ngModel',
            'restrict': 'A',
            'link' : function (scope, elm, attrs, ctrl) {
                var dateFormat = attrs.plgDateFormat;

                attrs.$observe('plgDateFormat', function (newValue) {
                    if (dateFormat === newValue || !ctrl.$modelValue) return;
                    dateFormat = newValue;
                    ctrl.$modelValue = new Date(ctrl.$setViewValue);
                });

                ctrl.$formatters.unshift(function (modelValue) {
                    if (!dateFormat || !modelValue) return '';
                    return moment.utc(modelValue).format(dateFormat);
                });

                ctrl.$parsers.unshift(function (viewValue) {
                    var date = moment(viewValue, dateFormat);

                    return date && date.isValid() && date.year() > 1950 ? date.toDate() : '';
                });
            }
        };
    }
}());

(function () {

    angular.module('plingUi').component('plgDatePicker', {
        'bindings'  : {
            'selected'        : '=?',
            'ngModel'         : '=?',
            'onChange'        : '&?',
            'ngBlur'          : '&?',
            'disableRange'    : '=',
            'disableIcon'     : '@',
            'disableEvents'   : '@',
            'monthsLimit'     : '@',
            'class'           : '@',
            'classIcon'       : '@',
            'classInput'      : '@',
            'idEvent'         : '@?',
            'hideError'       : '@?',
            'disableDateInit' : '@?',
            'disableOptions'  : '=?',
            'label'           : '='
        },
        'controller' : PlgDatePickerCtrl,
        'templateUrl' : 'plg-date-picker.html'
    });

    function PlgDatePickerCtrl() {
        var ctrl = this,
            fromDate,
            toDate,
            dateFormat;

        ctrl.inputId     = (((1+Math.random())*0x10000)).toString(16);
        ctrl.onChange    = ctrl.onChange || angular.noop;
        ctrl.ngBlur      = ctrl.ngBlur   || angular.noop;
        ctrl.selected    = ctrl.selected || ctrl.ngModel;
        ctrl.monthsLimit = ctrl.monthsLimit || 1;

        ctrl.mask = ctrl.disableRange ? '?9?9/?9?9/?9?9?9?9' : '?9?9/?9?9/?9?9?9?9 - ?9?9/?9?9/?9?9?9?9';

        ctrl.setDates = function (select) {
            if (select.display && select.display.length >= 8 && !select.$invalid) {
                createDates(select.display);
                handleDates(select);
            } else {
                select.fromDate = null;
                select.toDate   = null;
            }
        };

        ctrl.validate = function (select) {
            if (select && select.display) {
                dateFormat = select.display.replace(new RegExp('(_\/|\/_|_)', 'g'), '') || '';

                if (dateFormat) {
                    fromDate = dateFormat.split(' - ')[0];
                    toDate   = dateFormat.split(' - ')[1];

                    if (!isValid(fromDate) || toDate && !isValid(toDate)) {
                        select.$invalid = true;
                        select.fromDate = null;
                        select.toDate   = null;
                        return false;
                    }

                    select.$invalid = false;
                }
            }
        };

        function isValid(date) {
            return moment(date, 'DD/MM/YYYY', true).isValid();
        }

        function createDates(display) {
            dateFormat = display.replace(new RegExp('(_\/|\/_|_)', 'g'), '') || '';
            fromDate = dateFormat.split(' - ')[0];
            toDate   = dateFormat.split(' - ')[1];
            fromDate = fromDate.slice(-4) + '-' + fromDate.slice(3, 5) + '-' + fromDate.slice(0, 2);
            toDate   = toDate ? toDate.slice(-4) + '-' + toDate.slice(3, 5) + '-' + toDate.slice(0, 2) : '';
        }

        function handleDates(select) {
            if (toDate && fromDate > toDate) {
                select.fromDate = toDate;
                select.toDate   = fromDate;

                select.display  = select.display.slice(-10) + ' - ' + select.display.slice(0, 10);
            } else {
                select.fromDate = fromDate;
                select.toDate   = toDate || fromDate;
            }
        }
    }
}());

(function () {
    'use strict';

    // Injeção de dependências
    plgDialogController.$inject = [
        '$scope',
        '$rootScope',
        '$mdDialog'
    ];

    // Component configuration
    angular.module('plingUi').component('plgDialog', {
        'bindings'  : {
        },
        'controller'  : plgDialogController
    });

    // CREATING CONTROLLER
    function plgDialogController($scope, $rootScope, $mdDialog) {

        $rootScope.$on('DIALOG-CLOSE', function() {
            $mdDialog.hide();
        });

        $rootScope.$on('DIALOG-ACTION', function(event, obj, clickOutsideToClose) {
            $scope.customFullscreen = false;

            $mdDialog.show({
                'controller'    : 'plgDialogController',
                'templateUrl'   : 'plg-dialog.html',
                'locals': {
                    '$scope'      : $scope,
                    '$rootScope'  : $rootScope,
                    'title'       : obj.title,
                    'message'     : obj.message,
                    'template'    : obj.template,
                    'more'        : obj.more,
                    'button'      : obj.button
                },
                'parent'              : angular.element(document.body),
                'focusOnOpen'         : false,
                'targetEvent'         : obj.ev,
                'clickOutsideToClose' : clickOutsideToClose || false,
                'fullscreen'          : $scope.customFullscreen
            }).then(function(cb) {
                if (cb)
                    cb();
            }, function() {});
        });

    }
}());

(function() {
    'use strict';

    angular
        .module('plingUi')
        .directive('plgErrorSrc', plgErrorSrc);

    function plgErrorSrc () {
        return {
            'restrict': 'A',
            'link':function(scope, element, attrs) {
                element.bind('error', function() {
                    element.addClass('error');
                    if (attrs.src !== attrs.plgErrorSrc) {
                        attrs.$set('src', attrs.plgErrorSrc);
                        attrs.$set('ng-src', attrs.plgErrorSrc);
                    }
                });
            }
        };
    }
})();

/* global angular */
(function () {
    'use strict';

    plgFabButtonController.$inject = [ ];

    angular
        .module('plingUi')
            .directive('plgFabButton', plgFabButtonController);

    function plgFabButtonController () {

        return {
            'restrict' : 'E',
            'templateUrl': 'plg-fab-button.html',
            'scope': {
                'fabButton': '=params'
            },
            'link': function(scope) {
                scope.$watch('fabButton', function() {

                });
            }
        };
    }

}());

(function() {

    'use strict';

    // CREATING COMPONENT WITH BINDINGS
    angular
        .module('plingUi')
        .component('plgImageDrive', {
            'controller' : plgImageDriveController,
            'templateUrl': 'plg-image-drive.html',
            'bindings'   : {
                'imageId'   : '=',
                'imageType' : '='
            }
        });

    plgImageDriveController.$inject = [
        'credentialsService'
    ];

    function plgImageDriveController(credentialsService) {
        var ctrl        = this,
            localUser   = credentialsService.getLocal();

        ctrl.imageId    = this.imageId;
        ctrl.imageType  = this.imageType;

        ctrl.imageIcon  = null;
        ctrl.image      = null;

        // INICIALMENTE TRATANDO APENAS PROFILE IMAGES
        if (ctrl.imageType === 'profile-images' && !ctrl.imageId) {
            ctrl.imageIcon  = '../../node_modules/pling-ui/assets/icons/icone_person.svg';
        } else if (ctrl.imageType === 'profile-images' && ctrl.imageId) {
            if (localUser)
                ctrl.image  = 'https://s3.amazonaws.com/pling-customers/' + localUser.customer_id + '/' + ctrl.imageType + '/' + ctrl.imageId + '_32px';
        }

    }
}());

/*
 * ngImgCrop v0.3.2
 * https://github.com/alexk111/ngImgCrop
 *
 * Copyright (c) 2014 Alex Kaul
 * License: MIT
 *
 * Generated at Wednesday, December 3rd, 2014, 3:54:12 PM
 */
(function() {
    'use strict';

    cropAreaCircleController.$inject = [ 'cropArea' ];

    angular.module('plingUi').factory('cropAreaCircle', cropAreaCircleController);

    function cropAreaCircleController(CropArea) {
        var CropAreaCircle = function() {
            CropArea.apply(this, arguments);

            this._boxResizeBaseSize = 20;
            this._boxResizeNormalRatio = 0.9;
            this._boxResizeHoverRatio = 1.2;
            this._iconMoveNormalRatio = 0.9;
            this._iconMoveHoverRatio = 1.2;

            this._boxResizeNormalSize = this._boxResizeBaseSize*this._boxResizeNormalRatio;
            this._boxResizeHoverSize = this._boxResizeBaseSize*this._boxResizeHoverRatio;

            this._posDragStartX=0;
            this._posDragStartY=0;
            this._posResizeStartX=0;
            this._posResizeStartY=0;
            this._posResizeStartSize=0;

            this._boxResizeIsHover = false;
            this._areaIsHover = false;
            this._boxResizeIsDragging = false;
            this._areaIsDragging = false;
        };

        CropAreaCircle.prototype = new CropArea();

        CropAreaCircle.prototype._calcCirclePerimeterCoords=function(angleDegrees) {
            var hSize=this._size/2;
            var angleRadians = angleDegrees * (Math.PI / 180),
                circlePerimeterX = this._x + hSize * Math.cos(angleRadians),
                circlePerimeterY = this._y + hSize * Math.sin(angleRadians);

            return [circlePerimeterX, circlePerimeterY];
        };

        CropAreaCircle.prototype._calcResizeIconCenterCoords=function() {
            return this._calcCirclePerimeterCoords(-45);
        };

        CropAreaCircle.prototype._isCoordWithinArea=function(coord) {
            return Math.sqrt((coord[0]-this._x)*(coord[0]-this._x) + (coord[1]-this._y)*(coord[1]-this._y)) < this._size/2;
        };
        CropAreaCircle.prototype._isCoordWithinBoxResize=function(coord) {
            var resizeIconCenterCoords=this._calcResizeIconCenterCoords();
            var hSize=this._boxResizeHoverSize/2;

            return coord[0] > resizeIconCenterCoords[0] - hSize && coord[0] < resizeIconCenterCoords[0] + hSize &&
                   coord[1] > resizeIconCenterCoords[1] - hSize && coord[1] < resizeIconCenterCoords[1] + hSize;
        };

        CropAreaCircle.prototype._drawArea=function(ctx, centerCoords, size) {
            ctx.arc(centerCoords[0], centerCoords[1], size/2, 0, 2 * Math.PI);
        };

        CropAreaCircle.prototype.draw=function() {
            CropArea.prototype.draw.apply(this, arguments);

            // draw move icon
            this._cropCanvas.drawIconMove([this._x, this._y], this._areaIsHover?this._iconMoveHoverRatio:this._iconMoveNormalRatio);

            // draw resize cubes
            this._cropCanvas.drawIconResizeBoxNESW(this._calcResizeIconCenterCoords(), this._boxResizeBaseSize, this._boxResizeIsHover?this._boxResizeHoverRatio:this._boxResizeNormalRatio);
        };

        CropAreaCircle.prototype.processMouseMove=function(mouseCurX, mouseCurY) {
            var cursor='default', iFR, iFX, iFY;
            var res=false;

            this._boxResizeIsHover = false;
            this._areaIsHover = false;

            if (this._areaIsDragging) {
                this._x = mouseCurX - this._posDragStartX;
                this._y = mouseCurY - this._posDragStartY;
                this._areaIsHover = true;
                cursor='move';
                res=true;
                this._events.trigger('area-move');
            } else if (this._boxResizeIsDragging) {
                cursor = 'nesw-resize';
                iFX = mouseCurX - this._posResizeStartX;
                iFY = this._posResizeStartY - mouseCurY;
                if (iFX > iFY) {
                    iFR = this._posResizeStartSize + iFY*2;
                } else {
                    iFR = this._posResizeStartSize + iFX*2;
                }

                this._size = Math.max(this._minSize, iFR);
                this._boxResizeIsHover = true;
                res=true;
                this._events.trigger('area-resize');
            } else if (this._isCoordWithinBoxResize([mouseCurX, mouseCurY])) {
                cursor = 'nesw-resize';
                this._areaIsHover = false;
                this._boxResizeIsHover = true;
                res=true;
            } else if (this._isCoordWithinArea([mouseCurX, mouseCurY])) {
                cursor = 'move';
                this._areaIsHover = true;
                res=true;
            }

            this._dontDragOutside();
            angular.element(this._ctx.canvas).css({'cursor': cursor});

            return res;
        };

        CropAreaCircle.prototype.processMouseDown=function(mouseDownX, mouseDownY) {
            if (this._isCoordWithinBoxResize([mouseDownX, mouseDownY])) {
                this._areaIsDragging = false;
                this._areaIsHover = false;
                this._boxResizeIsDragging = true;
                this._boxResizeIsHover = true;
                this._posResizeStartX=mouseDownX;
                this._posResizeStartY=mouseDownY;
                this._posResizeStartSize = this._size;
                this._events.trigger('area-resize-start');
            } else if (this._isCoordWithinArea([mouseDownX, mouseDownY])) {
                this._areaIsDragging = true;
                this._areaIsHover = true;
                this._boxResizeIsDragging = false;
                this._boxResizeIsHover = false;
                this._posDragStartX = mouseDownX - this._x;
                this._posDragStartY = mouseDownY - this._y;
                this._events.trigger('area-move-start');
            }
        };

        CropAreaCircle.prototype.processMouseUp = function(/* eslint-disable-line no-console. mouseUpX, mouseUpY */) {
            if (this._areaIsDragging) {
                this._areaIsDragging = false;
                this._events.trigger('area-move-end');
            }
            if (this._boxResizeIsDragging) {
                this._boxResizeIsDragging = false;
                this._events.trigger('area-resize-end');
            }
            this._areaIsHover = false;
            this._boxResizeIsHover = false;

            this._posDragStartX = 0;
            this._posDragStartY = 0;
        };

        return CropAreaCircle;
    }

    cropAreaSquareController.$inject = [ 'cropArea' ];

    angular.module('plingUi').factory('cropAreaSquare', cropAreaSquareController);

    function cropAreaSquareController(CropArea) {

        var CropAreaSquare = function() {
            CropArea.apply(this, arguments);

            this._resizeCtrlBaseRadius = 10;
            this._resizeCtrlNormalRatio = 0.75;
            this._resizeCtrlHoverRatio = 1;
            this._iconMoveNormalRatio = 0.9;
            this._iconMoveHoverRatio = 1.2;

            this._resizeCtrlNormalRadius = this._resizeCtrlBaseRadius*this._resizeCtrlNormalRatio;
            this._resizeCtrlHoverRadius = this._resizeCtrlBaseRadius*this._resizeCtrlHoverRatio;

            this._posDragStartX=0;
            this._posDragStartY=0;
            this._posResizeStartX=0;
            this._posResizeStartY=0;
            this._posResizeStartSize=0;

            this._resizeCtrlIsHover = -1;
            this._areaIsHover = false;
            this._resizeCtrlIsDragging = -1;
            this._areaIsDragging = false;
        };

        CropAreaSquare.prototype = new CropArea();

        CropAreaSquare.prototype._calcSquareCorners=function() {
            var hSize=this._size/2;

            return [
              [this._x-hSize, this._y-hSize],
              [this._x+hSize, this._y-hSize],
              [this._x-hSize, this._y+hSize],
              [this._x+hSize, this._y+hSize]
            ];
        };

        CropAreaSquare.prototype._calcSquareDimensions=function() {
            var hSize=this._size/2;

            return {
                'left': this._x-hSize,
                'top': this._y-hSize,
                'right': this._x+hSize,
                'bottom': this._y+hSize
            };
        };

        CropAreaSquare.prototype._isCoordWithinArea=function(coord) {
            var squareDimensions=this._calcSquareDimensions();

            return coord[0]>=squareDimensions.left&&coord[0]<=squareDimensions.right&&coord[1]>=squareDimensions.top&&coord[1]<=squareDimensions.bottom;
        };

        CropAreaSquare.prototype._isCoordWithinResizeCtrl=function(coord) {
            var resizeIconsCenterCoords=this._calcSquareCorners();
            var res=-1, i, len, resizeIconCenterCoords;

            for (i=0, len = resizeIconsCenterCoords.length; i < len; i++) {
                resizeIconCenterCoords = resizeIconsCenterCoords[i];
                if (coord[0] > resizeIconCenterCoords[0] - this._resizeCtrlHoverRadius && coord[0] < resizeIconCenterCoords[0] + this._resizeCtrlHoverRadius &&
                 coord[1] > resizeIconCenterCoords[1] - this._resizeCtrlHoverRadius && coord[1] < resizeIconCenterCoords[1] + this._resizeCtrlHoverRadius) {
                    res=i;
                    break;
                }
            }
            return res;
        };

        CropAreaSquare.prototype._drawArea=function(ctx, centerCoords, size) {
            var hSize=size/2;

            ctx.rect(centerCoords[0]-hSize, centerCoords[1]-hSize, size, size);
        };

        CropAreaSquare.prototype.draw=function() {
            var resizeIconsCenterCoords, i, len, resizeIconCenterCoords;

            CropArea.prototype.draw.apply(this, arguments);
            // draw move icon
            this._cropCanvas.drawIconMove([this._x, this._y], this._areaIsHover?this._iconMoveHoverRatio:this._iconMoveNormalRatio);

            // draw resize cubes
            resizeIconsCenterCoords = this._calcSquareCorners();
            for (i = 0, len = resizeIconsCenterCoords.length; i < len; i++) {
                resizeIconCenterCoords=resizeIconsCenterCoords[i];
                this._cropCanvas.drawIconResizeCircle(resizeIconCenterCoords, this._resizeCtrlBaseRadius, this._resizeCtrlIsHover===i?this._resizeCtrlHoverRatio:this._resizeCtrlNormalRatio);
            }
        };

        CropAreaSquare.prototype.processMouseMove=function(mouseCurX, mouseCurY) {
            var cursor='default', xMulti, yMulti, iFX, iFY, iFR, wasSize, posModifier, hoveredResizeBox, res = false;

            this._resizeCtrlIsHover = -1;
            this._areaIsHover = false;

            if (this._areaIsDragging) {
                this._x = mouseCurX - this._posDragStartX;
                this._y = mouseCurY - this._posDragStartY;
                this._areaIsHover = true;
                cursor='move';
                res=true;
                this._events.trigger('area-move');
            } else if (this._resizeCtrlIsDragging>-1) {
                switch (this._resizeCtrlIsDragging) {
                    case 0: // eslint-disable-line no-console. Top Left
                        xMulti=-1;
                        yMulti=-1;
                        cursor = 'nwse-resize';
                        break;
                    case 1: // eslint-disable-line no-console. Top Right
                        xMulti=1;
                        yMulti=-1;
                        cursor = 'nesw-resize';
                        break;
                    case 2: // eslint-disable-line no-console. Bottom Left
                        xMulti=-1;
                        yMulti=1;
                        cursor = 'nesw-resize';
                        break;
                    case 3: // eslint-disable-line no-console. Bottom Right
                        xMulti=1;
                        yMulti=1;
                        cursor = 'nwse-resize';
                        break;
                }
                iFX = (mouseCurX - this._posResizeStartX)*xMulti;
                iFY = (mouseCurY - this._posResizeStartY)*yMulti;
                if (iFX>iFY) {
                    iFR = this._posResizeStartSize + iFY;
                } else {
                    iFR = this._posResizeStartSize + iFX;
                }
                wasSize=this._size;
                this._size = Math.max(this._minSize, iFR);
                posModifier=(this._size-wasSize)/2;
                this._x+=posModifier*xMulti;
                this._y+=posModifier*yMulti;
                this._resizeCtrlIsHover = this._resizeCtrlIsDragging;
                res=true;
                this._events.trigger('area-resize');
            } else {
                hoveredResizeBox=this._isCoordWithinResizeCtrl([mouseCurX, mouseCurY]);
                if (hoveredResizeBox>-1) {
                    switch (hoveredResizeBox) {
                        case 0:
                            cursor = 'nwse-resize';
                            break;
                        case 1:
                            cursor = 'nesw-resize';
                            break;
                        case 2:
                            cursor = 'nesw-resize';
                            break;
                        case 3:
                            cursor = 'nwse-resize';
                            break;
                    }
                    this._areaIsHover = false;
                    this._resizeCtrlIsHover = hoveredResizeBox;
                    res=true;
                } else if (this._isCoordWithinArea([mouseCurX, mouseCurY])) {
                    cursor = 'move';
                    this._areaIsHover = true;
                    res=true;
                }
            }

            this._dontDragOutside();
            angular.element(this._ctx.canvas).css({'cursor': cursor});

            return res;
        };

        CropAreaSquare.prototype.processMouseDown=function(mouseDownX, mouseDownY) {
            var isWithinResizeCtrl=this._isCoordWithinResizeCtrl([mouseDownX, mouseDownY]);

            if (isWithinResizeCtrl>-1) {
                this._areaIsDragging = false;
                this._areaIsHover = false;
                this._resizeCtrlIsDragging = isWithinResizeCtrl;
                this._resizeCtrlIsHover = isWithinResizeCtrl;
                this._posResizeStartX=mouseDownX;
                this._posResizeStartY=mouseDownY;
                this._posResizeStartSize = this._size;
                this._events.trigger('area-resize-start');
            } else if (this._isCoordWithinArea([mouseDownX, mouseDownY])) {
                this._areaIsDragging = true;
                this._areaIsHover = true;
                this._resizeCtrlIsDragging = -1;
                this._resizeCtrlIsHover = -1;
                this._posDragStartX = mouseDownX - this._x;
                this._posDragStartY = mouseDownY - this._y;
                this._events.trigger('area-move-start');
            }
        };

        CropAreaSquare.prototype.processMouseUp=function(/* eslint-disable-line no-console. mouseUpX, mouseUpY */) {
            if (this._areaIsDragging) {
                this._areaIsDragging = false;
                this._events.trigger('area-move-end');
            }
            if (this._resizeCtrlIsDragging>-1) {
                this._resizeCtrlIsDragging = -1;
                this._events.trigger('area-resize-end');
            }
            this._areaIsHover = false;
            this._resizeCtrlIsHover = -1;

            this._posDragStartX = 0;
            this._posDragStartY = 0;
        };

        return CropAreaSquare;
    }

    cropAreaController.$inject = [ 'cropCanvas' ];

    angular.module('plingUi').factory('cropArea', cropAreaController);

    function cropAreaController(CropCanvas) {

        /* global Image */
        var CropArea = function(ctx, events) {
            this._ctx=ctx;
            this._events=events;

            this._minSize=80;

            this._cropCanvas=new CropCanvas(ctx);

            this._image = new Image();
            this._x = 0;
            this._y = 0;
            this._size = 200;
        };

  /* GETTERS/SETTERS */

        CropArea.prototype.getImage = function () {
            return this._image;
        };
        CropArea.prototype.setImage = function (image) {
            this._image = image;
        };

        CropArea.prototype.getX = function () {
            return this._x;
        };
        CropArea.prototype.setX = function (x) {
            this._x = x;
            this._dontDragOutside();
        };

        CropArea.prototype.getY = function () {
            return this._y;
        };
        CropArea.prototype.setY = function (y) {
            this._y = y;
            this._dontDragOutside();
        };

        CropArea.prototype.getSize = function () {
            return this._size;
        };
        CropArea.prototype.setSize = function (size) {
            this._size = Math.max(this._minSize, size);
            this._dontDragOutside();
        };

        CropArea.prototype.getMinSize = function () {
            return this._minSize;
        };
        CropArea.prototype.setMinSize = function (size) {
            this._minSize = size;
            this._size = Math.max(this._minSize, this._size);
            this._dontDragOutside();
        };

        /* FUNCTIONS */
        CropArea.prototype._dontDragOutside=function() {
            var h=this._ctx.canvas.height,
                w=this._ctx.canvas.width;

            if (this._size>w) { this._size=w; }
            if (this._size>h) { this._size=h; }
            if (this._x<this._size/2) { this._x=this._size/2; }
            if (this._x>w-this._size/2) { this._x=w-this._size/2; }
            if (this._y<this._size/2) { this._y=this._size/2; }
            if (this._y>h-this._size/2) { this._y=h-this._size/2; }
        };

        CropArea.prototype._drawArea=function() {};

        CropArea.prototype.draw=function() {
            // draw crop area
            this._cropCanvas.drawCropArea(this._image, [this._x, this._y], this._size, this._drawArea);
        };

        CropArea.prototype.processMouseMove=function() {};

        CropArea.prototype.processMouseDown=function() {};

        CropArea.prototype.processMouseUp=function() {};

        return CropArea;
    }

    angular.module('plingUi').factory('cropCanvas', cropCanvasController);

    function cropCanvasController() {

    // Shape = Array of [x,y]; [0, 0] - center
        var shapeArrowNW=[[-0.5, -2], [-3, -4.5], [-0.5, -7], [-7, -7], [-7, -0.5], [-4.5, -3], [-2, -0.5]];
        var shapeArrowNE=[[0.5, -2], [3, -4.5], [0.5, -7], [7, -7], [7, -0.5], [4.5, -3], [2, -0.5]];
        var shapeArrowSW=[[-0.5, 2], [-3, 4.5], [-0.5, 7], [-7, 7], [-7, 0.5], [-4.5, 3], [-2, 0.5]];
        var shapeArrowSE=[[0.5, 2], [3, 4.5], [0.5, 7], [7, 7], [7, 0.5], [4.5, 3], [2, 0.5]];
        var shapeArrowN=[[-1.5, -2.5], [-1.5, -6], [-5, -6], [0, -11], [5, -6], [1.5, -6], [1.5, -2.5]];
        var shapeArrowW=[[-2.5, -1.5], [-6, -1.5], [-6, -5], [-11, 0], [-6, 5], [-6, 1.5], [-2.5, 1.5]];
        var shapeArrowS=[[-1.5, 2.5], [-1.5, 6], [-5, 6], [0, 11], [5, 6], [1.5, 6], [1.5, 2.5]];
        var shapeArrowE=[[2.5, -1.5], [6, -1.5], [6, -5], [11, 0], [6, 5], [6, 1.5], [2.5, 1.5]];

  // Colors
        var colors={
            'areaOutline': '#fff',
            'resizeBoxStroke': '#fff',
            'resizeBoxFill': '#444',
            'resizeBoxArrowFill': '#fff',
            'resizeCircleStroke': '#fff',
            'resizeCircleFill': '#444',
            'moveIconFill': '#fff'
        };

        return function(ctx) {

            /* Base functions */

            // Calculate Point
            var calcPoint=function(point, offset, scale) {
                return [scale*point[0]+offset[0], scale*point[1]+offset[1]];
            };

            // Draw Filled Polygon
            var drawFilledPolygon=function(shape, fillStyle, centerCoords, scale) {
                var pc, p, pc0;

                ctx.save();
                ctx.fillStyle = fillStyle;
                ctx.beginPath();
                pc0=calcPoint(shape[0], centerCoords, scale);
                ctx.moveTo(pc0[0], pc0[1]);

                for (p in shape) {
                    if (p > 0) {
                        pc=calcPoint(shape[p], centerCoords, scale);
                        ctx.lineTo(pc[0], pc[1]);
                    }
                }

                ctx.lineTo(pc0[0], pc0[1]);
                ctx.fill();
                ctx.closePath();
                ctx.restore();
            };

            /* Icons */
            this.drawIconMove=function(centerCoords, scale) {
                drawFilledPolygon(shapeArrowN, colors.moveIconFill, centerCoords, scale);
                drawFilledPolygon(shapeArrowW, colors.moveIconFill, centerCoords, scale);
                drawFilledPolygon(shapeArrowS, colors.moveIconFill, centerCoords, scale);
                drawFilledPolygon(shapeArrowE, colors.moveIconFill, centerCoords, scale);
            };

            this.drawIconResizeCircle=function(centerCoords, circleRadius, scale) {
                var scaledCircleRadius=circleRadius*scale;

                ctx.save();
                ctx.strokeStyle = colors.resizeCircleStroke;
                ctx.lineWidth = 2;
                ctx.fillStyle = colors.resizeCircleFill;
                ctx.beginPath();
                ctx.arc(centerCoords[0], centerCoords[1], scaledCircleRadius, 0, 2*Math.PI);
                ctx.fill();
                ctx.stroke();
                ctx.closePath();
                ctx.restore();
            };

            this.drawIconResizeBoxBase=function(centerCoords, boxSize, scale) {
                var scaledBoxSize=boxSize*scale;

                ctx.save();
                ctx.strokeStyle = colors.resizeBoxStroke;
                ctx.lineWidth = 2;
                ctx.fillStyle = colors.resizeBoxFill;
                ctx.fillRect(centerCoords[0] - scaledBoxSize/2, centerCoords[1] - scaledBoxSize/2, scaledBoxSize, scaledBoxSize);
                ctx.strokeRect(centerCoords[0] - scaledBoxSize/2, centerCoords[1] - scaledBoxSize/2, scaledBoxSize, scaledBoxSize);
                ctx.restore();
            };
            this.drawIconResizeBoxNESW=function(centerCoords, boxSize, scale) {
                this.drawIconResizeBoxBase(centerCoords, boxSize, scale);
                drawFilledPolygon(shapeArrowNE, colors.resizeBoxArrowFill, centerCoords, scale);
                drawFilledPolygon(shapeArrowSW, colors.resizeBoxArrowFill, centerCoords, scale);
            };
            this.drawIconResizeBoxNWSE=function(centerCoords, boxSize, scale) {
                this.drawIconResizeBoxBase(centerCoords, boxSize, scale);
                drawFilledPolygon(shapeArrowNW, colors.resizeBoxArrowFill, centerCoords, scale);
                drawFilledPolygon(shapeArrowSE, colors.resizeBoxArrowFill, centerCoords, scale);
            };

            /* Crop Area */
            this.drawCropArea=function(image, centerCoords, size, fnDrawClipPath) {
                var xRatio=image.width/ctx.canvas.width,
                    yRatio=image.height/ctx.canvas.height,
                    xLeft=centerCoords[0]-size/2,
                    yTop=centerCoords[1]-size/2;

                ctx.save();
                ctx.strokeStyle = colors.areaOutline;
                ctx.lineWidth = 2;
                ctx.beginPath();
                fnDrawClipPath(ctx, centerCoords, size);
                ctx.stroke();
                ctx.clip();

                 // draw part of original image
                if (size > 0) {
                    ctx.drawImage(image, xLeft*xRatio, yTop*yRatio, size*xRatio, size*yRatio, xLeft, yTop, size, size);
                }

                ctx.beginPath();
                fnDrawClipPath(ctx, centerCoords, size);
                ctx.stroke();
                ctx.clip();

                ctx.restore();
            };
        };
    }

    /**
     * EXIF service is based on the exif-js library (https://github.com/jseidelin/exif-js)
     */

    angular.module('plingUi').service('cropEXIF', cropEXIFService);

    function cropEXIFService () {
        var debug = false;
        var IptcFieldMap = {
            '0x78' : 'caption',
            '0x6E' : 'credit',
            '0x19' : 'keywords',
            '0x37' : 'dateCreated',
            '0x50' : 'byline',
            '0x55' : 'bylineTitle',
            '0x7A' : 'captionWriter',
            '0x69' : 'headline',
            '0x74' : 'copyright',
            '0x0F' : 'category'
        };

        function imageHasData(img) {
            return !!img.exifdata;
        }

        function base64ToArrayBuffer(base64, contentType) {

            /* global atob */
            var binary, len, buffer, view, i;

            contentType = contentType || base64.match(/^data\:([^\;]+)\;base64,/mi)[1] || ''; // eslint-disable-line no-console. e.g. 'data:image/jpeg;base64,...' => 'image/jpeg'
            base64 = base64.replace(/^data\:([^\;]+)\;base64,/gmi, '');
            binary = atob(base64);
            len = binary.length;
            buffer = new ArrayBuffer(len);
            view = new Uint8Array(buffer);
            for (i = 0; i < len; i++) {
                view[i] = binary.charCodeAt(i);
            }
            return buffer;
        }

        function objectURLToBlob(url, callback) {
            var http = new XMLHttpRequest();

            http.open('GET', url, true);
            http.responseType = 'blob';
            http.onload = function() {
                if (this.status === 200 || this.status === 0) {
                    callback(this.response);
                }
            };
            http.send();
        }

        function getStringFromDB(buffer, start, length) {
            var outstr = '', n;

            for (n = start; n < start+length; n++) {
                outstr += String.fromCharCode(buffer.getUint8(n));
            }
            return outstr;
        }

        function findEXIFinJPEG(file) {
            var dataView = new DataView(file), offset = 2, length, marker;

            if (debug) console.log('Got file of length ' + file.byteLength); // eslint-disable-line no-console
            if (dataView.getUint8(0) !== 0xFF || dataView.getUint8(1) !== 0xD8) {
                if (debug) console.log('Not a valid JPEG'); // eslint-disable-line no-console
                return false; // eslint-disable-line no-console. not a valid jpeg
            }

            length = file.byteLength;

            while (offset < length) {
                if (dataView.getUint8(offset) !== 0xFF) {
                    if (debug) console.log('Not a valid marker at offset ' + offset + ', found: ' + dataView.getUint8(offset)); // eslint-disable-line no-console
                    return false; // eslint-disable-line no-console. not a valid marker, something is wrong
                }

                marker = dataView.getUint8(offset + 1);
                if (debug) console.log(marker); // eslint-disable-line no-console

              // eslint-disable-line no-console. we could implement handling for other markers here,
              // eslint-disable-line no-console. but we're only looking for 0xFFE1 for EXIF data

                if (marker === 225) {
                    if (debug) console.log('Found 0xFFE1 marker'); // eslint-disable-line no-console

                    return;
              // eslint-disable-line no-console. offset += 2 + file.getShortAt(offset+2, true);

                } else {
                    offset += 2 + dataView.getUint16(offset+2);
                }

            }

        }

        function readIPTCData(file, startOffset, sectionLength) {
            var dataView = new DataView(file);
            var data = {};
            var fieldValue, fieldName, dataSize, segmentType;
            var segmentStartPos = startOffset;

            while (segmentStartPos < startOffset+sectionLength) {
                if (dataView.getUint8(segmentStartPos) === 0x1C && dataView.getUint8(segmentStartPos+1) === 0x02) {
                    segmentType = dataView.getUint8(segmentStartPos+2);
                    if (segmentType in IptcFieldMap) {
                        dataSize = dataView.getInt16(segmentStartPos+3);
                        fieldName = IptcFieldMap[segmentType];
                        fieldValue = getStringFromDB(dataView, segmentStartPos+5, dataSize);
                        // Check if we already stored a value with this name
                        if (data.hasOwnProperty(fieldName)) {
                            // Value already stored with this name, create multivalue field
                            if (data[fieldName] instanceof Array) {
                                data[fieldName].push(fieldValue);
                            }
                            else {
                                data[fieldName] = [data[fieldName], fieldValue];
                            }
                        }
                        else {
                            data[fieldName] = fieldValue;
                        }
                    }

                }
                segmentStartPos++;
            }
            return data;
        }

        function findIPTCinJPEG(file) {
            var dataView = new DataView(file), offset = 2, length, isFieldSegmentStart, nameHeaderLength, startOffset, sectionLength;

            if (debug) console.log('Got file of length ' + file.byteLength); // eslint-disable-line no-console
            if (dataView.getUint8(0) !== 0xFF || dataView.getUint8(1) !== 0xD8) {
                if (debug) console.log('Not a valid JPEG'); // eslint-disable-line no-console
                return false; // eslint-disable-line no-console. not a valid jpeg
            }
            length = file.byteLength;

            isFieldSegmentStart = function(dataView, offset) {
                return (
                  dataView.getUint8(offset) === 0x38 &&
                  dataView.getUint8(offset+1) === 0x42 &&
                  dataView.getUint8(offset+2) === 0x49 &&
                  dataView.getUint8(offset+3) === 0x4D &&
                  dataView.getUint8(offset+4) === 0x04 &&
                  dataView.getUint8(offset+5) === 0x04
                );
            };

            while (offset < length) {

                if ( isFieldSegmentStart(dataView, offset )) {

                    // Get the length of the name header (which is padded to an even number of bytes)
                    nameHeaderLength = dataView.getUint8(offset+7);
                    if (nameHeaderLength % 2 !== 0) nameHeaderLength += 1;
                    // Check for pre photoshop 6 format
                    if (nameHeaderLength === 0) {
                        // Always 4
                        nameHeaderLength = 4;
                    }

                    startOffset = offset + 8 + nameHeaderLength;
                    sectionLength = dataView.getUint16(offset + 6 + nameHeaderLength);

                    return readIPTCData(file, startOffset, sectionLength);

                }

                // Not the marker, continue searching
                offset++;

            }
        }

        function getImageData(img, callback) {
            var http, arrayBuffer, fileReader;

            function handleBinaryFile(binFile) {

                /* global  FileReader, XMLHttpRequest */
                var data = findEXIFinJPEG(binFile), iptcdata = findIPTCinJPEG(binFile);

                img.exifdata = data || {};
                img.iptcdata = iptcdata || {};
                if (callback) {
                    callback.call(img);
                }
            }

            if (img.src) {
                if (/^data\:/i.test(img.src)) {
                    arrayBuffer = base64ToArrayBuffer(img.src);

                    handleBinaryFile(arrayBuffer);

                } else if (/^blob\:/i.test(img.src)) {
                    fileReader = new FileReader();

                    fileReader.onload = function(e) {
                        handleBinaryFile(e.target.result);
                    };
                    objectURLToBlob(img.src, function (blob) {
                        fileReader.readAsArrayBuffer(blob);
                    });
                } else {
                    http = new XMLHttpRequest();

                    http.onload = function() {
                        if (this.status === 200 || this.status === 0) {
                            handleBinaryFile(http.response);
                        } else {
                            throw new Error('Could not load image');
                        }
                        http = null;
                    };
                    http.open('GET', img.src, true);
                    http.responseType = 'arraybuffer';
                    http.send(null);
                }
            } else if (window.FileReader && (img instanceof window.Blob || img instanceof window.File)) {
                fileReader = new FileReader();

                fileReader.onload = function(e) {
                    if (debug) console.log('Got file of length ' + e.target.result.byteLength); // eslint-disable-line no-console
                    handleBinaryFile(e.target.result);
                };

                fileReader.readAsArrayBuffer(img);
            }
        }

        this.getData = function(img, callback) {

            /* global HTMLImageElement */
            if ((img instanceof Image || img instanceof HTMLImageElement) && !img.complete) return false;

            if (!imageHasData(img)) {
                getImageData(img, callback);
            } else if (callback) {
                callback.call(img);
            }
            return true;
        };

        this.getTag = function(img, tag) {
            if (!imageHasData(img)) return;
            return img.exifdata[tag];
        };

        this.getAllTags = function(img) {
            var a,
                data = img.exifdata,
                tags = {};

            if (!imageHasData(img)) return {};

            for (a in data) {
                if (data.hasOwnProperty(a)) {
                    tags[a] = data[a];
                }
            }
            return tags;
        };

        this.pretty = function(img) {
            var a,
                data = img.exifdata,
                strPretty = '';

            if (!imageHasData(img)) return '';
            for (a in data) {
                if (data.hasOwnProperty(a)) {
                    if (typeof data[a] === 'object') {
                        if (data[a] instanceof Number) {
                            strPretty += a + ' : ' + data[a] + ' [' + data[a].numerator + '/' + data[a].denominator + ']\r\n';
                        } else {
                            strPretty += a + ' : [' + data[a].length + ' values]\r\n';
                        }
                    } else {
                        strPretty += a + ' : ' + data[a] + '\r\n';
                    }
                }
            }
            return strPretty;
        };

        this.readFromBinaryFile = function(file) {
            return findEXIFinJPEG(file);
        };
    }

    cropHostController.$inject = [ '$document', 'cropAreaCircle', 'cropAreaSquare', 'cropEXIF' ];

    angular.module('plingUi').factory('cropHost', cropHostController);

    function cropHostController($document, CropAreaCircle, CropAreaSquare, cropEXIF) {

    /* STATIC FUNCTIONS */

        // Get Element's Offset
        var getElementOffset=function(elem) {
            var box = elem.getBoundingClientRect();

            var body = document.body;
            var docElem = document.documentElement;

            var scrollTop = window.pageYOffset || docElem.scrollTop || body.scrollTop;
            var scrollLeft = window.pageXOffset || docElem.scrollLeft || body.scrollLeft;

            var clientTop = docElem.clientTop || body.clientTop || 0;
            var clientLeft = docElem.clientLeft || body.clientLeft || 0;

            var top  = box.top +  scrollTop - clientTop;
            var left = box.left + scrollLeft - clientLeft;

            return { 'top': Math.round(top), 'left': Math.round(left) };
        };

        return function(elCanvas, opts, events) {

        /* PRIVATE VARIABLES */

            // Object Pointers
            var ctx=null,
                image=null,
                theArea=null;

            // Dimensions
            var minCanvasDims=[300, 300],
                maxCanvasDims=[800, 800];

            // Result Image size
            var resImgSize=150;

            // Result Image type
            var resImgFormat='image/png';

            // Result Image quality
            var resImgQuality=null;

            var resetCropHost;
            var getChangedTouches;
            var onMouseMove;
            var onMouseDown;
            var onMouseUp;

            /* PRIVATE FUNCTIONS */

            // Draw Scene
            function drawScene() {
                // clear canvas
                ctx.clearRect(0, 0, ctx.canvas.width, ctx.canvas.height);

                if (image!==null) {
                // draw source image
                    ctx.drawImage(image, 0, 0, ctx.canvas.width, ctx.canvas.height);
                    ctx.save();
                    // and make it darker
                    ctx.fillStyle = 'rgba(0, 0, 0, 0.65)';
                    ctx.fillRect(0, 0, ctx.canvas.width, ctx.canvas.height);
                    ctx.restore();
                    // draw Area
                    theArea.draw();
                }
            }

                // Resets CropHost
            resetCropHost=function() {
                var imageDims, imageRatio, canvasDims;

                if (image!==null) {
                    theArea.setImage(image);
                    imageDims=[image.width, image.height];
                    imageRatio=image.width/image.height;
                    canvasDims=imageDims;

                    if (canvasDims[0]>maxCanvasDims[0]) {
                        canvasDims[0]=maxCanvasDims[0];
                        canvasDims[1]=canvasDims[0]/imageRatio;
                    } else if (canvasDims[0]<minCanvasDims[0]) {
                        canvasDims[0]=minCanvasDims[0];
                        canvasDims[1]=canvasDims[0]/imageRatio;
                    }
                    if (canvasDims[1]>maxCanvasDims[1]) {
                        canvasDims[1]=maxCanvasDims[1];
                        canvasDims[0]=canvasDims[1]*imageRatio;
                    } else if (canvasDims[1]<minCanvasDims[1]) {
                        canvasDims[1]=minCanvasDims[1];
                        canvasDims[0]=canvasDims[1]*imageRatio;
                    }
                    elCanvas.prop('width', canvasDims[0]).prop('height', canvasDims[1]).css({'margin-left': -canvasDims[0]/2+'px', 'margin-top': -canvasDims[1]/2+'px'});

                    theArea.setX(ctx.canvas.width/2);
                    theArea.setY(ctx.canvas.height/2);
                    theArea.setSize(Math.min(200, ctx.canvas.width/2, ctx.canvas.height/2));
                } else {
                    elCanvas.prop('width', 0).prop('height', 0).css({'margin-top': 0});
                }

                drawScene();
            };

    /*
     * Returns event.changedTouches directly if event is a TouchEvent.
     * If event is a jQuery event, return changedTouches of event.originalEvent
     */
            getChangedTouches=function(event) {
                if (angular.isDefined(event.changedTouches)) {
                    return event.changedTouches;
                } else {
                    return event.originalEvent.changedTouches;
                }
            };

            onMouseMove=function(e) {
                var offset, pageX, pageY;

                if (image!==null) {
                    offset=getElementOffset(ctx.canvas);
                    if (e.type === 'touchmove') {
                        pageX=getChangedTouches(e)[0].pageX;
                        pageY=getChangedTouches(e)[0].pageY;
                    } else {
                        pageX=e.pageX;
                        pageY=e.pageY;
                    }
                    theArea.processMouseMove(pageX-offset.left, pageY-offset.top);
                    drawScene();
                }
            };

            onMouseDown=function(e) {
                var offset,
                    pageX, pageY;

                e.preventDefault();
                e.stopPropagation();
                if (image!==null) {
                    offset=getElementOffset(ctx.canvas);
                    if (e.type === 'touchstart') {
                        pageX=getChangedTouches(e)[0].pageX;
                        pageY=getChangedTouches(e)[0].pageY;
                    } else {
                        pageX=e.pageX;
                        pageY=e.pageY;
                    }
                    theArea.processMouseDown(pageX-offset.left, pageY-offset.top);
                    drawScene();
                }
            };

            onMouseUp=function(e) {
                var offset, pageX, pageY;

                if (image!==null) {
                    offset=getElementOffset(ctx.canvas);
                    if (e.type === 'touchend') {
                        pageX=getChangedTouches(e)[0].pageX;
                        pageY=getChangedTouches(e)[0].pageY;
                    } else {
                        pageX=e.pageX;
                        pageY=e.pageY;
                    }
                    theArea.processMouseUp(pageX-offset.left, pageY-offset.top);
                    drawScene();
                }
            };

            this.getResultImageDataURI=function() {
                var temp_ctx, temp_canvas;

                temp_canvas = angular.element('<canvas></canvas>')[0];
                temp_ctx = temp_canvas.getContext('2d');
                temp_canvas.width = resImgSize;
                temp_canvas.height = resImgSize;
                if (image!==null) {
                    temp_ctx.drawImage(image, (theArea.getX()-theArea.getSize()/2)*(image.width/ctx.canvas.width), (theArea.getY()-theArea.getSize()/2)*(image.height/ctx.canvas.height), theArea.getSize()*(image.width/ctx.canvas.width), theArea.getSize()*(image.height/ctx.canvas.height), 0, 0, resImgSize, resImgSize);
                }
                if (resImgQuality!==null ) {
                    return temp_canvas.toDataURL(resImgFormat, resImgQuality);
                }
                return temp_canvas.toDataURL(resImgFormat);
            };

            this.setNewImageSource=function(imageSource) {
                var newImage;

                image=null;
                resetCropHost();
                events.trigger('image-updated');
                if (!!imageSource) {
                    newImage = new Image();
                    if (imageSource.substring(0, 4).toLowerCase()==='http') {
                        newImage.crossOrigin = 'anonymous';
                    }
                    newImage.onload = function() {
                        events.trigger('load-done');

                        cropEXIF.getData(newImage, function() {
                            var orientation=cropEXIF.getTag(newImage, 'Orientation'), canvas, ctx, cw, ch, cx, deg, cy;

                            if ([3, 6, 8].indexOf(orientation)>-1) {
                                canvas = document.createElement('canvas');
                                ctx=canvas.getContext('2d');
                                cw = newImage.width;
                                ch = newImage.height;
                                cx = 0;
                                cy = 0;
                                deg=0;
                                switch (orientation) {
                                    case 3:
                                        cx=-newImage.width;
                                        cy=-newImage.height;
                                        deg=180;
                                        break;
                                    case 6:
                                        cw = newImage.height;
                                        ch = newImage.width;
                                        cy=-newImage.height;
                                        deg=90;
                                        break;
                                    case 8:
                                        cw = newImage.height;
                                        ch = newImage.width;
                                        cx=-newImage.width;
                                        deg=270;
                                        break;
                                }

                                canvas.width = cw;
                                canvas.height = ch;
                                ctx.rotate(deg*Math.PI/180);
                                ctx.drawImage(newImage, cx, cy);

                                image=new Image();
                                image.src = canvas.toDataURL('image/png');
                            } else {
                                image=newImage;
                            }
                            resetCropHost();
                            events.trigger('image-updated');
                        });
                    };
                    newImage.onerror=function() {
                        events.trigger('load-error');
                    };
                    events.trigger('load-start');
                    newImage.src=imageSource;
                }
            };

            this.setMaxDimensions=function(width, height) {
                var curWidth, curHeight, imageDims, imageRatio, canvasDims, ratioNewCurWidth, ratioNewCurHeight, ratioMin;

                maxCanvasDims=[width, height];

                if (image!==null) {
                    curWidth=ctx.canvas.width;
                    curHeight=ctx.canvas.height;
                    imageDims=[image.width, image.height];
                    imageRatio=image.width/image.height;
                    canvasDims=imageDims;

                    if (canvasDims[0]>maxCanvasDims[0]) {
                        canvasDims[0]=maxCanvasDims[0];
                        canvasDims[1]=canvasDims[0]/imageRatio;
                    } else if (canvasDims[0]<minCanvasDims[0]) {
                        canvasDims[0]=minCanvasDims[0];
                        canvasDims[1]=canvasDims[0]/imageRatio;
                    }
                    if (canvasDims[1]>maxCanvasDims[1]) {
                        canvasDims[1]=maxCanvasDims[1];
                        canvasDims[0]=canvasDims[1]*imageRatio;
                    } else if (canvasDims[1]<minCanvasDims[1]) {
                        canvasDims[1]=minCanvasDims[1];
                        canvasDims[0]=canvasDims[1]*imageRatio;
                    }
                    elCanvas.prop('width', canvasDims[0]).prop('height', canvasDims[1]).css({'margin-left': -canvasDims[0]/2+'px', 'margin-top': -canvasDims[1]/2+'px'});

                    ratioNewCurWidth=ctx.canvas.width/curWidth;
                    ratioNewCurHeight=ctx.canvas.height/curHeight;
                    ratioMin=Math.min(ratioNewCurWidth, ratioNewCurHeight);

                    theArea.setX(theArea.getX()*ratioNewCurWidth);
                    theArea.setY(theArea.getY()*ratioNewCurHeight);
                    theArea.setSize(theArea.getSize()*ratioMin);
                } else {
                    elCanvas.prop('width', 0).prop('height', 0).css({'margin-top': 0});
                }
                drawScene();
            };

            this.setAreaMinSize=function(size) {
                size=parseInt(size, 10);
                if (!isNaN(size)) {
                    theArea.setMinSize(size);
                    drawScene();
                }
            };

            this.setResultImageSize=function(size) {
                size=parseInt(size, 10);
                if (!isNaN(size)) {
                    resImgSize=size;
                }
            };

            this.setResultImageFormat=function(format) {
                resImgFormat = format;
            };

            this.setResultImageQuality=function(quality) {
                quality = parseFloat(quality);
                if (!isNaN(quality) && quality>=0 && quality<=1) {
                    resImgQuality = quality;
                }
            };

            this.setAreaType=function(type) {
                var curSize=theArea.getSize(),
                    curMinSize=theArea.getMinSize(),
                    curX=theArea.getX(),
                    curY=theArea.getY(),
                    AreaClass;

                AreaClass=CropAreaCircle;
                if (type==='square') {
                    AreaClass=CropAreaSquare;
                }
                theArea = new AreaClass(ctx, events);
                theArea.setMinSize(curMinSize);
                theArea.setSize(curSize);
                theArea.setX(curX);
                theArea.setY(curY);

                // resetCropHost();
                if (image!==null) {
                    theArea.setImage(image);
                }
                drawScene();
            };

            /* Life Cycle begins */

            // Init Context var
            ctx = elCanvas[0].getContext('2d');

            // Init CropArea
            theArea = new CropAreaCircle(ctx, events);

            // Init Mouse Event Listeners
            $document.on('mousemove', onMouseMove);
            elCanvas.on('mousedown', onMouseDown);
            $document.on('mouseup', onMouseUp);

            // Init Touch Event Listeners
            $document.on('touchmove', onMouseMove);
            elCanvas.on('touchstart', onMouseDown);
            $document.on('touchend', onMouseUp);

            // CropHost Destructor
            this.destroy=function() {
                $document.off('mousemove', onMouseMove);
                elCanvas.off('mousedown', onMouseDown);
                $document.off('mouseup', onMouseMove);

                $document.off('touchmove', onMouseMove);
                elCanvas.off('touchstart', onMouseDown);
                $document.off('touchend', onMouseMove);

                elCanvas.remove();
            };
        };

    }

    angular.module('plingUi').factory('cropPubSub', cropPubSubController);

    function cropPubSubController () {

        return function() {
            var events = {};

            // Subscribe
            this.on = function(names, handler) {
                names.split(' ').forEach(function(name) {
                    if (!events[name]) {
                        events[name] = [];
                    }
                    events[name].push(handler);
                });
                return this;
            };
            // Publish
            this.trigger = function(name, args) {
                angular.forEach(events[name], function(handler) {
                    handler.call(null, args);
                });
                return this;
            };
        };
    }

    imgCropController.$inject = [ '$timeout', 'cropHost', 'cropPubSub' ];

    angular.module('plingUi').directive('imgCrop', imgCropController);

    function imgCropController ($timeout, CropHost, CropPubSub) {
        return {
            'restrict': 'E',
            'scope': {
                'image': '=',
                'resultImage': '=',

                'changeOnFly': '=',
                'areaType': '@',
                'areaMinSize': '=',
                'resultImageSize': '=',
                'resultImageFormat': '@',
                'resultImageQuality': '=',

                'onChange': '&',
                'onLoadBegin': '&',
                'onLoadDone': '&',
                'onLoadError': '&'
            },
            'template': '<canvas></canvas>',
            'controller': ['$scope', function($scope) {
                $scope.events = new CropPubSub();
            }],
            'link': function(scope, element) {
                // Init Events Manager
                var events = scope.events,
                    cropHost = new CropHost(element.find('canvas'), {}, events),
                    storedResultImage;

                var updateResultImage = function(scope) {
                    var resultImage = cropHost.getResultImageDataURI();

                    if (storedResultImage !== resultImage) {
                        storedResultImage = resultImage;
                        if (angular.isDefined(scope.resultImage)) {
                            scope.resultImage = resultImage;
                        }
                        scope.onChange({'$dataURI': scope.resultImage});
                    }
                };

                // Wrapper to safely exec functions within $apply on a running $digest cycle
                var fnSafeApply=function(fn) {
                    return function() {
                        $timeout(function() {
                            scope.$apply(function(scope) {
                                fn(scope);
                            });
                        });
                    };
                };

                // Setup CropHost Event Handlers

                events.on('load-start', fnSafeApply(function(scope) {
                    scope.onLoadBegin({});
                }))
                .on('load-done', fnSafeApply(function(scope) {
                    scope.onLoadDone({});
                }))
                .on('load-error', fnSafeApply(function(scope) {
                    scope.onLoadError({});
                }))
                .on('area-move area-resize', fnSafeApply(function(scope) {
                    if (!!scope.changeOnFly) {
                        updateResultImage(scope);
                    }
                }))
                .on('area-move-end area-resize-end image-updated', fnSafeApply(function(scope) {
                    updateResultImage(scope);
                }));

                // Sync CropHost with Directive's options
                scope.$watch('image', function() {
                    cropHost.setNewImageSource(scope.image);
                });
                scope.$watch('areaType', function() {
                    cropHost.setAreaType(scope.areaType);
                    updateResultImage(scope);
                });
                scope.$watch('areaMinSize', function() {
                    cropHost.setAreaMinSize(scope.areaMinSize);
                    updateResultImage(scope);
                });
                scope.$watch('resultImageSize', function() {
                    cropHost.setResultImageSize(scope.resultImageSize);
                    updateResultImage(scope);
                });
                scope.$watch('resultImageFormat', function() {
                    cropHost.setResultImageFormat(scope.resultImageFormat);
                    updateResultImage(scope);
                });
                scope.$watch('resultImageQuality', function() {
                    cropHost.setResultImageQuality(scope.resultImageQuality);
                    updateResultImage(scope);
                });

                // Update CropHost dimensions when the directive element is resized
                scope.$watch(
                    function () {
                        return [element[0].clientWidth, element[0].clientHeight];
                    },
                    function (value) {
                        cropHost.setMaxDimensions(value[0], value[1]);
                        updateResultImage(scope);
                    }, true);

                // Destroy CropHost Instance when the directive is destroying
                scope.$on('$destroy', function() {
                    cropHost.destroy();
                });
            }
        };
    }

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .directive('plgInfiniteScroll', PlgInfiniteScroll);

    PlgInfiniteScroll.$inject = [
        '$window', '$document'
    ];

    function PlgInfiniteScroll($window, $document) {

        var directive;

        // directive
        function linkFunc(scope, elem, attrs) {
            var checkBounds;


            checkBounds = function (event) {
                if (scope.listType !== 'datatable') { // eslint-disable-line no-console. No paginate DATATABLE, only LISTING and CARDS

                    if ($window.innerHeight + $window.scrollY === $document[0].body.offsetHeight) {
                        if (scope.controlCount > 0) {
                            scope.showLoadingScroll = true;
                        }
                        scope.$apply(attrs.plgInfiniteScroll);
                    }
                    angular.noop(event, elem);

                }
            };

            angular.element($window).bind('scroll load', checkBounds);
        }

        directive = {
            'restrict' : 'A',
            'link'     : linkFunc
        };

        return directive;
    }
}());

(function () {

    'use strict';

    angular
        .module('plingUi')
        .directive('plgLogin', PlgLogin);

    PlgLogin.$inject = ['plgLoginFactory'];

    function PlgLogin(plgLoginFactory) {
        var customerConfig, t;

        var inactivityTime = function (cb, timeOut) {
            if (timeOut < 0) return;

            window.onload        = resetTimer;
            document.onmousemove = resetTimer;
            document.onkeypress  = resetTimer;

            function resetTimer() {
                clearTimeout(t);//eslint-disable-line
                t = setTimeout(cb, timeOut);
            }
        };

        function showModal(scope) {
            if (customerConfig && customerConfig.loginTimeOutMinutes && +customerConfig.loginTimeOutMinutes > 0)//eslint-disable-line
                inactivityTime(function () {// eslint-disable-line
                    if (!scope.isOpen) {
                        plgLoginFactory.showModal(scope, null, showModal);
                        plgLoginFactory.removeToken();
                        inactivityTime(plgLoginFactory.removeToken, +customerConfig.logoutInactivyHours * 3600000);
                    }
                }, +customerConfig.loginTimeOutMinutes * 60000);
        }

        function getConfig(scope) {
            customerConfig = localStorage.getItem('PLING-CUSTOMER-CONFIG') || '{}';//eslint-disable-line
            try {
                customerConfig = JSON.parse(customerConfig);
            } catch (error) {
                customerConfig = { 'loginTimeOutMinutes': 30 };
            }
            scope.opacity = customerConfig.opacityBlocked;
        }

        return {
            'restrict'    : 'E',
            'scope'       : {},
            'templateUrl' : 'plg-login.html',
            'compile'     : function compile() {

                return {
                    'pre': function(scope) {
                        getConfig(scope);
                    },
                    'post': function(scope, element) {
                        if (element && element[0]) element[0].id = 'LOGIN_PANEL_ID';

                        scope.config = { 'panelClass': 'login-panel', 'clickOutsideToClose': false, 'escapeToClose': false };

                        if (customerConfig && customerConfig.loginTimeOutMinutes && +customerConfig.loginTimeOutMinutes > 0)//eslint-disable-line
                            showModal(scope);

                        scope.checkCapslock = function checkCapslock(e) {
                            var charCode = false, shifton = false;

                            e = e ? e : window.event;

                            charCode = e.which || e.keyCode;

                            if (e.shiftKey)
                                shifton = e.shiftKey;
                            else if (e.modifiers)
                                shifton = !!(e.modifiers & 4);

                            scope.isCapsLock = charCode >= 97 && charCode <= 122 && shifton || charCode >= 65 && charCode <= 90 && !shifton;
                        };

                        scope.$on('PLG-LOGIN-RETOKEN', function () {
                            if (!scope.isOpen)
                                plgLoginFactory.showModal(scope, null);
                        });

                        scope.$on('PLG-LOGIN-SHOW', function (event, data) {
                            scope.onLogin        = data.onLogin || angular.noop;
                            scope.enableUsername = data.enableUsername;
                            scope.titleMessage   = data.titleMessage;
                            scope.opacity        = data.opacity;
                            scope.config.clickOutsideToClose = true;
                            scope.config.escapeToClose       = true;
                            scope.config.onCloseSuccess      = data.onClose || angular.noop;
                            plgLoginFactory.showModal(scope, true);
                        });

                        scope.$on('PLG-LOGIN-UPDATE', function () {
                            if (t)
                                clearTimeout(t);//eslint-disable-line
                            window.onload        = null;
                            document.onmousemove = null;
                            document.onkeypress  = null;
                            getConfig(scope);
                            showModal(scope);
                        });
                    }
                };
            }
        };
    }
}());
(function () {
    'use strict';

    // Injeção de dependências
    plgAllBarController.$inject = [
        '$scope',
        '$route',
        'credentialsService',
        'ApplicationsService',
        'websocketService',
        '$location',
        '$timeout',
        '$localstorage',
        '$rootScope',
        '$mdPanel',
        '$mdSidenav',
        'notificationService',
        'sidenavAllBar',
        'boot.options'
    ];

    // Component configuration
    angular.module('plingUi').component('plgAllBar', {
        'bindings'  : {
            'showMenu'                  : '=',
            'showActions'               : '=',
            'applicationActions'        : '=',
            'selectedIndex'             : '=',
            'sidenavMenu'               : '=',
            'menuNotRoutes'             : '=',
            'menu'                      : '=',
            'toolbarOptions'            : '='
        },
        'templateUrl' : 'plg-all-bar.html',
        'controller'  : plgAllBarController
    });

    // CREATING CONTROLLER
    function plgAllBarController($scope, $route, credentialsService, applicationsService, websocketService,
        $location, $timeout, $localstorage, $rootScope, $mdPanel, $mdSidenav, notificationsService, sidenavAllBar, options) {

        var mdPanel,
            ctrl  = this,
            token = $localstorage.get('PLING-TOKEN'),
            showActionsBarLenght;

        ctrl.showMenu               = this.showMenu;
        ctrl.showActions            = this.showActions;

        // Top bar
        $scope.arrayNotifications  = [];
        $scope.chatNotifications   = 0;
        $scope.isNotificationAdded = false;

        // Menu bar
        $scope.menuNotRoutes       = this.menuNotRoutes;
        ctrl.currentMenuIndex      = 0;
        $scope.menu                = this.menu;

        // Actions bar
        ctrl.sidenavMenu           = this.sidenavMenu;

        ctrl.actionsBarShow = function () {

            if (ctrl.showActionsBar || ctrl.showActionsBarList) {
                ctrl.showActionsBar     = false;
                ctrl.showActionsBarList = false;
            } else {
                ctrl.showActionsBar     = true;
            }

        };

        ctrl.openMenu = function ($mdMenu, ev) {
            $mdMenu.open(ev);
        };

        // Side Menu
        ctrl.toggleSideMenu = function() {
            $rootScope.$emit('TOGGLE-MENU');
        };

        ctrl.toggleFilter = function() {
            $rootScope.$emit('TOGGLE-FILTER');
        };

        $rootScope.$on('TOGGLE-MENU', function() {
            $mdSidenav('sidenavDynamicLeft').toggle();
        });

        sidenavAllBar.on('showActionsBar', function () {

            if (showActionsBarLenght !== ctrl.applicationActions.length) {
                ctrl.showActionsBarList = false;
                ctrl.applicationActions.forEach(function(menuItem) {
                    if (menuItem.click === 'settings') {
                        ctrl.showActionsBarList = true;
                    }
                });
            }

            showActionsBarLenght = ctrl.applicationActions.length;

        });

        $scope.getAppCoreUrl = function (app, moduleStr) {
            var url;

            url = options.core_url + options.def_api_version;

            url += app ? '/' + app : '';
            url += moduleStr ? '/' + moduleStr : '';

            return url;
        };

        // Mostra ou esconde o Chat
        ctrl.toggleChat= function () {
            $rootScope.$broadcast('PLING-TOGGLE-CHAT', $('.plg-button-chat'));
        };

        // Obtém notificações geradas pelo recebimento de message no Websocket
        $rootScope.$on('PANEL-CLOSE', function() {
            mdPanel.close();
        });

        ctrl.showApp = function (ev) {
            var config,
                position = $mdPanel.newPanelPosition().relativeTo('.plg-button-apps').addPanelPosition($mdPanel.xPosition.OFFSET_START, $mdPanel.yPosition.BELOW),
                animation = $mdPanel.newPanelAnimation().duration(300 || {'open' : 300, 'close': 300}).openFrom('.plg-button-apps').closeTo('.plg-button-apps').withAnimation($mdPanel.animation.FADE);


            config = {
                'attachTo'     : angular.element(document.body),
                'controller'   : 'plgAllBarMenuApp',
                'templateUrl'  : 'plg-all-bar-menu-app.html',
                'locals': {
                    '$scope'             : $scope,
                    '$rootScope'         : $rootScope,
                    'applicationsService': applicationsService,
                    'event'              : $('.plg-button-apps')
                },
                'panelClass'   : 'plg-app-bar-panel',
                'hasBackdrop'  : true,
                'position'     : position,
                'clickOutsideToClose': true,
                'clickEscapeToClose' : true,
                'trapFocus'    : true,
                'animation'    : animation,
                'targetEvent'  : ev,
                'escapeToClose': true,
                'focusOnOpen'  : true,
                'zIndex'       : 90
            };
            mdPanel = $mdPanel.create(config);
            mdPanel.open();
        };

        ctrl.showUser = function (ev) {
            var config,
                position = $mdPanel.newPanelPosition().relativeTo('.plg-button-user').addPanelPosition($mdPanel.xPosition.OFFSET_END, $mdPanel.yPosition.BELOW),
                animation = $mdPanel.newPanelAnimation().duration(300 || {'open' : 300, 'close': 300}).openFrom('.plg-button-user').closeTo('.plg-button-user').withAnimation($mdPanel.animation.FADE);

            config = {
                'attachTo'     : angular.element(document.body),
                'controller'   : 'plgAllBarUser',
                'templateUrl'  : 'plg-all-bar-user.html',
                'locals': {
                    '$scope'             : $scope,
                    '$rootScope'         : $rootScope,
                    'credentialsService' : credentialsService,
                    'controlPanelUrl'    : $scope.controlPanelUrl,
                    'event'              : $('.plg-button-user')
                },
                'panelClass'   : 'plg-user-panel',
                'hasBackdrop'  : true,
                'position'     : position,
                'clickOutsideToClose': true,
                'clickEscapeToClose' : true,
                'trapFocus'    : true,
                'animation'    : animation,
                'targetEvent'  : ev,
                'escapeToClose': true,
                'focusOnOpen'  : true,
                'zIndex'       : 90
            };
            mdPanel = $mdPanel.create(config);
            mdPanel.open();
        };

        ctrl.showNotification = function (ev) {
            var config,
                position = $mdPanel.newPanelPosition().relativeTo('.plg-button-notification').addPanelPosition($mdPanel.xPosition.OFFSET_START, $mdPanel.yPosition.BELOW),
                animation = $mdPanel.newPanelAnimation().duration(300 || {'open' : 300, 'close': 300}).openFrom('.plg-button-notification').closeTo('.plg-button-notification').withAnimation($mdPanel.animation.FADE);

            config = {
                'attachTo'     : angular.element(document.body),
                'controller'   : 'plgAllBarNotification',
                'templateUrl'  : 'plg-all-bar-notification.html',
                'locals': {
                    '$scope'               : $scope,
                    '$rootScope'           : $rootScope,
                    'websocketService'     : websocketService,
                    'arrayNotifications'   : $scope.arrayNotifications,
                    'event'                : $('.plg-button-notification')
                },
                'panelClass'   : 'plg-notification-panel',
                'hasBackdrop'  : true,
                'position'     : position,
                'clickOutsideToClose': true,
                'clickEscapeToClose' : true,
                'trapFocus'    : true,
                'animation'    : animation,
                'targetEvent'  : ev,
                'escapeToClose': true,
                'focusOnOpen'  : true,
                'zIndex'       : 90
            };
            mdPanel = $mdPanel.create(config);
            mdPanel.open();
        };

        ctrl.clearChatNotification = function() {
            $scope.chatNotifications = 0;
        };

        $rootScope.$on('PLING-WEBSOCKET-EXTERNAL', function(event, externalData) {
            var doc = {
                'options': {
                    'key': externalData.caller
                },
                'doc': {
                    'description': externalData.message,
                    'data'       : externalData.date
                }
            };

            $timeout(function() {
                $scope.isNotificationAdded = true;
                $scope.arrayNotifications.push(doc);
            });
        });

        // Atualiza a imagem do usuário no topo da barra
        $rootScope.$on('PLING-ALL-BAR-UPDATE-CREDENTIAL', function (ev, credential) {
            if (ev) {
                $scope.user              = $scope.user || {};
                $scope.user.profileImage = credential.image;
                $scope.user.nickname     = credential.nickname;
            }
        });

        $scope.currentMenuIndexPng = function (pngicon, currentMenuIndex, index) {
            if (currentMenuIndex === index)
                return pngicon + '_blue';

            return pngicon;
        };

        $scope.tabMenuSelected = function (index, item) {
            $rootScope.$broadcast('MENU-BAR-SELECTED', index, item);
        };

        $scope.tabMenuSelectedShowDialog = function (ev) {
            $rootScope.$broadcast('MENU-BAR-SELECTED-SHOW-DIALOG', ev);
        };

        $scope.changeRoute = function(routeItem) {
            var routeArr = $route.current.originalPath ? $route.current.originalPath.split('/') : [];

            if (routeArr[1] === routeItem.route.split('/')[1])
                return;

            $location.path(routeItem.route);
        };

        $rootScope.$on('$routeChangeSuccess', function (event, route) {
            var routeArr = route.originalPath ? route.originalPath.split('/') : [];

            if ($scope.menu) {
                $scope.menu.forEach(function(item, index) {
                    if (routeArr[1] === item.route.split('/')[1])
                        ctrl.currentMenuIndex = index;
                });
            }
        });

        if ($scope.menuNotRoutes) {
            ctrl.currentMenuIndex = this.selectedIndex;
            $scope.menu           = this.menu;
        }

        ctrl.applicationActionsClick = function (item, ev, itemMenu) {
            $rootScope.$broadcast('ACTIONS-BAR-CLICK', item, itemMenu, ev);
        };

        /** Obtém notificações geradas pelo recebimento de message no Websocket
         * @param {object} notifications - Array de notificacoes.
         * @returns {boolean} false when notifications are not filled up.
         */
        function handleNotificationWebSocketMessage(notifications) {
            var i, isExist;

            if (!notifications || !notifications.result || notifications.entity.indexOf('notifications') === - 1)
                return false;

            $timeout(function() {
                $scope.isNotificationAdded = true;
            });

            for (i = 0; i < notifications.result.length; i += 1) {

                // Validando campos
                if (!notifications.result[i]._id || !notifications.result[i].doc || !notifications.result[i].options) {
                    continue;
                }

                // Validando existencia
                if ($scope.arrayNotifications.length > 0) {
                    $scope.arrayNotifications.map(function(value) { // eslint-disable-line
                        if (value._id === notifications.result[i]._id) {
                            isExist = true;
                        }
                    });
                }

                if (!isExist || $scope.arrayNotifications.length === 0) {
                    // Formatting date
                    notifications.result[i].doc.date = moment(notifications.result[i].doc.date).format('DD/MM/YYYY');

                    // Adicionando na fila
                    $scope.arrayNotifications.push(notifications.result[i]);
                }
            }

            $scope.isNotificationAdded = false;
        }

        // abrir e fechar sidenav
        ctrl.sidenavShow = function (sidenav) {

            if ($mdSidenav('sidenavDynamic').isOpen()) {
                $mdSidenav('sidenavDynamic').close();
                ctrl.sidenavDynamic.fnClose();
                ctrl.sidenavDynamic = null;
            }

            if (sidenav)
                if (ctrl.sidenavId === sidenav.id) {
                    ctrl.sidenavId = null;
                } else if (ctrl.sidenavId !== sidenav.id) {
                    $timeout(function() {
                        ctrl.backAction     = sidenav.backAction;
                        ctrl.sidenavDynamic = sidenav;
                        ctrl.sidenavId      = sidenav.id;
                        $mdSidenav('sidenavDynamic').toggle();
                        ctrl.sidenavDynamic.fnOpen();
                    });
                }

        };

        // configurações do sidenav
        ctrl.sidenavConfigurations  = sidenavAllBar.showCreate('configuration') || {};
        ctrl.sidenavActivities      = sidenavAllBar.showCreate('activities') || {};
        ctrl.sidenavHelp            = sidenavAllBar.showCreate('help') || {};

        sidenavAllBar.on('sidenavDynamic', function () {

            ctrl.sidenavDynamic     = sidenavAllBar.showCreate('dynamic');
            if (ctrl.sidenavDynamic)
                $timeout(function() {
                    ctrl.sidenavShow(ctrl.sidenavDynamic);
                });

        });

        sidenavAllBar.on('sidenavShowHide', function () {

            if ($mdSidenav('sidenavDynamic').isOpen()) {
                ctrl.sidenavBackdropShowHide = true;
            } else {
                ctrl.sidenavBackdropShowHide = null;
            }

            $mdSidenav('sidenavDynamic').toggle();

        });

        sidenavAllBar.on('sidenavClose', function () {

            $timeout(function() {
                ctrl.sidenavShow(ctrl.sidenavDynamic);
            });

        });

        sidenavAllBar.on('sidenavUpdate', function (params) {

            if (params)
                $timeout(function() {
                    ctrl.backdropOpacity = params.backdropOpacity;
                });

        });

        (function () {
            var i,
                localUser   = credentialsService.getLocal();

            $rootScope.$emit('PLING-SERVICE-BAR-ISLOADING', true);

            $scope.user = credentialsService.getLocal();

            if (localUser.imageDriveId && localUser.customer_id)
                $scope.user.profileImage = credentialsService.getProfileImage(localUser.imageDriveId, localUser.customer_id);

            $localstorage.set('PLING-USER', JSON.stringify($scope.user));

            $scope.currentAppModule = applicationsService.getCurrentAppModule();
            $scope.customerName     = localUser.customerName;

            $rootScope.$emit('PLING-SERVICE-BAR-ISLOADING', false);

            for (i = 0; i < applicationsService.getLocal().length; i += 1) {
                if (applicationsService.getLocal()[i].appModule === applicationsService.getCurrentAppModule()) {
                    ctrl.currentApp = applicationsService.getLocal()[i].name;
                }
                ctrl.env = applicationsService.getLocal()[i].env;
            }

            if (ctrl.env === 'homolog') {
                $scope.controlPanelUrl = 'https://admin-hml.pling.net.br?token=' + token;
            } else if (ctrl.env === 'pre-production') {
                $scope.controlPanelUrl = 'https://admin-pp.pling.net.br?token=' + token;
            } else if (ctrl.env === 'production') {
                $scope.controlPanelUrl = 'https://admin.pling.net.br?token=' + token;
            }

            ctrl.currentApp = ctrl.currentApp || applicationsService.getCurrentAppModule();

        }());

    }
}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .component('plgMenu', {
            'controller' : MenuController,
            'templateUrl': 'plg-menu.html'
        });

    MenuController.$inject = [
        '$scope', '$location', '$rootScope'
    ];

    function MenuController($scope, $location, $rootScope) {

        $scope.changeRoute = function (path) {
            if ($location.path().split('/')[1] !== path) {
                $location.path(path);
            }
        };

        $scope.$on('$routeChangeSuccess', function () {
            var i;

            // Activate the route item on menu
            for (i = 0; i < $scope.arrMenu.length; i += 1) {
                if ($scope.arrMenu[i].route === $location.path()) {
                    $scope.arrMenu[i].active = true;
                } else {
                    $scope.arrMenu[i].active = false;
                }

            }
        });

        $scope.arrMenu = $rootScope.menuRoutes;

    }
}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .directive('plgNavControl', PlgNavControl);

    function PlgNavControl() {

        function change(scope, e) {
            if (scope.navClass) {
                scope.each(function (ee) {
                    ee.setAttribute('class', (ee.getAttribute('class') || '').replace(scope.navClass, ''));
                });
                e.setAttribute('class', (e.getAttribute('class') || '') + ' ' + scope.navClass);
            }
            scope.plgNavControl = e.getAttribute('value');
        }

        return {
            'restrict': 'A',
            'scope': {
                'plgNavControl' : '=?',
                'navInit'       : '@?',
                'navClass'      : '@'
            },
            'compile': function compile() {
                return {
                    'pre': function(scope) {
                        scope.plgNavControl = scope.plgNavControl || scope.navInit || '';
                        scope.each = function (cb) {
                            Array.prototype.map.call(scope.elems, cb);
                        };
                    },
                    'post': function(scope, element) {
                        scope.elems = (element[0] || {}).children || { 'length': 0 };
                        scope.each(function (e) {
                            e.addEventListener('click', function () {
                                change(scope, e);
                            });
                            if (scope.plgNavControl === e.getAttribute('value')) change(scope, e);
                        });
                    }
                };
            }
        };
    }
}());
(function () {
    'use strict';

    angular
        .module('plingUi')
        .directive('plgPanel', PlgPanel);

    PlgPanel.$inject = [
        '$mdPanel', 'plgPanelFactory'
    ];

    function PlgPanel($mdPanel, plgPanelFactory) {
        var templatesDic = {};

        function DialogController(mdPanelRef) {
            this.close = function close(err, cb) {
                cb = cb || angular.noop;
                if (!err) mdPanelRef.close().then(function() { mdPanelRef.destroy(); cb(null, true); });
                else cb(err);
            };
        }

        DialogController.$inject = ['mdPanelRef'];

        return {
            'restrict'   : 'E',
            'scope'      : {
                // none
                'alignType': '@?',
                // { 'hasBackdrop': true }
                'config': '=?'
            },
            'transclude' : false,
            'compile'    : function compile(tElement, tScope) {
                templatesDic[tScope.id] = tElement[0].innerHTML;
                tElement[0].style.display = 'none';
                tElement[0].innerHTML = '';

                return {
                    'pre': function() {
                    },
                    'post': function(scope, elem, attrs) {
                        scope.$on((attrs.id || 'PLG_PANEL').toUpperCase() + '_OPEN', function (evt, locals, domEvent) {

                            scope.config = scope.config || {};

                            plgPanelFactory.buildConfig(scope.config, {
                                'attachTo'            : angular.element(document.body),
                                'controllerAs'        : '$ctrl',
                                'template'            : plgPanelFactory.buildTemplate(templatesDic[attrs.id], attrs),
                                'clickOutsideToClose' : true,
                                'escapeToClose'       : true,
                                'focusOnOpen'         : false,
                                'zIndex'              : 104
                            });

                            plgPanelFactory.checkIdError(locals.dom_id);

                            scope.config['position'] = plgPanelFactory.setAligment($mdPanel.newPanelPosition().relativeTo('[id="' + locals.dom_id + '"]'), scope.alignType, $mdPanel);

                            scope.config['openFrom']   = domEvent;
                            scope.config['locals']     = locals;
                            scope.config['controller'] = DialogController;
                            $mdPanel.open(scope.config).then(function(result) {
                                if (scope.alignType !== 'center') {
                                    // ALGORITMO QUE LIMITA O PANEL A SEMPRE APARECER NA TELA
                                    plgPanelFactory.limitInScreen(result);
                                }
                            });
                        });
                    }
                };
            }
        };
    }
}());
(function () {
    'use strict';

    angular
        .module('plingUi')
        .directive('plgPasswordStrength', plgPasswordStrength);

    plgPasswordStrength.$inject = [ 'zxcvbnFactory' ];

    function plgPasswordStrength(zxcvbnFactory) {
        return {
            'restrict': 'E',
            'scope' : {
                'password' : '='
            },
            'templateUrl' : 'plg-password-strength.html',
            'link': function($scope) {
                $scope.$watch('password', function(password) {
                    $scope.passwordStrength = password ? password.length > 6 && zxcvbnFactory.score(password) || 0 : null;
                }, true);
            }
        };
    }

})();
(function() {
    'use strict';

    angular
        .module('plingUi')
        .component('plgScreenImageCrop', {
            'templateUrl' : 'plg-screen-image-crop.html',
            'transclude'  : false,
            'bindings'    : {}
        });
    angular
        .module('plingUi')
        .controller('ScreenImageCropController', ScreenImageCropController);

    ScreenImageCropController.$inject = [
        '$rootScope', '$scope', '$element', '$timeout', '$window',
        'plgScreenImageCropFactory'
    ];

    function ScreenImageCropController($rootScope, $scope, $element, $timeout, $window, plgScreenImageCropFactory) {
        var
            reader,
            _video,
            fileSelectedElem;

        /*
         *--------------------------------------------------------------------------
         * UPLOAD FILE
         *--------------------------------------------------------------------------
         */

        $scope.openFileDialog =  function () {
            fileSelectedElem = $window.document.getElementById('customerFileUploader');
            fileSelectedElem.onclick =  charge;
            $scope.isUpload = false;
            $scope.isShowWebCam = false;
            fileSelectedElem.click();

            $scope.title = 'Recorte a imagem';
        };

        function checkFileDialog () {

            $timeout(function () {
                if (fileSelectedElem.files.length === 0)
                    return;

                reader.readAsDataURL(fileSelectedElem.files[0]);

                $scope.showFileFooter   = true;
                $scope.showWebcamFooter = false;

                $scope.$apply(function ($scope) {
                    $scope.imageData = reader.result;
                });
            }, 300);

        }

        function charge () {
            $window.document.body.onfocus = checkFileDialog;
        }

        /*
         *--------------------------------------------------------------------------
         * WEBCAM
         *--------------------------------------------------------------------------
         */
        $scope.takePicture = function() {
            $scope.showFileFooter   = false;
            $scope.showWebcamFooter = true;

            $scope.isTake = true;
            $scope.isShowWebCam = true;
            $scope.isShowImage = false;
            $scope.isClick = true;
            $scope.isCrop = false;

            $scope.title = 'Tirar fotografia';
        };

        $scope.makeSnapshot = function() {
            var
                patCanvas,
                ctxPat,
                idata;

            $scope.showFileFooter   = false;
            $scope.showWebcamFooter = true;

            if (_video) {

                patCanvas = document.createElement('canvas');

                patCanvas.width = _video.width;
                patCanvas.height = _video.height;

                ctxPat = patCanvas.getContext('2d');
                idata = getVideoData($scope.patOpts.x, $scope.patOpts.y, $scope.patOpts.w, $scope.patOpts.h);

                ctxPat.putImageData(idata, 0, 0);

                $timeout(function () {
                    $scope.$apply(function ($scope) {
                        $scope.imageData = patCanvas.toDataURL();
                        $scope.isShowWebCam = false;
                        $scope.isShowImage = true;
                        $scope.isClick = false;
                        $scope.isCrop = true;
                        $scope.title = 'Recorte a imagem';

                        $scope.showFileFooter   = true;
                        $scope.showWebcamFooter = false;
                    });
                }, 300);
            }
        };

        function getVideoData(x, y, w, h) {
            var
                hiddenCanvas = document.createElement('canvas'),
                ctx;

            hiddenCanvas.width = _video.width;
            hiddenCanvas.height = _video.height;

            ctx = hiddenCanvas.getContext('2d');
            ctx.drawImage(_video, 0, 0, _video.width, _video.height);

            return ctx.getImageData(x, y, w, h);
        }

        $scope.onSuccess = function () {
            _video = $scope.channel.video;
            $scope.$apply(function() {
                $scope.patOpts.w = _video.width;
                $scope.patOpts.h = _video.height;
            });
        };

        $scope.cropImage = function() {
            var obj = {
                'image' : $scope.croppedImageData,
                'imageFile' : base64ToFile($scope.croppedImageData)
            };

            $rootScope.cropCb(obj);

            $scope.$ctrl.close();
        };

        $scope.onError = function() {
            $scope.noWebCam = true;
        };

        $scope.isLoading = true;
        $scope.onInit = function() {
            $scope.isLoading = false;
        };

        function base64ToFile (base64) {
            var fileName = 'profileImage';

            return plgScreenImageCropFactory.base64ToFile(base64, fileName);
        }

        (function init() {
            reader                  = new FileReader();
            $scope.croppedImageData = '';
            $scope.patOpts          = { 'x': 0, 'y': 0, 'w': 25, 'h': 25 };
            $scope.channel          = {};
            $scope.isCrop           = false;
            $scope.isClick          = true;
            $scope.isTake           = false;
            $scope.isUpload         = false;
            $scope.isShowWebCam     = false;

            $scope.title = 'Selecione uma opção';
        })();

        reader.onloadend = function () {
            $scope.$apply(function ($scope) {
                $scope.imageData    = reader.result;
                $scope.isTake       = true;
                $scope.isShowWebCam = false;
                $scope.isShowImage  = true;
                $scope.isCrop       = true;
                $scope.isClick      = false;
            });
        };
    }

}());
(function(angular) {
    'use strict';

    var
        bottom = {
            // + 1 catches off by one errors in chrome
            'isAttached': function(el) { return el.scrollTop + el.clientHeight + 1 >= el.scrollHeight; },
            'scroll'    : function(el) { el.scrollTop = el.scrollHeight; }
        },

        top = {
            'isAttached': function(el) { return el.scrollTop <= 1; },
            'scroll'    : function(el) { el.scrollTop = 0; }
        },

        right = {
            'isAttached': function(el) {
                return el.scrollLeft + el.clientWidth + 1 >= el.scrollWidth;
            },
            'scroll': function(el) {
                el.scrollLeft = el.scrollWidth;
            }
        },

        left = {
            'isAttached': function(el) { return el.scrollLeft <= 1; },
            'scroll'    : function(el) { el.scrollLeft = 0; }
        },
        angularModule = angular.module('luegg.directives', []);

    createDirective(angularModule, 'plgScrollGlue', bottom);
    createDirective(angularModule, 'plgScrollGlueTop', top);
    createDirective(angularModule, 'plgScrollGlueBottom', bottom);
    createDirective(angularModule, 'plgScrollGlueLeft', left);
    createDirective(angularModule, 'plgScrollGlueRight', right);

    function createActivationState($parse, attr, scope) {

        var getter;

        function unboundState(initValue) {
            var activated = initValue;

            return {
                'getValue': function() { return activated; },
                'setValue': function(value) { activated = value; }
            };
        }

        function oneWayBindingState(getter, scope) {
            return {
                'getValue': function() { return getter(scope); },
                'setValue': function() {}
            };
        }

        function twoWayBindingState(getter, setter, scope) {
            return {
                'getValue': function() { return getter(scope); },
                'setValue': function(value) {
                    if (value !== getter(scope)) {
                        scope.$apply(function() { setter(scope, value); });
                    }
                }
            };
        }

        if (attr !== '') {
            getter = $parse(attr);

            if (getter.assign !== undefined) { // eslint-disable-line
                return twoWayBindingState(getter, getter.assign, scope);
            } else {
                return oneWayBindingState(getter, scope);
            }
        } else {
            return unboundState(true);
        }
    }

    function createDirective(module, attrName, direction) {
        module.directive(attrName, ['$parse', '$window', '$timeout', function($parse, $window, $timeout) {
            return {
                'priority' : 1,
                'restrict' : 'A',
                'link'     : function(scope, $el, attrs) {
                    var
                        el              = $el[0],
                        activationState = createActivationState($parse, attrs[attrName], scope);

                    function scrollIfGlued() {
                        if (activationState.getValue() && !direction.isAttached(el))
                            direction.scroll(el);
                    }

                    function onScroll() { activationState.setValue(direction.isAttached(el)); }

                    scope.$watch(scrollIfGlued);

                    $timeout(scrollIfGlued, 0, false);

                    $window.addEventListener('resize', scrollIfGlued, false);

                    $el.on('scroll', onScroll);

                    // Remove listeners on directive destroy
                    $el.on('$destroy', function() {
                        $el.unbind('scroll', onScroll);
                    });

                    scope.$on('$destroy', function() {
                        $window.removeEventListener('resize', scrollIfGlued, false);
                    });
                }
            };
        }]);
    }

}(angular));
(function () {

    angular
        .module('plingUi')
        .value('routesConfigMap', {});

    angular
        .module('plingUi')
        .component('plgSearch', {
            'controller' : plgSearchCtrl,
            'templateUrl' : 'plg-search.html',
            'bindings'  : {
                'setFocus': '=?'
            }
        });

    plgSearchCtrl.$inject = [
        '$rootScope', '$element', 'plgSearchService', 'plgSearchFactory'
    ];

    function plgSearchCtrl($rootScope, $element, plgSearchService, plgSearchFactory) {
        var ctrl = this, onTypingEnd;

        ctrl.searchText      = '';
        ctrl.getDocumentName = plgSearchService.getRefName;
        ctrl.items           = plgSearchService.items;
        ctrl.getFields       = plgSearchService.getFields;

        ctrl.fieldSelected = plgSearchFactory.fieldSelected(ctrl);
        ctrl.showMenu      = plgSearchFactory.showMenu(ctrl, $element);

        ctrl.selectedItemChange = function (items) {
            if (items) {
                plgSearchService.onSelectedItemChange(angular.copy(items));
                ctrl.showMenu(false);
            }
        };

        ctrl.querySearch = function (term, cb, debounce) {
            ctrl.isLoading = false;
            ctrl.hasError  = false;

            window.clearTimeout(onTypingEnd);

            if (ctrl.dateField && (!term || !term.fromDate)) {
                term = ctrl.dateSelected || {};
            }

            if (term.length <= 2 || ctrl.dateField && !term.$invalid && term.fromDate && term.fromDate.length <= 0) {
                ctrl.items.length = 0;
                plgSearchService.close();
            }

            if (term && term.length > 2 || ctrl.dateField && !term.$invalid && term.fromDate) {
                onTypingEnd = setTimeout(function() {
                    ctrl.isLoading = true;
                    ctrl.isEmpty   = false;
                    plgSearchService.querySearch(term, function (err, data) {
                        if (err) console.error(err);// eslint-disable-line

                        ctrl.isLoading = false;
                        ctrl.hasError  = err;
                        ctrl.isEmpty   = !(ctrl.items && ctrl.items.length > 0);

                        cb = cb || angular.noop;
                        cb(err, data);
                    });
                }, debounce || 500);
            }
        };

        document.body.addEventListener('click', plgSearchFactory.bodyClick(ctrl, $element, $rootScope));

        $rootScope.$on('$routeChangeStart', function (event, next) {
            if (next && next.$$route && next.$$route.originalPath) {
                plgSearchService.setRouteAPI(next.$$route.originalPath);
            }
        });

        $rootScope.$on('PLGCALENDAR_CLOSE_PLG_SBAR', function (ev, selected) {
            if (selected) {
                ctrl.querySearch(selected, function (err, data) {
                    if (data) {
                        ctrl.showMenu(true);
                    }
                }, 0);
            }
        });

        $rootScope.$on('PLG-FOCUS-SBAR-INP', function () {
            ctrl.showMenu();
        });
    }
}());
(function() {

    'use strict';

    // CREATING COMPONENT WITH BINDINGS
    angular
        .module('plingUi')
        .component('plgSelect', {
            'controller' : plgSelectController,
            'templateUrl': 'plg-select.html',
            'bindings'   : {
                'configModel'   : '=',
                'items'         : '=',
                'ngModel'       : '=',
                'isDisabled'    : '=',
                'isLoading'     : '=',
                'isFocus'       : '=',
                'fnOnBlur'      : '&',
                'fnSaveItem'    : '&',
                'fnDeleteItem'  : '&'
            }
        });

    plgSelectController.$inject = [
        '$scope', '$mdPanel', '$element', '$timeout'
    ];

    function plgSelectController($scope, $mdPanel, element, $timeout) {
        var ctrl = this;

        ctrl.configModel        = this.configModel;
        ctrl.configModel.refName= ctrl.configModel.refName  || 'name';
        ctrl.configModel.refId  = ctrl.configModel.refId    || '_id';
        ctrl.items              = this.items;
        ctrl.ngModel            = this.ngModel;
        ctrl.isDisabled         = this.isDisabled;
        ctrl.isLoading          = this.isLoading;
        ctrl.fnOnBlur           = this.fnOnBlur;
        ctrl.fnSaveItem         = this.fnSaveItem;
        ctrl.fnDeleteItem       = this.fnDeleteItem;
        ctrl.isFocus            = this.isFocus;
        ctrl.filterSelect       = null;
        ctrl.itemName           = null;
        ctrl.isLoadingStart     = false;
        ctrl.isFocusItem        = false;
        ctrl.isMsgErr           = false;
        ctrl.ngModelSelect      = angular.copy(ctrl.ngModel);

        function cloneNgModel (items, id) {
            if (id === items[ctrl.configModel.refId]) {

                ctrl.itemName  = items[ctrl.configModel.refName];

                if (ctrl.configModel.returnField) {
                    return items[ctrl.configModel.returnField];
                } else if (!ctrl.configModel.returnField) {
                    return JSON.parse(JSON.stringify(items));
                }
            }
            return false;
        }

        ctrl.reload = function (param) {
            var arrItem,
                arrModel,
                ngModelSelectClone,
                id,
                i,
                j;

            // console.log(ctrl.ngModelSelect + 'legal'); // eslint-disable-line

            ctrl.arrItemName = [];

            if (ctrl.items) {

                arrItem  = Array.isArray(ctrl.items);
                arrModel = Array.isArray(ctrl.ngModelSelect);

                if (arrModel) {
                    ngModelSelectClone = [];
                }

                // verifica se é um array
                if (arrItem) {
                    for (i = 0; i < ctrl.items.length; i += 1) {

                        ctrl.items[i].icon = 'icone_check_box_outline';

                        if (arrModel) {

                            for (j = 0; j < ctrl.ngModelSelect.length; j += 1) {
                                // verifica no array, se é um object
                                id = typeof ctrl.ngModelSelect[j] === 'object' ? ctrl.ngModelSelect[j][ctrl.configModel.refId] : ctrl.ngModelSelect[j];

                                if (cloneNgModel(ctrl.items[i], id)) {
                                    ngModelSelectClone.push(cloneNgModel(ctrl.items[i], id));
                                    ctrl.items[i].icon = 'icone_check_box';
                                    if (ctrl.configModel.isChips) {
                                        ctrl.arrItemName.push(ctrl.items[i]);
                                    }
                                }
                            }

                        } else if (!arrModel) {
                            // verifica se é um object
                            if (ctrl.ngModelSelect) {
                                id = typeof ctrl.ngModelSelect === 'object' ? ctrl.ngModelSelect[ctrl.configModel.refId] : ctrl.ngModelSelect;

                                if (cloneNgModel(ctrl.items[i], id)) {
                                    ngModelSelectClone = cloneNgModel(ctrl.items[i], id);
                                    ctrl.items[i].icon = 'icone_check_box';
                                }
                            }
                        }
                    }
                }

                ctrl.ngModelSelect  = ngModelSelectClone;
                ctrl.isLoadingStart = true;
                arrModel            = Array.isArray(ctrl.ngModelSelect);

                if (arrModel) {

                    if (ctrl.ngModelSelect.length > 1)
                        ctrl.itemName  = ctrl.ngModelSelect.length + ' Selecionados';

                    ctrl.ngModelSelect.map(function (u) {

                        delete u.icon;
                        delete u.actionMouse1;
                        delete u.actionMouse2;

                        return u;

                    });
                }

                if (!ctrl.ngModelSelect) {
                    ctrl.itemName    = null;
                    ctrl.arrItemName = null;
                }

                if (ctrl.ngModelSelect)
                    if (ctrl.ngModelSelect.length < 1) {
                        ctrl.itemName    = null;
                        ctrl.arrItemName = null;
                    }

                ctrl.ngModel   = angular.copy(ctrl.ngModelSelect);
                if (param === 'onBlur') {
                    $timeout(function () {
                        ctrl.fnOnBlur(ctrl);

                        if (!ctrl.configModel.isMultiple)
                            ctrl.closeFocus();
                    });
                }

            }

        };

        ctrl.focus = function (ev) {
            var config,
                target,
                position, i;

            if (ev.path) {
                for (i = 0; i < ev.path.length; i += 1) {
                    if (ev.path[i].id === ctrl.configModel.ref) {
                        target = ev.path[i];
                    }
                }
            }

            if (!ev.path && ev.currentTarget) {
                target = ev.currentTarget;
            }

            position = $mdPanel.newPanelPosition()
                               .relativeTo(target)
                               .addPanelPosition($mdPanel.xPosition.ALIGN_START, $mdPanel.yPosition.BELOW);

            ctrl.msgErr  = false;
            config = {
                'attachTo'            : angular.element(document.body),
                'controller'          : 'plgSelectOptions',
                'templateUrl'         : 'plg-select-options.html',
                'position'            : position,
                'panelClass'          : 'plg-select-item',
                'clickOutsideToClose' : true,
                'hasBackdrop'         : false,
                'escapeToClose'       : true,
                'focusOnOpen'         : true,
                'zIndex'              : 90,
                'onRemoving'          : ctrl.closeFocus,
                'locals': {
                    '$scope'    : $scope,
                    'ctrl'      : ctrl,
                    '$timeout'  : $timeout,
                    'width'     : element[0].parentElement.scrollWidth
                }
            };

            ctrl.mdPanel = $mdPanel.create(config);
            ctrl.mdPanel.open();
        };

        ctrl.closeFocus = function () {
            ctrl.isFocusItem = false;
            ctrl.isMsgErr    = true;
            ctrl.mdPanel.close();
        };

        ctrl.selectItem = function (item) {
            var arrModel,
                index;

            if (typeof item === 'object') {

                item.actionMouse1 = false;

                if (!ctrl.configModel.isMultiple) {

                    if (ctrl.configModel.returnField) {
                        ctrl.ngModelSelect = item[ctrl.configModel.returnField];
                    } else if (!ctrl.configModel.returnField) {
                        ctrl.ngModelSelect = item;
                    }

                } else if (ctrl.configModel.isMultiple) {

                    arrModel = Array.isArray(ctrl.ngModelSelect);

                    if (!arrModel) {
                        ctrl.ngModelSelect = [];
                    }

                    if (item.icon === 'icone_check_box_outline') {

                        if (ctrl.configModel.returnField) {
                            ctrl.ngModelSelect.push(item[ctrl.configModel.returnField]);
                        } else if (!ctrl.configModel.returnField) {
                            ctrl.ngModelSelect.push(item);
                        }

                    } else if (item.icon === 'icone_check_box') {

                        index = ctrl.ngModelSelect.map( function(d) {
                            if (typeof d === 'object')
                                return d[ctrl.configModel.refId];

                            return d;
                        }).indexOf(item[ctrl.configModel.refId]);

                        ctrl.ngModelSelect.splice(index, 1);

                    }
                }

                ctrl.reload('onBlur');

            }
        };

        ctrl.selectSaveItem = function () {

            var newSelectItem = JSON.parse(JSON.stringify(ctrl.filterSelect));

            ctrl.configModel.save        = {};
            ctrl.filterSelect            = null;
            ctrl.isLoading               = true;
            ctrl.configModel.save[ctrl.configModel.refName] = newSelectItem;

            ctrl.fnSaveItem(ctrl);

        };

        ctrl.selectDeleteItem = function (item) {

            ctrl.configModel.delete = item;
            ctrl.isLoading          = true;
            ctrl.fnDeleteItem(ctrl);

        };

        $scope.$watchCollection('$ctrl.items', function ngModelWatch(newVal, oldVal) {

            var arrNewVal  = Array.isArray(newVal),
                arrOldVal  = Array.isArray(oldVal);

            $timeout(function () {
                if (arrNewVal && arrOldVal) {
                    return ctrl.reload();
                }
            });

        });

        $scope.$watchCollection('$ctrl.ngModelSelect', function ngModelWatch(newVal, oldVal) {

            var arrNewVal  = Array.isArray(newVal);

            $timeout(function () {
                if (arrNewVal)
                    if (newVal.length !== oldVal.length)
                        return ctrl.reload();

                if (newVal !== oldVal)
                    return ctrl.reload();
            });

        });

        $scope.$watchCollection('$ctrl.ngModel', function ngModelWatch(newVal, oldVal) {

            var arrNewVal  = Array.isArray(newVal);

            $timeout(function () {
                if (arrNewVal)
                    if (newVal.length !== oldVal.length) {
                        ctrl.ngModelSelect      = angular.copy(ctrl.ngModel);
                        return ctrl.reload();
                    }

                if (newVal !== oldVal) {
                    ctrl.ngModelSelect      = angular.copy(ctrl.ngModel);
                    return ctrl.reload();
                }
            });

        });

        (function init() {
            // Carregamento
            ctrl.reload();
        }());

    }

}());

(function () {
    'use strict';

    angular
        .module('plingUi')
        .directive('plgSetFocus', PlgSetFocus);

    PlgSetFocus.$inject = [ '$rootScope', '$parse', '$timeout'];

    function PlgSetFocus($rootScope, $parse, $timeout) {
        return {
            'restrict' : 'A',
            'replace'  : true,
            'link'     : function($scope, element, attrs) {

                var model     = $parse(attrs.plgSetFocus),
                    elementId = attrs.elementId,
                    elem;

                $scope.$watch(model, function (value) {
                    if (value) {

                        elem = element[0];

                        if (elementId) {
                            elem = document.getElementById(elementId) || elem;
                        }

                        if (attrs.byEvent && elementId) {
                            $rootScope.$broadcast('PLG-FOCUS-' + elementId.toUpperCase());
                        }
                        $timeout(function() {
                            elem.focus();
                        });

                    }
                });

                element.bind('blur', function () {
                    if (model && model.assign) {
                        $scope.$apply(model.assign($scope, false));
                    }
                });

            }
        };
    }
}());

(function() {

    'use strict';

    angular
        .module('plingUi')
        .directive('plgTheming', PlingTheming);

    PlingTheming.$inject = [ 'plingThemingService' ];

    function PlingTheming(plingThemingService) {
        var theming = plingThemingService.showCreate('theming-default');

        return {
            'restrict'  : 'A',
            'replace'   : true,
            'link'      : function (scope, element, attrs) {

                attrs.$observe('plingTheming', function(background) {
                    if (background) {
                        if (theming[background])
                            background = theming[background];

                        element.css({
                            'background-color' : background,
                            'color' : theming.primaryColor
                        });

                    } else if (!background) {

                        element.css({
                            'background-color' : theming.primary,
                            'color' : theming.primaryColor
                        });

                    }
                });

            }
        };

    }

}());

(function() {

    'use strict';

    // CREATING COMPONENT WITH BINDINGS
    angular
        .module('plingUi')
        .component('plgSidenav', {
            'controller' : PlgSidenav,
            'templateUrl': 'plg-sidenav.html',
            'bindings'   : {
                'sidenavId'     : '=',
                'id'            : '=',
                'name'          : '=',
                'template'      : '@',
                'backAction'    : '=',
                'menu'          : '=',
                'fnMenu'        : '&',
                'fnReturnMenu'  : '&',
                'fnClose'       : '&'
            }
        });

    PlgSidenav.$inject = [
        '$scope', '$mdPanel', '$element', '$timeout', '$mdSidenav'
    ];

    function PlgSidenav($scope, $mdPanel, $element, $timeout, $mdSidenav) {

        var ctrl = this;

        ctrl.sidenavId      = this.sidenavId;
        ctrl.id             = this.id;
        ctrl.name           = this.name;
        ctrl.template       = this.template;
        ctrl.backAction     = this.backAction;
        ctrl.menu           = this.menu;
        ctrl.fnMenu         = this.fnMenu;
        ctrl.fnReturnMenu   = this.fnReturnMenu;
        ctrl.fnClose        = this.fnClose;

        ctrl.sidenavClick = function (item) {
            if (!item.children) {

                ctrl.backAction = item;
                $timeout(function() {
                    ctrl.fnMenu();
                });

            }
        };

        ctrl.sidenavBack = function () {
            ctrl.fnReturnMenu();
            ctrl.backAction = false;
        };

        ctrl.sidenavClose = function () {
            $mdSidenav('sidenavDynamic').close();
            ctrl.sidenavId = null;
            ctrl.fnClose();
        };

    }

}());

(function () {
    'use strict';

    angular.module('plingUi').component('plgToast', {
        'bindings'   : {},
        'controller' : plgToastController
    });

    plgToastController.$inject = [
        '$scope', '$rootScope', '$mdToast'
    ];

    function plgToastController($scope, $rootScope, $mdToast) {
        var last = {
            'bottom' : true,
            'top'    : false,
            'left'   : false,
            'right'  : false
        };

        $scope.toastPosition = angular.extend({}, last);

        $scope.getToastPosition = function() {
            sanitizePosition();

            return Object.keys($scope.toastPosition)
              .filter(function(pos) { return $scope.toastPosition[pos]; })
              .join(' ');
        };

        function sanitizePosition() {
            var current = $scope.toastPosition;

            if ( current.bottom && last.top ) current.top = false;
            if ( current.top && last.bottom ) current.bottom = false;
            if ( current.right && last.left ) current.left = false;
            if ( current.left && last.right ) current.right = false;

            last = angular.extend({}, current);
        }

        $rootScope.$on('TOAST-ACTION', function(event, obj) {
            $mdToast.show({
                'hideDelay'   : 4000,
                'position'    : $scope.getToastPosition(),
                'controller'  : 'plgToastController',
                'locals': {
                    '$scope'      : $scope,
                    '$mdToast'    : $mdToast,
                    '$rootScope'  : $rootScope,
                    'message'     : obj.message,
                    'button'      : obj.button,
                    'callback'    : obj.cb
                },
                'highlightClass' : 'md-primary',
                'templateUrl'    : 'plg-toast.html'
            });
        });
    }

}());

(function () {

    angular
        .module('plingUi')
        .directive('plgTooltip', PlgTooltip);

    PlgTooltip.$inject = [ '$timeout' ];

    function PlgTooltip ($timeout) {

        return {
            'restrict' : 'E',
            'replace': false,
            'scope'    : {
                'tooltip': '='
            },
            'template' : '<span ng-show="showTooltip" ng-if="tooltip" ng-style="left" class="plg-tooltip" ng-bind-html="tooltip | plgToTrustedHtml"></span>',
            'link'     : function (scope, element) {

                var clickTooltip = function (event) {
                        var clickover = $(event.target);

                        $timeout(function() {
                            if (!clickover.hasClass('fa-question-circle') && !clickover.hasClass('img-using-tooltip') && !clickover.hasClass('plg-tooltip'))
                                if (scope.showTooltip)
                                    scope.showTooltip = false;
                        });
                    },
                    parentElement = element.parent()[0];

                document.addEventListener('touchstart', clickTooltip, false);
                $(document).click(clickTooltip);

                parentElement.addEventListener('mousemove', function() {
                    $timeout(function() {
                        var rect;

                        if (element[0].getBoundingClientRect) {
                            rect = element[0].getBoundingClientRect();

                            scope.left = {
                                'left': rect.left + 'px',
                                'top': rect.top + 'px'
                            };
                        }

                        scope.showTooltip = true;

                        $timeout(function () {
                            limitInScreen(element[0].lastElementChild);
                        });

                    });
                });

                parentElement.addEventListener('mouseleave', function() {
                    $timeout(function() {
                        scope.showTooltip = false;
                    });
                });

                function limitInScreen(result) {
                    var rect;

                    if (result && result.getBoundingClientRect && result.style) {
                        rect = result.getBoundingClientRect();

                        if (rect) {
                            if (rect.left + rect.width > window.innerWidth)
                                result.style.left = Math.abs(rect.left + rect.width - window.innerWidth - rect.left) + 'px';//eslint-disable-line
                            if (rect.top < 0)
                                result.style.top = '0px';
                        }
                    }
                }

            }
        };
    }

}());

(function() {

    'use strict';

    angular
        .module('plingUi')
        .directive('plingVersion', PlingVersion);

    PlingVersion.$inject = [ '$http' ];

    function PlingVersion($http) {

        return {
            'restrict'  : 'E',
            'replace'   : true,
            'template'  : function() {
                return '<div class="pling-version" >' +
                            '<div > {{ version }} </div>' +
                            '<div > {{ versionPling }} </div>' +
                        '</div>';
            },
            'link': function (scope) {

                $http.get('../../bower.json')
                    .success(function (data) {
                        if (data.description && data.version)
                            scope.version       = data.description + ' v' + data.version;
                        if (data.dependencies)
                            if (data.dependencies['pling-ui'])
                                scope.versionPling  = 'PlingUI v' + data.dependencies['pling-ui'];
                    }).error(function (err) {
                        window.console.log(err);
                    });

            }
        };

    }

}());

(function () {

    'use strict';

    angular
        .module('plingUi')
        .directive('plgWebcam', PlgWebcam);

    function PlgWebcam() {
        return {
            'template': '<div class="webcam" ng-transclude></div>',
            'restrict': 'E',
            'replace': true,
            'transclude': true,
            'scope': {
                'onInit': '&?',
                'onError': '&',
                'onStream': '&',
                'onStreaming': '&',
                'placeholder': '=',
                'config': '=channel'
            },
            'link': function postLink($scope, element) {
                var
                    videoElem = null,
                    videoStream = null,
                    placeholder = null,
                    _removeDOMElement,
                    onDestroy,
                    onSuccess,
                    onFailure,
                    startWebcam,
                    stopWebcam;

                $scope.config = $scope.config || {};

                _removeDOMElement = function _removeDOMElement(DOMel) {
                    if (DOMel) {
                        angular.element(DOMel).remove();
                    }
                };

                onDestroy = function onDestroy() {
                    var
                        checker,
                        tracks;

                    if (!!videoStream ) {
                        checker = typeof videoStream.getVideoTracks === 'function';

                        if (videoStream.getVideoTracks && checker) {
                            // get video track to call stop in it
                            // videoStream.stop() is deprecated and may be removed in the
                            // near future
                            // ENSURE THIS IS CHECKED FIRST BEFORE THE FALLBACK
                            // videoStream.stop()
                            tracks = videoStream.getVideoTracks();

                            if (tracks && tracks[0] && tracks[0].stop) {
                                tracks[0].stop();
                            }
                        } else if (videoStream.stop) {
                            // deprecated, may be removed in the near future
                            videoStream.stop();
                        }
                    }
                    if (!!videoElem) {
                        delete videoElem.src;
                    }
                };

                // called when camera stream is loaded
                onSuccess = function onSuccess(stream) {
                    var vendorURL;

                    videoStream = stream;

                    // Firefox supports a src object
                    if (window.navigator.mozGetUserMedia) {
                        videoElem.mozSrcObject = stream;
                    } else {
                        vendorURL = window.URL || window.webkitURL;
                        videoElem.src = vendorURL.createObjectURL(stream);
                    }

                    /* Start playing the video to show the stream from the webcam */
                    videoElem.play();
                    $scope.config.video = videoElem;

                    /* Call custom callback */
                    if ($scope.onStream) {
                        $scope.onStream({'stream': stream});
                    }

                    $scope.onInit = $scope.onInit || angular.noop;
                    $scope.onInit(null);
                };

                // called when any error happens
                onFailure = function onFailure(err) {
                    _removeDOMElement(placeholder);

                    /* Call custom callback */
                    if ($scope.onError) {
                        $scope.onError({'err':err});
                    }

                    $scope.onInit = $scope.onInit || angular.noop;
                    $scope.onInit(err);

                    return;
                };

                startWebcam = function startWebcam() {
                    var
                        isStreaming = false,
                        width,
                        height,
                        mediaConstraint;

                    videoElem = document.createElement('video');
                    videoElem.setAttribute('class', 'webcam-live');
                    videoElem.setAttribute('autoplay', '');
                    element.append(videoElem);

                    if ($scope.placeholder) {
                        placeholder = document.createElement('img');
                        placeholder.setAttribute('class', 'webcam-loader');
                        placeholder.src = $scope.placeholder;
                        element.append(placeholder);
                    }

                    // Default variables
                    width = element.width = $scope.config.videoWidth || 500;
                    height = element.height = 500;

                    // Check the availability of getUserMedia across supported browsers
                    if (!window.hasUserMedia()) {
                        onFailure({'code':-1, 'msg': 'Browser não suporta getUserMedia.'});
                        return;
                    }

                    mediaConstraint = { 'video': true, 'audio': false };
                    window.navigator.getMedia(mediaConstraint, onSuccess, onFailure);

                    /* Start streaming the webcam data when the video element can play
                    * It will do it only once
                    */
                    videoElem.addEventListener('canplay', function() {
                        var scale;

                        if (!isStreaming) {
                            scale = width / videoElem.videoWidth;
                            height = videoElem.videoHeight * scale || $scope.config.videoHeight;

                            videoElem.setAttribute('width', width);
                            videoElem.setAttribute('height', height);

                            isStreaming = true;

                            $scope.config.video = videoElem;

                            _removeDOMElement(placeholder);

                            /* Call custom callback */
                            if ($scope.onStreaming) {
                                $scope.onStreaming();
                            }
                        }
                    }, false);
                };

                stopWebcam = function stopWebcam() {
                    onDestroy();
                    videoElem.remove();
                };

                $scope.$on('$destroy', onDestroy);
                $scope.$on('START_WEBCAM', startWebcam);
                $scope.$on('STOP_WEBCAM', stopWebcam);

                startWebcam();
            }
        };
    }
}());

(function() {
    'use strict';

    angular
        .module('plingUi')
        .component('plgWizard', {
            'templateUrl' : 'plgWizard.html',
            'transclude'  : true,
            'controller'  : WizardController,
            'bindings'    : {
                'steps'              : '@',
                'stepnames'          : '@',
                'wizardtemplatepath' : '@',
                'index'              : '@'
            }
        });

    function WizardController($scope) {
        var ctrl = this;

        ctrl.initWizard = function(isLoad) {
            var itemSteps,
                style     = '<style>',
                divisor   =  100 / (ctrl.steps - 1),
                indexWithoutZero;

            if (isLoad) {

                divisor = parseFloat(divisor.toFixed(2));

                if (ctrl.stepnames)
                    ctrl.stepnames = JSON.parse(ctrl.stepnames);

                ctrl.loadWizard = true;

                ctrl.totalSteps = new Array(parseInt(ctrl.steps, 10)).join().split(',').map(function(item, index, array) {
                    itemSteps = {};

                    // Monta o css
                    indexWithoutZero = index + 1;

                    style += '[data-step="' + index + '"] p:nth-child(' + (parseInt(index, 10) + 1) + ') { color: #000; }';
                    style += '[data-step="' + index + '"] p:nth-child(' + (parseInt(index, 10) + 1) + ')::before { outline : none; border : 0; background : #458be3; color : #fff;}';

                    Array(indexWithoutZero).join().split(',').map(function(innerItem, innerIndex) {
                        style += '[data-step="' + indexWithoutZero + '"] p:nth-child(' + (parseInt(innerIndex, 10) + 1) + ')::before { content: "✔";}';
                        style += '[data-step="' + indexWithoutZero + '"] p:nth-child(' + (parseInt(innerIndex, 10) + 1) + ')::before { outline : none; border : 0; background : #458be3; color : #fff;}';
                    });

                    if (ctrl.stepnames.length === array.length)
                        itemSteps.name = ctrl.stepnames[index];

                    itemSteps.index = ++index;

                    return itemSteps;
                });

                // Carrega % da barra de status do Wizard
                ctrl.totalSteps.reverse().map(function(item, index) {
                    var totalSteps = item.index || item;
                    var percent = (parseInt(totalSteps, 10) - 1) *  Math.round(divisor);

                    if (index > 2)
                        percent += 1;

                    if (totalSteps === 1)
                        style += '.step-wizard[data-step="' + parseInt(index, 10) + '"]::after { right : 3%; }';
                    else
                        style += '.step-wizard[data-step="' + parseInt(index, 10) + '"]::after { right : ' + parseFloat(percent) + '%; }';
                });

                style += '</style>';

                $(style).appendTo('head');

                ctrl.totalSteps.reverse();

                ctrl.parent = $scope.$parent;
            }
        };

        $scope.$parent.initWizard = ctrl.initWizard;

        ctrl.parent = $scope.$parent;
    }
}());
(function () {

    'use strict';


    angular
        .module('plingUi')
        .filter('plgChatInteractionDateFilter', plgChatInteractionDateFilterController);

    function plgChatInteractionDateFilterController () {
        return function(value) {
            var
                date = null,
                time  = '',
                today       = moment(),
                format      = 'DD/MM';

            if (value) {
                date = moment(value);
                time = ' às ' + date.format('HH:mm');

                if (today.format('DD/MM/YYYY') === date.format('DD/MM/YYYY'))
                    return 'hoje' + time;

                if (today.subtract(1, 'days').format('DD/MM/YYYY') === date.format('DD/MM/YYYY'))
                    return 'ontem' + time;

                if (today.format('YYYY') !== date.format('YYYY'))
                    format = 'DD/MM/YYYY';

                return 'em ' + date.format(format) + time;
            }
        };
    }

    angular
        .module('plingUi')
        .controller('PlgChatConversationController', PlgChatConversationController);

    PlgChatConversationController.$inject = [
        '$rootScope', '$scope', '$timeout', 'chatService', 'credentialsService', '$window', 'chatFactory'
    ];

    function PlgChatConversationController($rootScope, $scope, $timeout, chatService, credentialService, $window, chatFactory) {

        var self = this;

        self.isLoading = true;
        self.chatMessagelimit = 0;
        self.interactions = 1;
        self.totalMessages = 0;
        self.newMessages = 0;
        self.typing = false;
        self.userTyping = [];

        function getFormattedDate(createDate) {
            var
                today       = moment(),
                format      = 'DD/MM',
                currentDate = moment(createDate);

            if (today.format('DD/MM/YYYY') === currentDate.format('DD/MM/YYYY'))
                return 'Hoje';

            if (today.subtract(1, 'days').format('DD/MM/YYYY') === currentDate.format('DD/MM/YYYY'))
                return 'Ontem';

            if (today.format('YYYY') !== currentDate.format('YYYY'))
                format = 'DD/MM/YYYY';

            return currentDate.format(format);
        }

        self.getTooltipUsersList = function(room) {
            return chatFactory.buildTooltipUsersList(room, self.currentUser);
        };

        self.getUserImage = function(imageDriveId, customer_id) {
            return $scope.$parent.$parent.getUserImage(imageDriveId, customer_id);
        };

        self.loadMoreMessages = function() {
            var skip = self.interactions * self.chatMessagelimit + self.newMessages;

            self.isLoadingMessages = true;

            chatService.getMessages(self.chatRoom._id, skip)
                .success(function(messageResp) {
                    messageResp.messages.reverse().map(function(message) {
                        message.formattedDate = getFormattedDate(message.createDate);
                        message.message = $window.EmojiPicker.prototype.unicodeToImage(message.message);
                        self.currentChat.messages.unshift(message);
                    });
                    self.interactions++;
                    self.totalMessages = messageResp.totalMessages;
                    self.isLoadingMessages = false;
                })
                .error(function(reason) {
                    console.error(reason); // eslint-disable-line
                });
        };

        self.scrollUp = function() {
            if (!self.isLoadingMessages && self.currentChat.messages.length < self.totalMessages)
                self.loadMoreMessages();
        };

        self.init = function(currentUserObj, chatRoomObj) {

            self.chatRoom = chatRoomObj;
            // Inicia loader
            self.isLoading = true;

            // Setando Websocket Listener
            setRoomSocketListener(chatRoomObj);

            // Setar como ativo
            chatRoomObj.isOpen = true;

            // Usuario corrente
            self.currentUser = currentUserObj;

            // Chat corrente
            self.currentChat = chatRoomObj;

            // isNewMessageArrived: Animação que pisca o Header
            self.isNewMessageArrived = chatRoomObj.isFirstMessage || false;

            // Atributos Chat
            setRoomAttributes(self.currentChat);

            // Buscar Msgs
            chatService.getMessages(chatRoomObj._id)
                .success(function(messageResp) {

                    $timeout(function() {
                        var atachEvents = null;
                        var currentTimeout = null;

                        self.chatMessagelimit = messageResp.limit;

                        // Mensagens Chat
                        self.currentChat.messages = messageResp.messages;

                        self.currentChat.messages.forEach(function (message) {
                            message.formattedDate = getFormattedDate(message.createDate);
                            message.message = $window.EmojiPicker.prototype.unicodeToImage(message.message);
                        });

                        self.totalMessages = messageResp.totalMessages;

                        // Loader
                        self.isLoading = false;

                        window.emojiPicker.discover();

                        if (!chatRoomObj.isOpenRoom)
                            self.isNewMessageArrived = true;

                        self.currentChat.isFocused = false;
                        // Scrolla para o final da janela
                        scrollBottom();

                        chatService.sendDeliveryConfirmation([self.currentChat]);

                        chatService.sendReadingConfirmation(self.currentChat);
                        // Focus no input Text
                        atachEvents = window.setInterval(function() {
                            var element = document.body.querySelector('.chat-rooom-id-' + self.currentChat._id);

                            if (!element)
                                return false;

                            element.querySelector('.emoji-wysiwyg-editor').addEventListener('focus', function() {
                                // timeout para executar o apply sem disparar erro
                                $timeout(function() {
                                    self.currentChat.isFocused =  true;
                                    self.clearNotification();
                                });
                            });

                            element.querySelector('.emoji-wysiwyg-editor').addEventListener('blur', function() {
                                // timeout para executar o apply sem disparar erro
                                $timeout(function() {
                                    self.currentChat.isFocused =  false;
                                    self.clearNotification();
                                });
                            });

                            element.onkeydown = function() {
                                if (currentTimeout) {
                                    $timeout.cancel(currentTimeout);
                                } else {
                                    chatService.sendTypingViaWs(self.currentChat, 'start');
                                }

                                currentTimeout = $timeout(function() {
                                    chatService.sendTypingViaWs(self.currentChat, 'end');
                                    $timeout.cancel(currentTimeout);
                                    currentTimeout = null;
                                }, 800);
                            };
                            $timeout(function() {
                                element.querySelector('.emoji-wysiwyg-editor').focus();
                            });
                            window.clearInterval(atachEvents);
                        }, 100);

                        $scope.$on('$locationChangeStart', function() {
                            window.clearInterval(atachEvents);
                        });

                    });
                })
                .error(function(reason) {
                    console.error(reason); // eslint-disable-line
                });
        };

        self.getUserImage = function(imageDriveId) {
            return credentialService.getProfileImage(imageDriveId, self.currentUser.customer_id);
        };

        self.setTopMost = function() {
            self.topMost = true;
        };

        self.cancelAndFocus = function() {
            self.isLoading = false;
            self.currentChat.isFocused = true;
        };

        self.set_zoom = function (text) {
            var
                test           = text.message.split('<img'),
                firstCharater  = text.message.substring(0, 1),
                lastCharater   = text.message.charAt(text.message.length-1);

            self.setZoom = false;

            if (firstCharater === '<' && lastCharater === '>' && test.length === 2) {
                self.setZoom = true;
                return { 'zoom': '2' };
            }
        };

        self.sendMessage = function(room, dataId) {
            var
                text = '',
                messageObj,
                roomObj = {};

            // Valor do ContentEditable
            if (dataId)
                text = $('div').find('[data-id="' + dataId + '"]')[2].innerHTML;
            else
                text = $('#chat-input-' + room._id).val();

            if (text !== '') {
                messageObj = {
                    'message'       : text,
                    'isFirstMessage': room.messages.length === 0
                };

                messageObj.username   = self.currentUser.nickname || self.currentUser.fullname || self.currentUser.usr;
                messageObj.name       = room.name;
                messageObj.people     = room.people;

                // Setando objeto da mensagem
                roomObj = {
                    'credential_id' : self.currentUser.id,
                    'message'       : text
                };

                // Verificando imagem do usuario
                if (self.currentUser.imageDriveId)
                    messageObj.imageDriveId = self.currentUser.imageDriveId;

                // Adicionando mensagem na lista
                roomObj.message = $window.EmojiPicker.prototype.unicodeToImage(roomObj.message);
                room.messages.push(angular.copy(roomObj));

                // Scrolando para o final da lista
                scrollBottom();

                // Limpando mensagem
                self.chatMessage = null;
                $('#chat-input-' + room._id).val('');
                $('#chat-input-' + room._id).next().empty();

                if (dataId)
                    $('div').find('[data-id="' + dataId + '"]')[2].innerHTML = '';

                // Enviando via ws
                chatService.sendMessageViaWs(messageObj, room);
                chatService.sendInteractionViaWs();
            }
        };

        function scrollBottom() {
            $timeout(function() {
                self.isToScroll = true;
            });
        }

        function setRoomAttributes(roomObj) {
            var currentUser = self.currentUser;

            // Validação para sala com 1 people
            if (roomObj.people.length === 1) {

                // Usuário corrente é o owner
                if (currentUser.id === roomObj.owner._id) {
                    roomObj.name         = roomObj.people[0].name;
                    roomObj.imageDriveId = roomObj.people[0].imageDriveId;
                }

                // Usuário corrente é amigo
                else if (currentUser.id === roomObj.people[0]._id) {
                    roomObj.name         = roomObj.owner.name;
                    roomObj.imageDriveId = roomObj.owner.imageDriveId;
                }
                roomObj.userImageUrl = roomObj.imageDriveId ? self.getUserImage(roomObj.imageDriveId) : '';
            }
        }

        function setRoomSocketListener(roomObj) {

            var roomChannel = 'chat:room:' + (roomObj.room_id || roomObj._id);

            // Registrando Listener para Sala de Conversa
            chatService.setRealTimeListener(roomChannel, function(messageObj) {
                var oldList;
                var index =  null;
                var i = 0;

                switch (messageObj.action) {
                    case 'readed' :  {

                        if (messageObj.sender.id === self.currentUser.id)
                            break;

                        self.currentChat.messages.some(function(message) {
                            if (messageObj.message_id.indexOf(message._id) >= 0) {
                                if (!message.readed)
                                    message.readed = [];

                                if (message.readed.indexOf(messageObj.sender.id) < 0)
                                    message.readed.push(messageObj.sender.id);
                                i++;
                            }

                            if (i === messageObj.message_id.length) {
                                $scope.$apply();
                                return true;
                            }
                        });
                        break;
                    }

                    case 'received' :  {

                        if (messageObj.sender.id === self.currentUser.id)
                            break;

                        self.currentChat.messages.some(function(message) {
                            if (messageObj.message_id.indexOf(message._id) >= 0) {
                                if (!message.received)
                                    message.received = [];

                                if (message.received.indexOf(messageObj.sender.id) < 0)
                                    message.received.push(messageObj.sender.id);
                                i++;
                            }

                            if (i === messageObj.message_id.length) {
                                $scope.$apply();
                                return true;
                            }
                        });
                        break;
                    }
                    case 'typing' :

                        if (messageObj.sender.id === self.currentUser.id)
                            break;

                        if (self.currentChat.people === 1)
                            self.typing = messageObj.event === 'start';
                        else {
                            if (messageObj.event === 'start') {
                                index = self.userTyping.findIndex(function(x) {return x.id === messageObj.sender.id; });
                                if (index === -1)
                                    self.userTyping.push(messageObj.sender);
                            } else
                                self.userTyping = self.userTyping.filter(function (x) { return x.id !== messageObj.sender.id; });

                            self.typing = self.userTyping.length > 0;
                        }


                        $scope.$apply();
                        break;
                    default :
                        if (self.currentChat.isCollapsed) {
                            $rootScope.$broadcast('PLING-CHAT-NOTIFICATION');
                        }

                        // Se o usuario que enviou for o usuario corrente
                        if (self.currentUser.id !== messageObj.sender.id) {
                            self.isNewMessageArrived = true;
                            chatService.sendDeliveryConfirmation(messageObj.data.message, true);
                            if (self.currentChat.isOpen)
                                chatService.sendReadingConfirmation(messageObj.data.message, true);
                        } else {
                            oldList = self.currentChat.messages;

                            // Encontra a mensagem sem ID
                            self.currentChat.messages = oldList.filter(function(message) {
                                return message._id;
                            });
                        }

                        $timeout(function() {
                            var lastMessage = messageObj.data.message;

                            lastMessage.formattedDate = getFormattedDate(lastMessage.currentDate);
                            lastMessage.message = $window.EmojiPicker.prototype.unicodeToImage(lastMessage.message);
                            self.currentChat.messages.push(lastMessage);

                            self.currentChat.lastMessage = {
                                'credential_id': messageObj.data.message.credential_id,
                                'message': lastMessage
                            };
                            self.newMessages += 1;
                            self.totalMessages += 1;
                            scrollBottom();
                        });
                        break;
                }
            });
        }

        self.clearNotification = function() {
            self.isNewMessageArrived = false;
        };

        self.roomName = function(currentUser, owner, people) {
            return owner._id !== currentUser._id ? people[0].name
                                                 : owner.name;
        };

        self.minimizerToggle = function() {
            // Limpando notificacao topbar quando expandir o chat
            if (self.currentChat.isCollapsed) $rootScope.$broadcast('PLING-CHAT-NOTIFICATION', true);

            // Determina collapsed/ellapsed
            self.currentChat.isCollapsed = !self.currentChat.isCollapsed;

            // Remove notificacao
            self.isNewMessageArrived = false;

            // Scrolla para o final da janela
            self.scrollMessage = true;
        };

        self.focus = function() {
            self.currentChat.isFocused = true;
            self.clearNotification();
            chatService.setFocusedRoomId( self.currentChat._id);
        };

        self.blur = function() {
            self.currentChat.isFocused = false;
            self.clearNotification();
            chatService.setFocusedRoomId(null);
        };
    }

}());


(function () {

    'use strict';

    angular
        .module('plingUi')
        .directive('plgActiveChat', PlgActiveChatDirective);

    PlgActiveChatDirective.$inject = ['$filter'];

    function PlgActiveChatDirective($filter) {
        return {
            'restrict'   : 'E',
            'templateUrl': 'plg-chat-conversation.html',
            'link': function ($scope) {
                $scope.close = function(room) {
                    var chatList = $scope.chatRoomList;

                    room.isOpen = false;
                    room.isRemoved = true;

                    chatList = $filter('filter')(chatList, function(value) {
                        return value._id.toString() !== room._id.toString();
                    });

                    $scope.$emit('CHAT-NEW-ACTIVE-LIST', chatList);
                };
            }
        };
    }

}());
(function () {

    'use strict';

    angular
        .module('plingUi')
        .directive('plgScrollChat', PlgScrollChat);

    PlgScrollChat.$inject = [];

    function PlgScrollChat() {
        return {
            'restrict' : 'A',
            'scope'    : {
                'fn'   : '&plgScrollChat'
            },
            'link'     : function ($scope, element) {
                element.bind('scroll', function (evt) {
                    if (evt.target.scrollTop === 0)
                        evt.target.scrollTop = 10;

                    if (evt.target.scrollTop < 50) {
                        $scope.$apply($scope.fn({'top' : evt.target.scrollTop}));
                    }
                });
            }
        };
    }

}());
(function() {
    'use strict';

    angular.module('plingUi').directive('plgContentLeftAlign', plgLeftAlignDirective);

    function plgLeftAlignDirective() {
        return {
            'restrict': 'A',
            'link': function(scope, elem) {
                var raw = elem[0];
                var contentWidth = 416;
                var elemsRow = raw.offsetWidth / contentWidth;
                var restPercent = elemsRow % 1;
                var restWidth = restPercent * contentWidth;

                raw.style.marginLeft = restWidth/2 + 'px';
            }
        };
    }

})();
(function () {
    'use strict';

    angular.module('plingUi').directive('plgDataListHorizontalScroll', plgDataListHorizontalScroll);

    function plgDataListHorizontalScroll() {
        return {
            'restrict': 'A',
            'link': function(scope, elem, attrs) {
                var raw = elem[0];
                var scrollLeft   = $(raw).parent().find('.scroll-left');
                var scrollRight  = $(raw).parent().find('.scroll-right');
                var btnAddItem = $(raw).parent().find('.btn-add-item');

                function onWheel(event) {
                    var delta = Math.max(-1, Math.min(1, event.wheelDelta || -event.detail)) * 40;

                    raw.scrollLeft += delta;

                    // for Chrome and Firefox
                    if (event.preventDefault)
                        event.preventDefault();
                }

                elem.bind('DOMSubtreeModified', function () {
                    if (raw.offsetHeight < raw.scrollHeight || raw.offsetWidth < raw.scrollWidth)
                        $(raw).parent().find('.toolbar-btn-scroll').show();
                    else
                        $(raw).parent().find('.toolbar-btn-scroll').hide();
                });

                scrollLeft.bind('click', function() {
                    $(elem).animate({
                        'scrollLeft': '-=338'
                    }, 400);
                });

                scrollRight.bind('click', function () {
                    $(elem).animate({
                        'scrollLeft': '+=338'
                    }, 400);
                });

                btnAddItem.bind('click', function() {
                    $(elem).animate({
                        'scrollLeft' : '+=338'
                    }, 400);
                });

                // For FF and Opera
                raw.addEventListener('DOMMouseScroll', onWheel, false);

                // For others
                raw.addEventListener('mousewheel', onWheel, false);

                (function () {
                    if (attrs.plgDataListHorizontalScroll === 'filter') {
                        scope.$watch('saveNewFilter', function() {
                            if (scope.saveNewFilter)
                                $(elem).animate({
                                    'scrollLeft': '+=338'
                                }, 400);
                        });

                        scope.$watch('changedFilters', function() {
                            $(elem).animate({
                                'scrollLeft': '+=350'
                            }, 400);
                        });
                    }
                    else if (attrs.plgDataListHorizontalScroll === 'sort') {
                        scope.$watch('changedSort', function() {
                            $(elem).animate({
                                'scrollLeft': '+=350'
                            }, 400);
                        });
                    }

                }());

            }
        };
    }
})();
(function() {
    'use strict';

    angular.module('plingUi').directive('plgDataListInfiniteScroll', plgDataListInfiniteScroll);

    function plgDataListInfiniteScroll() {
        return {
            'restrict': 'A',
            'link': function(scope, elem, attrs) {
                var raw = $(elem).parents('.dynamic-content')[0];

                $(raw).bind('scroll', function() {
                    if (raw.scrollTop+raw.offsetHeight >= raw.scrollHeight)
                        scope.$apply(attrs.plgDataListInfiniteScroll);
                });
            }
        };
    }

})();
(function() {

    'use strinct';

    angular
        .module('plingUi')
        .directive('plgDataListLimit', plgDataListLimitDirective);

    plgDataListLimitDirective.$inject = [ '$timeout' ];

    function plgDataListLimitDirective ($timeout) {
        return {
            'restrict': 'A',
            'scope' : {
                'plgDataListLimit' : '=',
                'onInit'           : '='
            },
            'link': function(scope, elem) {
                var raw = $(elem).parents('.dynamic-content')[0], cardContainer, elemsRow, containerHeight;
                var card = {
                    'height' : 360,
                    'width' : 416
                };
                var list = {
                    'height' : 72
                };

                (function init() {
                    if (!scope.plgDataListLimit)
                        return;

                    scope.plgDataListLimit.changeView = function (value, cb) {
                        $timeout(function() {
                            containerHeight = raw.scrollHeight;

                            switch (value) {
                                case 'list':
                                    return cb(Math.ceil(containerHeight/list.height));
                                case 'card':
                                    cardContainer = angular.element(document.querySelector('.card-container'))[0];
                                    elemsRow = Math.floor(cardContainer.offsetWidth / card.width);
                                    return cb(Math.ceil(containerHeight/card.height) * elemsRow);
                                default:
                                    return cb(0);
                            }
                        });
                    };

                    scope.onInit();
                })();

            }
        };
    }

})();
(function() {
    'use strict';

    plgDataListController.$inject = ['$scope', '$rootScope', '$timeout', '$localstorage', '$location', 'credentialsService', 'sidenavAllBar'];

    angular.module('plingUi').component('plgDataList', {
        'bindings'  : {
            'plgItems'                : '=',
            'plgDataOptions'          : '=',
            'plgAvatarNull'           : '@',
            'plgDataInternalTemplate' : '@',
            'plgHighlightField'       : '@',
            'plgComplementaryField'   : '@',
            'hideToolbar'             : '=',
            'hideChangeView'          : '='
        },
        'templateUrl' : 'plg-data-list.html',
        'controller'  : plgDataListController
    });

    function plgDataListController($scope, $rootScope, $timeout, $localstorage, $location, credentialsService, sidenavAllBar) {
        var viewObj, ctrl = this;

        // Altera a visualizacao e persiste em banco
        function changeView(view) {
            ctrl.plgItems = [];
            ctrl.plgDataOptions.page = 1;

            ctrl.plgDataOptions.currentView = view;
            credentialsService.setViewPreference(view, function(err, data) {
                if (!err && data) {
                    viewObj = credentialsService.getViewPreference();

                    viewObj.limits.map(function(obj) {
                        if (ctrl.route === obj.route)
                            viewObj.limit = obj.limit;
                    });
                    setActionView(view);

                    $scope.dataListLimit.changeView(view, function(newLimit) {
                        switch (view)
                        {
                            case 'card':
                            case 'list':
                                if (newLimit > 0)
                                    ctrl.plgDataOptions.limit = angular.copy(newLimit);
                                break;
                            case 'table':
                                if (viewObj && ctrl.plgDataOptions.limitOptions.indexOf(viewObj.limit) >= 0)
                                    ctrl.plgDataOptions.limit = viewObj.limit;
                                else
                                    ctrl.plgDataOptions.limit = angular.copy(ctrl.plgDataOptions.limitOptions[0]);
                                break;
                            default:
                                break;
                        }

                        if (view !== 'table' || $scope.isFirstLoading)
                            $scope.onPaginate();
                    });
                }
            });


        }

        // Altera icone de proxima visualizacao
        function setActionView(item) {
            var newAction = {'index': '0', 'type': 'button'};
            var indexView = ctrl.plgDataOptions.availableViews.indexOf(item) + 1;
            var view, find;

            if (ctrl.hideToolbar || ctrl.hideChangeView || ctrl.plgDataOptions.availableViews.length === 1)
                return;

            if (indexView > ctrl.plgDataOptions.availableViews.length - 1)
                indexView = 0;
            view = ctrl.plgDataOptions.availableViews[indexView];

            switch (view)
            {
                case 'card':
                    newAction.label = 'Card';
                    newAction.icon = 'icone_card';
                    newAction.click = 'card';
                    break;
                case 'list':
                    newAction.label = 'Lista';
                    newAction.icon =  'icone_list';
                    newAction.click = 'list';
                    break;
                default:
                    newAction.label = 'Table';
                    newAction.icon =  'icone_grid';
                    newAction.click = 'table';
                    break;
            }

            $rootScope.applicationActions.forEach(function(menuItem) {
                if (ctrl.plgDataOptions.availableViews.indexOf(menuItem.click) >= 0) {
                    menuItem.label = newAction.label;
                    menuItem.icon = newAction.icon;
                    menuItem.click = newAction.click;
                    find = true;
                }
            });

            if (!find)
                $rootScope.applicationActions.push(newAction);
        }

        // Seleciona todos os items
        function selectAll() {
            ctrl.plgItems.map(function(plgItem) {
                if (!plgItem.isPrincipal || !ctrl.plgDataOptions.notSelectedPrincipal)
                    plgItem.selected = true;
                return plgItem;
            });
            $scope.selectItem();
        }

        // Desmarca todos dos items
        function unselectAll() {
            ctrl.plgItems.map(function(plgItem) {
                if (!plgItem.isPrincipal || !ctrl.plgDataOptions.notSelectedPrincipal)
                    plgItem.selected = false;
                return plgItem;
            });
            $scope.selectItem();
        }

        function setToolbarOptions() {
            var filter, sort;

            $rootScope.plgDataListToolbar = ctrl.plgDataOptions;
            $rootScope.plgDataListToolbar.clearFilters = function() {
                sort = ctrl.plgDataOptions.sortItems.filter(function(item) { return item.key && item.order; });
                filter = ctrl.plgDataOptions.filterItems.filter(function(item) { return item.key; });
                unselectAll();
                ctrl.plgItems = [];
                ctrl.plgDataOptions.selectedItems = [];
                ctrl.plgDataOptions.page = 1;
                ctrl.plgDataOptions.fnOnPaginate(false, filter.length > 0 ? angular.copy(filter) : [], sort.length > 0 ? angular.copy(sort) : []);
            };
        }

        // Funcao de ordenacao para table
        ctrl.plgDataOptions.reorder = function(sorts, index) {
            var sort, i;

            if (index >= 0  && !sorts[index].order)
                sorts[index].order = 'asc';

            ctrl.plgItems = ctrl.plgItems.sort(function (a, b) {
                for (i=0; i<sorts.length; i++) {
                    sort = sorts[i];
                    if (sort.order === 'desc') {
                        if ((a[sort.key] || '').toLowerCase() > (b[sort.key] || '').toLowerCase()) return -1;
                        if ((a[sort.key] || '').toLowerCase() < (b[sort.key] || '').toLowerCase()) return 1;
                    } else {
                        if ((a[sort.key] || '').toLowerCase() < (b[sort.key] || '').toLowerCase()) return -1;
                        if ((a[sort.key] || '').toLowerCase() > (b[sort.key] || '').toLowerCase()) return 1;
                    }
                }
                return 0;
            });
        };

        // Aplica filtros informados
        ctrl.plgDataOptions.applyFilters = function() {
            var filter = angular.copy(ctrl.plgDataOptions.filterItems.filter(function(item) {
                return item.key;
            }) || []);
            var sort = ctrl.plgDataOptions.sortItems.filter(function(item) {
                return item.key && item.order;
            });

            unselectAll();
            ctrl.plgDataOptions.selectedItems = [];
            ctrl.plgDataOptions.page = 1;
            filter.map(function (f) {
                if (f && f.valueOptions)
                    delete f.valueOptions;
            });
            // Chama funcao de busca de dados com parametro indicando que filtro e/ou sort foi informado
            ctrl.plgDataOptions.fnOnPaginate(true, filter.length > 0 ? angular.copy(filter) : [], sort.length > 0 ? angular.copy(sort) : []);
        };

        // Clique em plgAllBar
        $scope.$on('ACTIONS-BAR-CLICK', function (event, item, menuItem) {
            if (ctrl.plgDataOptions.availableViews.indexOf(item.click) >= 0)
                return changeView(item.click);

            switch (item.click)
            {
                case 'settings':
                    if (ctrl.plgDataOptions.selectedItems.length === 1)
                        menuItem.fn(ctrl.plgDataOptions.selectedItems[0]);
                    else if (ctrl.plgDataOptions.selectedItems.length > 1)
                        menuItem.fn(ctrl.plgDataOptions.selectedItems);
                    $scope.selectItem();
                    break;
                case 'itemSelect':
                    menuItem.fn();
                    break;
                default:
                    break;
            }
        });

        // Acao ao clicar nas funcoes passadas em plgItems
        $scope.actionClick = function(item, action, event) {
            action.fn(item, action, event);
        };

        // Detallhes de visualizacao de list
        $scope.expandDetails = function(index, event) {
            var
                previousElement = $('md-icon.rotated'),
                element         = $(event.target);

            $scope.expandDetailsTooltip = !$scope.expandDetailsTooltip;

            if (previousElement.length > 0 && previousElement[0].className !== element[0].className)
                previousElement.toggleClass('rotated');

            element.toggleClass('rotated');
            $scope.selectedItem = $scope.selectedItem === index ? -1 : index;
        };

        // Clique em item do menu settings
        $scope.clickItem = function(item, event) {
            if (ctrl.plgDataOptions.fnOnClick)
                ctrl.plgDataOptions.fnOnClick(item, event);
        };

        // Atualiza array de itens selecionados(list)
        $scope.selectItem = function(item) {

            $timeout(function() {
                var menuAction, menuItems, i;
                var selectMenu, registerCount;
                var lastId = item ? item._id : null;

                if (item)
                    item.selected = !item.selected;

                ctrl.plgDataOptions.selectedItems = ctrl.plgItems.filter(function(plgItem) {
                    return plgItem.selected;
                });

                if (ctrl.hideToolbar)
                    return;

                for (i = 0; i<$rootScope.applicationActions.length; i++) {
                    if ($rootScope.applicationActions[i].index === '3')
                        menuAction = $rootScope.applicationActions[i];
                    if ($rootScope.applicationActions[i].index === '4')
                        selectMenu = $rootScope.applicationActions[i];
                }

                if (ctrl.plgDataOptions.selectedItems.length > 0) {
                    registerCount = ctrl.plgDataOptions.selectedItems.length;
                    menuItems = [];

                    if (ctrl.plgDataOptions.selectedItems.length === 1)
                        menuItems = menuItems.concat(ctrl.plgDataOptions.selectedItems[0].settings);
                    else
                        menuItems = menuItems.concat(ctrl.plgDataOptions.multipleSelect);


                    // Caso Compromisso Social (Quando selecionar menu com status diferente do selecionado desmarca todo o resto.)
                    if (ctrl.route === 'compromisso-social') {

                        if (item && item.status === 'doado') {

                            // Remove a opção doado
                            menuItems = menuItems.filter(function(item) {
                                if (item.name !== 'Doado')
                                    return item;
                                else if (item.name === 'Doado')
                                    ctrl.bkpMenuItems = item;
                            });

                            ctrl.plgItems.map(function(item) {
                                item.settings = item.settings.filter(function(item) {
                                    if (item.name !== 'Doado')
                                        return item;
                                });

                            });
                        } else if (item && item.status === 'confirmada' && ctrl.bkpMenuItems) {
                            ctrl.plgItems.map(function(item) {
                                item.settings.push(ctrl.bkpMenuItems);
                            });
                        }

                        if (item)
                            $rootScope.donationLastStatus = item.status;

                        if (ctrl.plgDataOptions.selectedItems.length === 1 && item) {
                            $rootScope.donationFirstStatus = item.status;
                        }

                        if ($rootScope.newDonationFirstStatus) {
                            $rootScope.donationFirstStatus = $rootScope.newDonationFirstStatus;
                            $rootScope.newDonationFirstStatus = null;
                        }


                        if ($rootScope.undoObject) {

                            ctrl.plgItems.map(function(plgItem) {
                                plgItem.selected = false;
                                return plgItem;
                            });

                            registerCount = 0;
                            $rootScope.undoObject.map(function(plgItem) {
                                plgItem.selected = true;
                                registerCount++;
                                return plgItem;
                            });

                            $scope.selectItem();

                            ctrl.plgDataOptions.selectedItems = $rootScope.undoObject;

                            $rootScope.undoObject = null;
                        }

                        // Se for verdadeiro desmarca todos outras seleções.
                        if ($rootScope.donationLastStatus != $rootScope.donationFirstStatus && lastId) { //eslint-disable-line
                            $rootScope.donationFirstStatus = $rootScope.donationLastStatus;
                            $rootScope.undoObject = null;

                            $rootScope.addButtonDonation();

                            for (i = 0; i < ctrl.plgDataOptions.selectedItems.length - 1; i++) {

                                // Remove item
                                if (i < ctrl.plgDataOptions.selectedItems.length - 1) {

                                    ctrl.plgItems.map(function(plgItem) {
                                        if (plgItem._id !== lastId)
                                            plgItem.selected = false;
                                        return plgItem;
                                    });
                                    $scope.selectItem();
                                }

                                registerCount = 1;
                            }
                        }

                    }

                    if (!selectMenu) {
                        selectMenu = {
                            'index': '4',
                            'color': true,
                            'value': registerCount,
                            'click': 'itemSelect',
                            'type' : 'menu',
                            'menuItem' : [{'name': 'Selecionar todos', 'fn': selectAll},
                            {'name': 'Desmarcar todos', 'fn': unselectAll}]
                        };
                        $rootScope.applicationActions.push(selectMenu);
                    }
                    else
                        selectMenu.value = registerCount;

                    if (!menuAction) {
                        menuAction = {
                            'index': '3',
                            'icon' : 'icone_more_vert',
                            'color': true,
                            'click': 'settings',
                            'type' : 'menu',
                            'menuItem' : menuItems
                        };
                        $rootScope.applicationActions.push(menuAction);

                    } else if (ctrl.route !== 'compromisso-social') {
                        menuAction.menuItem = menuItems;
                    }

                }
                else
                    $rootScope.applicationActions = $rootScope.applicationActions.filter(function(appItem) {
                        return appItem.index < 3;
                    });

                // Chama funcoes de selecao passadas para componente
                if (item) {
                    if (item.selected && ctrl.plgDataOptions.fnOnSelect)
                        ctrl.plgDataOptions.fnOnSelect(item);
                    else if (!item.selected && ctrl.plgDataOptions.fnOnDeselect)
                        ctrl.plgDataOptions.fnOnDeselect(item);

                }

                $timeout(function() {
                    sidenavAllBar.emit('showActionsBar');
                });

            });
        };

        // Registros paginados
        $scope.onPaginate = function () {
            var viewPreference, sort, filter, limitRoute;

            $timeout(function() {
                ctrl.plgDataOptions.selectedItems = [];
                sort = ctrl.plgDataOptions.sortItems.filter(function(item) { return item.key && item.order; });
                filter = ctrl.plgDataOptions.filterItems.filter(function(item) { return item.key; });

                ctrl.plgDataOptions.fnOnPaginate(false, filter.length > 0 ? angular.copy(filter) : [], sort.length > 0 ? angular.copy(sort) : []);

                if (viewObj.limits) {
                    viewObj.limits.map(function(objLimit) {
                        if (ctrl.route === objLimit.route)
                            limitRoute = objLimit.limit;
                    });
                }

                if (viewObj && ctrl.plgDataOptions.limit !== limitRoute) {
                    viewPreference = {
                        'viewType' : ctrl.plgDataOptions.currentView
                    };

                    if (ctrl.plgDataOptions.currentView === 'table')
                        viewPreference.limit = ctrl.plgDataOptions.limit;

                    credentialsService.setViewPreference(viewPreference, function (error, viewPreferences) {
                        if (viewPreferences && viewPreferences.limit)
                            viewObj.limit = viewPreferences.limit;
                        else
                            viewObj.limit = ctrl.plgDataOptions.limit;
                    });
                }
            });
        };

        $scope.$watch('$ctrl.plgDataOptions.loadingData', function(newValue) {
            $scope.hasData = true;
            if (typeof newValue !== 'undefined' && !newValue) {
                $scope.isFirstLoading = false;
                $timeout(function() {
                    if (ctrl.plgItems.length === 0)
                        $scope.hasData = false;
                });
            }
        }, true);

        $scope.$watch('$ctrl.plgDataOptions.selectedItems', function(newValue) {
            if (newValue)
                if (newValue.length === 0) {
                    $timeout(function() {
                        $scope.selectItem();
                    });
                }
        }, true);

        $scope.$watch('$ctrl.plgDataOptions.multipleSelect', function(newValue, newOld) {
            if (newValue && newOld)
                if (newValue.length !== newOld.length) {
                    $timeout(function() {
                        if (ctrl.plgDataOptions.multipleSelect.length > 0)
                            ctrl.notMultipleSelect = false;
                        if (ctrl.plgDataOptions.multipleSelect.length === 0)
                            ctrl.notMultipleSelect = true;
                    });
                }
        }, true);

        $scope.infiniteScroll = function() {
            var limit = ctrl.plgDataOptions.limit;
            var page = ctrl.plgDataOptions.page;
            var total = ctrl.plgDataOptions.total;

            if (page < Math.ceil(total / limit)) {
                ctrl.plgDataOptions.page++;
                $scope.onPaginate();
            }
        };

        $scope.getImageUrl = function(imageUrl) {
            var vImageUrl = angular.copy(imageUrl);
            var regex = new RegExp(/_[0-9]{2,3}px/);

            if (regex.test(imageUrl) && (ctrl.plgDataOptions.currentView === 'list' || ctrl.plgDataOptions.currentView === 'card'))
                vImageUrl = vImageUrl.replace(regex, '_40px');

            return vImageUrl || '../../node_modules/pling-ui/assets/icons/' + $scope.defaultAvatar + '.svg';
        };

        $scope.initializedLimit = function() {
            changeView(ctrl.plgDataOptions.currentView);
        };

        $scope.getPropertyValue = function(obj, key) {
            var keys = key.split('.');
            var value = obj, i, arrKey;

            if (!keys || !keys.length)
                return '';

            for (i=0; i<keys.length; i++)
                if (keys[i].indexOf('[') >= 0) {
                    arrKey = keys[i].substr(0, keys[i].indexOf('['));
                    value = (value[arrKey] || []) [keys[i].substr(keys[i].indexOf('[')+1, 1)] || '';
                }
                else
                    value = value[keys[i]] || '';

            value = value || '';

            return value;
        };

        $scope.getTotalValue = function(items, key) {
            var total;

            if (items && items.length > 0 && items.reduce)
                total = items.reduce(function (prev, next) {
                    return (typeof prev === 'object' ? +$scope.getPropertyValue(prev, key) : prev) + +$scope.getPropertyValue(next, key);
                });

            return total;
        };

        (function init() {
            var route = $location.path().split('/');

            $scope.expandDetailsTooltip = true;
            $scope.dataListLimit        = {};
            $scope.parentScope          = $scope.$parent;
            $scope.isFirstLoading       = true;
            $scope.hasData              = true;

            if (ctrl.plgDataOptions.multipleSelect)
                if (ctrl.plgDataOptions.multipleSelect.length === 0) {
                    ctrl.notMultipleSelect = true;
                }

            // defaul limit options
            ctrl.plgDataOptions.limitOptions = [5, 10, 15, 25, 50, 100];

            ctrl.plgDataOptions.loadingData = true;

            ctrl.route = route[route.length - 1];

            // Busca preferencias de visualizacao do usuario logado
            viewObj = credentialsService.getViewPreference();

            $scope.defaultAvatar = ctrl.plgAvatarNull || 'icone_myaccount';

            // Filtro default pling(status = ativo)
            if (typeof ctrl.plgDataOptions.defaultFilter === 'undefined' || ctrl.plgDataOptions.defaultFilter === true)
                ctrl.plgDataOptions.defaultFilter = {
                    'label': 'Status', 'key': 'status',
                    'exp': 'active',
                    'options' : [
                        { 'text': 'Ativo', 'key' : 'active'},
                        { 'text': 'Inativo', 'key' : 'inactive' },
                        { 'text': 'Lixeira', 'key' : 'trash' }]
                };

            if (!ctrl.hideToolbar) {
                // Acoes para habilitar filtro e ordenacao
                $rootScope.applicationActions = [{
                    'index' : '1',
                    'label' : 'Ordenação',
                    'icon'  : 'icone_sort',
                    'click' : 'sort',
                    'type'  : 'button'
                },
                {
                    'index' : '2',
                    'label' : 'Filtros',
                    'icon'  : 'icone_filter',
                    'click' : 'filter',
                    'type'  : 'button'
                }];
            }

            // Carrega preferencia de visualizacao
            if (viewObj) {
                if (viewObj.viewType)
                    ctrl.plgDataOptions.currentView = viewObj.viewType;
                if (viewObj.limits) {
                    viewObj.limits.map(function(obj) {
                        if (obj.route === ctrl.route)
                            ctrl.plgDataOptions.limit = obj.limit;
                    });
                }
                if (viewObj.filtersPreference)
                    ctrl.plgDataOptions.filtersPreference = viewObj.filtersPreference;
                if (viewObj.sorts)
                    ctrl.plgDataOptions.sortItems = viewObj.sorts;
            }

            // Inicializa filtros e ordenacao
            ctrl.plgDataOptions.sortItems = ctrl.plgDataOptions.sortItems || [];
            ctrl.plgDataOptions.filterItems = ctrl.plgDataOptions.filterItems || [];

            if (ctrl.plgDataOptions.sortItems.length === 0)
                ctrl.plgDataOptions.sortItems.push({
                    'key' : ctrl.plgDataOptions.itemColumns[0].key,
                    'order' : 'asc',
                    'route' : ctrl.route
                });
            if (ctrl.plgDataOptions.itemColumns)
                ctrl.hasCurrencyColumn = !ctrl.plgDataOptions.itemColumns.every(function (col) {
                    return !col || col.type !== 'currency';
                });

            setToolbarOptions();

        })();

    }

})();

(function() {
    'use strict';

    angular.module('plingUi').component('plgDataListToolbar', {
        'bindings'  : {
            'toolbarOptions' : '='
        },
        'templateUrl' : 'plg-data-list-toolbar.html',
        'controller'  : plgDataListToolbarController
    });

    plgDataListToolbarController.$inject = ['$scope', '$rootScope', 'httpService', '$localstorage', '$location', 'credentialsService', '$timeout', '$routeParams'];

    function plgDataListToolbarController($scope, $rootScope, httpService, $localstorage, $location, credentialsService, $timeout, $routeParams) {
        var ctrl = this;

        $scope.showFilter = $rootScope.isFilterActive;
        $scope.showFilter = $rootScope.isSortActive;

        // Salva preferencia de visualizacao
        function saveFilterPreference(filterName, cb) {
            var filters = [], view;

            ctrl.toolbarOptions.filterItems.map(function(item) {
                if (item.key) {
                    if (item.label)
                        item.type = 'default';
                    filters.push({
                        'key' : item.key,
                        'exp' : item.exp,
                        'type': item.type,
                        'value' : item.value,
                        'value2': item.value2 || ''
                    });
                }
                return item;
            });
            view = {
                'name'    : filterName,
                'filters' : filters
            };

            credentialsService.setViewPreference(view, function() {
                var viewObj = credentialsService.getViewPreference();

                if (viewObj && viewObj.filtersPreference) {
                    ctrl.toolbarOptions.filtersPreference = viewObj.filtersPreference;
                    $rootScope.$broadcast('TOAST-ACTION', {
                        'message' : 'Salvo com sucesso.',
                        'cb' : function() {}
                    });
                    return cb();
                }
            });
        }

        $scope.removeFilter = function(index) {
            ctrl.toolbarOptions.filterItems.splice(index, 1);
            $scope.disabledClearFilters = false;
        };

        $scope.addItem = function(listItem) {
            listItem.push({'key': '', 'route' : ctrl.route });
            if (ctrl.toolbarOptions.filterItems.length > 1 && !ctrl.toolbarOptions.defaultFilter)
                $scope.disabledClearFilters = false;
        };

        $scope.existingItem = function(item, list) {
            return list.find(function(sortItem) {
                return sortItem.key === item.key;
            });
        };

        $scope.saveFilterPreference = function(filterName) {
            $scope.filterNameFocused = false;
            if (!$scope.saveNewFilter) {
                $scope.saveNewFilter = true;
                $timeout(function() {
                    $scope.filterNameFocused = true;
                }, 100);
                return;
            }

            saveFilterPreference(filterName, function() {
                $scope.saveNewFilter = false;
                delete ctrl.filterPreferenceName;
                ctrl.preferenceFilter = filterName;
            });
        };

        $scope.changeFilterType = function (filterItem) {
            var existingType = ctrl.toolbarOptions.itemColumns.find(function(item) {
                return item.key === filterItem.key;
            });

            if (existingType)
                filterItem.type = existingType.type || 'string';
            else
                filterItem.type = '';

            switch (filterItem.type) {
                case 'date'   :
                case 'number' :
                    filterItem.exp = 'gtlt';
                    break;
                case 'phone'  :
                case 'string' :
                default:
                    filterItem.exp = 'in';
                    break;
            }

            filterItem.valueOptions = existingType && existingType.options ? existingType.options : null;

            if (filterItem.valueOptions)
                filterItem.exp = 'eq';
        };

        // Altera filtro
        $scope.changeFilter = function(filters) {
            var existingFilter = filters.find(function(item) {
                if (item.label)
                    return item.key && item.exp;
                if (item.exp && item.exp.indexOf('gtlt') !== -1)
                    return item.key && item.exp && item.value && item.value2;
                return item.key && item.exp && item.value;
            });

            if (filters.length > 0 && (filters[0].key || filters[0].exp) || filters.length > 1)
                $scope.disabledClearFilters = false;
            else
                $scope.disabledClearFilters = true;

            $scope.disabledFilters = existingFilter ? false : true;
            $scope.changedFilters++;
        };

        $scope.getInputMask = function (filterItem) {
            switch (filterItem.type)
            {
                case 'phone':
                    return '(99) 9999-9999?9';
                case 'date':
                    return '99/99/9999';
                default:
                    return '';
            }
        };

        // Remove uma preferencia de filtro/sort
        $scope.deleteFiltersPreference = function(preference) {
            credentialsService.deleteViewPreference(preference.name)
                .success(function () {
                    ctrl.toolbarOptions.filtersPreference = ctrl.toolbarOptions.filtersPreference.filter(function(item) {
                        return item.name !== preference.name;
                    });
                    $rootScope.$broadcast('TOAST-ACTION', {
                        'message' : 'Filtro excluído com sucesso.',
                        'cb' : function() {}
                    });
                })
                .error(function (reason) {
                    console.log(reason); //eslint-disable-line
                    $rootScope.$broadcast('TOAST-ACTION', {
                        'message': 'Ocorreu um erro ao excluir filtro.',
                        'cb': function() {}
                    });
                });
        };

        // Selecao de preferencia no drop
        $scope.changePreferenceFilter = function(preferenceFilterName) {
            var selected = ctrl.toolbarOptions.filtersPreference.find(function(item) {
                return item.name === preferenceFilterName;
            });

            if (!selected) {
                ctrl.toolbarOptions.filterItems = [{'key': ''}];
                $scope.disabledFilters = true;
                $scope.disabledClearFilters = true;
                return;
            }

            ctrl.preferenceFilter = preferenceFilterName;

            // Filters
            if (selected.filters && selected.filters.length > 0) {
                ctrl.toolbarOptions.filterItems = selected.filters.map(function(item) {
                    if (item.type === 'default') {
                        item.label = ctrl.toolbarOptions.defaultFilter.label;
                        item.options = ctrl.toolbarOptions.defaultFilter.options;
                    }
                    return item;
                });

                $scope.showFilter = true;
                $scope.disabledFilters = false;
                $scope.disabledClearFilters = false;
            }
            else {
                ctrl.toolbarOptions.filterItems = [];
                $scope.showFilter = false;
            }

            // Carrega registros com preferencia informada
            if ($scope.showFilter)
                ctrl.toolbarOptions.applyFilters(ctrl.toolbarOptions.filterItems);
        };

        $scope.removeSortItem = function(sortItem) {
            var index = ctrl.toolbarOptions.sortItems.indexOf(sortItem);

            ctrl.toolbarOptions.sortItems.splice(index, 1);
        };


        // Salva ordenacao do usuario
        $scope.saveSortPreference = function() {
            var view  = { 'sorts' : [] }, allSorts, currentApp;
            var route = $location.path().split('/');

            if (ctrl.toolbarOptions && ctrl.toolbarOptions.sortItems && ctrl.toolbarOptions.sortItems.length > 0) {
                ctrl.toolbarOptions.sortItems.map(function(objSort) {
                    if (objSort.route === route[route.length - 1])
                        view.sorts.push(objSort);
                });
            }

            view.sorts.map(function(item) {
                if (item.key) {
                    item.route = route[route.length - 1];
                }

                return item;
            });

            currentApp = JSON.parse($localstorage.get('PLING-APPS')).find(function(appItem) {
                return appItem.appModule === $localstorage.get('PLING-CURRENT-APP');
            });

            if (!currentApp)
                return null;

            allSorts = JSON.parse($localstorage.get('PLING-CURRENT-VIEW-PREFERENCES')).find(function(vp) {
                return currentApp._id === vp.product_id;
            });

            if (!allSorts)
                return null;

            if (allSorts.sorts) {
                allSorts.sorts.map(function(obj) {
                    if (obj.route !== route[route.length - 1])
                        view.sorts.push(obj);
                });
            }

            credentialsService.setViewPreference(view, function(err, data) {
                if (!err && data) {
                    $scope.showSort = false;
                    $rootScope.applicationActions.forEach(function(item) {
                        if (item.click === 'sort')
                            delete item.color;
                    });
                    $rootScope.$broadcast('TOAST-ACTION', {
                        'message'  : 'Ordenação salva com sucesso. Os dados passarão a ser organizados de acordo com esta ordenação.',
                        'hideDelay' : 6000,
                        'cb' : function() {}
                    });
                }
            });
        };

        $scope.checkItemColums = function(listItems) {
            var itemColumns = ctrl.toolbarOptions.itemColumns.filter(function(item) {
                return !item.template;
            });

            return listItems.filter(function(item) { return !item.label; }).length === itemColumns.length;
        };

        // Route change
        $scope.$on('$routeChangeStart', function () {
            var dataListStatus = {}, arraySortItem = [];

            ctrl.toolbarOptions.sortItems = [];

            ctrl.toolbarOptions.sortItems = arraySortItem;

            // salvar filtro/ordenacao aberto ao voltar
            if ($scope.showFilter)
                dataListStatus.filter = ctrl.toolbarOptions.filterItems;
            if ($scope.showSort)
                dataListStatus.sort = ctrl.toolbarOptions.sortItems;

            if (!angular.equals(dataListStatus, {}))
                $localstorage.setObject('DATA-LIST-STATUS', dataListStatus);

            // apaga toolbar de icones
            if ($rootScope.applicationActions)
                $rootScope.applicationActions = $rootScope.applicationActions.filter(function(item) {
                    return item.click !== 'sort' && item.click !== 'filter' &&
                            item.click !== 'card' && item.click !== 'itemSelect' &&
                            item.click !== 'settings';
                });

            delete $rootScope.plgDataListToolbar;
        });

        // limpa filtros
        $scope.clearFilters = function() {
            ctrl.toolbarOptions.filterItems = [];
            if (ctrl.toolbarOptions.defaultFilter) {
                ctrl.toolbarOptions.filterItems.push(angular.copy(ctrl.toolbarOptions.defaultFilter));
                $scope.disabledFilters = false;
            }
            else {
                $scope.disabledFilters = true;
                $scope.addItem(ctrl.toolbarOptions.filterItems);
            }
            ctrl.preferenceFilter = '';
            $scope.disabledClearFilters = true;
            ctrl.toolbarOptions.clearFilters();
        };

        $scope.changeSort = function() {
            $scope.changedSort++;
        };

        // Clique em plgAllBar
        $scope.$on('ACTIONS-BAR-CLICK', function (event, item) {
            switch (item.click)
            {
                case 'filter':
                    $scope.showFilter = !$scope.showFilter;

                    $timeout(function() {
                        $rootScope.isFilterActive = $scope.showFilter;
                    });

                    $scope.disabledFilters      = true;
                    $scope.disabledClearFilters = true;
                    $scope.saveNewFilter        = false;

                    ctrl.filterPreferenceName = '';
                    ctrl.preferenceFilter = '';

                    // desfaz filtro ao fechar
                    if ($scope.showFilter) {
                        if (ctrl.toolbarOptions.defaultFilter) {
                            ctrl.toolbarOptions.filterItems.splice(0, 0, angular.copy(ctrl.toolbarOptions.defaultFilter));
                            $scope.disabledFilters = false;
                        }
                        else
                            $scope.addItem(ctrl.toolbarOptions.filterItems);
                    }
                    else {
                        ctrl.toolbarOptions.filterItems = [];
                        ctrl.toolbarOptions.applyFilters(ctrl.toolbarOptions.filterItems);
                    }
                    break;
                case 'sort':
                    $scope.showSort = !$scope.showSort;

                    $timeout(function() {
                        $rootScope.isSortActive = $scope.showSort;
                    });

                    if (ctrl.toolbarOptions.sortItems.length === 0)
                        $scope.addItem(ctrl.toolbarOptions.sortItems);
                    break;
            }

            $rootScope.applicationActions.forEach(function(menuItem) {
                if (item.click !== 'sort' && menuItem.click !== 'filter')
                    return;

                if (menuItem.click === item.click && !item.color)
                    item.color = '#1165ae';
                else if (menuItem.click === item.click)
                    delete item.color;
            });
        });

        (function init() {
            var dataListStatus, route = $location.path().split('/');

            $scope.disabledFilters = true;
            $scope.disabledClearFilters = true;
            $scope.changedFilters = 0;
            $scope.changedSort = 0;
            $scope.options = {
                'order' : ctrl.toolbarOptions.itemColumns[0].key
            };

            ctrl.route = route[route.length - 1];

            dataListStatus = $localstorage.get('DATA-LIST-STATUS') ? $localstorage.getObject('DATA-LIST-STATUS') : false;

            if ($routeParams.hasFilter === 'true' && dataListStatus) {

                if (dataListStatus.sort) {

                    dataListStatus.sort.map(function(obj) {
                        if (obj.route !== route[route.length - 1])
                            ctrl.toolbarOptions.sortItems.push(obj);
                    });

                    $timeout(function() {
                        $scope.showSort = true;
                    });
                }

                if (dataListStatus.filter) {
                    ctrl.toolbarOptions.filterItems = dataListStatus.filter;
                    $timeout(function() {
                        $scope.showFilter = true;
                    });
                    $scope.disabledFilters = false;
                    $scope.disabledClearFilters = false;
                }

                if ($rootScope.applicationActions)
                    $rootScope.applicationActions.forEach(function(menuItem) {
                        if (menuItem.click === 'sort' && dataListStatus.sort)
                            menuItem.color = '#1165ae';
                        if (menuItem.click === 'filter' && dataListStatus.filter)
                            menuItem.color = '#1165ae';
                    });

                $location.search('hasFilter', null);
            }

            $localstorage.deleteKey('DATA-LIST-FILTER');
        })();

    }

})();

(function() {
    'use strict';

    angular
        .module('plingUi')
        .filter('plgCurrency', plgCurrency);

    plgCurrency.$inject = [ '$filter' ];

    function plgCurrency ($filter) {

        var output;

        return function(value, symbol, fractionSize) {

            if (value) {
                if (value.match)
                    value = value.match(/\d.+/g);
            }

            output = $filter('currency')(+value, symbol, fractionSize) || '';

            return output.split('.').join(',');
        };
    }

})();

(function() {

    'use strict';

    angular
        .module('plingUi')
        .controller('plgDialogController', plgDialogController);

    function plgDialogController($scope, $rootScope, title, message, template, more, button) {
        $scope.title      = title.text;
        $scope.titleAlign = title.align;
        $scope.message    = message;
        $scope.template   = template;
        $scope.button     = button;

        $rootScope.$on('DIALOG-ACTION-BUTTON', function(event, button) {
            $scope.button = button;
        });

        if (more) {
            $scope.btnMore = more;
        }

        $rootScope.$on('DIALOG-PROGRESS', function(event, mode, action, value) {
            $scope.progressMode   = mode;
            $scope.progressAction = action;
            $scope.progressValue  = value;
        });

    }
}());

(function() {

    'use strict';

    angular
        .module('plingUi')
        .controller('plgAllBarMenuApp', plgAllBarMenuApp);

    function plgAllBarMenuApp($scope, $rootScope, applicationsService, event, chatService, $timeout) {

        $timeout(function() {
            $scope.arrowUp = {
                'left' : event[0].offsetLeft + 'px'
            };
        });

        $scope.closeAppDialog = function () {
            $rootScope.$broadcast('PANEL-CLOSE');
        };

        $scope.getToken = function () {
            return localStorage.getItem('PLING-TOKEN');// eslint-disable-line
        };

        (function () {
            $scope.rooms = chatService.openedRooms ? '&rooms=' + encodeURI(chatService.openedRooms) : '';
            $scope.applications = applicationsService.getLocal();
        }());

    }

}());

(function() {

    'use strict';

    angular
        .module('plingUi')
        .controller('plgAllBarNotification', plgAllBarNotification);

    function plgAllBarNotification($scope, $rootScope, websocketService, arrayNotifications, event, $timeout) {

        $timeout(function() {
            $scope.arrowUp = {
                'left' : event[0].offsetLeft + 'px'
            };
        });

        $scope.arrayNotifications = arrayNotifications;

        $scope.reconnectWebsocket = function() {
            $rootScope.isWebsocketLoading   = false;
            $rootScope.isWebsocketConnected = true;
            websocketService.connect();
        };

    }
}());

(function() {

    'use strict';

    angular
        .module('plingUi')
        .controller('plgAllBarUser', PlgAllBarUser);

    // CREATING CONTROLLER
    function PlgAllBarUser($scope, $rootScope, credentialsService, controlPanelUrl, event, $timeout) {

        $scope.controlPanelUrl = controlPanelUrl;

        $scope.myAccount = function () {
            $rootScope.$broadcast('PANEL-CLOSE');
        };

        $timeout(function() {
            $scope.arrowUp = {
                'left' : '173px'
            };
        });

        $scope.logout = function () {
            $rootScope.$broadcast('PANEL-CLOSE');
            credentialsService.logout();
        };

    }
}());

(function() {

    'use strict';

    angular
        .module('plingUi')
        .controller('plgSelectOptions', plgSelectOptions);

    // CREATING CONTROLLER
    function plgSelectOptions($scope, ctrl, $timeout, width) {

        $scope.ctrl              = ctrl;
        $scope.ctrl.isFocusItem  = true;
        $scope.width             = width;

        function closePanel() {

            $timeout(function () {
                $scope.ctrl.fnOnBlur($scope.ctrl);
            });

        }

        $scope.createFilterFor = function (query) {
            var lowercaseQuery = angular.lowercase(query);

            return function filterFn(termItem) {
                var lowercaseOptions = angular.lowercase(termItem[$scope.ctrl.configModel.refName]);

                return lowercaseOptions.indexOf(lowercaseQuery) >= 0;
            };
        };

        $scope.filterItems = function (items, term) {
            var results = term ? items.filter($scope.createFilterFor(term)) : $scope.ctrl.items;

            $scope.addItem = false;

            if (results && term) {
                if (results.length === 0 && term.length > 0) {
                    $scope.addItem = true;
                }
            }

            return results;
        };

        $scope.filterIconeCheck = function (element) {
            return element.icon === 'icone_check_box' ? true : false;
        };

        $scope.filterIcone = function (element) {
            return element.icon === 'icone_check_box_outline' ? true : false;
        };

        $scope.noneItem = function () {
            var i;

            if ($scope.ctrl.items) {
                for (i = 0; i < $scope.ctrl.items.length; i += 1) {
                    $scope.ctrl.items[i].icon = 'icone_check_box_outline';
                }
            }

            $scope.ctrl.arrItemName   = [];
            $scope.ctrl.isFocusItem   = false;
            $scope.ctrl.itemName      = null;
            $scope.ctrl.ngModel       = null;
            $scope.ctrl.ngModelSelect = null;
            $scope.ctrl.mdPanel.close();

            closePanel();
        };

        $scope.allNoneItem = function (action) {
            ctrl.ngModelSelect            = action ? JSON.parse(JSON.stringify(ctrl.items)) : [];
            $scope.ctrl.arrItemName = [];
            $scope.ctrl.itemName    = null;

            $scope.ctrl.reload();

            // Chama o fnOnBlur no clique do selecionar todos e nenhum
            closePanel();
        };

        $scope.saveItemEnter = function (keyCode) {
            var item;

            if (keyCode === 13) {
                if ($scope.addItem && !$scope.ctrl.isLoading && $scope.ctrl.configModel.isInsert) {
                    $scope.ctrl.selectSaveItem();
                } else {
                    item = $scope.filterItems($scope.ctrl.items, $scope.ctrl.filterSelect);
                    if (item.length === 1)
                        if (item[0])
                            $scope.ctrl.selectItem(item[0]);

                    $scope.ctrl.filterSelect = null;
                }
            }
        };

        $scope.checkItem = function (icon) {
            var i,
                results = $scope.ctrl.filterSelect ? $scope.ctrl.items.filter($scope.createFilterFor($scope.ctrl.filterSelect)) : $scope.ctrl.items;

            if (results) {
                for (i = 0; i < results.length; i += 1) {
                    if (results[i].icon === icon) {
                        return true;
                    }
                }
            }
        };

    }
}());

(function () {

    'use strict';

    PlgSelectWidth.$inject = [];

    angular.module('plingUi').directive('plgSelectWidth', PlgSelectWidth);

    function PlgSelectWidth() {
        return {
            'restrict' : 'A',
            'link' : function(scope, element, attrs) {
                attrs.$observe('plgSelectWidth', function(width) {
                    if (width) {
                        element.css({
                            'width' : width + 'px'
                        });
                    }
                });

            }
        };
    }

}());
(function() {

    'use strict';

    angular.module('plingUi').controller('plgToastController', plgToastController);

    // CREATING CONTROLLER
    function plgToastController($scope, $timeout, $mdToast, $rootScope, message, button, callback, hideDelay) {
        var timer;

        timer = $timeout(function() {
            if (callback)
                callback('success');
        }, hideDelay);

        $scope.msg = message || 'Salvo com sucesso!';

        if (button) {
            $scope.backToast = function() {
                $timeout.cancel(timer);
                $mdToast
                    .hide()
                    .then(function() {
                        if (callback)
                            callback('cancel');
                    });
            };
        }
    }
}());

angular.module("plingUi.templates", []).run(["$templateCache", function($templateCache) {$templateCache.put("plg-all-bar.html","<plg-login id=LOGIN_PANEL_ID></plg-login><section class=plg-all-bar><md-toolbar layout=row class=plg-top-bar style=\"overflow: hidden; position: fixed; width: 100%\"><div flex=\"\" layout=row layout-align=\"start center\"><md-button class=md-icon-button ng-click=$ctrl.toggleSideMenu() aria-label=menu><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_menu.svg aria-label=menu></md-icon></md-button><span class=\"md-subhead plg-white-space\">Backoffice</span><span class=bar-pipe></span><span flex=\"\"></span><plg-search flex=50></plg-search><md-button class=md-icon-button ng-click=$ctrl.toggleFilter() aria-label=menu><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_filter.svg aria-label=menu></md-icon></md-button><span flex=\"\"></span><span class=\"md-subhead plg-white-space\">{{customerName}}</span> <span class=bar-pipe></span><md-button class=\"md-icon-button user-bar-open plg-button-user\" ng-click=$ctrl.showUser($event) aria-label=\"foto usuário\'\"><md-icon ng-if=\"user && !user.profileImage\" class=app-no-avatar md-svg-src=../../node_modules/pling-ui/assets/icons/icone_person.svg aria-label=Foto></md-icon><img flex=\"\" ng-if=\"user && user.profileImage\" ng-src=\"{{ user.profileImage }}\" class=app-avatar alt=foto></md-button></div></md-toolbar><div class=route-menu-container layout=row layout-align=\"end center\" style=\"width: 100%; position: fixed; top: 56px; z-index: 5;\"><div ng-if=\"!$ctrl.showActionsBar && !$ctrl.showActionsBarList && $ctrl.showMenu\" class=menu flex=\"\"><md-tabs flex=\"\" md-selected=$ctrl.currentMenuIndex md-border-bottom=\"\" ng-if=\"menu.length > 0 && !menuNotRoutes\"><md-tab ng-repeat=\"item in menu track by $index\" ng-click=\"changeRoute(item, false)\"><img ng-if=item.pngiconpath ng-src=\"../../node_modules/pling-ui/assets/icons/{{ currentMenuIndexPng(item.pngiconpath, $ctrl.currentMenuIndex, $index) }}.png\" aria-label={{item.pngiconpath}}><md-icon ng-class=\"{\'md-active-svg\': $ctrl.currentMenuIndex === $index}\" ng-if=!item.pngiconpath md-svg-src=\"../../node_modules/pling-ui/assets/icons/icone_{{ item.icon }}.svg\" aria-label={{item.icon}}></md-icon><span class=menu-title ng-bind=item.name></span></md-tab></md-tabs><md-tabs md-selected=$ctrl.currentMenuIndex md-border-bottom=\"\" ng-if=\"menu.length > 0 && menuNotRoutes\"><md-tab ng-repeat=\"item in menu track by $index\" md-on-select=\"tabMenuSelected($index, item)\"><md-icon ng-class=\"{\'md-active-svg\': $ctrl.currentMenuIndex === $index}\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_dashboard.svg aria-label={{item.name}}></md-icon><span class=menu-title ng-bind=item.name></span></md-tab></md-tabs><md-tabs md-border-bottom=\"\" ng-if=\"menu.length === 0 && menuNotRoutes\"><md-tab md-on-select=tabMenuSelectedShowDialog($event)><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_dashboard.svg aria-label=\"Novo Quadro\"></md-icon><span class=menu-title>Novo Quadro</span></md-tab></md-tabs></div><div layout=row layout-align=\"end center\" class=plg-menu-aplication-icon style=\"margin-right: 24px;\"><div ng-if=\"$ctrl.showActions && $ctrl.showActionsBar || $ctrl.showActionsBarList\" class=plg-actions-bar layout=row layout-align=\"end center\"><div ng-if=\"$ctrl.applicationActions.length > 0\" ng-repeat=\"item in $ctrl.applicationActions | orderBy:\'-index\'\"><p ng-if=\"item.type === \'label\' && item.value === 1\">{{ item.value }} item selecionado</p><p ng-if=\"item.type === \'label\' && item.value > 1\">{{ item.value }} itens selecionados</p><md-nav-bar ng-if=\"item.type === \'nav\'\" md-selected-nav-item=currentNavItem nav-bar-aria-label=item.label><md-nav-item ng-repeat=\"itemNav in item.navItem\" md-nav-click=\"$ctrl.applicationActionsClick(item, $event, itemNav)\">{{itemNav.name}}</md-nav-item></md-nav-bar><md-menu ng-if=\"item.type === \'menu\' || !item.type\" md-offset=\"-13 40\" md-position-mode=\"target-right target\" class=actionsSet><md-button aria-label=selecione ng-class=\"{\'md-button md-primary\' : item.label || item.value, \'md-icon-button\' : !item.label && !item.value}\" ng-click=\"$ctrl.openMenu($mdMenu, $event)\" md-prevent-menu-close=md-prevent-menu-close>{{ item.label }} <span ng-if=\"item.value === 1\">{{ item.value }} item selecionado</span> <span ng-if=\"item.value > 1\">{{ item.value }} itens selecionados</span><md-icon ng-if=item.icon ng-class=\"{ \'md-primary\' : item.color }\" md-svg-src=\"../../node_modules/pling-ui/assets/icons/{{ item.icon }}.svg\"></md-icon></md-button><md-menu-content layout=column layout-wrap=\"\" width=3 class=plg-actions-bar-menu-bar><md-menu-item flex=\"\" ng-show=module class=filterDataTableItem>{{ item.label }}</md-menu-item><md-menu-item flex=\"\" ng-repeat=\"itemMenu in item.menuItem\"><md-button ng-click=\"$ctrl.applicationActionsClick(item, $event, itemMenu)\"><md-icon ng-if=itemMenu.icon md-svg-src=\"../../node_modules/pling-ui/assets/icons/{{ itemMenu.icon }}.svg\"></md-icon>{{itemMenu.name}}</md-button></md-menu-item></md-menu-content></md-menu><md-button class=md-icon-button ng-class=\"{ \'md-primary\' : item.color }\" ng-if=\"item.type === \'button\'\" aria-label=\"{{ item.label }}\" ng-click=\"$ctrl.applicationActionsClick(item, $event)\"><md-icon md-svg-icon=\"../../node_modules/pling-ui/assets/icons/{{ item.icon }}.svg\" aria-label=\"{{ item.label }}\"></md-icon><md-tooltip md-direction=bottom>{{ item.label }}</md-tooltip></md-button></div></div><div class=rotate-icon ng-class=\"{\'rotate-icon-hover\' : $ctrl.showActionsBar || $ctrl.showActionsBarList}\"><md-button ng-if=$ctrl.showActions aria-label=\"Ações\'\" class=md-icon-button ng-click=$ctrl.actionsBarShow()><md-icon ng-if=\"!$ctrl.showActionsBar && !$ctrl.showActionsBarList\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_menu.svg></md-icon><md-icon class=md-primary ng-if=\"$ctrl.showActionsBar || $ctrl.showActionsBarList\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_arrow2.svg></md-icon></md-button></div><md-button ng-if=$ctrl.sidenavHelp.showIcon aria-label=Ajuda ng-click=$ctrl.sidenavShow($ctrl.sidenavHelp) class=md-icon-button><md-icon md-svg-icon=../../node_modules/pling-ui/assets/icons/icone_help.svg aria-label=Configurações></md-icon><md-tooltip md-direction=botton>Ajuda</md-tooltip></md-button><md-button ng-if=$ctrl.sidenavActivities.showIcon aria-label=Atividades ng-click=$ctrl.sidenavShow($ctrl.sidenavActivities) class=md-icon-button><md-icon md-svg-icon=../../node_modules/pling-ui/assets/icons/icone_history.svg aria-label=Configurações></md-icon><md-tooltip md-direction=botton>Atividades</md-tooltip></md-button><md-button ng-if=$ctrl.sidenavConfigurations.showIcon aria-label=Configurações ng-click=$ctrl.sidenavShow($ctrl.sidenavConfigurations) class=md-icon-button><md-icon md-svg-icon=../../node_modules/pling-ui/assets/icons/icone_settings.svg aria-label=Configurações></md-icon><md-tooltip md-direction=botton>Configurações</md-tooltip></md-button></div></div><md-divider></md-divider><plg-backdrop id=allbarbackdrop opacity=$ctrl.backdropOpacity on=\"$ctrl.sidenavId && $ctrl.sidenavDynamic.backdrop && !$ctrl.sidenavBackdropShowHide\" click=$ctrl.sidenavShow($ctrl.sidenavDynamic)></plg-backdrop><md-sidenav md-component-id=sidenavDynamic class=md-sidenav-right md-whiteframe=4 md-dynamic-height=\"\" md-disable-backdrop=\"\" style=\"overflow: hidden; position: fixed\"><plg-sidenav ng-if=$ctrl.sidenavId sidenav-id=$ctrl.sidenavId id=$ctrl.sidenavDynamic.id name=$ctrl.sidenavDynamic.name template=\"{{ $ctrl.sidenavDynamic.template }}\" back-action=$ctrl.backAction menu=$ctrl.sidenavDynamic.menu fn-menu=$ctrl.sidenavDynamic.fnMenu($ctrl.backAction) fn-return-menu=$ctrl.sidenavDynamic.fnReturnMenu() fn-close=$ctrl.sidenavDynamic.fnClose()></plg-sidenav></md-sidenav><md-sidenav md-component-id=sidenavDynamicLeft class=md-sidenav-left md-whiteframe=4 md-dynamic-left=\"\" md-disable-backdrop=\"\" style=\"overflow: hidden; position: fixed\"><plg-menu></plg-menu></md-sidenav><plg-data-list-toolbar ng-if=$ctrl.toolbarOptions toolbar-options=$ctrl.toolbarOptions></plg-data-list-toolbar><md-divider ng-if=$ctrl.toolbarOptions></md-divider><plg-toast></plg-toast><plg-dialog></plg-dialog></section>");
$templateCache.put("plg-attachment.html","<div layout=row ng-if=\"files && files.length > 0\" class=list-upload-file-ticket><plg-chips chips=files remove=removeFile></plg-chips></div><md-button class=plg-attachment-button ng-click=selectFile()>Anexar arquivos<md-icon class=attach-ticket-file-float aria-label=Anexo md-svg-icon=../../node_modules/pling-ui/assets/icons/icone_attach_file.svg aria-hidden=true></md-icon></md-button><input style=display:none type=file id=file>");
$templateCache.put("plg-calendar.html","<div class=plg-calendar-container layout=\"\" layout-margin=\"\"><ul class=plg-calendar-list style=float:left; layout=\"\" layout-margin=\"\" ng-if=!$ctrl.disableOptions plg-nav-control=\"\" nav-class=plg-calendar-option-selected><li flex=\"\" name=1 ng-click=$ctrl.setToday() md-prevent-menu-close=md-prevent-menu-close>Hoje</li><li flex=\"\" name=2 ng-click=\"$ctrl.setToday(\'d\', -1)\" md-prevent-menu-close=true>Ontem</li><li flex=\"\" name=3 ng-click=\"$ctrl.setToday(\'d\', -7)\" md-prevent-menu-close=true>Últimos 7 dias</li><li flex=\"\" name=4 ng-click=\"$ctrl.setToday(\'d\', -14)\" md-prevent-menu-close=true>Últimos 14 dias</li><li flex=\"\" name=5 ng-click=\"$ctrl.setToday(\'d\', -30)\" md-prevent-menu-close=true>Últimos 30 dias</li><li flex=\"\" name=6 ng-click=\"$ctrl.setToday(\'M\', -1)\" md-prevent-menu-close=true>Mês passado</li><li flex=\"\" name=7 ng-click=$ctrl.setThisMonth() md-prevent-menu-close=true>Este mês</li></ul><div style=\"float:left;margin: 0 auto;\" class={{$ctrl.containerClass}} ng-class=\"{ \'plg-calendar-right-side\': !$ctrl.disableOptions }\"><div layout=row layout-fill=\"\"><md-button aria-label=\"previous month\" class=\"md-icon-button plg-calendar-fill-button\" ng-click=\"$ctrl.prevDate(\'year\');\" md-prevent-menu-close=true><md-icon>keyboard_arrow_left</md-icon></md-button><span flex=100 class=plg-calendar-monthyear style=\"padding-top: 12px;font-size: 13px;text-align:center;\">{{ $ctrl.todayYear }}</span><md-button aria-label=\"next month\" class=\"md-icon-button plg-calendar-fill-button\" ng-click=\"$ctrl.nextDate(\'year\');\" md-prevent-menu-close=true><md-icon>keyboard_arrow_right</md-icon></md-button><md-button aria-label=\"previous month\" class=\"md-icon-button plg-calendar-fill-button\" ng-click=\"$ctrl.prevDate(\'month\');\" md-prevent-menu-close=true ng-if=\"$ctrl.monthsLimit < 2\"><md-icon>keyboard_arrow_left</md-icon></md-button><span flex=100 class=plg-calendar-monthyear style=\"font-size: 13px;text-align:center;padding-top: 12px;\" ng-if=\"$ctrl.monthsLimit < 2\">{{ $ctrl.getMonth(i) }}</span><md-button aria-label=\"next month\" class=\"md-icon-button plg-calendar-fill-button\" ng-click=\"$ctrl.nextDate(\'month\');\" md-prevent-menu-close=true ng-if=\"$ctrl.monthsLimit < 2\"><md-icon>keyboard_arrow_right</md-icon></md-button></div><div layout=column layout-align=\"start center\" class=plg-calendar-calendar ng-repeat=\"i in $ctrl.monthsNumbers\"><div layout=row layout-align=\"space-between center\" class=plg-calendar-monthyear ng-if=\"$ctrl.monthsLimit > 1\"><md-button aria-label=\"previous month\" class=\"md-icon-button plg-calendar-fill-button\" ng-click=\"$ctrl.prevDate(\'month\');\" md-prevent-menu-close=true><md-icon>keyboard_arrow_left</md-icon></md-button>{{ $ctrl.getMonth(i) }}<md-button aria-label=\"next month\" class=\"md-icon-button plg-calendar-fill-button\" ng-click=\"$ctrl.nextDate(\'month\');\" md-prevent-menu-close=true><md-icon>keyboard_arrow_right</md-icon></md-button></div><div layout=row layout-align=\"space-around center\" class=plg-calendar-week-days><div class=\"md-body-2 {{$ctrl.dayClass}}\" layout=\"\" layout-align=\"center center\" ng-repeat=\"d in $ctrl.weekDaysMin track by $index\">{{ d }}</div></div><div layout=row layout-wrap=\"\" class=plg-calendar-days><div layout=\"\" layout-align=\"center center\" ng-repeat-start=\"objD in $ctrl.daysInMonth[i] track by $index\" class={{$ctrl.dayClass}}><div ng-if=\"objD.events.length > 0 && !$ctrl.disableEvents && $ctrl.onBags(objD) > 0\" class=plg-calendar-badge>{{ $ctrl.onBags(objD) }}</div><md-button aria-label=\"Selecionar dia\" ng-if=\"objD.day !== false\" md-prevent-menu-close=true class=\"plg-calendar-days-button md-fab {{$ctrl.dayClass}}\" ng-class=\"{\'plg-calendar-selected\': $ctrl.isSelected(objD.day, i), \'plg-calendar-days-in-range\': $ctrl.isInRange(objD.day, i), \'plg-calendar-today\': $ctrl.isToday(objD.day, i)}\" ng-click=\"$ctrl.selectDate(objD.day, i)\">{{ objD.day }}</md-button></div><div flex=\"\" ng-if=\"($index + 1) % 7 == 0\" style=display:none ng-repeat-end=\"\"></div></div></div><div style=\"clear: both;\"></div></div></div>");
$templateCache.put("plg-chat.html","<div class=plg-chat-area><div class=chat-arrow-up-container ng-show=visible ng-style=arrowUp><md-content class=chat-arrow-up></md-content></div><md-content id=plg-chat-pannel class=plg-chat-container ng-show=visible click-outside=closeChat() outside-if-not=bt-chat-create-group><audio id=chat-notification><source ng-src=\"{{s3SoundUrlOgg }}\" type=audio/ogg><source ng-src={{s3SoundUrlMp3}} type=audio/mpeg></audio><div ng-if=!isChatLoading class=plg-chat-list-content ng-cloak=\"\"><div ng-include=\"\'plg-chat-list.html\'\" class=plg-chat-list-items ng-cloak=\"\"></div></div><md-content ng-show=isChatLoading class=plg-chat-loader layout=column layout-align=\"center center\"><md-progress-circular md-mode=indeterminate></md-progress-circular></md-content><div ng-if=!isChatLoading class=plg-chat-search-container ng-cloak=\"\"><md-button style=\"float: left; margin: 0 0 0 -10px;\" ng-show=\"showSearchInput || showGroupInput\" ng-click=clearChatTopBarSelection() aria-label=Voltar class=md-icon-button><md-tooltip>Voltar e limpar alterações</md-tooltip><md-icon class=\"plg-chat-toolbox-container-top-icons md-primary\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_arrow_left.svg></md-icon></md-button><md-menu><md-button ng-hide=\"showSearchInput || showGroupInput\" style=\"margin: 0; padding: 0;\" ng-click=\"openMenu($mdOpenMenu, $event)\" aria-label=\"Definir status\" class=\"md-icon-button md-primary\"><md-tooltip md-direction=top>Definir Status</md-tooltip><md-icon class=plg-chat-toolbox-container-top-icons md-svg-src=../../node_modules/pling-ui/assets/icons/icone_more_vert.svg></md-icon></md-button><md-menu-content width=4><md-menu-item><md-button ng-click=toggleNotifications()>Ativar Notificações</md-button></md-menu-item><md-menu-divider></md-menu-divider><md-menu-item><md-button ng-click=toggleNotifications()>Desativar Notificações</md-button></md-menu-item></md-menu-content></md-menu><md-button ng-hide=\"showSearchInput || showGroupInput\" ng-click=\"showTopBarInput(\'search\')\" aria-label=\"Nome Grupo\" class=\"md-icon-button md-primary\"><md-tooltip md-direction=top>Buscar conversas e usuários</md-tooltip><md-icon class=plg-chat-toolbox-container-top-icons md-svg-src=../../node_modules/pling-ui/assets/icons/icone_search.svg></md-icon></md-button><md-button ng-hide=\"showSearchInput || showGroupInput\" ng-click=\"showTopBarInput(\'group\')\" aria-label=\"Criar grupo\" class=\"md-icon-button md-primary\"><md-tooltip md-direction=top>Criar grupo de usuários</md-tooltip><md-icon class=plg-chat-toolbox-container-top-icons md-svg-src=../../node_modules/pling-ui/assets/icons/icone_group_add.svg></md-icon></md-button><md-button ng-if=soundEnabled ng-hide=\"showSearchInput || showGroupInput\" ng-click=toggleSound() aria-label=\"Desativar som\" class=\"md-icon-button md-primary\"><md-tooltip md-direction=top>Desativar som</md-tooltip><md-icon class=plg-chat-toolbox-container-top-icons md-svg-src=../../node_modules/pling-ui/assets/icons/icon_volume_up.svg></md-icon></md-button><md-button ng-if=!soundEnabled ng-hide=\"showSearchInput || showGroupInput\" ng-click=toggleSound() aria-label=\"Aativar som\" class=\"md-icon-button md-primary\"><md-tooltip md-direction=top>Ativar som</md-tooltip><md-icon class=plg-chat-toolbox-container-top-icons md-svg-src=../../node_modules/pling-ui/assets/icons/icon_volume_off.svg></md-icon></md-button><md-button ng-if=maximized ng-hide=\"showSearchInput || showGroupInput\" ng-click=toggleChatMode() aria-label=\"Fixar chat\" class=\"md-icon-button md-primary toggle-chat-mode\"><md-tooltip md-direction=top>Soltar chat</md-tooltip><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_arrow2.svg></md-icon></md-button><md-button ng-if=!maximized ng-hide=\"showSearchInput || showGroupInput\" ng-click=toggleChatMode() aria-label=\"Maximizar chat\" class=\"md-icon-button md-primary toggle-chat-mode\"><md-tooltip md-direction=top>Fixar chat</md-tooltip><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_arrow2.svg></md-icon></md-button><md-input-container ng-show=showGroupInput ischatloading=\"\" md-no-float=\"\" class=\"md-block group-name-input\"><input plg-auto-focus=\"{{ chatTopBarInputGroupFocused }}\" ng-model=userGroups.name placeholder=\"Nome do grupo\" maxlength=20 ng-keyup=keyUpInputGroup($event)></md-input-container><md-input-container ng-show=showSearchInput md-no-float=\"\" class=\"md-block search-input\"><input plg-auto-focus=\"{{ chatTopBarInputSearchFocused }}\" ng-keyup=searchTextChange(searchObj.text); ng-model=searchObj.text placeholder=\"Buscar por nome..\"></md-input-container><md-button id=bt-chat-create-group ng-show=\"showGroupInput && userGroups.name.length > 1 && userGroups.count > 1\" ng-click=\"openRoom(getSelectedUsers(), userGroups.name)\" aria-label=\"Criar grupo\" class=\"bt-create-group md-primary\"><md-tooltip md-direction=top>Iniciar conversa no grupo {{ userGroups.name }}</md-tooltip>Criar</md-button></div></md-content><div class=chat-row><div ng-repeat=\"chatRoom in chatRoomList track by chatRoom._id\"><plg-active-chat></plg-active-chat></div><div class=chat-conversation-group ng-if=\"activeChatGroup.length > 0\"><a class=chat-conversation-group-badge href=# data-number=\"{{ activeChatGroup.length }}\"></a><md-menu><md-button md-no-ink=\"\" ng-click=\"openMenu($mdOpenMenu, $event)\" aria-label=\"Conversas agrupadas\" class=md-icon-button><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_chat.svg></md-icon></md-button><md-menu-content width=4><md-menu-item ng-repeat=\"activeChatItem in activeChatGroup track by activeChatItem._id\"><md-content style=\"top:0; padding: 0; width: 200px;float: left; color: grey; background: transparent; overflow: hidden;\"><md-button class=md-no-focus aria-label=\"{{ activeChatItem.name }}\" ng-click=\"chatListRightPop(activeChatItem, $index)\" style=margin-right:0;padding-right:0;><span style=\"width:185px; overflow: hidden; text-overflow: ellipsis; display: block; text-align: left\">{{ activeChatItem.name }}</span></md-button></md-content><md-content style=\"top:0; width: 36px;padding: 0;overflow: hidden;text-align: center; background: transparent;\"><md-button class=md-no-focus aria-label=\"Fechar conversa com {{ activeChatItem.nickname || activeChatItem.name }}\" style=\"min-width: 0; margin: 0; padding: 0;\" ng-click=\"closeGroupRoomById(activeChatItem, $index)\"><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_close.svg></md-icon></md-button></md-content></md-menu-item></md-menu-content></md-menu></div></div></div>");
$templateCache.put("plg-date-picker.html","<form name=datePickerForm class=\"{{$ctrl.class}} plg-date-picker-form\" ng-class=\"{\'plg-date-picker-form-size-min\': !$ctrl.disableRange}\"><md-menu off-set=\"0 10\"><md-input-container layout=row class=\"md-icon-float md-block md-icon-left plg-date-picker-input-container\"><label ng-click=\"!$ctrl.disableIcon && $mdOpenMenu($event)\" tabindex=-1 role=button for={{$ctrl.inputId}}></label> <label ng-if=$ctrl.label>{{ $ctrl.label }}</label><md-icon class=\"{{$ctrl.classIcon}} material-icons\" ng-click=$mdOpenMenu($event) ng-show=!$ctrl.disableIcon>date_range</md-icon><input ng-if=$ctrl.mask class=\"md-input {{$ctrl.classInput}}\" id={{$ctrl.inputId}} aria-label=hidden model-view-value=true ui-mask={{$ctrl.mask}} ui-options=\"{ \'clearOnBlur\': false }\" ng-model=$ctrl.selected.display ng-change=$ctrl.validate($ctrl.selected);$ctrl.setDates($ctrl.selected);$ctrl.onChange() ng-blur=$ctrl.validate($ctrl.selected);$ctrl.setDates($ctrl.selected);$ctrl.ngBlur() ng-class=\"{\'plg-date-picker-input-size-min\': $ctrl.disableRange}\" md-menu-origin=\"\"><div class=md-errors-spacer ng-show=\"$ctrl.selected.$invalid && $ctrl.selected && $ctrl.selected.display && $ctrl.selected.display.length > 0 && !$ctrl.hideError\">Por favor informe uma data valida.</div></md-input-container><md-menu-content><plg-calendar force-init=true disable-events=true disable-options=$ctrl.disableOptions disable-range=$ctrl.disableRange id-event=$ctrl.idEvent months-limit=$ctrl.monthsLimit selected=$ctrl.selected disable-day-choice=true disable-month-choice=true disable-year-choice=true disable-date-init=$ctrl.disableDateInit style=\"margin-top: -5px;overflow: hidden;\"></plg-calendar></md-menu-content></md-menu></form>");
$templateCache.put("plg-fab-button.html","<div class=fab-container><md-fab-speed-dial class=md-scale ng-mouseenter=\"isOpen=true\" ng-mouseleave=\"isOpen=false\" md-open=isOpen md-direction=up><md-fab-trigger><md-button style=\"padding: inherit;\" aria-label=menu class=\"md-fab fab-trigger-button\"><div class=fab-trigger></div></md-button></md-fab-trigger><md-fab-actions><div ng-repeat=\"action in fabButton.fabActions\"><md-button ng-if=action.isPng ng-click=action.fn(event) aria-label=acao class=\"md-fab md-primary md-mini plg-fab-action-button\"><img class=fab-actions-icon src={{action.iconPath}} style=\"margin-top: 30%; width: 20px; height: 20px;\"><md-tooltip ng-if=action.tooltip class=plg-tooltip md-direction=left md-visible=tooltipVisible md-autohide=false>{{action.tooltip}}</md-tooltip></md-button><md-button ng-if=!action.isPng ng-click=action.fn(event) aria-label=acao class=\"md-fab md-primary md-mini plg-fab-action-button\"><md-icon class=fab-actions-icon md-svg-src={{action.iconPath}} aria-label=acao></md-icon><md-tooltip ng-if=action.tooltip class=plg-tooltip md-direction=left md-visible=tooltipVisible md-autohide=false>{{action.tooltip}}</md-tooltip></md-button></div></md-fab-actions></md-fab-speed-dial></div>");
$templateCache.put("plg-image-drive.html","<div ng-class=\"{\'plg-image-item plg-image-icon-avatar\' : $ctrl.imageType === \'profile-images\'}\"><md-icon ng-if=$ctrl.imageIcon ng-class=\"{\'plg-image-icon-avatar\' : $ctrl.imageType === \'profile-images\'}\" md-svg-src=\"{{ $ctrl.imageIcon }}\" aria-label=imagem></md-icon><img ng-if=$ctrl.image ng-class=\"{\'plg-image-icon-avatar\' : $ctrl.imageType === \'profile-images\'}\" ng-src=\"{{ $ctrl.image }}\" aria-label=imagem></div>");
$templateCache.put("plg-login.html","<plg-panel id=login_panel class=login-panel-content align-type=none config=config><md-button class=\"md-icon-button login-panel-close\" ng-click=$ctrl.close() ng-if=$ctrl.scope.isByEvent><md-icon md-svg-src=node_modules/pling-ui/assets/icons/icone_close.svg aria-label=\"Close dialog\"></md-icon></md-button><p class=login-panel-title ng-hide=$ctrl.scope.isLoading>{{ $ctrl.scope.titleMessage || \'Faça login em sua conta\'}}</p><md-progress-circular md-mode=indeterminate class=login-panel-loader ng-if=$ctrl.scope.isLoading></md-progress-circular><md-input-container class=login-panel-input ng-hide=$ctrl.scope.isLoading><label>Email</label> <input ng-model=$ctrl.user type=text ng-disabled=!$ctrl.scope.enableUsername ng-keypress=$ctrl.scope.checkCapslock($event)></md-input-container><md-input-container class=login-panel-input ng-hide=$ctrl.scope.isLoading><label>Senha</label> <input ng-model=$ctrl.scope.fakePassword type=text autofocus=\"\" plg-set-focus=true autocomplete=off ng-keypress=\"$event.which === 13 && $ctrl.submit($ctrl.user, $ctrl.scope.pwd, $ctrl.close, $ctrl.scope)\" ng-keyup=$ctrl.scope.checkCapslock($event)></md-input-container><span ng-if=$ctrl.scope.isCapsLock class=caps-lock-message>Tecla Caps Lock ativada</span><md-button class=\"md-raised login-panel-button\" ng-click=\"$ctrl.submit($ctrl.user, $ctrl.scope.pwd, $ctrl.close, $ctrl.scope)\" ng-hide=$ctrl.scope.isLoading>Login</md-button></plg-panel><plg-backdrop ng-if=isOpen on=isOpen opacity=opacity z-index=103></plg-backdrop>");
$templateCache.put("plg-menu.html","<md-content hide-sm=\"\"><md-list class=menu-container-list><md-list-item class=menu-container-list-item ng-repeat=\"item in arrMenu\" md-no-ink=\"\" ng-class=\"{ menuActive : item.active}\" ng-click=changeRoute(item.route)><p><md-icon style=\"margin-right: 10px; margin-top:-3px;\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_{{item.icon}}.svg aria-label={{item.icon}}></md-icon>{{item.name}}</p></md-list-item></md-list></md-content>");
$templateCache.put("plg-password-strength.html","<div class=plg-strength-meter-container><div class=plg-strength-meter><div class=plg-strength-meter-fill data-strength={{passwordStrength}}></div></div></div>");
$templateCache.put("plg-screen-image-crop.html","<plg-panel id=IMAGE_CROP_PANEL align-type=middle config=\"{ \'hasBackdrop\': true, \'zIndex\': 90 }\" class=crop-panel><div ng-controller=ScreenImageCropController class=crop-container layout=column layout-wrap=\"\"><div class=crop-panel-title ng-hide=isLoading><div class=left>{{title}}</div></div><md-progress-circular md-mode=indeterminate ng-if=isLoading style=\"position:absolute;left: calc(50% - 50px/2);top: calc(50% - 50px/2);\"></md-progress-circular><div style=\"color: rgba(0,0,0,.58)!important; line-height: 22px!important;padding: 0 24px;\" layout=row ng-hide=isLoading><p ng-show=\"!isShowWebCam && !isShowImage\">Você pode tirar uma foto nova (opção Webcam) ou subir uma imagem existente (opção Upload)</p><p ng-show=\"isShowWebCam && !isShowImage\">Após clicar no botão tirar foto, você poderá selecionar o melhor ângulo/pedaço da imagem que será utilizada.</p><p ng-show=isShowImage>Selecione o melhor ângulo/pedaço da imagem e após clique no botão recortar.</p></div><div ng-hide=isLoading layout=row layout-wrap=\"\" layout-align=space-around style=\"padding: 0 24px;\"><input id=customerFileUploader file-model=myAccountImage type=file name=myAccountImage ng-show=false accept=image/*><div class=crop-webcam-ico ng-if=!noWebCam ng-hide=isTake><i plg-theming=\"\" ng-click=takePicture() class=material-icons style=color:rgba(0,0,0,.58)!important>&#xE412;</i> <label>Webcam</label></div><div class=crop-file-upload-ico ng-hide=isTake><i plg-theming=\"\" ng-click=openFileDialog() class=material-icons style=color:rgba(0,0,0,.58)!important>file_upload</i> <label style=\"margin-left: 7px;\">Upload</label></div><div style=\"margin-top: 20px;\" ng-show=isTake><plg-webcam ng-show=isShowWebCam channel=channel on-init=onInit() on-streaming=onSuccess() on-error=onError(err) on-stream=onStream(stream)></plg-webcam><div ng-show=isShowImage class=cropArea><img-crop image=imageData result-image=croppedImageData area-min-size=50></img-crop></div></div></div><footer ng-hide=\"isLoading || !showWebcamFooter\" class=crop-panel-footer><md-button ng-click=$ctrl.close()>Cancelar</md-button><md-button md-no-ink=\"\" class=md-primary ng-click=makeSnapshot()>Tirar Foto</md-button></footer><footer ng-hide=\"isLoading || !showFileFooter\" class=crop-panel-footer><md-button ng-click=$ctrl.close()>Cancelar</md-button><md-button md-no-ink=\"\" class=md-primary ng-click=cropImage()>Recortar</md-button></footer></div></plg-panel>");
$templateCache.put("plg-search.html","<div class=plg-search-container layout=row layout-align=\"start center\" ng-click=$ctrl.showMenu();><md-icon flex=10 md-svg-src=../../node_modules/pling-ui/assets/icons/icone_search.svg aria-label=Pesquisa ng-hide=\"($ctrl.items.length > 0 || $ctrl.isEmpty) && $ctrl.isOpen\"></md-icon><span flex=\"\"></span> <input id=sbar-inp ng-model=$ctrl.searchText placeholder=Pesquisa ng-if=!$ctrl.dateField ng-keyup=\"$event.keyCode == 13 && $ctrl.selectedItemChange($ctrl.items)\" ng-change=$ctrl.querySearch($ctrl.searchText)> <input id=sbar-date ng-model=$ctrl.dateSelected ng-if=$ctrl.dateField placeholder=\"Pesquisa entre datas\" ng-keyup=\"$event.keyCode == 13 && $ctrl.selectedItemChange($ctrl.items)\" on-change=$ctrl.querySearch($ctrl.dateSelected)><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_expand_more.svg aria-label=\"\" ng-click=\"$ctrl.isMenu = !$ctrl.isMenu;$event.stopPropagation();\" ng-show=\"($ctrl.items.length > 0 || $ctrl.isEmpty) && $ctrl.isOpen\" style=cursor:pointer></md-icon><md-content ng-style=$ctrl.listStyle id=plgSearchContent ng-class=\"{\'plg-search-loading\': $ctrl.isLoading}\" ng-show=\"($ctrl.searchText.length > 2 || $ctrl.dateField) && $ctrl.isOpen\"><md-progress-linear md-mode=indeterminate ng-if=$ctrl.isLoading></md-progress-linear><md-list ng-if=$ctrl.isMenu class=plg-search-options-menu><div class=\"plg-search-item plg-search-option\" ng-repeat=\"f in $ctrl.getFields()\" ng-click=\"$ctrl.fieldSelected(f);$ctrl.querySearch($ctrl.dateField ? $ctrl.dateSelected : $ctrl.searchText);$event.stopPropagation();\" ng-class=\"{\'plg-search-selected\': f.isSelected}\">{{ f.label }}</div></md-list><md-list layout-fill=\"\" ng-if=\"!$ctrl.isLoading && ($ctrl.items.length > 0 || $ctrl.isEmpty)\"><md-list-item class=\"md-1-line plg-search-item\" ng-repeat=\"item in $ctrl.items\" ng-click=$ctrl.selectedItemChange(item);$event.stopPropagation(); aria-label=not ng-if=\"$ctrl.searchText.length > 2 && !$ctrl.dateField || ($ctrl.dateField && !$ctrl.dateSelected.$invalid)\">{{ item._source[$ctrl.getDocumentName()] }}</md-list-item><md-list-item ng-if=\"$ctrl.isEmpty || $ctrl.dateField && $ctrl.dateSelected.$invalid\" aria-label=not>Nenhum resultado encontrado</md-list-item></md-list></md-content></div>");
$templateCache.put("plg-select.html","<md-content class=plg-select ng-if=$ctrl.isLoadingStart><div class=plg-select-input ng-class=\"{\'disabled\': $ctrl.isDisabled}\"><div flex=\"\" plg-set-focus={{$ctrl.isFocus}} ng-click=\"!$ctrl.isDisabled && $ctrl.focus($event)\" ng-attr-id=\"{{ $ctrl.configModel.ref }}\" class=plg-select-input-line ng-class=\"{ \'plg-select-input-line-err\': !$ctrl.itemName && !$ctrl.isFocusItem && $ctrl.configModel.isRequired && $ctrl.isMsgErr, \'plg-select-input-line-selected\': $ctrl.isFocusItem }\"><span class=plg-select-input-label-color ng-class=\"{ \'plg-select-input-label-selected\': $ctrl.itemName || $ctrl.isFocusItem, \'plg-select-input-cursor\': !$ctrl.itemName && !$ctrl.isFocusItem && !$ctrl.isDisabled, \'plg-select-input-label-blue\': $ctrl.isFocusItem, \'plg-select-input-label\': !$ctrl.itemName, \'plg-select-input-label-err\': $ctrl.configModel.isRequired && !$ctrl.itemName && !$ctrl.isFocusItem && $ctrl.isMsgErr }\">{{$ctrl.configModel.label}}</span> <span ng-class=\"{ \'plg-select-input-cursor\': !$ctrl.isDisabled, \'plg-select-input-line-height\': !$ctrl.configModel.isChips, \'plg-select-input-line-height-chips\': $ctrl.configModel.isChips, \'plg-select-input-line-height-chips-padding\': $ctrl.configModel.isChips && !$ctrl.itemName }\"><span class=plg-select-input-line-text ng-if=!$ctrl.configModel.isChips>{{$ctrl.itemName}}</span> <span class=plg-select-input-line-chips ng-if=$ctrl.configModel.isChips ng-repeat=\"item in $ctrl.arrItemName\"><span class=plg-select-input-line-chips-span>{{item[$ctrl.configModel.refName]}}<md-button aria-label=\"Selecionar Item\" class=md-icon-button ng-click=$ctrl.selectItem(item)>X</md-button></span></span></span> <span class=plg-select-input-line-icon aria-label=Abrir><md-icon aria-label=Abrir md-svg-src=../../node_modules/pling-ui/assets/icons/icone_arrow_drop_down.svg></md-icon></span></div><div class=plg-select-input-err><span ng-if=\"$ctrl.configModel.isRequired && !$ctrl.itemName && !$ctrl.isFocusItem && $ctrl.isMsgErr\">{{$ctrl.configModel.requiredMessage}}</span></div></div></md-content><input type=hidden ng-model=$ctrl.ngModelSelect>");
$templateCache.put("plg-sidenav.html","<md-toolbar class=md-toolbar-tools><div class=sidenav-toolbar flex=\"\" layout=row layout-align=\"start center\"><span ng-if=!$ctrl.backAction class=sidenav-toolbar-space></span><md-button ng-if=$ctrl.backAction class=md-icon-button aria-label=Voltar ng-click=$ctrl.sidenavBack()><md-icon md-svg-icon=../../node_modules/pling-ui/assets/icons/icone_keyboard_backspace.svg aria-label=Voltar></md-icon></md-button><span flex=\"\"></span> <span class=sidenav-toolbar-text>{{$ctrl.name}}</span> <span flex=\"\"></span><md-button class=md-icon-button aria-label=Fechar><md-icon md-svg-icon=../../node_modules/pling-ui/assets/icons/icone_close.svg aria-label=Fechar ng-click=$ctrl.sidenavClose()></md-icon></md-button></div></md-toolbar><div ng-if=\"!$ctrl.backAction && $ctrl.menu\" ng-repeat=\"menu in $ctrl.menu\" class=sidenav-menu ng-cloak=\"\"><div class=sidenav-menu-title>{{menu.name}}</div><ul ng-if=menu.submenu ng-repeat=\"submenu in menu.submenu\"><li ng-class=\"{\'mouseover\' : submenu.mouse && !submenu.children}\" ng-mouseover=\"submenu.mouse = true\" ng-mouseleave=\"submenu.mouse = false\" ng-click=$ctrl.sidenavClick(submenu)><div class=sidenav-menu-submenu><md-icon aria-label=submenu.name md-svg-icon=../../node_modules/pling-ui/assets/icons/{{submenu.icon}}.svg></md-icon><p>{{ submenu.name }}</p></div><ul ng-if=submenu.children ng-repeat=\"children in submenu.children\"><li ng-class=\"{\'mouseover\' : children.mouse}\" ng-mouseover=\"children.mouse = true\" ng-mouseleave=\"children.mouse = false\" ng-click=$ctrl.sidenavClick(children)><div class=sidenav-menu-children><p>{{ children.name }}</p></div></li></ul></li></ul></div><div ng-show=\"$ctrl.backAction || !$ctrl.menu\" class=\"sidenav-content sidenav-overflow\"><div class=sidenav-content show-gt-md=\"\" md-dynamic-height=\"\" ng-include=$ctrl.template></div></div>");
$templateCache.put("plgWizard.html","<div class=wizard-component-container><div class=wizardwrap><md-progress-linear class=md-accent style=\"width: 94%;\" md-mode=indertaminate ng-if=!$ctrl.loadWizard></md-progress-linear><div ng-if=$ctrl.loadWizard><div id=wizardwrap ng-style=\"$ctrl.totalSteps.length === 2 && {\'width\' : \'30%\'} || $ctrl.totalSteps.length > 2 && {\'width\' : \'90%\'}\"><div class=\"step-wizard {{ $ctrl.foward }}\" data-step=\"{{ $ctrl.index }}\"><p ng-repeat=\"wizard in $ctrl.totalSteps\" for=\"step-{{ wizard.index }}\">{{ wizard.name }}</p></div></div></div></div><div style=\"width: 90%; margin:auto;\" ng-include=$ctrl.wizardtemplatepath></div></div>");
$templateCache.put("plg-all-bar-menu-app.html","<div class=plg-panel-icon ng-style=arrowUp><div style=\"width: 14px; height: 14px; padding: 0; transform: rotate(45deg); z-index: 24; position: absolute; top: 4px; left: 4px; background-color: white\"></div></div><md-content class=.md-whiteframe-3dp><section layout=row layout-xs=column layout-align=\"start center\" layout-wrap=\"\"><div ng-repeat=\"app in applications\" flex=50 layout=column layout-align=\"center center\"><md-button pling-theming=\"{{ app.theming }}\" class=md-fab aria-label=\"{{ app.name }}\" ng-click=closeAppDialog() href=\"{{ app.callbackUrl + \'?token=\' + getToken() + rooms }}\"><md-icon md-svg-src=\"{{ app.iconPath }}\"></md-icon></md-button><div class=\"md-subhead plg-white-space\">{{ app.name }}</div></div></section></md-content>");
$templateCache.put("plg-all-bar-notification.html","<div class=plg-panel-icon ng-style=arrowUp><div style=\"width: 14px; height: 14px; padding: 0; transform: rotate(45deg); z-index: 24; position: absolute; top: 4px; left: 4px; background-color: white\"></div></div><md-content class=.md-whiteframe-2dp><div class=plg-notification-connection-lost ng-show=!$root.isWebsocketConnected><span>Conexão indisponível com o servidor</span><md-button aria-label=Reconectar class=md-raised ng-disabled=$root.isWebsocketLoading ng-click=reconnectWebsocket();>{{ $root.isWebsocketLoading ? \'Aguarde..\' : \'Reconectar\' }}</md-button></div><div ng-show=\"arrayNotifications.length === 0 && $root.isWebsocketConnected\" class=plg-no-notifications><span>Não existem notificações no momento</span></div><div ng-show=\"arrayNotifications.length > 0 && $root.isWebsocketConnected\" class=plg-notification-length><span>Notificações ({{ arrayNotifications.length }})</span></div><md-divider></md-divider><div ng-show=\"arrayNotifications.length > 0 && $root.isWebsocketConnected\" class=plg-notification-items><md-list ng-cloak=\"\"><md-list-item ng-repeat=\"not in arrayNotifications\"><p>{{ not.doc.description }}</p><p>{{ not.doc.date }}</p></md-list-item></md-list></div><md-divider></md-divider><div ng-show=\"arrayNotifications.length > 0 && $root.isWebsocketConnected\" class=plg-notification-footer><span>Ver todas notificações</span></div></md-content>");
$templateCache.put("plg-all-bar-user.html","<div class=plg-panel-icon ng-style=arrowUp><div style=\"width: 14px; height: 14px; padding: 0; transform: rotate(45deg); z-index: 24; position: absolute; top: 4px; left: 4px; background-color: white\"></div></div><md-content class=.md-whiteframe-2dp ng-if=controlPanelUrl><md-list ng-cloak=\"\"><md-list-item ng-click=myAccount() ng-hide=\"currentAppModule === \'painelDoClienteApp\'\" href=\"{{ controlPanelUrl }}\" target=_blank><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_person.svg></md-icon><p flex=\"\">Minha Conta</p></md-list-item><md-list-item ng-click=logout()><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_power_settings_new.svg></md-icon><p flex=\"\">Sair</p></md-list-item></md-list></md-content>");
$templateCache.put("plg-chat-conversation.html","<section class=\"conversation {{\'chat-rooom-id-\' + ctrl.currentChat._id}}\" ng-controller=\"PlgChatConversationController as ctrl\" tab-index=0 ng-focus=ctrl.focus() ng-blur=ctrl.blur() ng-click=ctrl.click() id=chatConversation ng-init=\"ctrl.init(currentUser, chatRoom)\" ng-class=\"{ \'collapsed\' : ctrl.currentChat.isCollapsed }\" ng-if=!isLoading ng-cloak=\"\"><header pling-theming=\"\" ng-click=\"ctrl.topMost(); ctrl.minimizerToggle($event);\" ng-class=\"{ \'blink-animation\' : ctrl.isNewMessageArrived && !ctrl.currentChat.isFocused}\"><div class=chat-image ng-if=\"ctrl.currentChat.people.length === 1 && ctrl.currentChat.imageDriveId\"><img ng-src=\"{{ctrl.currentChat.userImageUrl || ctrl.getUserImage(ctrl.currentChat.imageDriveId) }}\" plg-error-src=../../node_modules/pling-ui/assets/icons/icone_person_white.svg style=fill:#FAFAFA></div><md-icon class=conversation-icon aria-labelpling-theming=\"Chat Icon\" ng-show=\"ctrl.currentChat.people.length === 1 && !ctrl.currentChat.imageDriveId\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_person.svg></md-icon><div ng-show=\"ctrl.currentChat.people.length > 1\" class=group-conversation-avatar><md-icon class=conversation-icon aria-label=\"Chat Icon\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_people.svg></md-icon><span class=counter>{{ctrl.currentChat.people.length}}</span><md-tooltip ng-if=\"ctrl.currentChat.people.length > 1\" md-direction=top>{{ctrl.getTooltipUsersList(ctrl.currentChat)}}</md-tooltip></div><div class=chating-with><div>{{ctrl.currentChat.name}}</div><div ng-show=\"ctrl.typing && ctrl.currentChat.isCollapsed === true\" class=last-interaction><span ng-show=\"ctrl.currentChat.people.length > 1\" ng-repeat=\"user in ctrl.userTyping\"><span ng-show=\"$index > 0\">,&nbsp;</span>{{user.nickname || user.fullname}}}</span> <span ng-show=\"ctrl.userTyping.length > 1\">estão</span><span ng-show=\"ctrl.userTyping.length == 1\">está</span> digitando...</div><div ng-show=\"!ctrl.isLoading && ctrl.currentChat.chatLastInteraction && !(ctrl.typing && ctrl.currentChat.isCollapsed === true)\" class=last-interaction>Visto por último {{ctrl.currentChat.chatLastInteraction | plgChatInteractionDateFilter}}</div></div><button style=margin:0 class=\"icon minimize\" title=Minimizar ng-hide=ctrl.currentChat.isCollapsed></button> <button style=margin:0 class=\"icon popout\" ng-show=ctrl.currentChat.isCollapsed title=Maximizar></button><button ng-click=\"close(chatRoom, $index)\" ng-disabled=ctrl.isLoading style=margin:0 class=\"icon close\" title=Fechar></button></header><div class=messages plg-scroll-glue=ctrl.isToScroll ng-class=\"{ \'no-overflow\': ctrl.isLoading }\" plg-scroll-chat=ctrl.scrollUp><md-content class=conversation-no-results-container layout=column layout-align=\"center center\" flex=\"\" ng-if=\"!ctrl.isLoading && (!ctrl.currentChat.messages || ctrl.currentChat.messages.length === 0)\"><md-icon class=conversation-no-results-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_chat.svg></md-icon></md-content><md-content ng-show=ctrl.isLoading class=conversation-no-results-container layout=column layout-align=\"center center\" flex=\"\"><md-progress-circular md-mode=indeterminate md-diameter=30px></md-progress-circular><h3>Carregando mensagens...</h3></md-content><div class=chat-conversation-loader ng-show=\"ctrl.isLoadingMessages === true\"><md-progress-circular md-mode=indeterminate md-diameter=12px style=display:inline></md-progress-circular><span>Carregando mensagens</span></div><div ng-repeat=\"messageObj in ctrl.currentChat.messages track by $index\" ng-hide=ctrl.isLoading><div class=date ng-show=\"$index === 0 || ctrl.currentChat.messages[$index - 1].formattedDate !== messageObj.formattedDate\" ng-class=\"{first : $index === 0}\">{{messageObj.formattedDate}}</div><div class=\"message collapsed\" ng-class=\"{ \'me\': ctrl.currentUser.id === messageObj.credential_id }\"><p class=content style=\"word-break: break-word;\"><span class=chat-conversation-username ng-if=\"ctrl.currentUser.id !== messageObj.credential_id\" style=\"{{\'color: \' + ctrl.currentChat.colors[messageObj.credential_id]}}\">{{ messageObj.username }}</span> <span ng-style=ctrl.set_zoom(messageObj); ng-bind-html=\"messageObj.message | plgUrlify | plgToTrustedHtml\"></span><br ng-if=ctrl.setZoom><time>{{messageObj.createDate | date:\'HH:mm\'}}<md-icon class=\"icon-message-sent icon-message-sent-notconfirmed\" ng-if=!messageObj._id md-svg-src=../../node_modules/pling-ui/assets/icons/icone_time.svg></md-icon><md-icon class=\"icon-message-sent icon-message-sent-notconfirmed\" ng-if=\"messageObj._id && ctrl.currentUser.id === messageObj.credential_id && (!messageObj.received || messageObj.received.length < ctrl.currentChat.people.length)\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_done.svg></md-icon><md-icon class=icon-message-sent ng-if=\"messageObj._id && ctrl.currentUser.id === messageObj.credential_id && messageObj.received && messageObj.received.length === ctrl.currentChat.people.length\" ng-class=\"{ \'icon-message-sent-notconfirmed\': !messageObj.readed || messageObj.readed.length < ctrl.currentChat.people.length, \'md-primary\' : messageObj.readed && messageObj.readed.length === ctrl.currentChat.people.length}\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_done_all.svg></md-icon></time></p></div></div></div><div class=typing ng-show=\"ctrl.typing && ctrl.currentChat.isCollapsed === false\"><div class=avatar-icon ng-if=\"ctrl.currentChat.people.length > 1\" ng-repeat=\"user in ctrl.userTyping\"><md-tooltip md-direction=top>{{user.nickname || user.fullname}} está digitando</md-tooltip><img ng-show=user.imageDriveId ng-src=\"{{ ctrl.getUserImage(user.imageDriveId) }}\" plg-error-src=../../node_modules/pling-ui/assets/icons/icon_chat_default.svg><md-icon aria-labelpling-theming=\"Chat Icon\" ng-show=!user.imageDriveId md-svg-src=../../node_modules/pling-ui/assets/icons/icone_person.svg></md-icon></div><div class=\"message collapsed\"><p class=content><md-icon class=md-primary md-svg-src=../../node_modules/pling-ui/assets/icons/icon_chat_bubbles.svg></md-icon></p></div></div><md-input-container class=container-input ng-hide=ctrl.currentChat.isCollapsed md-no-float=\"\" style=\"width: 100%; margin: 0 !important; padding: 0;\"><input id=chat-input-{{ctrl.currentChat._id}} class=\"valueEmoji plg-chat-conversation-input\" data-emojiable=true ng-focus=ctrl.focus(chatRoom) ng-blur=ctrl.blur(chatRoom) style=\"width: 77%; margin-left: 15px;\" md-no-autogrow=false maxlength=300 md-select-on-focus=\"\" ng-model=ctrl.chatMessage ng-keyup=\"ctrl.chatMessage && $event.keyCode === 13 && ctrl.sendMessage(ctrl.chatMessage, ctrl.currentChat)\" plg-auto-focus=\"{{ ctrl.currentChat.isFocused }}\" plg-enter-key=\"\" placeholder=\"Digite sua mensagem..\"><md-button class=\"md-icon-button md-primary\" aria-label=Enviar><md-icon class=send-icon ng-click=ctrl.sendMessage(ctrl.currentChat) md-svg-src=../../node_modules/pling-ui/assets/icons/icone_send.svg></md-icon></md-button></md-input-container></section>");
$templateCache.put("plg-chat-groups.html","<section><md-subheader class=plg-chat-group-subheader ng-if=\"peopleList.length > 0\"><md-input-container class=plg-chat-group-name-container><input placeholder=\"Nome do Grupo\" type=text md-maxlength=30 ng-model=userGroups.name></md-input-container><md-input-container style=\"float: right;\" ng-show=\"userGroups.count > 1\"><md-button ng-click=\"openRoom(getSelectedUsers(), userGroups.name)\" aria-label=\"Nome Grupo\" class=md-icon-button><md-icon style=\"color: #808080\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_add.svg></md-icon></md-button></md-input-container></md-subheader><md-list ng-if=\"peopleList.length > 0\"><md-list-item class=md-2-line ng-repeat=\"chatPerson in peopleList track by $index\" ng-mouseenter=toggleGroupCheckBox(chatPerson) ng-mouseleave=toggleGroupCheckBox(chatPerson) ng-click=changeGroupSelection(chatPerson);><div class=md-avatar><md-checkbox class=md-primary md-no-ink=\"\" ng-show=\"chatPerson.isShowGroupCheckBox || chatPerson.isSelected\" ng-change=changeGroupSelection(chatPerson) ng-model=chatPerson.isSelected aria-label=\"Usuario do Chat\"></md-checkbox><md-content class=md-avatar ng-show=\"chatPerson.imageDriveId && !chatPerson.isShowGroupCheckBox && !chatPerson.isSelected\" plg-back-img=\"{{ getUserImage(chatPerson.imageDriveId) }}\"></md-content><md-icon class=md-avatar ng-show=\"!chatPerson.imageDriveId && !chatPerson.isShowGroupCheckBox && !chatPerson.isSelected\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_myaccount.svg></md-icon></div><div class=\"md-list-item-text plg-chat-list-item-text\" layout=column><h3>{{ chatPerson.nickname || chatPerson.fullname }}</h3><p>{{ chatPerson.nickname }}</p></div></md-list-item></md-list></section>");
$templateCache.put("plg-chat-list.html","<md-list ng-if=\"peopleChatList.length > 0\" style=\"overflow: auto;\"><md-list-item md-no-ink=\"\" class=\"md-2-line plg-chat-list-item\" ng-disabled=isChatLoading ng-repeat=\"credentialOrRoom in peopleChatList | filter:{\'type\' : activeSection}\" ng-click=openRoom(credentialOrRoom); ng-hide=\"showGroupInput && credentialOrRoom.people\"><div class=md-avatar ng-show=showGroupInput style=margin-right:2px;><md-tooltip>Adicionar {{ credentialOrRoom.nickname || credentialOrRoom.fullname }} no grupo {{ userGroups.name }}</md-tooltip><md-checkbox class=md-primary md-no-ink=\"\" style=\"margin-left: 10px;\" ng-model=credentialOrRoom.isSelected aria-label=\"Usuario do Chat\" ng-click=incrementeUserGroups(credentialOrRoom.isSelected)></md-checkbox></div><img ng-if=\"credentialOrRoom.imageDriveId && !showGroupInput\" class=md-avatar style=margin-right:2px; ng-src=\"{{ getUserImage(credentialOrRoom.imageDriveId) }}\" plg-error-src=../../node_modules/pling-ui/assets/icons/icon_chat_default.svg><div class=md-avatar style=\"border: solid 1px #ececec; margin-right:0px;\" ng-if=\"!credentialOrRoom.imageDriveId && (credentialOrRoom.fullname || credentialOrRoom.nickname) && !showGroupInput\"><md-icon style=\"width:40px; height:40px;\" aria-label=\"Avatar {{ credentialOrRoom.nickname || credentialOrRoom.fullname }}\" md-svg-src=../../node_modules/pling-ui/assets/icons/icon_chat_default.svg></md-icon></div><div class=\"md-avatar avatar-group\" ng-if=\"!credentialOrRoom.imageDriveId && credentialOrRoom.people.length > 1 && !showGroupInput\"><md-icon style=\"width:28px; height:28px; margin:0 6px; vertical-align: middle;\" aria-label=\"Avatar {{ credentialOrRoom.nickname || credentialOrRoom.fullname }}\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_people.svg></md-icon><div class=counter><md-tooltip md-direction=top>{{getTooltipUsersList(credentialOrRoom)}}</md-tooltip>{{credentialOrRoom.people.length}}</div></div><div class=\"md-list-item-text plg-chat-list-item-text\" layout=column><h3 style=\"font-size: 11pt; width:100px; display: inline\">{{ credentialOrRoom.nickname || credentialOrRoom.fullname || credentialOrRoom.name }}</h3><md-icon ng-hide=\"credentialOrRoom.people.length > 1\" class=plg-chat-icon-status ng-class=\"{online : credentialOrRoom.isConnected}\" aria-label=status md-svg-src=../../node_modules/pling-ui/assets/icons/icon_chat_status.svg></md-icon><p style=\"font-size: 10pt\" ng-if=credentialOrRoom.room.lastMessage.message.message ng-class=\"{ \'last-message-bold\': credentialOrRoom.isNewMessageArrived }\" ng-bind-html=\"credentialOrRoom.room.lastMessage.message.message | plgToTrustedHtml\"></p><p style=\"font-size: 10pt\" ng-if=!credentialOrRoom.room.lastMessage.message.message ng-class=\"{ \'last-message-bold\': credentialOrRoom.isNewMessageArrived }\" ng-bind-html=\"credentialOrRoom.lastMessage.message.message || credentialOrRoom.fullname | plgToTrustedHtml\"></p></div></md-list-item></md-list><md-content class=plg-chat-no-results-container layout=column layout-align=\"center center\" flex=\"\" ng-if=\"peopleChatList.length === 0\"><md-icon class=\"plg-chat-no-results-icon md-primary\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_myaccount.svg></md-icon><h4>Nenhum registro de usuário ou conversa encontrado</h4><p ng-show=showSearchInput>Tente outra palavra chave no campo de busca</p></md-content>");
$templateCache.put("plg-chat-people.html","<section><md-list ng-if=\"peopleList.length > 0\"><md-list-item class=\"md-2-line plg-chat-list-item\" md-no-ink=\"\" ng-disabled=isChatLoading ng-if=\"peopleList.length > 0\" ng-repeat=\"credential in peopleList\" ng-click=\"openRoom(credential); $event.stopPropagation();\"><div class=md-avatar ng-show=credential.imageDriveId style=\"width: 30px !important; height: 30px !important;\" plg-back-img=\"{{ getUserImage(credential.imageDriveId) }}\"></div><md-icon class=md-avatar ng-hide=credential.imageDriveId style=\"width: 30px !important; height: 30px !important;\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_myaccount.svg></md-icon><div class=\"md-list-item-text plg-chat-list-item-text\" layout=column><h3 style=\"font-size: 11pt\">{{ credential.nickname || credential.fullname }}</h3><p style=\"font-size: 9pt\">{{ credential.isActive ? credential.nickname : \'DESATIVADO\' }}</p></div></md-list-item></md-list><md-content class=plg-chat-no-results-container layout=column layout-align=\"center center\" flex=\"\" ng-if=\"peopleList.length === 0\"><md-icon class=plg-chat-no-results-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_myaccount.svg></md-icon><h4>Não existem usuários ou conversas</h4><p>Existe apenas você cadastrado na sua empresa..</p></md-content></section>");
$templateCache.put("plg-chat-rooms.html","<section><md-list ng-if=\"roomList.length > 0\"><md-list-item class=\"md-2-line plg-chat-list-item\" md-no-ink=\"\" ng-disabled=isChatLoading ng-repeat=\"room in roomList\" ng-click=\"openRoom(room); $event.stopPropagation();\"><div class=md-avatar ng-show=room.imageDriveId plg-back-img=\"{{ getUserImage(room.imageDriveId) }}\"></div><md-icon class=md-avatar ng-show=\"!room.imageDriveId && room.people.length === 1\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_myaccount.svg></md-icon><md-icon class=md-avatar ng-show=\"!room.imageDriveId && room.people.length > 1\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_users.svg></md-icon><div class=\"md-list-item-text plg-chat-list-item-text\" layout=column><h3>{{ room.name }}</h3><p ng-class=\"{\'last-message-bold\': room.isNewMessageArrived}\">{{ room.lastMessage.credential_id === currentUser.id ? \'Você: \' : \'\'}} {{ room.lastMessage.message.message }}</p></div><md-menu md-position-mode=\"target-right target\"><md-button aria-label=Opcoes class=md-icon-button ng-click=$mdOpenMenu($event)><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_more_vert.svg></md-icon></md-button><md-menu-content width=2><md-menu-item><md-button ng-click=removeRoom(room._id)><div layout=row flex=\"\" style=\"text-align: center\"><p flex=\"\">Remover</p></div></md-button></md-menu-item></md-menu-content></md-menu></md-list-item></md-list><md-content class=plg-chat-no-results-container ng-if=\"roomList.length === 0\" layout=column layout-align=\"center center\" flex=\"\"><md-icon class=plg-chat-no-results-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_chat.svg></md-icon><h4>Não existem conversas</h4><p>Selecione um usuário ou crie um grupo</p></md-content></section>");
$templateCache.put("plg-data-list-toolbar.html","<div class=plg-data-list-toolbar ng-if=\"showSort || showFilter\" layout=row layout-wrap=\"\"><div flex=100 layout=row layout-align=\"start center\" ng-show=showSort><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_sort.svg></md-icon><span class=\"md-subhead text-toolbar\">Ordenar:</span><md-button class=\"toolbar-btn-scroll scroll-left\" aria-label=\"scroll left\"><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_arrow_left.svg></md-icon></md-button><div class=content-horizontal-scroll plg-data-list-horizontal-scroll=sort><div class=toolbar-item ng-repeat=\"sortItem in $ctrl.toolbarOptions.sortItems\"><md-input-container><md-select ng-model=sortItem.key ng-change=\"$ctrl.toolbarOptions.reorder($ctrl.toolbarOptions.sortItems, $index); changeSort();\" placeholder=Campo aria-label=drop-sort><md-option ng-if=!opt.template ng-value=opt.key ng-hide=\"opt.key !== sortItem.key && existingItem(opt, $ctrl.toolbarOptions.sortItems)\" ng-repeat=\"opt in $ctrl.toolbarOptions.itemColumns\">{{opt.text}}</md-option></md-select></md-input-container><md-input-container><md-select ng-model=sortItem.order ng-change=\"$ctrl.toolbarOptions.reorder($ctrl.toolbarOptions.sortItems, sortItem); changeSort();\" placeholder=Ordem aria-label=\"drop order\"><md-option value=asc>Ascendente</md-option><md-option value=desc>Descendente</md-option></md-select></md-input-container><md-button class=btn-toolbar aria-label=remove_sort ng-show=\"$ctrl.toolbarOptions.sortItems.length > 1\" ng-click=removeSortItem(sortItem)><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_remove.svg></md-icon></md-button></div><md-button md-no-ink=\"\" class=\"md-primary btn-toolbar-order\" ng-click=saveSortPreference()>Salvar ordenação</md-button></div><md-button class=\"toolbar-btn-scroll scroll-right\" aria-label=\"scroll right\"><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_arrow_right.svg></md-icon></md-button></div><div flex=100 layout=row layout-align=\"start center\" ng-show=showFilter><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_filter.svg></md-icon><span class=\"md-subhead text-toolbar\">Filtros:</span><md-button class=\"toolbar-btn-scroll scroll-left\" aria-label=\"scroll left\"><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_arrow_left.svg></md-icon></md-button><div class=content-horizontal-scroll plg-data-list-horizontal-scroll=filter><div class=toolbar-item ng-if=\"$ctrl.toolbarOptions.filtersPreference.length > 0\"><md-input-container><md-select ng-model=$ctrl.preferenceFilter ng-change=changePreferenceFilter($ctrl.preferenceFilter) placeholder=\"Preferência de filtros\" aria-label=filter-and-sort><md-option>Preferências de filtros</md-option><div layout=row class=filter-item ng-repeat=\"opt in $ctrl.toolbarOptions.filtersPreference\"><md-option style=\"background-color: transparent;\" ng-value=opt.name>{{opt.name}}</md-option><span flex=\"\"></span><md-button class=btn-remove-preference aria-label=\"delete filter\" ng-click=deleteFiltersPreference(opt)><md-icon style=\"min-width:16px; width:16px;\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_trash.svg></md-icon></md-button></div></md-select></md-input-container></div><div class=toolbar-item ng-repeat=\"filterItem in $ctrl.toolbarOptions.filterItems\"><md-input-container><md-select ng-if=filterItem.label ng-model=filterItem.key ng-change=\"changeFilterType(filterItem); changeFilter($ctrl.toolbarOptions.filterItems);\" placeholder=Campo aria-label=drop-filter><md-option ng-if=filterItem.label ng-value=filterItem.key>{{filterItem.label}}</md-option></md-select><md-select ng-if=!filterItem.label ng-model=filterItem.key ng-change=\"changeFilterType(filterItem); changeFilter($ctrl.toolbarOptions.filterItems);\" placeholder=Campo aria-label=drop-filter><md-option ng-if=!opt.template ng-value=opt.key ng-hide=\"opt.key !== filterItem.key && existingItem(opt, $ctrl.toolbarOptions.filterItems)\" ng-repeat=\"opt in $ctrl.toolbarOptions.itemColumns\">{{opt.text}}</md-option></md-select></md-input-container><md-input-container ng-if=filterItem.options><md-select ng-model=filterItem.exp placeholder=Condição aria-label=drop-filter ng-change=changeFilter($ctrl.toolbarOptions.filterItems);><md-option ng-value=opt.key ng-repeat=\"opt in filterItem.options\">{{opt.text}}</md-option></md-select></md-input-container><md-input-container ng-if=\"!filterItem.options && !filterItem.valueOptions\"><md-select ng-model=filterItem.exp placeholder=Condição aria-label=drop-filter ng-change=changeFilter($ctrl.toolbarOptions.filterItems);><md-option ng-show=\"filterItem.type === \'string\' || filterItem.type === \'phone\'\" ng-value=\"\'in\'\">contém</md-option><md-option ng-show=\"filterItem.type === \'number\' || filterItem.type === \'date\'\" ng-value=\"\'gtlt\'\">está entre</md-option><md-option ng-show=\"filterItem.type === \'number\' || filterItem.type === \'date\'\" ng-value=\"\'gt\'\">maior que</md-option><md-option ng-show=\"filterItem.type === \'number\' || filterItem.type === \'date\'\" ng-value=\"\'lt\'\">menor que</md-option><md-option ng-show=\"filterItem.type === \'string\' || filterItem.type === \'phone\'\" ng-value=\"\'notin\'\">não contém</md-option><md-option ng-show=\"filterItem.type === \'number\'\" ng-value=\"\'notgtlt\'\">não está entre</md-option></md-select></md-input-container><md-input-container ng-show=\"filterItem.key && !filterItem.label\"><label></label> <input class=input-filter ng-if=!filterItem.valueOptions ng-model=filterItem.value ng-change=changeFilter($ctrl.toolbarOptions.filterItems); aria-label=\"input 1\" maxlength=25 ui-mask-placeholder=\"\" ui-mask-placeholder-char=_ ui-mask={{getInputMask(filterItem)}}><md-select ng-if=filterItem.valueOptions ng-model=filterItem.value ng-change=changeFilter($ctrl.toolbarOptions.filterItems); placeholder=Valor aria-label=drop-filter><md-option ng-repeat=\"opt in filterItem.valueOptions\" ng-value=opt>{{ opt }}</md-option></md-select></md-input-container><span ng-show=\"filterItem.exp === \'gtlt\' || filterItem.exp === \'notgtlt\'\" style=\"margin: 8px;\">-</span><md-input-container ng-show=\"filterItem.key && (filterItem.exp === \'gtlt\' || filterItem.exp === \'notgtlt\')\"><label></label> <input class=input-filter ng-model=filterItem.value2 ng-change=changeFilter($ctrl.toolbarOptions.filterItems); aria-label=\"input 2\" maxlength=25 ui-mask={{getInputMask(filterItem)}}></md-input-container><md-button class=btn-toolbar aria-label=remove_filter ng-show=\"$ctrl.toolbarOptions.filterItems.length > 1\" ng-click=\"removeFilter($index); changeFilterType(filterItem); $ctrl.toolbarOptions.applyFilters($ctrl.toolbarOptions.filterItems);\"><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_remove.svg></md-icon></md-button></div><md-button class=\"btn-toolbar btn-add-item\" aria-label=add_sort ng-hide=checkItemColums($ctrl.toolbarOptions.filterItems) ng-click=addItem($ctrl.toolbarOptions.filterItems);><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_add.svg></md-icon></md-button><md-button md-no-ink=\"\" class=\"md-primary btn-toolbar-text\" ng-disabled=disabledFilters ng-click=$ctrl.toolbarOptions.applyFilters($ctrl.toolbarOptions.filterItems)>Aplicar</md-button><md-button md-no-ink=\"\" class=\"md-primary btn-toolbar-text\" ng-disabled=disabledClearFilters ng-click=clearFilters()>Limpar</md-button><md-input-container ng-show=saveNewFilter><label></label> <input class=input-save-filter ng-model=$ctrl.filterPreferenceName plg-auto-focus={{filterNameFocused}} aria-label=input_filter maxlength=25></md-input-container><md-button md-no-ink=\"\" class=\"md-primary btn-toolbar-text\" ng-click=saveFilterPreference($ctrl.filterPreferenceName) style=\"width: 100px;min-width: 100px !important;\">Salvar filtro</md-button></div><md-button class=\"toolbar-btn-scroll scroll-right\" aria-label=\"scroll right\"><md-icon md-svg-src=../../node_modules/pling-ui/assets/icons/icone_arrow_right.svg></md-icon></md-button></div></div>");
$templateCache.put("plg-data-list.html","<md-content flex=100 class=\"no-overflow plg-data-list-content\" plg-data-list-limit=dataListLimit on-init=initializedLimit><md-list flex=100 ng-if=\"$ctrl.plgDataOptions.currentView == \'list\'\" ng-show=hasData><div class=scroll-content plg-data-list-infinite-scroll=infiniteScroll()><div class=plg-list-item ng-class=\"{\'active\': selectedItem === $index }\" ng-repeat=\"item in $ctrl.plgItems | orderBy:orderBySearch track by $index\"><md-list-item class=md-2-line layout=row layout-wrap=\"\" md-no-ink=\"\" ng-class=\"{\'selected\': item.selected}\" ng-class-even=\"\'even\'\" ng-class-odd=\"\'odd\'\"><div flex=100 layout=row><div ng-if=\"(!$ctrl.notMultipleSelect && !$ctrl.plgDataOptions.notSelectedPrincipal) || (!$ctrl.notMultipleSelect && $ctrl.plgDataOptions.notSelectedPrincipal && !item.isPrincipal)\" flex=10 class=data-list-image><div pling-theming=transparent class=chk-select ng-if=!item.selected ng-model=item.selected ng-click=selectItem(item)></div><div pling-theming=\"\" class=\"chk-select item-selected\" ng-if=item.selected ng-model=item.selected ng-click=selectItem(item)></div><div class=\"avatar-container avatar-selected\" ng-hide=item.selected ng-class=\"{\'principal\':item.isPrincipal}\"><img ng-if=item.imageUrl ng-src={{getImageUrl(item.imageUrl)}} alt=\"{{ getPropertyValue(item, $ctrl.plgHighlightField) }}\"><md-icon ng-if=!item.imageUrl md-svg-src={{getImageUrl(item.imageUrl)}} aria-label=\"{{ getPropertyValue(item, $ctrl.plgHighlightField) }}\"></md-icon><md-icon ng-if=item.badgeIcon class=badge-icon md-svg-src=../../node_modules/pling-ui/assets/icons/{{item.badgeIcon}}.svg aria-label=Master></md-icon></div></div><div ng-if=\"$ctrl.notMultipleSelect || ($ctrl.plgDataOptions.notSelectedPrincipal && item.isPrincipal)\" class=data-list-image><div class=avatar-container ng-class=\"{\'principal\':item.isPrincipal}\"><img ng-if=item.imageUrl ng-src={{getImageUrl(item.imageUrl)}} alt=\"{{ getPropertyValue(item, $ctrl.plgHighlightField) }}\"><md-icon ng-if=!item.imageUrl md-svg-src={{getImageUrl(item.imageUrl)}} aria-label=\"{{ getPropertyValue(item, $ctrl.plgHighlightField) }}\"></md-icon><md-icon ng-if=item.badgeIcon class=badge-icon md-svg-src=../../node_modules/pling-ui/assets/icons/{{item.badgeIcon}}.svg aria-label=Master></md-icon></div></div><div flex=70 class=list-content layout=row ng-click=\"clickItem(item, $event)\"><div flex=40 class=\"plg-list-item-text md-list-item-text\" layout=column><h3>{{ getPropertyValue(item, $ctrl.plgHighlightField) }}</h3><h4>{{ getPropertyValue(item, $ctrl.plgComplementaryField) }}</h4></div><div flex=60 class=data-list-second-text><div ng-repeat=\"txtDetail in item.textDetails\" flex=auto><p>{{txtDetail}}</p></div></div></div><div flex=20 class=data-list-actions layout=row layout-align=\"end center\"><div class=hover-options ng-repeat=\"actItem in item.dataActions\"><md-button class=md-icon-button aria-label={{actItem.name}} ng-click=\"actionClick(item, actItem, $event)\"><md-icon class=material-icons md-svg-src=../../node_modules/pling-ui/assets/icons/{{actItem.icon}}.svg></md-icon></md-button><md-tooltip md-direction=bottom>{{ actItem.name }}</md-tooltip></div><div class=hover-options ng-if=item.settings><md-menu md-offset=\"0 -7\"><md-button aria-label=Menu class=md-icon-button ng-click=$mdOpenMenu($event)><md-icon md-menu-origin=\"\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_vert.svg></md-icon></md-button><md-menu-content width=4><md-menu-item ng-repeat=\"menuItem in item.settings\"><md-button ng-click=\"actionClick(item, menuItem, $event)\"><md-icon ng-if=menuItem.icon class=material-icons md-svg-src=../../node_modules/pling-ui/assets/icons/{{menuItem.icon}}.svg></md-icon><span md-menu-align-target=\"\">{{menuItem.name}}</span></md-button></md-menu-item></md-menu-content></md-menu></div><div ng-if=$ctrl.plgDataInternalTemplate class=expand-details><md-icon class=\"material-icons rotate\" ng-click=\"expandDetails($index, $event)\">expand_less</md-icon><md-tooltip ng-if=expandDetailsTooltip md-direction=bottom>Abrir detalhes</md-tooltip><md-tooltip ng-if=!expandDetailsTooltip md-direction=bottom>Fechar detalhes</md-tooltip></div></div></div></md-list-item><div flex=100 layout=row class=list-item-details ng-if=$ctrl.plgDataInternalTemplate ng-class=\"{\'active\': selectedItem === $index}\"><div ng-include=$ctrl.plgDataInternalTemplate id={{$index}}></div></div></div><div class=container-loading-data layout=row layout-align=space-around ng-show=$ctrl.plgDataOptions.loadingData><md-progress-circular md-mode=indeterminate></md-progress-circular></div></div></md-list><div class=\"card-container scroll-content\" ng-if=\"$ctrl.plgDataOptions.currentView == \'card\'\" ng-show=hasData plg-content-left-align=\"\" plg-data-list-infinite-scroll=infiniteScroll()><md-card class=plg-list-card ng-repeat=\"item in $ctrl.plgItems | orderBy:orderBySearch track by $index\" ng-class=\"{\'selected\': item.selected}\"><div pling-theming=rgba(0,0,0,.2) class=\"md-toolbar-tools card-header\" ng-class=\"{\'principal\': item.isPrincipal}\"><md-list-item class=card-header-container md-no-ink=\"\"><div ng-if=\"(!$ctrl.notMultipleSelect && !$ctrl.plgDataOptions.notSelectedPrincipal) || (!$ctrl.notMultipleSelect && $ctrl.plgDataOptions.notSelectedPrincipal && !item.isPrincipal)\" class=card-avatar ng-mouseenter=$ctrl.enterHover(item) ng-mouseleave=$ctrl.leaveHover(item)><div class=chk-select ng-if=!item.selected ng-model=item.selected ng-click=selectItem(item)></div><div pling-theming=\"\" class=\"chk-select item-selected\" ng-if=item.selected ng-model=item.selected ng-click=selectItem(item)></div><div class=\"avatar-container avatar-selected\" ng-hide=item.selected ng-class=\"{\'principal\':item.isPrincipal}\"><img ng-if=item.imageUrl ng-src={{getImageUrl(item.imageUrl)}} alt=\"{{ getPropertyValue(item, $ctrl.plgHighlightField) }}\"><md-icon ng-if=!item.imageUrl md-svg-src={{getImageUrl(item.imageUrl)}} aria-label=\"{{ getPropertyValue(item, $ctrl.plgHighlightField) }}\"></md-icon><md-icon ng-if=item.badgeIcon class=badge-icon md-svg-src=../../node_modules/pling-ui/assets/icons/{{item.badgeIcon}}.svg aria-label=Master></md-icon></div></div><div ng-if=\"$ctrl.notMultipleSelect || ($ctrl.plgDataOptions.notSelectedPrincipal && item.isPrincipal)\" class=card-avatar><div class=avatar-container ng-class=\"{\'principal\':item.isPrincipal}\"><img ng-if=item.imageUrl ng-src={{getImageUrl(item.imageUrl)}} alt=\"{{ getPropertyValue(item, $ctrl.plgHighlightField) }}\"><md-icon ng-if=!item.imageUrl md-svg-src={{getImageUrl(item.imageUrl)}} aria-label=\"{{ getPropertyValue(item, $ctrl.plgHighlightField) }}\"></md-icon><md-icon ng-if=item.badgeIcon class=badge-icon md-svg-src=../../node_modules/pling-ui/assets/icons/{{item.badgeIcon}}.svg aria-label=Master></md-icon></div></div><div class=header-content ng-click=\"clickItem(item, $event)\"><span class=first-text>{{ getPropertyValue(item, $ctrl.plgHighlightField) }}<br><span class=second-text>{{ getPropertyValue(item, $ctrl.plgComplementaryField) }}</span></span></div><md-menu class=header-menu ng-if=item.settings><md-button class=\"btn-setting md-icon-button\" aria-label=More ng-click=$mdOpenMenu($event)><md-icon md-menu-origin=\"\" md-svg-src=../../node_modules/pling-ui/assets/icons/icone_vert.svg></md-icon></md-button><md-menu-content width=3><md-menu-item ng-repeat=\"menuItem in item.settings\"><md-button ng-click=\"actionClick(item, menuItem, $event)\"><md-icon ng-if=menuItem.icon class=icon-app md-svg-src=../../node_modules/pling-ui/assets/icons/{{menuItem.icon}}.svg></md-icon><span class=color-gray>{{menuItem.name}}</span></md-button></md-menu-item></md-menu-content></md-menu></md-list-item></div><md-divider></md-divider><div class=card-content><div ng-if=$ctrl.plgDataInternalTemplate ng-include=$ctrl.plgDataInternalTemplate id={{$index}}></div></div></md-card><div style=\"position: absolute; left: 50%; bottom: 0%;\" layout=row layout-align=space-around ng-show=$ctrl.plgDataOptions.loadingData><md-progress-circular md-mode=indeterminate></md-progress-circular></div></div><div class=scroll-content ng-if=\"$ctrl.plgDataOptions.currentView === \'table\'\" ng-show=hasData><div class=container-loading-data-table layout=row layout-align=space-around ng-show=\"$ctrl.plgDataOptions.loadingData && isFirstLoading\"><md-progress-circular md-mode=indeterminate></md-progress-circular></div><div class=table-container ng-show=!isFirstLoading><md-table-container><table md-table=\"\" md-row-select=!$ctrl.notMultipleSelect ng-model=$ctrl.plgDataOptions.selectedItems><thead md-head=\"\" md-on-reorder=changeOrder md-order=options.order><tr md-row=\"\"><th md-order-by=\"{{ col.key }}\" md-column=\"\" ng-repeat=\"col in $ctrl.plgDataOptions.itemColumns\">{{ col.text }}</th></tr></thead><tbody md-body=\"\"><tr><th colspan=\"{{$ctrl.plgDataOptions.itemColumns.length + 2}}\"><md-progress-linear style=\"height: 0; top: -3px; position: relative !important;\" class=md-accent layout=row md-mode=indeterminate ng-show=$ctrl.plgDataOptions.loadingData></md-progress-linear></th></tr><tr md-row=\"\" ng-repeat=\"item in $ctrl.plgItems | orderBy : options.order\" ng-disabled=\"$ctrl.plgDataOptions.notSelectedPrincipal && item.isPrincipal\" md-select=item md-on-select=selectItem md-on-deselect=selectItem ng-click=\"clickItem(item, $event)\" ng-class-even=\"\'even\'\" ng-class-odd=\"\'odd\'\"><td md-cell=\"\" ng-repeat=\"col in $ctrl.plgDataOptions.itemColumns\"><plg-tooltip md-direction=top ng-if=col.tooltip tooltip=col.tooltip(item)></plg-tooltip><div ng-if=\"!col.template && col.type === \'date\'\"><p style=\"margin: 0;\">{{ getPropertyValue(item, col.key) | date:\'dd/MM/yyyy\' }}</p><p style=\"margin: 0;\">{{ getPropertyValue(item, col.key) | date:\'HH:mm:ss\' }}</p></div><div ng-if=\"!col.template && col.type === \'simpledate\'\"><p style=\"margin: 0;\">{{ getPropertyValue(item, col.key) | date:\'dd/MM/yyyy\' }}</p></div><div ng-if=\"!col.template && col.type === \'currency\'\">{{ getPropertyValue(item, col.key) | plgCurrency:\"R$ \":2 }}</div><div ng-if=\"!col.template && !col.type || col.type === \'string\' || col.type === \'number\'\">{{ getPropertyValue(item, col.key) }}</div><div ng-if=col.template ng-include=col.template></div></td><td></td></tr><tr md-row=\"\" ng-disabled=true class=cursor-default ng-if=$ctrl.hasCurrencyColumn><td md-cell=\"\">Totalizador</td><td md-cell=\"\" ng-repeat=\"col in $ctrl.plgDataOptions.itemColumns track by $index\" ng-if=\"$index !== 0\"><div ng-if=\"!col.template && col.type === \'currency\'\">{{ getTotalValue($ctrl.plgItems, col.key) | plgCurrency:\"R$ \":2 }}</div></td><td></td></tr></tbody></table></md-table-container><md-table-pagination md-limit=$ctrl.plgDataOptions.limit md-page=$ctrl.plgDataOptions.page md-total={{$ctrl.plgDataOptions.total}} md-options=$ctrl.plgDataOptions.limitOptions md-limit-options=$ctrl.plgDataOptions.limitOptions md-on-paginate=onPaginate md-page-select=\"\" ng-class=\"{\'remove-pagination\': ($ctrl.plgDataOptions.total/$ctrl.plgDataOptions.limit) <= 1}\" md-label=\"{page: \'Página:\', rowsPerPage: \'Linhas por página:\', of: \'de\'}\"></md-table-pagination></div></div><div ng-if=!hasData class=content-no-data><i class=material-icons style=\"font-size: 40px; color: gray;\">sentiment_very_dissatisfied</i><p style=\"color: gray; font-size: 16px; margin-top: 8px;\">Não foram encontrados resultados para os filtros utilizados.</p></div></md-content>");
$templateCache.put("plg-dialog.html","<md-dialog class=dialog-container aria-label={{title}}><md-progress-linear class=md-accent md-mode={{progressMode}} value={{progressValue}} ng-if=progressAction></md-progress-linear><div ng-if=title class=dialog-title><div class={{titleAlign}}>{{title}}</div></div><md-dialog-content><div ng-if=message>{{message}}</div><div ng-if=template ng-include=template></div></md-dialog-content><md-dialog-actions layout=row><md-button ng-hide=btnMore.hidden ng-if=btnMore ng-disabled=btnMore.disabled ng-class=\"{\'md-primary\' : btnMore.important}\" ng-click=btnMore.cb()>{{btnMore.text}}</md-button><span flex=\"\"></span><md-button ng-hide=btn.hidden ng-if=button ng-repeat=\"btn in button\" ng-class=\"{\'md-primary\' : btn.important}\" ng-disabled=btn.disabled ng-click=btn.cb()>{{btn.text}}</md-button></md-dialog-actions></md-dialog>");
$templateCache.put("plg-select-options.html","<md-content ng-if=ctrl.isFocusItem class=plg-select-item-content plg-select-width={{width}}><md-content flex=\"\" class=plg-select-item-input ng-show=!ctrl.configModel.isNotSearch><span><input type=text placeholder=Pesquisar ng-model=ctrl.filterSelect {ctrl.configmodel.maxlength=\"\" ?=\"\" maxlength={{ctrl.configModel.maxlength}} }=\"\" ng-keyup=saveItemEnter($event.keyCode)></span> <a ng-click=ctrl.selectSaveItem() ng-if=\"!ctrl.isLoading && addItem && ctrl.configModel.isInsert\">Adicionar</a><md-progress-circular ng-if=\"ctrl.isLoading && ctrl.configModel.isInsert && ctrl.configModel.save\" ng-disabled=false md-mode=indeterminate md-diameter=20px></md-progress-circular></md-content><md-content flex=\"\" layout-padding=\"\" class=plg-select-item-input-err ng-if=ctrl.configModel.inputMessageErr>{{ctrl.configModel.inputMessageErr}}</md-content><md-content flex=\"\" layout=row layout-align=\"start center\" class=plg-select-item-check ng-if=\"filterItems(ctrl.items, ctrl.filterSelect).length > 0 && (ctrl.configModel.isMultiple || (!ctrl.configModel.isMultiple && !ctrl.configModel.isRequired))\"><a ng-if=ctrl.configModel.isMultiple aria-label=Todos ng-click=allNoneItem(true)>Todos</a> <a ng-if=ctrl.configModel.isMultiple aria-label=Nenhum ng-click=allNoneItem(false)>Nenhum</a> <a ng-if=\"!ctrl.configModel.isMultiple && !ctrl.configModel.isRequired\" aria-label=Nenhum ng-click=noneItem()>Nenhum</a></md-content><md-content class=plg-select-list ng-if=ctrl.items layout-padding=\"\" ng-cloak=\"\"><div layout=column><p class=plg-select-list-title ng-if=\"ctrl.configModel.isMultiple && checkItem(\'icone_check_box\') && ctrl.configModel.isMultiple && checkItem(\'icone_check_box_outline\')\">Selecionados</p><div class=plg-select-list-item layout=row layout-align=\"start center\" ng-repeat=\"item in filterItems(ctrl.items, ctrl.filterSelect) | filter: filterIconeCheck\" ng-mouseover=\"item.actionMouse1 = true\" ng-mouseleave=\"item.actionMouse1 = false\" aria-label=\"Selecionar item\" ng-click=ctrl.selectItem(item) ng-class=\"{\'plg-select-list-item-ower\' : item.actionMouse1}\"><md-button class=md-icon-button ng-if=\"ctrl.configModel.isMultiple && item.icon\" aria-label=\"Selecionar item\" ng-click=ctrl.selectItem(item)><md-icon aria-label=Checar md-svg-src=../../node_modules/pling-ui/assets/icons/{{item.icon}}.svg></md-icon></md-button><plg-image-drive image-id=item[ctrl.configModel.refImageId] image-type=ctrl.configModel.imageType class=plg-select-item-avatar></plg-image-drive><p class=action-selected ng-class=\"{\'action-selected-padding\': !ctrl.configModel.isMultiple}\">{{item[ctrl.configModel.refName]}}</p></div><p class=plg-select-list-title ng-if=\"ctrl.configModel.isMultiple && checkItem(\'icone_check_box_outline\') && ctrl.configModel.isMultiple && checkItem(\'icone_check_box\')\">Não selecionados</p><div class=plg-select-list-item layout=row layout-align=\"start center\" ng-repeat=\"item in filterItems(ctrl.items, ctrl.filterSelect) | filter: filterIcone\" ng-mouseover=\"item.actionMouse1 = true\" ng-mouseleave=\"item.actionMouse1 = false\" aria-label=\"Selecionar item\" ng-click=ctrl.selectItem(item) ng-class=\"{\'plg-select-list-item-ower\' : item.actionMouse1}\"><md-button class=md-icon-button ng-if=\"ctrl.configModel.isMultiple && item.icon\" aria-label=\"Selecionar item\" ng-click=ctrl.selectItem(item)><md-icon aria-label=Checar md-svg-src=../../node_modules/pling-ui/assets/icons/{{item.icon}}.svg></md-icon></md-button><plg-image-drive image-id=item[ctrl.configModel.refImageId] image-type=ctrl.configModel.imageType></plg-image-drive><p ng-class=\"{\'action-selected-padding\': !ctrl.configModel.isMultiple}\">{{item[ctrl.configModel.refName]}}</p><span flex=\"\"></span><md-button ng-if=\"ctrl.configModel.isDelete && item.actionMouse1 && !ctrl.configModel.delete\" aria-label=Excluir class=\"md-secondary md-icon-button\" ng-click=ctrl.selectDeleteItem(item)><md-icon aria-label=Excluir md-svg-src=../../node_modules/pling-ui/assets/icons/icone_trash.svg></md-icon></md-button><md-progress-circular ng-if=\"ctrl.configModel.isDelete && ctrl.configModel.delete && (ctrl.configModel.delete[ctrl.configModel.returnField] === item[ctrl.configModel.returnField] && item.id) && ctrl.isLoading\" ng-disabled=false md-mode=indeterminate class=\"md-secondary md-hue-2\" md-diameter=20px></md-progress-circular></div></div></md-content></md-content>");
$templateCache.put("plg-toast.html","<md-toast><span class=md-toast-text flex=\"\">{{msg}}</span><md-button ng-if=backToast ng-click=backToast()>DESFAZER</md-button></md-toast>");}]);